@@ -6,7 +6,7 @@
  * Author:
  *   Nat Friedman (nat@ximian.com)
  *
- * Copyright 2000, Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  */
 
 #ifndef __E_BOOK_TYPES_H__
@@ -43,7 +43,9 @@ typedef enum {
 	E_BOOK_ERROR_NO_SUCH_SOURCE,
 	E_BOOK_ERROR_OFFLINE_UNAVAILABLE,
 	E_BOOK_ERROR_OTHER_ERROR,
-	E_BOOK_ERROR_INVALID_SERVER_VERSION
+	E_BOOK_ERROR_INVALID_SERVER_VERSION,
+	E_BOOK_ERROR_UNSUPPORTED_AUTHENTICATION_METHOD,
+	E_BOOK_ERROR_NO_SPACE
 } EBookStatus;
 
 
