@@ -5,7 +5,7 @@
  * Author:
  *   Nat Friedman (nat@ximian.com)
  *
- * Copyright 1999, 2000, Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  */
 
 #include <config.h>
@@ -24,7 +24,7 @@ struct _EBookViewPrivate {
 
 	EBookViewListener     *listener;
 
-	int                    response_id;
+	gint                    response_id;
 };
 
 enum {
