@@ -3,7 +3,7 @@
 /*
  * e-destination.h
  *
- * Copyright (C) 2001-2004 Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Authors: Jon Trowbridge <trow@ximian.com>
  *          Chris Toshok <toshok@ximian.com>
@@ -13,12 +13,12 @@
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
@@ -75,26 +75,26 @@ gboolean       e_destination_empty              (const EDestination *dest);
 gboolean       e_destination_equal              (const EDestination *a, const EDestination *b);
 
 /* for use with EDestinations that wrap a particular contact */
-void           e_destination_set_contact        (EDestination *dest, EContact *contact, int email_num);
-void           e_destination_set_contact_uid    (EDestination *dest, const char *uid, gint email_num);
+void           e_destination_set_contact        (EDestination *dest, EContact *contact, gint email_num);
+void           e_destination_set_contact_uid    (EDestination *dest, const gchar *uid, gint email_num);
 void           e_destination_set_book           (EDestination *dest, EBook *book);
 EContact      *e_destination_get_contact        (const EDestination *dest);
-const char    *e_destination_get_source_uid     (const EDestination *dest);
-const char    *e_destination_get_contact_uid    (const EDestination *dest);
-int            e_destination_get_email_num      (const EDestination *dest);
+const gchar    *e_destination_get_source_uid     (const EDestination *dest);
+const gchar    *e_destination_get_contact_uid    (const EDestination *dest);
+gint            e_destination_get_email_num      (const EDestination *dest);
 
 /* for use with EDestinations built up from strings (not corresponding to contacts in a user's address books) */
-void           e_destination_set_name           (EDestination *dest, const char *name);
-void           e_destination_set_email          (EDestination *dest, const char *email);
-const char    *e_destination_get_name           (const EDestination *dest);  /* "Jane Smith" */
-const char    *e_destination_get_email          (const EDestination *dest);  /* "jane@assbarn.com" */
-const char    *e_destination_get_address        (const EDestination *dest);  /* "Jane Smith <jane@assbarn.com>" (or a comma-sep set of such for a list) */
+void           e_destination_set_name           (EDestination *dest, const gchar *name);
+void           e_destination_set_email          (EDestination *dest, const gchar *email);
+const gchar    *e_destination_get_name           (const EDestination *dest);  /* "Jane Smith" */
+const gchar    *e_destination_get_email          (const EDestination *dest);  /* "jane@assbarn.com" */
+const gchar    *e_destination_get_address        (const EDestination *dest);  /* "Jane Smith <jane@assbarn.com>" (or a comma-sep set of such for a list) */
 
 gboolean       e_destination_is_evolution_list   (const EDestination *dest);
 gboolean       e_destination_list_show_addresses (const EDestination *dest);
 const GList   *e_destination_list_get_dests      (const EDestination *dest);
-gboolean       e_destination_is_ignored  	 (const EDestination *dest);
-void           e_destination_set_ignored 	 (EDestination *dest, gboolean ignored);
+gboolean       e_destination_is_ignored	 (const EDestination *dest);
+void           e_destination_set_ignored	 (EDestination *dest, gboolean ignored);
 
 /* If true, they want HTML mail. */
 void           e_destination_set_html_mail_pref (EDestination *dest, gboolean flag);
@@ -108,17 +108,17 @@ gboolean       e_destination_is_auto_recipient  (const EDestination *dest);
 void           e_destination_set_auto_recipient (EDestination *dest, gboolean value);
 
 /* parse out an EDestination (name/email, not contact) from a free form string. */
-void           e_destination_set_raw            (EDestination *dest, const char *raw);
+void           e_destination_set_raw            (EDestination *dest, const gchar *raw);
 
 /* generate a plain-text representation of an EDestination* or EDestination** */
-const char    *e_destination_get_textrep        (const EDestination *dest, gboolean include_email);  /* "Jane Smith" or "jane@assbarn.com" */
-char          *e_destination_get_textrepv       (EDestination **destv);
+const gchar    *e_destination_get_textrep        (const EDestination *dest, gboolean include_email);  /* "Jane Smith" or "jane@assbarn.com" */
+gchar          *e_destination_get_textrepv       (EDestination **destv);
 
 /* XML export/import routines. */
-char          *e_destination_export             (const EDestination *dest);
-char          *e_destination_exportv            (EDestination **destv);
-EDestination  *e_destination_import             (const char *str);
-EDestination **e_destination_importv            (const char *str);
+gchar          *e_destination_export             (const EDestination *dest);
+gchar          *e_destination_exportv            (EDestination **destv);
+EDestination  *e_destination_import             (const gchar *str);
+EDestination **e_destination_importv            (const gchar *str);
 
 /* EVCard "export" routines */
 void          e_destination_export_to_vcard_attribute   (EDestination *dest, EVCardAttribute *attr);
