@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * pas-backend-card-sexp.c
- * Copyright 1999, 2000, 2001, Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -37,8 +37,8 @@ struct _SearchContext {
 };
 
 static gboolean
-compare_im (EContact *contact, const char *str,
-	    char *(*compare)(const char*, const char*),
+compare_im (EContact *contact, const gchar *str,
+	    gchar *(*compare)(const gchar *, const gchar *),
 	    EContactField im_field)
 {
 	GList    *aims, *l;
@@ -47,7 +47,7 @@ compare_im (EContact *contact, const char *str,
 	aims = e_contact_get (contact, im_field);
 
 	for (l = aims; l != NULL; l = l->next) {
-		char *im = (char *) l->data;
+		gchar *im = (gchar *) l->data;
 
 		if (im && compare (im, str)) {
 			found_it = TRUE;
@@ -62,63 +62,70 @@ compare_im (EContact *contact, const char *str,
 }
 
 static gboolean
-compare_im_aim (EContact *contact, const char *str,
-		char *(*compare)(const char*, const char*))
+compare_im_aim (EContact *contact, const gchar *str,
+		gchar *(*compare)(const gchar *, const gchar *))
 {
 	return compare_im (contact, str, compare, E_CONTACT_IM_AIM);
 }
 
 static gboolean
-compare_im_msn (EContact *contact, const char *str,
-		char *(*compare)(const char*, const char*))
+compare_im_msn (EContact *contact, const gchar *str,
+		gchar *(*compare)(const gchar *, const gchar *))
 {
 	return compare_im (contact, str, compare, E_CONTACT_IM_MSN);
 }
 
 static gboolean
-compare_im_icq (EContact *contact, const char *str,
-		char *(*compare)(const char*, const char*))
+compare_im_skype (EContact *contact, const gchar *str,
+		gchar *(*compare)(const gchar *, const gchar *))
+{
+	return compare_im (contact, str, compare, E_CONTACT_IM_SKYPE);
+}
+
+static gboolean
+compare_im_icq (EContact *contact, const gchar *str,
+		gchar *(*compare)(const gchar *, const gchar *))
 {
 	return compare_im (contact, str, compare, E_CONTACT_IM_ICQ);
 }
 
 static gboolean
-compare_im_yahoo (EContact *contact, const char *str,
-		  char *(*compare)(const char*, const char*))
+compare_im_yahoo (EContact *contact, const gchar *str,
+		  gchar *(*compare)(const gchar *, const gchar *))
 {
 	return compare_im (contact, str, compare, E_CONTACT_IM_YAHOO);
 }
 
 static gboolean
-compare_im_gadugadu (EContact *contact, const char *str,
-		  char *(*compare)(const char*, const char*))
+compare_im_gadugadu (EContact *contact, const gchar *str,
+		  gchar *(*compare)(const gchar *, const gchar *))
 {
 	return compare_im (contact, str, compare, E_CONTACT_IM_GADUGADU);
 }
 
 
 static gboolean
-compare_im_jabber (EContact *contact, const char *str,
-		   char *(*compare)(const char*, const char*))
+compare_im_jabber (EContact *contact, const gchar *str,
+		   gchar *(*compare)(const gchar *, const gchar *))
 {
 	return compare_im (contact, str, compare, E_CONTACT_IM_JABBER);
 }
 
 static gboolean
-compare_im_groupwise (EContact *contact, const char *str,
-		      char *(*compare)(const char*, const char*))
+compare_im_groupwise (EContact *contact, const gchar *str,
+		      gchar *(*compare)(const gchar *, const gchar *))
 {
 	return compare_im (contact, str, compare, E_CONTACT_IM_GROUPWISE);
 }
 
 static gboolean
-compare_email (EContact *contact, const char *str,
-	       char *(*compare)(const char*, const char*))
+compare_email (EContact *contact, const gchar *str,
+	       gchar *(*compare)(const gchar *, const gchar *))
 {
-	int i;
+	gint i;
 
 	for (i = E_CONTACT_EMAIL_1; i <= E_CONTACT_EMAIL_4; i ++) {
-		const char *email = e_contact_get_const (contact, i);
+		const gchar *email = e_contact_get_const (contact, i);
 
 		if (email && compare(email, str))
 			return TRUE;
@@ -128,14 +135,14 @@ compare_email (EContact *contact, const char *str,
 }
 
 static gboolean
-compare_phone (EContact *contact, const char *str,
-	       char *(*compare)(const char*, const char*))
+compare_phone (EContact *contact, const gchar *str,
+	       gchar *(*compare)(const gchar *, const gchar *))
 {
-	int i;
+	gint i;
 	gboolean rv = FALSE;
 
 	for (i = E_CONTACT_FIRST_PHONE_ID; i <= E_CONTACT_LAST_PHONE_ID; i ++) {
-		char *phone = e_contact_get (contact, i);
+		gchar *phone = e_contact_get (contact, i);
 
 		rv = phone && compare(phone, str);
 		g_free (phone);
@@ -148,10 +155,10 @@ compare_phone (EContact *contact, const char *str,
 }
 
 static gboolean
-compare_name (EContact *contact, const char *str,
-	      char *(*compare)(const char*, const char*))
+compare_name (EContact *contact, const gchar *str,
+	      gchar *(*compare)(const gchar *, const gchar *))
 {
-	const char *name;
+	const gchar *name;
 
 	name = e_contact_get_const (contact, E_CONTACT_FULL_NAME);
 	if (name && compare (name, str))
@@ -173,11 +180,11 @@ compare_name (EContact *contact, const char *str,
 }
 
 static gboolean
-compare_address (EContact *contact, const char *str,
-		 char *(*compare)(const char*, const char*))
+compare_address (EContact *contact, const gchar *str,
+		 gchar *(*compare)(const gchar *, const gchar *))
 {
 
-	int i;
+	gint i;
 	gboolean rv = FALSE;
 
 	for (i = E_CONTACT_FIRST_ADDRESS_ID; i <= E_CONTACT_LAST_ADDRESS_ID; i ++) {
@@ -203,8 +210,8 @@ compare_address (EContact *contact, const char *str,
 }
 
 static gboolean
-compare_category (EContact *contact, const char *str,
-		  char *(*compare)(const char*, const char*))
+compare_category (EContact *contact, const gchar *str,
+		  gchar *(*compare)(const gchar *, const gchar *))
 {
 	GList *categories;
 	GList *iterator;
@@ -213,7 +220,7 @@ compare_category (EContact *contact, const char *str,
 	categories = e_contact_get (contact, E_CONTACT_CATEGORY_LIST);
 
 	for (iterator = categories; iterator; iterator = iterator->next) {
-		const char *category = iterator->data;
+		const gchar *category = iterator->data;
 
 		if (compare(category, str)) {
 			ret_val = TRUE;
@@ -227,14 +234,17 @@ compare_category (EContact *contact, const char *str,
 	return ret_val;
 }
 
+enum prop_type {
+	PROP_TYPE_NORMAL,
+	PROP_TYPE_LIST
+};
+
 static struct prop_info {
 	EContactField field_id;
-	const char *query_prop;
-#define PROP_TYPE_NORMAL   0x01
-#define PROP_TYPE_LIST     0x02
-	int prop_type;
-	gboolean (*list_compare)(EContact *contact, const char *str,
-				 char *(*compare)(const char*, const char*));
+	const gchar *query_prop;
+	enum prop_type prop_type;
+	gboolean (*list_compare)(EContact *contact, const gchar *str,
+				 gchar *(*compare)(const gchar *, const gchar *));
 
 } prop_info_table[] = {
 #define NORMAL_PROP(f,q) {f, q, PROP_TYPE_NORMAL, NULL}
@@ -266,6 +276,7 @@ static struct prop_info {
 	NORMAL_PROP ( E_CONTACT_NOTE, "note"),
 	LIST_PROP ( "im_aim",    compare_im_aim ),
 	LIST_PROP ( "im_msn",    compare_im_msn ),
+	LIST_PROP ( "im_skype",    compare_im_skype ),
 	LIST_PROP ( "im_icq",    compare_im_icq ),
 	LIST_PROP ( "im_jabber", compare_im_jabber ),
 	LIST_PROP ( "im_yahoo",  compare_im_yahoo ),
@@ -279,18 +290,18 @@ static struct prop_info {
 
 static ESExpResult *
 entry_compare(SearchContext *ctx, struct _ESExp *f,
-	      int argc, struct _ESExpResult **argv,
-	      char *(*compare)(const char*, const char*))
+	      gint argc, struct _ESExpResult **argv,
+	      gchar *(*compare)(const gchar *, const gchar *))
 {
 	ESExpResult *r;
-	int truth = FALSE;
+	gint truth = FALSE;
 
 	if (argc == 2
 	    && argv[0]->type == ESEXP_RES_STRING
 	    && argv[1]->type == ESEXP_RES_STRING) {
-		char *propname;
+		gchar *propname;
 		struct prop_info *info = NULL;
-		int i;
+		gint i;
 		gboolean any_field;
 		gboolean saw_any = FALSE;
 
@@ -311,7 +322,7 @@ entry_compare(SearchContext *ctx, struct _ESExp *f,
 					truth = FALSE;
 				}
 				else if (info->prop_type == PROP_TYPE_NORMAL) {
-					const char *prop = NULL;
+					const gchar *prop = NULL;
 					/* straight string property matches */
 
 					prop = e_contact_get_const (ctx->contact, info->field_id);
@@ -344,7 +355,7 @@ entry_compare(SearchContext *ctx, struct _ESExp *f,
 			EContactField fid = e_contact_field_id (propname);
 
 			if (fid >= E_CONTACT_FIELD_FIRST && fid < E_CONTACT_FIELD_LAST) {
-				const char *prop = e_contact_get_const (ctx->contact, fid);
+				const gchar *prop = e_contact_get_const (ctx->contact, fid);
 
 				if (prop && compare (prop, argv[1]->value.string)) {
 					truth = TRUE;
@@ -360,7 +371,7 @@ entry_compare(SearchContext *ctx, struct _ESExp *f,
 				GList *l, *values = attr ? e_vcard_attribute_get_values (attr) : NULL;
 
 				for (l = values; l && !truth; l = l->next) {
-					const char *value = l->data;
+					const gchar *value = l->data;
 
 					if (value && compare (value, argv[1]->value.string)) {
 						truth = TRUE;
@@ -377,81 +388,307 @@ entry_compare(SearchContext *ctx, struct _ESExp *f,
 	return r;
 }
 
+static void
+contains_helper_free_word (gpointer data, gpointer user_data)
+{
+	if (data) {
+		g_string_free ((GString *)data, TRUE);
+	}
+}
+
+static gchar *
+try_contains_word (const gchar *s1, GSList *word)
+{
+	const gchar *o, *p;
+	gunichar unival, first_w_char;
+	GString *w;
+
+	if (s1 == NULL)
+		return NULL;
+	if (word == NULL)
+		return (gchar *)s1; /* previous was last word */
+	if (word->data == NULL)
+		return NULL; /* illegal structure */
+
+	w = word->data;
+	first_w_char = g_utf8_get_char (w->str);
+
+	o  = s1;
+	for (p = e_util_unicode_get_utf8 (o, &unival); p && unival; p = e_util_unicode_get_utf8 (p, &unival)) {
+		if (unival == first_w_char) {
+			gunichar unival2;
+			const gchar *q = p;
+			const gchar *r = e_util_unicode_get_utf8 (w->str, &unival2);
+			while (q && r && unival && unival2) {
+				q = e_util_unicode_get_utf8 (q, &unival);
+				if (!q)
+					break;
+				r = e_util_unicode_get_utf8 (r, &unival2);
+				if (!r)
+					break;
+				if (unival != unival2)
+					break;
+			}
+			if (!unival2 && r && q) {
+				/* we read whole word and no illegal character has been found */
+				if (word->next == NULL ||
+				    try_contains_word (e_util_unicode_get_utf8 (o, &unival), word->next)) {
+					return (gchar *)o;
+				}
+			}
+		}
+		o = p;
+	}
+
+	return NULL;
+}
+
+/* converts str into utf8 GString in lowercase;
+   returns NULL if str is invalid utf8 string otherwise
+   returns newly allocated GString
+*/
+static GString *
+chars_to_unistring_lowercase (const gchar *pstr)
+{
+	GString *res;
+	gunichar unich;
+	gchar *p, *str;
+
+	if (pstr == NULL)
+		return NULL;
+
+	str = e_util_utf8_remove_accents (pstr);
+	if (!str)
+		return NULL;
+
+	res = g_string_new ("");
+
+	for (p = e_util_unicode_get_utf8 (str, &unich); p && unich; p = e_util_unicode_get_utf8 (p, &unich)) {
+		g_string_append_unichar (res, g_unichar_tolower (unich));
+	}
+
+	g_free (str);
+
+	/* it was invalid unichar string */
+	if (p == NULL) {
+		g_string_free (res, TRUE);
+		return NULL;
+	}
+
+	return res;
+}
+
+/* first space between words is treated as wildcard character;
+   we are looking for s2 in s1, so s2 will be breaked into words
+*/
+static gchar *
+contains_helper (const gchar *s1, const gchar *s2)
+{
+	GString *s1uni;
+	GString *s2uni;
+	GSList *words;
+	gchar *next;
+	gboolean have_nonspace;
+	gboolean have_space;
+	GString *last_word, *w;
+	gchar *res = NULL;
+	gunichar unich;
+	glong len1, len2;
+
+	if (!s2)
+		return NULL;
+
+	/* the initial word contains an empty string for sure */
+	if (!*s2)
+		return (gchar *)s1;
+
+	s1uni = chars_to_unistring_lowercase (s1);
+	if (s1uni == NULL)
+		return NULL;
+
+	s2uni = chars_to_unistring_lowercase (s2);
+	if (s2uni == NULL) {
+		g_string_free (s1uni, TRUE);
+		return NULL;
+	}
+
+	len1 = g_utf8_strlen (s1uni->str, -1);
+	len2 = g_utf8_strlen (s2uni->str, -1);
+	if (len1 == 0 || len2 == 0) {
+		g_string_free (s1uni, TRUE);
+		g_string_free (s2uni, TRUE);
+
+		/* both are empty strings */
+		if (len1 == len2)
+			return (gchar *)s1;
+
+		return NULL;
+	}
+
+	/* breaking s2 into words */
+        words = NULL;
+	have_nonspace = FALSE;
+	have_space = FALSE;
+	last_word = NULL;
+	w = g_string_new ("");
+	for (next = e_util_unicode_get_utf8 (s2uni->str, &unich); next && unich; next = e_util_unicode_get_utf8 (next, &unich)) {
+		if (unich == ' ') {
+			if (have_nonspace && !have_space) {
+				/* treat only first space after nonspace character as wildcard,
+				   so we will start new word here
+				*/
+				have_space = TRUE;
+				words = g_slist_append (words, w);
+				last_word = w;
+				w = g_string_new ("");
+			} else {
+				g_string_append_unichar (w, unich);
+			}
+		} else {
+			have_nonspace = TRUE;
+			have_space = FALSE;
+			g_string_append_unichar (w, unich);
+		}
+	}
+
+	if (have_space) {
+		/* there was one or more spaces at the end of string,
+		   concat actual word with that last one
+		*/
+		g_string_append_len (last_word, w->str, w->len);
+		g_string_free (w, TRUE);
+	} else {
+		/* append actual word into words list */
+		words = g_slist_append (words, w);
+	}
+
+	res = try_contains_word (s1uni->str, words);
+
+	g_string_free (s1uni, TRUE);
+	g_string_free (s2uni, TRUE);
+	g_slist_foreach (words, contains_helper_free_word, NULL);
+	g_slist_free (words);
+
+	return res;
+}
+
 static ESExpResult *
-func_contains(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
+func_contains(struct _ESExp *f, gint argc, struct _ESExpResult **argv, gpointer data)
 {
 	SearchContext *ctx = data;
 
-	return entry_compare (ctx, f, argc, argv, (char *(*)(const char*, const char*)) e_util_utf8_strstrcase);
+	return entry_compare (ctx, f, argc, argv, contains_helper);
 }
 
-static char *
-is_helper (const char *s1, const char *s2)
+static gchar *
+is_helper (const gchar *ps1, const gchar *ps2)
 {
+	gchar *s1, *s2, *res;
+
+	s1 = e_util_utf8_remove_accents (ps1);
+	s2 = e_util_utf8_remove_accents (ps2);
+
 	if (!e_util_utf8_strcasecmp (s1, s2))
-		return (char*)s1;
+		res = (gchar *)ps1;
 	else
-		return NULL;
+		res = NULL;
+
+	g_free (s1);
+	g_free (s2);
+
+	return res;
 }
 
 static ESExpResult *
-func_is(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
+func_is(struct _ESExp *f, gint argc, struct _ESExpResult **argv, gpointer data)
 {
 	SearchContext *ctx = data;
 
 	return entry_compare (ctx, f, argc, argv, is_helper);
 }
 
-static char *
-endswith_helper (const char *s1, const char *s2)
+static gchar *
+endswith_helper (const gchar *ps1, const gchar *ps2)
 {
-	char *p;
-	if ((p = (char*) e_util_utf8_strstrcase(s1, s2))
-	    && (strlen(p) == strlen(s2)))
-		return p;
+	gchar *s1 = e_util_utf8_remove_accents (ps1);
+	gchar *s2 = e_util_utf8_remove_accents (ps2);
+	gchar *res;
+	glong s1len = g_utf8_strlen (s1, -1);
+	glong s2len = g_utf8_strlen (s2, -1);
+
+	if (s1len < s2len)
+		res = NULL;
 	else
-		return NULL;
+		res = (gchar *)e_util_utf8_strstrcase (g_utf8_offset_to_pointer (s1, s1len - s2len), s2);
+
+	g_free (s1);
+	g_free (s2);
+
+	return res;
 }
 
 static ESExpResult *
-func_endswith(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
+func_endswith(struct _ESExp *f, gint argc, struct _ESExpResult **argv, gpointer data)
 {
 	SearchContext *ctx = data;
 
 	return entry_compare (ctx, f, argc, argv, endswith_helper);
 }
 
-static char *
-beginswith_helper (const char *s1, const char *s2)
+static gchar *
+beginswith_helper (const gchar *ps1, const gchar *ps2)
 {
-	char *p;
-	if ((p = (char*) e_util_utf8_strstrcase(s1, s2))
+	gchar *p, *res;
+	gchar *s1 = e_util_utf8_remove_accents (ps1);
+	gchar *s2 = e_util_utf8_remove_accents (ps2);
+
+	if ((p = (gchar *) e_util_utf8_strstrcase(s1, s2))
 	    && (p == s1))
-		return p;
+		res = (gchar *)ps1;
 	else
-		return NULL;
+		res = NULL;
+
+	g_free (s1);
+	g_free (s2);
+
+	return res;
 }
 
 static ESExpResult *
-func_beginswith(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
+func_beginswith(struct _ESExp *f, gint argc, struct _ESExpResult **argv, gpointer data)
 {
 	SearchContext *ctx = data;
 
 	return entry_compare (ctx, f, argc, argv, beginswith_helper);
 }
 
+static gchar *
+exists_helper (const gchar *ps1, const gchar *ps2)
+{
+	gchar *res;
+	gchar *s1 = e_util_utf8_remove_accents (ps1);
+	gchar *s2 = e_util_utf8_remove_accents (ps2);
+
+	res = (gchar *)e_util_utf8_strstrcase (s1, s2);
+
+	g_free (s1);
+	g_free (s2);
+
+	return res;
+}
+
 static ESExpResult *
-func_exists(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
+func_exists(struct _ESExp *f, gint argc, struct _ESExpResult **argv, gpointer data)
 {
 	SearchContext *ctx = data;
 	ESExpResult *r;
-	int truth = FALSE;
+	gint truth = FALSE;
 
 	if (argc == 1
 	    && argv[0]->type == ESEXP_RES_STRING) {
-		char *propname;
+		gchar *propname;
 		struct prop_info *info = NULL;
-		int i;
+		gint i;
 		gboolean saw_any = FALSE;
 
 		propname = argv[0]->value.string;
@@ -462,7 +699,7 @@ func_exists(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
 				info = &prop_info_table[i];
 
 				if (info->prop_type == PROP_TYPE_NORMAL) {
-					const char *prop = NULL;
+					const gchar *prop = NULL;
 					/* searches where the query's property
 					   maps directly to an ecard property */
 
@@ -473,7 +710,7 @@ func_exists(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
 				}
 				else if (info->prop_type == PROP_TYPE_LIST) {
 				/* the special searches that match any of the list elements */
-					truth = info->list_compare (ctx->contact, "", (char *(*)(const char*, const char*)) e_util_utf8_strstrcase);
+					truth = info->list_compare (ctx->contact, "", exists_helper);
 				}
 
 				break;
@@ -487,7 +724,7 @@ func_exists(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
 			EContactField fid = e_contact_field_id (propname);
 
 			if (fid >= E_CONTACT_FIELD_FIRST && fid < E_CONTACT_FIELD_LAST) {
-				const char *prop = e_contact_get_const (ctx->contact, fid);
+				const gchar *prop = e_contact_get_const (ctx->contact, fid);
 
 				if (prop && *prop)
 					truth = TRUE;
@@ -497,7 +734,7 @@ func_exists(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
 				GList *l, *values = attr ? e_vcard_attribute_get_values (attr) : NULL;
 
 				for (l = values; l && !truth; l = l->next) {
-					const char *value = l->data;
+					const gchar *value = l->data;
 
 					if (value && *value)
 						truth = TRUE;
@@ -512,17 +749,17 @@ func_exists(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
 }
 
 static ESExpResult *
-func_exists_vcard(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
+func_exists_vcard(struct _ESExp *f, gint argc, struct _ESExpResult **argv, gpointer data)
 {
 	SearchContext *ctx = data;
 	ESExpResult *r;
-	int truth = FALSE;
+	gint truth = FALSE;
 
 	if (argc == 1 && argv[0]->type == ESEXP_RES_STRING) {
-		const char *attr_name;
+		const gchar *attr_name;
 		EVCardAttribute *attr;
 		GList *values;
-		char *s;
+		gchar *s;
 
 		attr_name = argv[0]->value.string;
 		attr = e_vcard_get_attribute (E_VCARD (ctx->contact), attr_name);
@@ -545,9 +782,9 @@ func_exists_vcard(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *
 
 /* 'builtin' functions */
 static struct {
-	char *name;
+	const gchar *name;
 	ESExpFunc *func;
-	int type;		/* set to 1 if a function can perform shortcut evaluation, or
+	gint type;		/* set to 1 if a function can perform shortcut evaluation, or
 				   doesn't execute everything, 0 otherwise */
 } symbols[] = {
 	{ "contains", func_contains, 0 },
@@ -601,7 +838,7 @@ e_book_backend_sexp_match_contact (EBookBackendSExp *sexp, EContact *contact)
  * Return value: %TRUE if the VCard matches, %FALSE otherwise.
  **/
 gboolean
-e_book_backend_sexp_match_vcard (EBookBackendSExp *sexp, const char *vcard)
+e_book_backend_sexp_match_vcard (EBookBackendSExp *sexp, const gchar *vcard)
 {
 	EContact *contact;
 	gboolean retval;
@@ -626,11 +863,11 @@ e_book_backend_sexp_match_vcard (EBookBackendSExp *sexp, const char *vcard)
  * Return value: A new #EBookBackendSExp.
  **/
 EBookBackendSExp *
-e_book_backend_sexp_new (const char *text)
+e_book_backend_sexp_new (const gchar *text)
 {
 	EBookBackendSExp *sexp = g_object_new (E_TYPE_BACKEND_SEXP, NULL);
-	int esexp_error;
-	int i;
+	gint esexp_error;
+	gint i;
 
 	sexp->priv->search_sexp = e_sexp_new();
 
