@@ -75,7 +75,7 @@ struct _ECalBackendGooglePrivate {
 	gchar *password;
 	gchar *uri;
 	gchar *feed;
-	gchar *local_attachments_store;	
+	gchar *local_attachments_store;
 
 	gboolean read_only;
 	gboolean mode_changed;
@@ -84,7 +84,7 @@ struct _ECalBackendGooglePrivate {
 };
 
 gint compare_ids (gconstpointer cache_id, gconstpointer modified_cache_id);
-gchar * form_query (const char *query);
+gchar * form_query (const gchar *query);
 
 gint
 compare_ids (gconstpointer cache_id, gconstpointer modified_cache_id)
@@ -95,7 +95,7 @@ compare_ids (gconstpointer cache_id, gconstpointer modified_cache_id)
 /************************************************** Calendar Backend Methods **********************************/
 
 static ECalBackendSyncStatus
-e_cal_backend_google_get_attachment_list (ECalBackendSync *backend, EDataCal *cal, const char *uid, const char *rid, GSList **list)
+e_cal_backend_google_get_attachment_list (ECalBackendSync *backend, EDataCal *cal, const gchar *uid, const gchar *rid, GSList **list)
 {
 	/* TODO implement this function */
 	return GNOME_Evolution_Calendar_Success;
@@ -109,7 +109,7 @@ e_cal_backend_google_internal_get_default_timezone (ECalBackend *backend)
 }
 
 static icaltimezone *
-e_cal_backend_google_internal_get_timezone (ECalBackend *backend, const char *tzid)
+e_cal_backend_google_internal_get_timezone (ECalBackend *backend, const gchar *tzid)
 {
 	icaltimezone *zone;
 
@@ -174,7 +174,7 @@ e_cal_backend_google_is_loaded (ECalBackend *backend)
 
 
 static ECalBackendSyncStatus
-e_cal_backend_google_add_timezone (ECalBackendSync *backend, EDataCal *cal, const char *tzobj)
+e_cal_backend_google_add_timezone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzobj)
 {
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
@@ -206,7 +206,7 @@ e_cal_backend_google_add_timezone (ECalBackendSync *backend, EDataCal *cal, cons
 }
 
 static ECalBackendSyncStatus
- e_cal_backend_google_discard_alarm (ECalBackendSync *backend, EDataCal *cal, const char *uid, const char *auid)
+ e_cal_backend_google_discard_alarm (ECalBackendSync *backend, EDataCal *cal, const gchar *uid, const gchar *auid)
 {
 	return GNOME_Evolution_Calendar_OtherError;
 }
@@ -224,7 +224,7 @@ e_cal_backend_google_get_mode (ECalBackend *backend)
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_get_timezone (ECalBackendSync *backend, EDataCal *cal, const char *tzid, char **object)
+e_cal_backend_google_get_timezone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzid, gchar **object)
 {
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
@@ -255,7 +255,7 @@ e_cal_backend_google_get_timezone (ECalBackendSync *backend, EDataCal *cal, cons
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_get_object (ECalBackendSync *backend, EDataCal *cal, const char *uid, const char *rid, char **object)
+e_cal_backend_google_get_object (ECalBackendSync *backend, EDataCal *cal, const gchar *uid, const gchar *rid, gchar **object)
 {
 	ECalComponent *comp;
 	ECalBackendGooglePrivate *priv;
@@ -290,7 +290,7 @@ e_cal_backend_google_get_object (ECalBackendSync *backend, EDataCal *cal, const
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_get_object_list (ECalBackendSync *backend, EDataCal *cal, const char *sexp, GList **objects)
+e_cal_backend_google_get_object_list (ECalBackendSync *backend, EDataCal *cal, const gchar *sexp, GList **objects)
 {
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
@@ -364,14 +364,14 @@ e_cal_backend_google_start_query (ECalBackend *backend, EDataCalView *query)
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_get_default_object (ECalBackendSync *backend, EDataCal *cal, char **object)
+e_cal_backend_google_get_default_object (ECalBackendSync *backend, EDataCal *cal, gchar **object)
 {
 	ECalComponent *comp;
 
         comp = e_cal_component_new ();
 	switch (e_cal_backend_get_kind (E_CAL_BACKEND (backend))) {
 	case ICAL_VEVENT_COMPONENT:
-        	e_cal_component_set_new_vtype (comp, E_CAL_COMPONENT_EVENT);
+		e_cal_component_set_new_vtype (comp, E_CAL_COMPONENT_EVENT);
 		break;
 	case ICAL_VTODO_COMPONENT:
 		e_cal_component_set_new_vtype (comp, E_CAL_COMPONENT_TODO);
@@ -389,7 +389,7 @@ e_cal_backend_google_get_default_object (ECalBackendSync *backend, EDataCal *cal
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_set_default_zone (ECalBackendSync *backend, EDataCal *cal, const char *tzobj)
+e_cal_backend_google_set_default_zone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzobj)
 {
 	icalcomponent *tz_comp;
 	ECalBackendGoogle *cbgo;
@@ -428,7 +428,7 @@ e_cal_backend_google_set_mode (ECalBackend *backend, CalMode mode)
 
 	if (!priv->mode && priv->mode == mode) {
 		e_cal_backend_notify_mode (backend, GNOME_Evolution_Calendar_CalListener_MODE_SET,
-				  	   cal_mode_to_corba (mode));
+					   cal_mode_to_corba (mode));
 		return;
 	}
 
@@ -476,41 +476,41 @@ in_offline (ECalBackendGoogle *cbgo)
 	/* Remove the Connection Object */
 	if (priv->service) {
 		g_object_unref (priv->service);
-		priv->service = NULL;	
+		priv->service = NULL;
 	}
 }
 
 static void
-fetch_attachments (ECalBackendGoogle *cbgo, ECalComponent *comp) 
+fetch_attachments (ECalBackendGoogle *cbgo, ECalComponent *comp)
 {
 	GSList *attach_list = NULL, *new_attach_list = NULL;
 	GSList *l = NULL;
-	const char *uid;	
+	const gchar *uid;
 	gchar *attach_store, *dest_file, *dest_url;
-	int fd;	
+	gint fd;
 
 	e_cal_component_get_attachment_list (comp, &attach_list);
 	e_cal_component_get_uid (comp, &uid);
-	
+
 	attach_store = g_strdup(e_cal_backend_google_get_local_attachments_store (cbgo));
 
-	for (l = attach_list; l; l = l->next) {	
-		char *sfname = (char *)l->data;
-		char *filename, *new_filename;
+	for (l = attach_list; l; l = l->next) {
+		gchar *sfname = (gchar *)l->data;
+		gchar *filename, *new_filename;
 		GMappedFile *mapped_file;
 		GError *error = NULL;
-	
+
 		mapped_file = g_mapped_file_new (sfname, FALSE, &error);
-		if (!mapped_file) {	
-			g_message ("DEBUG: could not map %s: %s \n", 
+		if (!mapped_file) {
+			g_message ("DEBUG: could not map %s: %s \n",
 			sfname, error->message);
 			g_error_free (error);
 			continue;
 		}
-	
+
 		filename = g_path_get_basename (sfname);
 		new_filename = g_strconcat (uid, "-", filename, NULL);
-		g_free (filename);	
+		g_free (filename);
 		dest_file = g_build_filename (attach_store, new_filename, NULL);
 		g_free (new_filename);
 		fd = g_open (dest_file, O_RDWR|O_CREAT|O_TRUNC|O_BINARY, 0600);
@@ -525,17 +525,17 @@ fetch_attachments (ECalBackendGoogle *cbgo, ECalComponent *comp)
 
 		g_mapped_file_free (mapped_file);
 		if (fd != -1)
-			close (fd);	
+			close (fd);
 		dest_url = g_filename_to_uri (dest_file, NULL, NULL);
 		g_free (dest_url);
-		new_attach_list = g_slist_append (new_attach_list, dest_url);	 
-	}	
+		new_attach_list = g_slist_append (new_attach_list, dest_url);
+	}
 	g_free (attach_store);
 	e_cal_component_set_attachment_list (comp, new_attach_list);
-}	
+}
 
-ECalBackendSyncStatus 
-static receive_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *icalcomp)
+static ECalBackendSyncStatus
+receive_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *icalcomp)
 {
 	ECalBackendGooglePrivate *priv;
 	EGoItem *item = NULL;
@@ -547,15 +547,15 @@ static receive_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *ic
 	gboolean instances = TRUE, found = FALSE, is_declined;
 
 	priv = cbgo->priv;
-	icalprop = icalcomponent_get_first_property (icalcomp, ICAL_X_PROPERTY);	
+	icalprop = icalcomponent_get_first_property (icalcomp, ICAL_X_PROPERTY);
 	while (icalprop) {
-		const char *x_name;
+		const gchar *x_name;
 		x_name	= icalproperty_get_x_name (icalprop);
-		
-		/* FIXME Set the Property for Google */	
+
+		/* FIXME Set the Property for Google */
 		if (!strcmp (x_name, "X-GW-RECUR-INSTANCES-MOD-TYPE")) {
-			instances = TRUE;	
-			icalcomponent_remove_property (icalcomp, icalprop);	
+			instances = TRUE;
+			icalcomponent_remove_property (icalcomp, icalprop);
 			break;
 		}
 		icalprop = icalcomponent_get_next_property (icalcomp, ICAL_X_PROPERTY);
@@ -565,39 +565,39 @@ static receive_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *ic
 
 	comp = e_cal_component_new ();
 	e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (icalcomp));
-	method = icalcomponent_get_method (icalcomp);	
+	method = icalcomponent_get_method (icalcomp);
 
 	/* Attachments */
 	if (!is_declined && e_cal_component_has_attachments (comp))
 		fetch_attachments (cbgo, comp);
 
 	/* Sent to Server */
-	item = e_go_item_from_cal_component (cbgo, comp);	
+	item = e_go_item_from_cal_component (cbgo, comp);
 	entry =	e_go_item_get_entry (item);
 
 	if (!GDATA_IS_ENTRY(entry))
-		return GNOME_Evolution_Calendar_InvalidObject;	
+		return GNOME_Evolution_Calendar_InvalidObject;
 
 	updated_entry = gdata_service_insert_entry (GDATA_SERVICE(priv->service), priv->uri, entry, NULL);
 
 	if (updated_entry) {
 		/* FIXME */
-		g_object_unref (updated_entry);	
+		g_object_unref (updated_entry);
 	}
 
 	/* Update the Cache */
 
 	modif_comp = g_object_ref (comp);
 	if (instances) {
-		const char *uid;
-		found = FALSE;	
+		const gchar *uid;
+		found = FALSE;
 
 		e_cal_component_get_uid (modif_comp, &uid);
 		comps = e_cal_backend_cache_get_components_by_uid (priv->cache, uid);
 
-		if (!comps) 	
+		if (!comps)
 			comps = g_slist_append (comps, g_object_ref (modif_comp));
-		else	
+		else
 			found = TRUE;
 	} else {
 		ECalComponentId *id = e_cal_component_get_id (modif_comp);
@@ -612,7 +612,7 @@ static receive_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *ic
 			found = TRUE;
 		}
 
-		e_cal_component_free_id (id);	
+		e_cal_component_free_id (id);
 	}
 
 	for (l = comps; l != NULL; l = l->next) {
@@ -628,9 +628,9 @@ static receive_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *ic
 
 			}
 
-		} 
+		}
 		else {
-			char *comp_str = NULL;
+			gchar *comp_str = NULL;
 
 			/* change_status (component, pstatus, e_gw_connection_get_user_email (priv->cnc)); */
 			e_cal_backend_cache_put_component (priv->cache, component);
@@ -654,14 +654,14 @@ static receive_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *ic
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_receive_objects (ECalBackendSync *backend, EDataCal *cal, const char *calobj)
+e_cal_backend_google_receive_objects (ECalBackendSync *backend, EDataCal *cal, const gchar *calobj)
 {
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
 	icalcomponent *icalcomp, *subcomp;
 	icalcomponent_kind kind;
 	ECalBackendSyncStatus status = GNOME_Evolution_Calendar_Success;
-		
+
 	cbgo = (ECalBackendGoogle *)backend;
 	priv = cbgo->priv;
 
@@ -669,46 +669,46 @@ e_cal_backend_google_receive_objects (ECalBackendSync *backend, EDataCal *cal, c
 		in_offline (cbgo);
 		return GNOME_Evolution_Calendar_RepositoryOffline;
 	}
-	
-	icalcomp = icalparser_parse_string (calobj);	
+
+	icalcomp = icalparser_parse_string (calobj);
 	if (!icalcomp)
 		return GNOME_Evolution_Calendar_InvalidObject;
 
 	kind = icalcomponent_isa (icalcomp);
 	if (kind == ICAL_VCALENDAR_COMPONENT) {
 		subcomp = icalcomponent_get_first_component (icalcomp, e_cal_backend_get_kind (E_CAL_BACKEND(backend)));
-		
+
 		while (subcomp) {
 			icalcomponent_set_method (subcomp, icalcomponent_get_method (icalcomp));
-			status = receive_object (cbgo, cal, subcomp);	
-		
-			if (status != GNOME_Evolution_Calendar_Success)	
+			status = receive_object (cbgo, cal, subcomp);
+
+			if (status != GNOME_Evolution_Calendar_Success)
 				break;
 			subcomp = icalcomponent_get_next_component (icalcomp, e_cal_backend_get_kind (E_CAL_BACKEND(backend)));
 		}
-	} else if (kind == e_cal_backend_get_kind (E_CAL_BACKEND(backend))) {	
+	} else if (kind == e_cal_backend_get_kind (E_CAL_BACKEND(backend))) {
 		status = receive_object (cbgo, cal, icalcomp);
-	} else 
-		status = GNOME_Evolution_Calendar_InvalidObject;	
+	} else
+		status = GNOME_Evolution_Calendar_InvalidObject;
 
 	icalcomponent_free (icalcomp);
 
 	return status;
 }
 
-static ECalBackendSyncStatus 
+static ECalBackendSyncStatus
 send_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *icalcomp, icalproperty_method method)
 {
 	ECalComponent *comp, *found_comp = NULL;
 	ECalBackendGooglePrivate *priv;
 	ECalBackendSyncStatus status = GNOME_Evolution_Calendar_OtherError;
-	const char *uid;
+	const gchar *uid;
 
 	priv = cbgo->priv;
 	comp = e_cal_component_new ();
-	e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (icalcomp));	
+	e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (icalcomp));
 
-	e_cal_component_get_uid (comp, (const char **)&uid);
+	e_cal_component_get_uid (comp, (const gchar **)&uid);
 	found_comp = e_cal_backend_cache_get_component (priv->cache, uid, NULL);
 
 	if (!found_comp) {
@@ -716,22 +716,22 @@ send_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *icalcomp, ic
 		return GNOME_Evolution_Calendar_InvalidObject;
 	}
 
-	status = GNOME_Evolution_Calendar_Success;	
+	status = GNOME_Evolution_Calendar_Success;
 	/* TODO Check if connection exists */
 	switch (priv->mode) {
 		case CAL_MODE_ANY:
-		case CAL_MODE_REMOTE: 	
+		case CAL_MODE_REMOTE:
 			if (method == ICAL_METHOD_CANCEL) {
 				gboolean instances = FALSE;
 				if (instances) {
-					char *old_object = NULL;
+					gchar *old_object = NULL;
 					GSList *l = NULL, *comp_list;
 					comp_list = e_cal_backend_cache_get_components_by_uid (priv->cache, uid);
-		
+
 					for (l = comp_list; l; l = l->next) {
 						ECalComponent *component = E_CAL_COMPONENT (l->data);
 						ECalComponentId *cid = e_cal_component_get_id (component);
-						char *object = e_cal_component_get_as_string (component);
+						gchar *object = e_cal_component_get_as_string (component);
 
 						if (e_cal_backend_cache_remove_component (priv->cache, cid->uid,
 									cid->rid))
@@ -741,12 +741,12 @@ send_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *icalcomp, ic
 						g_free (object);
 						g_object_unref (component);
 					}
-						
-					g_slist_free (comp_list);	
+
+					g_slist_free (comp_list);
 					g_free (old_object);
 				} else {
 					ECalComponentId *cid;
-					char * object;
+					gchar * object;
 
 					cid = e_cal_component_get_id (comp);
 					icalcomp = e_cal_component_get_icalcomponent (comp);
@@ -760,13 +760,13 @@ send_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *icalcomp, ic
 
 					g_free (object);
 					e_cal_component_free_id (cid);
-				}	
+				}
 			}
 			break;
 		case CAL_MODE_LOCAL:
 			status = GNOME_Evolution_Calendar_RepositoryOffline;
 			break;
-		default: 
+		default:
 			break;
 	}
 
@@ -777,7 +777,7 @@ send_object (ECalBackendGoogle *cbgo, EDataCal *cal, icalcomponent *icalcomp, ic
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_send_objects (ECalBackendSync *backend, EDataCal *cal, const char *calobj, GList **users, char **modified_calobj)
+e_cal_backend_google_send_objects (ECalBackendSync *backend, EDataCal *cal, const gchar *calobj, GList **users, gchar **modified_calobj)
 {
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
@@ -785,7 +785,7 @@ e_cal_backend_google_send_objects (ECalBackendSync *backend, EDataCal *cal, cons
 	icalcomponent *icalcomp, *subcomp;
 	icalcomponent_kind kind;
 	icalproperty_method method;
-		
+
 	cbgo = E_CAL_BACKEND_GOOGLE(backend);
 	priv = cbgo->priv;
 	if (priv->mode == CAL_MODE_LOCAL) {
@@ -796,23 +796,23 @@ e_cal_backend_google_send_objects (ECalBackendSync *backend, EDataCal *cal, cons
 	icalcomp = icalparser_parse_string (calobj);
 	if (!icalcomp)
 		return GNOME_Evolution_Calendar_InvalidObject;
-	
+
 	method = icalcomponent_get_method (icalcomp);
 	kind = icalcomponent_isa (icalcomp);
-	
-	if (kind == ICAL_VCALENDAR_COMPONENT) {		
+
+	if (kind == ICAL_VCALENDAR_COMPONENT) {
 		subcomp = icalcomponent_get_first_component (icalcomp, e_cal_backend_get_kind(E_CAL_BACKEND(backend)));
 		while (subcomp) {
 			status = send_object (cbgo, cal, subcomp, method);
-				
+
 			if (status != GNOME_Evolution_Calendar_Success)
 				break;
 			subcomp = icalcomponent_get_next_component (icalcomp, e_cal_backend_get_kind (E_CAL_BACKEND(backend)));
 		}
 	} else if (kind == e_cal_backend_get_kind (E_CAL_BACKEND(backend))) {
-		status = send_object (cbgo, cal, icalcomp, method);	
-	} else 
-		status = GNOME_Evolution_Calendar_InvalidObject;		
+		status = send_object (cbgo, cal, icalcomp, method);
+	} else
+		status = GNOME_Evolution_Calendar_InvalidObject;
 	if (status == GNOME_Evolution_Calendar_Success) {
 		ECalComponent *comp;
 
@@ -823,7 +823,7 @@ e_cal_backend_google_send_objects (ECalBackendSync *backend, EDataCal *cal, cons
 			e_cal_component_get_attendee_list (comp, &attendee_list);
 			/* convert this into GList */
 			for (tmp = attendee_list; tmp; tmp = g_slist_next (tmp)) {
-				const char *attendee = tmp->data;
+				const gchar *attendee = tmp->data;
 
 				if (attendee)
 					*users = g_list_append (*users, g_strdup (attendee));
@@ -833,14 +833,14 @@ e_cal_backend_google_send_objects (ECalBackendSync *backend, EDataCal *cal, cons
 		}
 		*modified_calobj = g_strdup (calobj);
 	}
-	g_printf ("\n %s, %s \n", *modified_calobj, G_STRLOC);	
-	icalcomponent_free (icalcomp);	
+	g_printf ("\n %s, %s \n", *modified_calobj, G_STRLOC);
+	icalcomponent_free (icalcomp);
 
 	return status;
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_get_changes (ECalBackendSync *backend, EDataCal *cal, const char *change_id, GList **adds, GList **modifies, GList **deletes)
+e_cal_backend_google_get_changes (ECalBackendSync *backend, EDataCal *cal, const gchar *change_id, GList **adds, GList **modifies, GList **deletes)
 {
 	/* FIXME Not Implemented */
 	return GNOME_Evolution_Calendar_Success;
@@ -859,7 +859,7 @@ e_cal_backend_google_is_read_only (ECalBackendSync *backend, EDataCal *cal, gboo
 
 /* Returns the email address of the person who opened the calendar */
 static ECalBackendSyncStatus
-e_cal_backend_google_get_cal_address (ECalBackendSync *backend, EDataCal *cal, char **address)
+e_cal_backend_google_get_cal_address (ECalBackendSync *backend, EDataCal *cal, gchar **address)
 {
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
@@ -873,7 +873,7 @@ e_cal_backend_google_get_cal_address (ECalBackendSync *backend, EDataCal *cal, c
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_get_alarm_email_address (ECalBackendSync *backend, EDataCal *cal, char **address)
+e_cal_backend_google_get_alarm_email_address (ECalBackendSync *backend, EDataCal *cal, gchar **address)
 {
 	/* Support email based alarms ? */
 
@@ -883,14 +883,14 @@ e_cal_backend_google_get_alarm_email_address (ECalBackendSync *backend, EDataCal
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_modify_object (ECalBackendSync *backend, EDataCal *cal, const char *calobj, CalObjModType mod, char **old_object, char **new_object)
+e_cal_backend_google_modify_object (ECalBackendSync *backend, EDataCal *cal, const gchar *calobj, CalObjModType mod, gchar **old_object, gchar **new_object)
 {
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
 	icalcomponent *icalcomp;
 	ECalComponent *comp = NULL, *cache_comp = NULL;
 	EGoItem *item;
-	const char *uid=NULL, *rid=NULL;
+	const gchar *uid=NULL, *rid=NULL;
 	GDataEntry *entry, *entry_from_server=NULL, *updated_entry=NULL;
 	gchar *edit_link;
 	GSList *l;
@@ -946,11 +946,11 @@ e_cal_backend_google_modify_object (ECalBackendSync *backend, EDataCal *cal, con
 			}
 
 			edit_link = gdata_entry_get_edit_link (entry_from_server);
-			updated_entry = gdata_service_update_entry_with_link (GDATA_SERVICE (priv->service), 
+			updated_entry = gdata_service_update_entry_with_link (GDATA_SERVICE (priv->service),
 					entry, edit_link, NULL);
 
 			if (updated_entry) {
-				/* FIXME Response from server contains, additional info about GDataEntry 
+				/* FIXME Response from server contains, additional info about GDataEntry
 				 * Store and use them later
 				 */
 			}
@@ -973,15 +973,15 @@ e_cal_backend_google_modify_object (ECalBackendSync *backend, EDataCal *cal, con
 
 static ECalBackendSyncStatus
 e_cal_backend_google_remove_object (ECalBackendSync *backend, EDataCal *cal,
-				       const char *uid, const char *rid,
-				       CalObjModType mod, char **old_object,
-				       char **object)
+				       const gchar *uid, const gchar *rid,
+				       CalObjModType mod, gchar **old_object,
+				       gchar **object)
 {
 	ECalBackendGoogle *cbgo;
 	GDataEntry *entry;
 	ECalBackendGooglePrivate *priv;
 	ECalComponent *comp = NULL;
-	char *calobj = NULL;
+	gchar *calobj = NULL;
 	GSList *entries = NULL;
 	EGoItem *item;
 
@@ -999,7 +999,7 @@ e_cal_backend_google_remove_object (ECalBackendSync *backend, EDataCal *cal,
 		ECalBackendSyncStatus status;
 		icalcomponent *icalcomp;
 		ECalComponentId *id;
-		char *comp_str;
+		gchar *comp_str;
 
 		status = e_cal_backend_google_get_object (backend, cal, uid, rid, &calobj);
 
@@ -1036,7 +1036,7 @@ e_cal_backend_google_remove_object (ECalBackendSync *backend, EDataCal *cal,
 			return GNOME_Evolution_Calendar_InvalidObject;
 		}
 
-	        gdata_service_delete_entry (GDATA_SERVICE(priv->service), entry, NULL);
+		gdata_service_delete_entry (GDATA_SERVICE(priv->service), entry, NULL);
 		*object = NULL;
 		*old_object = strdup (calobj);
 	}
@@ -1050,7 +1050,7 @@ e_cal_backend_google_remove_object (ECalBackendSync *backend, EDataCal *cal,
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_create_object (ECalBackendSync *backend, EDataCal *cal, char **calobj, char **uid)
+e_cal_backend_google_create_object (ECalBackendSync *backend, EDataCal *cal, gchar **calobj, gchar **uid)
 {
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
@@ -1119,7 +1119,7 @@ e_cal_backend_google_create_object (ECalBackendSync *backend, EDataCal *cal, cha
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_get_ldap_attribute (ECalBackendSync *backend, EDataCal *cal, char **attribute)
+e_cal_backend_google_get_ldap_attribute (ECalBackendSync *backend, EDataCal *cal, gchar **attribute)
 {
 	/* ldap attribute is specific to Sun ONE connector to get free busy information*/
 	/* return NULL here as google backend know how to get free busy information */
@@ -1131,7 +1131,7 @@ e_cal_backend_google_get_ldap_attribute (ECalBackendSync *backend, EDataCal *cal
 
 
 static ECalBackendSyncStatus
-e_cal_backend_google_get_static_capabilities (ECalBackendSync *backend, EDataCal *cal, char **capabilities)
+e_cal_backend_google_get_static_capabilities (ECalBackendSync *backend, EDataCal *cal, gchar **capabilities)
 {
 	/* FIXME */
 	*capabilities = NULL;
@@ -1139,14 +1139,15 @@ e_cal_backend_google_get_static_capabilities (ECalBackendSync *backend, EDataCal
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_google_open (ECalBackendSync *backend, EDataCal *cal, gboolean only_if_exists,const char *username, const char *password)
+e_cal_backend_google_open (ECalBackendSync *backend, EDataCal *cal, gboolean only_if_exists,const gchar *username, const gchar *password)
 {
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
 	ECalBackendSyncStatus status;
 	ECalSourceType source_type;
-	gchar *source = NULL, *mangled_uri = NULL, *filename = NULL;
-	int i;
+	const gchar *source = NULL;
+	gchar *mangled_uri = NULL, *filename = NULL;
+	gint i;
 
 	cbgo = E_CAL_BACKEND_GOOGLE(backend);
 	priv = cbgo->priv;
@@ -1173,7 +1174,7 @@ e_cal_backend_google_open (ECalBackendSync *backend, EDataCal *cal, gboolean onl
 	/* Not for remote */
 	if (priv->mode == CAL_MODE_LOCAL) {
 		ESource *esource;
-		const char *display_contents = NULL;
+		const gchar *display_contents = NULL;
 
 		cbgo->priv->read_only = TRUE;
 		esource = e_cal_backend_get_source (E_CAL_BACKEND(cbgo));
@@ -1214,11 +1215,11 @@ e_cal_backend_google_open (ECalBackendSync *backend, EDataCal *cal, gboolean onl
 			mangled_uri[i] = '_';
 		}
 	}
-	
-	filename = g_build_filename (g_get_home_dir (), 
+
+	filename = g_build_filename (g_get_home_dir (),
 				     ".evolution/cache", source,
 				     mangled_uri,
-			             NULL);
+				     NULL);
 
 	g_free (mangled_uri);
 	priv->local_attachments_store = g_filename_to_uri (filename, NULL, NULL);
@@ -1322,7 +1323,7 @@ proxy_settings_changed (EProxy *proxy, gpointer user_data)
 	}
 	gdata_service_set_proxy (GDATA_SERVICE (priv->service), proxy_uri);
 }
- 
+
 /* Object initialisation function for google backend */
 static void
 e_cal_backend_google_init (ECalBackendGoogle *cbgo, ECalBackendGoogleClass *class)
@@ -1741,7 +1742,7 @@ gchar *
 e_cal_backend_google_get_local_attachments_store (ECalBackendGoogle *cbgo)
 {
 	ECalBackendGooglePrivate *priv;
-	
+
 	g_return_val_if_fail (cbgo != NULL, NULL);
 	g_return_val_if_fail (E_IS_CAL_BACKEND_GOOGLE(cbgo), NULL);
 
