@@ -41,8 +41,10 @@
 
 /* Private part of the ECalBackendHttp structure */
 struct _ECalBackendHttpPrivate {
+	/* signal handler id for source's 'changed' signal */
+	gulong source_changed_id;
 	/* URI to get remote calendar data from */
-	char *uri;
+	gchar *uri;
 
 	/* Local/remote mode */
 	CalMode mode;
@@ -67,8 +69,8 @@ struct _ECalBackendHttpPrivate {
 	/* Flags */
 	gboolean opened;
 
-	char *username;
-	char *password;
+	gchar *username;
+	gchar *password;
 };
 
 
@@ -79,7 +81,7 @@ static void e_cal_backend_http_dispose (GObject *object);
 static void e_cal_backend_http_finalize (GObject *object);
 static gboolean begin_retrieval_cb (ECalBackendHttp *cbhttp);
 static ECalBackendSyncStatus
-e_cal_backend_http_add_timezone (ECalBackendSync *backend, EDataCal *cal, const char *tzobj);
+e_cal_backend_http_add_timezone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzobj);
 
 static ECalBackendSyncClass *parent_class;
 
@@ -97,6 +99,13 @@ e_cal_backend_http_dispose (GObject *object)
 
 	g_free (priv->username);
 	g_free (priv->password);
+	priv->username = NULL;
+	priv->password = NULL;
+
+	if (priv->source_changed_id) {
+		g_signal_handler_disconnect (e_cal_backend_get_source (E_CAL_BACKEND (cbhttp)), priv->source_changed_id);
+		priv->source_changed_id = 0;
+	}
 
 	if (G_OBJECT_CLASS (parent_class)->dispose)
 		(* G_OBJECT_CLASS (parent_class)->dispose) (object);
@@ -123,7 +132,7 @@ e_cal_backend_http_finalize (GObject *object)
 	}
 
 	if (priv->uri) {
-	        g_free (priv->uri);
+		g_free (priv->uri);
 		priv->uri = NULL;
 	}
 
@@ -166,7 +175,7 @@ e_cal_backend_http_is_read_only (ECalBackendSync *backend, EDataCal *cal, gboole
 
 /* Get_email_address handler for the file backend */
 static ECalBackendSyncStatus
-e_cal_backend_http_get_cal_address (ECalBackendSync *backend, EDataCal *cal, char **address)
+e_cal_backend_http_get_cal_address (ECalBackendSync *backend, EDataCal *cal, gchar **address)
 {
 	/* A HTTP backend has no particular email address associated
 	 * with it (although that would be a useful feature some day).
@@ -177,7 +186,7 @@ e_cal_backend_http_get_cal_address (ECalBackendSync *backend, EDataCal *cal, cha
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_http_get_ldap_attribute (ECalBackendSync *backend, EDataCal *cal, char **attribute)
+e_cal_backend_http_get_ldap_attribute (ECalBackendSync *backend, EDataCal *cal, gchar **attribute)
 {
 	*attribute = NULL;
 
@@ -185,18 +194,18 @@ e_cal_backend_http_get_ldap_attribute (ECalBackendSync *backend, EDataCal *cal,
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_http_get_alarm_email_address (ECalBackendSync *backend, EDataCal *cal, char **address)
+e_cal_backend_http_get_alarm_email_address (ECalBackendSync *backend, EDataCal *cal, gchar **address)
 {
- 	/* A HTTP backend has no particular email address associated
- 	 * with it (although that would be a useful feature some day).
- 	 */
+	/* A HTTP backend has no particular email address associated
+	 * with it (although that would be a useful feature some day).
+	 */
 	*address = NULL;
 
 	return GNOME_Evolution_Calendar_Success;
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_http_get_static_capabilities (ECalBackendSync *backend, EDataCal *cal, char **capabilities)
+e_cal_backend_http_get_static_capabilities (ECalBackendSync *backend, EDataCal *cal, gchar **capabilities)
 {
 	*capabilities = g_strdup (CAL_STATIC_CAPABILITY_NO_EMAIL_ALARMS);
 
@@ -221,7 +230,7 @@ webcal_to_http_method (const gchar *webcal_str, gboolean secure)
 static gboolean
 notify_and_remove_from_cache (gpointer key, gpointer value, gpointer user_data)
 {
-	const char *calobj = value;
+	const gchar *calobj = value;
 	ECalBackendHttp *cbhttp = E_CAL_BACKEND_HTTP (user_data);
 	ECalComponent *comp = e_cal_component_new_from_string (calobj);
 	ECalComponentId *id = e_cal_component_get_id (comp);
@@ -241,7 +250,7 @@ retrieval_done (SoupSession *session, SoupMessage *msg, ECalBackendHttp *cbhttp)
 	ECalBackendHttpPrivate *priv;
 	icalcomponent *icalcomp, *subcomp;
 	icalcomponent_kind kind;
-	const char *newuri;
+	const gchar *newuri;
 	GHashTable *old_cache;
 	GList *comps_in_cache;
 
@@ -250,6 +259,12 @@ retrieval_done (SoupSession *session, SoupMessage *msg, ECalBackendHttp *cbhttp)
 	priv->is_loading = FALSE;
 	d(g_message ("Retrieval done.\n"));
 
+	if (!priv->uri) {
+		/* uri changed meanwhile, retrieve again */
+		begin_retrieval_cb (cbhttp);
+		return;
+	}
+
 	/* Handle redirection ourselves */
 	if (SOUP_STATUS_IS_REDIRECTION (msg->status_code)) {
 		newuri = soup_message_headers_get (msg->response_headers,
@@ -278,6 +293,8 @@ retrieval_done (SoupSession *session, SoupMessage *msg, ECalBackendHttp *cbhttp)
 			e_cal_backend_notify_error (E_CAL_BACKEND (cbhttp),
 						    soup_status_get_phrase (msg->status_code));
 		}
+
+		e_cal_backend_empty_cache (E_CAL_BACKEND (cbhttp), priv->cache);
 		return;
 	}
 
@@ -287,6 +304,7 @@ retrieval_done (SoupSession *session, SoupMessage *msg, ECalBackendHttp *cbhttp)
 	if (!icalcomp) {
 		if (!priv->opened)
 			e_cal_backend_notify_error (E_CAL_BACKEND (cbhttp), _("Bad file format."));
+		e_cal_backend_empty_cache (E_CAL_BACKEND (cbhttp), priv->cache);
 		return;
 	}
 
@@ -294,6 +312,7 @@ retrieval_done (SoupSession *session, SoupMessage *msg, ECalBackendHttp *cbhttp)
 		if (!priv->opened)
 			e_cal_backend_notify_error (E_CAL_BACKEND (cbhttp), _("Not a calendar."));
 		icalcomponent_free (icalcomp);
+		e_cal_backend_empty_cache (E_CAL_BACKEND (cbhttp), priv->cache);
 		return;
 	}
 
@@ -302,7 +321,7 @@ retrieval_done (SoupSession *session, SoupMessage *msg, ECalBackendHttp *cbhttp)
 
 	comps_in_cache = e_cal_backend_cache_get_components (priv->cache);
 	while (comps_in_cache != NULL) {
-		const char *uid;
+		const gchar *uid;
 		ECalComponent *comp = comps_in_cache->data;
 
 		e_cal_component_get_uid (comp, &uid);
@@ -331,14 +350,14 @@ retrieval_done (SoupSession *session, SoupMessage *msg, ECalBackendHttp *cbhttp)
 		if (subcomp_kind == kind) {
 			comp = e_cal_component_new ();
 			if (e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (subcomp))) {
-				const char *uid, *orig_key, *orig_value;
-				char *obj;
+				const gchar *uid, *orig_key, *orig_value;
+				gchar *obj;
 
 				e_cal_backend_cache_put_component (priv->cache, comp);
 
 				e_cal_component_get_uid (comp, &uid);
-				/* middle (void*) cast only because of 'dereferencing type-punned pointer will break strict-aliasing rules' */
-				if (g_hash_table_lookup_extended (old_cache, uid, (void **)(void*)&orig_key, (void **)(void*)&orig_value)) {
+				/* middle (gpointer) cast only because of 'dereferencing type-punned pointer will break strict-aliasing rules' */
+				if (g_hash_table_lookup_extended (old_cache, uid, (gpointer *)(gpointer)&orig_key, (gpointer *)(gpointer)&orig_value)) {
 					obj = icalcomponent_as_ical_string_r (subcomp);
 					e_cal_backend_notify_object_modified (E_CAL_BACKEND (cbhttp),
 									      orig_value,
@@ -384,7 +403,7 @@ retrieval_done (SoupSession *session, SoupMessage *msg, ECalBackendHttp *cbhttp)
 
 static void
 soup_authenticate (SoupSession  *session,
-	           SoupMessage  *msg,
+		   SoupMessage  *msg,
 		   SoupAuth     *auth,
 		   gboolean      retrying,
 		   gpointer      data)
@@ -414,7 +433,7 @@ begin_retrieval_cb (ECalBackendHttp *cbhttp)
 	priv = cbhttp->priv;
 
 	if (priv->mode != CAL_MODE_REMOTE)
-		return TRUE;
+		return FALSE;
 
 	maybe_start_reload_timeout (cbhttp);
 
@@ -427,10 +446,10 @@ begin_retrieval_cb (ECalBackendHttp *cbhttp)
 
 	if (priv->uri == NULL) {
 		ESource *source = e_cal_backend_get_source (E_CAL_BACKEND (cbhttp));
-		const char *secure_prop = e_source_get_property (source, "use_ssl");
+		const gchar *secure_prop = e_source_get_property (source, "use_ssl");
 
 		priv->uri = webcal_to_http_method (e_cal_backend_get_uri (E_CAL_BACKEND (cbhttp)),
-		                                   (secure_prop && g_str_equal(secure_prop, "1")));
+						   (secure_prop && g_str_equal(secure_prop, "1")));
 	}
 
 	/* create the Soup session if not already created */
@@ -459,6 +478,7 @@ begin_retrieval_cb (ECalBackendHttp *cbhttp)
 	soup_message = soup_message_new (SOUP_METHOD_GET, priv->uri);
 	if (soup_message == NULL) {
 		priv->is_loading = FALSE;
+		e_cal_backend_empty_cache (E_CAL_BACKEND (cbhttp), priv->cache);
 		return FALSE;
 	}
 
@@ -517,19 +537,60 @@ maybe_start_reload_timeout (ECalBackendHttp *cbhttp)
 						 (GSourceFunc) reload_cb, cbhttp);
 }
 
+static void
+source_changed_cb (ESource *source, ECalBackendHttp *cbhttp)
+{
+	ECalBackendHttpPrivate *priv;
+
+	g_return_if_fail (cbhttp != NULL);
+	g_return_if_fail (cbhttp->priv != NULL);
+
+	priv = cbhttp->priv;
+
+	if (priv->uri) {
+		ESource *source = e_cal_backend_get_source (E_CAL_BACKEND (cbhttp));
+		const gchar *secure_prop = e_source_get_property (source, "use_ssl");
+		gchar *new_uri;
+
+		new_uri = webcal_to_http_method (e_cal_backend_get_uri (E_CAL_BACKEND (cbhttp)),
+						 (secure_prop && g_str_equal(secure_prop, "1")));
+
+		if (new_uri && !g_str_equal (priv->uri, new_uri)) {
+			/* uri changed, do reload some time soon */
+			g_free (priv->uri);
+			priv->uri = NULL;
+
+			if (!priv->is_loading)
+				g_idle_add ((GSourceFunc) begin_retrieval_cb, cbhttp);
+		}
+
+		g_free (new_uri);
+	}
+}
+
 /* Open handler for the file backend */
 static ECalBackendSyncStatus
 e_cal_backend_http_open (ECalBackendSync *backend, EDataCal *cal, gboolean only_if_exists,
-			 const char *username, const char *password)
+			 const gchar *username, const gchar *password)
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
 	ESource *source;
+	gchar *tmp;
 
 	cbhttp = E_CAL_BACKEND_HTTP (backend);
 	priv = cbhttp->priv;
 	source = e_cal_backend_get_source (E_CAL_BACKEND (backend));
 
+	if (priv->source_changed_id == 0) {
+		priv->source_changed_id = g_signal_connect (source, "changed", G_CALLBACK (source_changed_cb), cbhttp);
+	}
+
+	/* always read uri again */
+	tmp = priv->uri;
+	priv->uri = NULL;
+	g_free (tmp);
+
 	if (e_source_get_property (source, "auth") != NULL) {
 		if ((username == NULL || password == NULL)) {
 			return GNOME_Evolution_Calendar_AuthenticationRequired;
@@ -565,14 +626,14 @@ e_cal_backend_http_open (ECalBackendSync *backend, EDataCal *cal, gboolean only_
 		if (priv->default_zone) {
 			e_cal_backend_cache_put_default_timezone (priv->cache, priv->default_zone);
 		}
-
-		if (priv->mode == CAL_MODE_LOCAL)
-			return GNOME_Evolution_Calendar_Success;
-
-
-		g_idle_add ((GSourceFunc) begin_retrieval_cb, cbhttp);
 	}
 
+	if (priv->mode == CAL_MODE_LOCAL)
+		return GNOME_Evolution_Calendar_Success;
+
+
+	g_idle_add ((GSourceFunc) begin_retrieval_cb, cbhttp);
+
 	return GNOME_Evolution_Calendar_Success;
 }
 
@@ -673,7 +734,7 @@ e_cal_backend_http_set_mode (ECalBackend *backend, CalMode mode)
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_http_get_default_object (ECalBackendSync *backend, EDataCal *cal, char **object)
+e_cal_backend_http_get_default_object (ECalBackendSync *backend, EDataCal *cal, gchar **object)
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
@@ -693,7 +754,7 @@ e_cal_backend_http_get_default_object (ECalBackendSync *backend, EDataCal *cal,
 
 /* Get_object_component handler for the http backend */
 static ECalBackendSyncStatus
-e_cal_backend_http_get_object (ECalBackendSync *backend, EDataCal *cal, const char *uid, const char *rid, char **object)
+e_cal_backend_http_get_object (ECalBackendSync *backend, EDataCal *cal, const gchar *uid, const gchar *rid, gchar **object)
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
@@ -719,7 +780,7 @@ e_cal_backend_http_get_object (ECalBackendSync *backend, EDataCal *cal, const ch
 
 /* Get_timezone_object handler for the file backend */
 static ECalBackendSyncStatus
-e_cal_backend_http_get_timezone (ECalBackendSync *backend, EDataCal *cal, const char *tzid, char **object)
+e_cal_backend_http_get_timezone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzid, gchar **object)
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
@@ -750,7 +811,7 @@ e_cal_backend_http_get_timezone (ECalBackendSync *backend, EDataCal *cal, const
 
 /* Add_timezone handler for the file backend */
 static ECalBackendSyncStatus
-e_cal_backend_http_add_timezone (ECalBackendSync *backend, EDataCal *cal, const char *tzobj)
+e_cal_backend_http_add_timezone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzobj)
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
@@ -781,7 +842,7 @@ e_cal_backend_http_add_timezone (ECalBackendSync *backend, EDataCal *cal, const
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_http_set_default_zone (ECalBackendSync *backend, EDataCal *cal, const char *tzobj)
+e_cal_backend_http_set_default_zone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzobj)
 {
 	icalcomponent *tz_comp;
 	ECalBackendHttp *cbhttp;
@@ -814,7 +875,7 @@ e_cal_backend_http_set_default_zone (ECalBackendSync *backend, EDataCal *cal, co
 
 /* Get_objects_in_range handler for the file backend */
 static ECalBackendSyncStatus
-e_cal_backend_http_get_object_list (ECalBackendSync *backend, EDataCal *cal, const char *sexp, GList **objects)
+e_cal_backend_http_get_object_list (ECalBackendSync *backend, EDataCal *cal, const gchar *sexp, GList **objects)
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
@@ -888,7 +949,7 @@ e_cal_backend_http_start_query (ECalBackend *backend, EDataCalView *query)
 
 
 static icaltimezone *
-resolve_tzid (const char *tzid, gpointer user_data)
+resolve_tzid (const gchar *tzid, gpointer user_data)
 {
         icalcomponent *vcalendar_comp = user_data;
 
@@ -932,7 +993,7 @@ free_busy_instance (ECalComponent *comp,
 }
 
 static icalcomponent *
-create_user_free_busy (ECalBackendHttp *cbhttp, const char *address, const char *cn,
+create_user_free_busy (ECalBackendHttp *cbhttp, const gchar *address, const gchar *cn,
                        time_t start, time_t end)
 {
         GList *list = NULL, *l;
@@ -941,7 +1002,7 @@ create_user_free_busy (ECalBackendHttp *cbhttp, const char *address, const char
         ECalBackendSExp *obj_sexp;
         ECalBackendHttpPrivate *priv;
         ECalBackendCache *cache;
-        char *query, *iso_start, *iso_end;
+        gchar *query, *iso_start, *iso_end;
 
         priv = cbhttp->priv;
         cache = priv->cache;
@@ -1029,7 +1090,7 @@ e_cal_backend_http_get_free_busy (ECalBackendSync *backend, EDataCal *cal, GList
 	ECalBackendHttpPrivate *priv;
 	gchar *address, *name;
 	icalcomponent *vfb;
-	char *calobj;
+	gchar *calobj;
 
 
 	cbhttp = E_CAL_BACKEND_HTTP (backend);
@@ -1069,7 +1130,7 @@ e_cal_backend_http_get_free_busy (ECalBackendSync *backend, EDataCal *cal, GList
 
 /* Get_changes handler for the file backend */
 static ECalBackendSyncStatus
-e_cal_backend_http_get_changes (ECalBackendSync *backend, EDataCal *cal, const char *change_id,
+e_cal_backend_http_get_changes (ECalBackendSync *backend, EDataCal *cal, const gchar *change_id,
 				GList **adds, GList **modifies, GList **deletes)
 {
 	ECalBackendHttp *cbhttp;
@@ -1086,7 +1147,7 @@ e_cal_backend_http_get_changes (ECalBackendSync *backend, EDataCal *cal, const c
 
 /* Discard_alarm handler for the file backend */
 static ECalBackendSyncStatus
-e_cal_backend_http_discard_alarm (ECalBackendSync *backend, EDataCal *cal, const char *uid, const char *auid)
+e_cal_backend_http_discard_alarm (ECalBackendSync *backend, EDataCal *cal, const gchar *uid, const gchar *auid)
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
@@ -1099,7 +1160,7 @@ e_cal_backend_http_discard_alarm (ECalBackendSync *backend, EDataCal *cal, const
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_http_create_object (ECalBackendSync *backend, EDataCal *cal, char **calobj, char **uid)
+e_cal_backend_http_create_object (ECalBackendSync *backend, EDataCal *cal, gchar **calobj, gchar **uid)
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
@@ -1111,8 +1172,8 @@ e_cal_backend_http_create_object (ECalBackendSync *backend, EDataCal *cal, char
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_http_modify_object (ECalBackendSync *backend, EDataCal *cal, const char *calobj,
-				CalObjModType mod, char **old_object, char **new_object)
+e_cal_backend_http_modify_object (ECalBackendSync *backend, EDataCal *cal, const gchar *calobj,
+				CalObjModType mod, gchar **old_object, gchar **new_object)
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
@@ -1128,9 +1189,9 @@ e_cal_backend_http_modify_object (ECalBackendSync *backend, EDataCal *cal, const
 /* Remove_object handler for the file backend */
 static ECalBackendSyncStatus
 e_cal_backend_http_remove_object (ECalBackendSync *backend, EDataCal *cal,
-				const char *uid, const char *rid,
-				CalObjModType mod, char **old_object,
-				char **object)
+				const gchar *uid, const gchar *rid,
+				CalObjModType mod, gchar **old_object,
+				gchar **object)
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
@@ -1147,7 +1208,7 @@ e_cal_backend_http_remove_object (ECalBackendSync *backend, EDataCal *cal,
 
 /* Update_objects handler for the file backend. */
 static ECalBackendSyncStatus
-e_cal_backend_http_receive_objects (ECalBackendSync *backend, EDataCal *cal, const char *calobj)
+e_cal_backend_http_receive_objects (ECalBackendSync *backend, EDataCal *cal, const gchar *calobj)
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
@@ -1161,8 +1222,8 @@ e_cal_backend_http_receive_objects (ECalBackendSync *backend, EDataCal *cal, con
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_http_send_objects (ECalBackendSync *backend, EDataCal *cal, const char *calobj, GList **users,
-				 char **modified_calobj)
+e_cal_backend_http_send_objects (ECalBackendSync *backend, EDataCal *cal, const gchar *calobj, GList **users,
+				 gchar **modified_calobj)
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
@@ -1192,7 +1253,7 @@ e_cal_backend_http_internal_get_default_timezone (ECalBackend *backend)
 }
 
 static icaltimezone *
-e_cal_backend_http_internal_get_timezone (ECalBackend *backend, const char *tzid)
+e_cal_backend_http_internal_get_timezone (ECalBackend *backend, const gchar *tzid)
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
@@ -1202,7 +1263,7 @@ e_cal_backend_http_internal_get_timezone (ECalBackend *backend, const char *tzid
 	priv = cbhttp->priv;
 
 	if (!strcmp (tzid, "UTC"))
-	        zone = icaltimezone_get_utc_timezone ();
+		zone = icaltimezone_get_utc_timezone ();
 	else {
 		zone = icaltimezone_get_builtin_timezone_from_tzid (tzid);
 
@@ -1248,9 +1309,9 @@ e_cal_backend_http_class_init (ECalBackendHttpClass *class)
 
 	sync_class->is_read_only_sync = e_cal_backend_http_is_read_only;
 	sync_class->get_cal_address_sync = e_cal_backend_http_get_cal_address;
- 	sync_class->get_alarm_email_address_sync = e_cal_backend_http_get_alarm_email_address;
- 	sync_class->get_ldap_attribute_sync = e_cal_backend_http_get_ldap_attribute;
- 	sync_class->get_static_capabilities_sync = e_cal_backend_http_get_static_capabilities;
+	sync_class->get_alarm_email_address_sync = e_cal_backend_http_get_alarm_email_address;
+	sync_class->get_ldap_attribute_sync = e_cal_backend_http_get_ldap_attribute;
+	sync_class->get_static_capabilities_sync = e_cal_backend_http_get_static_capabilities;
 	sync_class->open_sync = e_cal_backend_http_open;
 	sync_class->remove_sync = e_cal_backend_http_remove;
 	sync_class->create_object_sync = e_cal_backend_http_create_object;
@@ -1259,7 +1320,7 @@ e_cal_backend_http_class_init (ECalBackendHttpClass *class)
 	sync_class->discard_alarm_sync = e_cal_backend_http_discard_alarm;
 	sync_class->receive_objects_sync = e_cal_backend_http_receive_objects;
 	sync_class->send_objects_sync = e_cal_backend_http_send_objects;
- 	sync_class->get_default_object_sync = e_cal_backend_http_get_default_object;
+	sync_class->get_default_object_sync = e_cal_backend_http_get_default_object;
 	sync_class->get_object_sync = e_cal_backend_http_get_object;
 	sync_class->get_object_list_sync = e_cal_backend_http_get_object_list;
 	sync_class->get_timezone_sync = e_cal_backend_http_get_timezone;
