@@ -27,16 +27,21 @@
 #include <libxml/xmlmemory.h>
 
 #include "e-cal-backend.h"
+#include "e-cal-backend-cache.h"
 
 
 
+G_DEFINE_TYPE (ECalBackend, e_cal_backend, G_TYPE_OBJECT)
+
 /* Private part of the CalBackend structure */
 struct _ECalBackendPrivate {
 	/* The source for this backend */
 	ESource *source;
+	/* signal handler ID for source's 'changed' signal */
+	gulong source_changed_id;
 
 	/* URI, from source. This is cached, since we return const. */
-	char *uri;
+	gchar *uri;
 
 	/* The kind of components for this backend */
 	icalcomponent_kind kind;
@@ -54,9 +59,14 @@ struct _ECalBackendPrivate {
 	/* used when notifying clients about progress of some operation,
 	 * we do not send multiple notifications with the same percent
 	 * value */
-	int last_percent_notified;
+	gint last_percent_notified;
 };
 
+#define E_CAL_BACKEND_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), E_TYPE_CAL_BACKEND, ECalBackendPrivate))
+
+/* For convenience */
+#define CLASS(backend) (E_CAL_BACKEND_GET_CLASS(backend))
+
 /* Property IDs */
 enum props {
 	PROP_0,
@@ -74,44 +84,31 @@ enum {
 };
 static guint e_cal_backend_signals[LAST_SIGNAL];
 
-static void e_cal_backend_class_init (ECalBackendClass *class);
-static void e_cal_backend_init (ECalBackend *backend);
 static void e_cal_backend_finalize (GObject *object);
 
-#define CLASS(backend) (E_CAL_BACKEND_CLASS (G_OBJECT_GET_CLASS (backend)))
-
-static GObjectClass *parent_class;
-
 
 
-/**
- * e_cal_backend_get_type:
- *
- * Registers the #ECalBackend class if necessary, and returns the type ID
- * associated to it.
- *
- * Return value: The type ID of the #ECalBackend class.
- **/
-GType
-e_cal_backend_get_type (void)
+static void
+source_changed_cb (ESource *source, ECalBackend *backend)
 {
-	static GType e_cal_backend_type = 0;
+	ECalBackendPrivate *priv;
+	gchar *suri;
 
-	if (!e_cal_backend_type) {
-		static GTypeInfo info = {
-                        sizeof (ECalBackendClass),
-                        (GBaseInitFunc) NULL,
-                        (GBaseFinalizeFunc) NULL,
-                        (GClassInitFunc) e_cal_backend_class_init,
-                        NULL, NULL,
-                        sizeof (ECalBackend),
-                        0,
-                        (GInstanceInitFunc) e_cal_backend_init,
-                };
-		e_cal_backend_type = g_type_register_static (G_TYPE_OBJECT, "ECalBackend", &info, 0);
+	g_return_if_fail (source != NULL);
+	g_return_if_fail (backend != NULL);
+	g_return_if_fail (E_IS_CAL_BACKEND (backend));
+
+	priv = backend->priv;
+	g_return_if_fail (priv != NULL);
+	g_return_if_fail (priv->source == source);
+
+	suri = e_source_get_uri (priv->source);
+	if (!priv->uri || (suri && !g_str_equal (priv->uri, suri))) {
+		g_free (priv->uri);
+		priv->uri = suri;
+	} else {
+		g_free (suri);
 	}
-
-	return e_cal_backend_type;
 }
 
 static void
@@ -128,9 +125,16 @@ e_cal_backend_set_property (GObject *object, guint property_id, const GValue *va
 		{
 			ESource *new_source;
 
+			if (priv->source_changed_id && priv->source) {
+				g_signal_handler_disconnect (priv->source, priv->source_changed_id);
+				priv->source_changed_id = 0;
+			}
+
 			new_source = g_value_get_object (value);
-			if (new_source)
+			if (new_source) {
 				g_object_ref (new_source);
+				priv->source_changed_id = g_signal_connect (new_source, "changed", G_CALLBACK (source_changed_cb), backend);
+			}
 
 			if (priv->source)
 				g_object_unref (priv->source);
@@ -162,7 +166,7 @@ e_cal_backend_set_property (GObject *object, guint property_id, const GValue *va
 static void
 e_cal_backend_get_property (GObject *object, guint property_id, GValue *value, GParamSpec *pspec)
 {
- 	ECalBackend *backend;
+	ECalBackend *backend;
 	ECalBackendPrivate *priv;
 
 	backend = E_CAL_BACKEND (object);
@@ -190,8 +194,6 @@ e_cal_backend_class_init (ECalBackendClass *class)
 {
 	GObjectClass *object_class;
 
-	parent_class = (GObjectClass *) g_type_class_peek_parent (class);
-
 	object_class = (GObjectClass *) class;
 
 	object_class->set_property = e_cal_backend_set_property;
@@ -268,6 +270,8 @@ e_cal_backend_class_init (ECalBackendClass *class)
 	class->get_timezone = NULL;
 	class->add_timezone = NULL;
 	class->set_default_timezone = NULL;
+
+	g_type_class_add_private (class, sizeof (ECalBackendPrivate));
 }
 
 /* Object initialization func for the calendar backend */
@@ -276,7 +280,7 @@ e_cal_backend_init (ECalBackend *backend)
 {
 	ECalBackendPrivate *priv;
 
-	priv = g_new0 (ECalBackendPrivate, 1);
+	priv = E_CAL_BACKEND_GET_PRIVATE (backend);
 	backend->priv = priv;
 
 	priv->clients = NULL;
@@ -304,10 +308,13 @@ e_cal_backend_finalize (GObject *object)
 	g_mutex_free (priv->queries_mutex);
 
 	g_free (priv->uri);
+	if (priv->source_changed_id && priv->source) {
+		g_signal_handler_disconnect (priv->source, priv->source_changed_id);
+		priv->source_changed_id = 0;
+	}
 	g_object_unref (priv->source);
-	g_free (priv);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (e_cal_backend_parent_class)->finalize (object);
 }
 
 
@@ -342,7 +349,7 @@ e_cal_backend_get_source (ECalBackend *backend)
  *
  * Return value: The URI where the calendar is stored.
  **/
-const char *
+const gchar *
 e_cal_backend_get_uri (ECalBackend *backend)
 {
 	ECalBackendPrivate *priv;
@@ -557,7 +564,7 @@ e_cal_backend_notify_readonly (ECalBackend *backend, gboolean read_only)
 }
 
 void
-e_cal_backend_notify_cal_address (ECalBackend *backend, char *address)
+e_cal_backend_notify_cal_address (ECalBackend *backend, gchar *address)
 {
 	ECalBackendPrivate *priv;
 	GList *l;
@@ -634,7 +641,7 @@ e_cal_backend_get_static_capabilities (ECalBackend *backend, EDataCal *cal)
  */
 void
 e_cal_backend_open (ECalBackend *backend, EDataCal *cal, gboolean only_if_exists,
-		    const char *username, const char *password)
+		    const gchar *username, const gchar *password)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
@@ -786,7 +793,7 @@ e_cal_backend_get_default_object (ECalBackend *backend, EDataCal *cal)
  * identifier and its recurrence ID (if a recurrent appointment).
  */
 void
-e_cal_backend_get_object (ECalBackend *backend, EDataCal *cal, const char *uid, const char *rid)
+e_cal_backend_get_object (ECalBackend *backend, EDataCal *cal, const gchar *uid, const gchar *rid)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
@@ -805,7 +812,7 @@ e_cal_backend_get_object (ECalBackend *backend, EDataCal *cal, const char *uid,
  * Calls the get_object_list method on the given backend.
  */
 void
-e_cal_backend_get_object_list (ECalBackend *backend, EDataCal *cal, const char *sexp)
+e_cal_backend_get_object_list (ECalBackend *backend, EDataCal *cal, const gchar *sexp)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
@@ -825,7 +832,7 @@ e_cal_backend_get_object_list (ECalBackend *backend, EDataCal *cal, const char *
  * on its unique identifier and its recurrence ID (if a recurrent appointment).
  */
 void
-e_cal_backend_get_attachment_list (ECalBackend *backend, EDataCal *cal, const char *uid, const char *rid)
+e_cal_backend_get_attachment_list (ECalBackend *backend, EDataCal *cal, const gchar *uid, const gchar *rid)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
@@ -867,7 +874,7 @@ e_cal_backend_get_free_busy (ECalBackend *backend, EDataCal *cal, GList *users,
  * the last time the give change_id was seen
  */
 void
-e_cal_backend_get_changes (ECalBackend *backend, EDataCal *cal, const char *change_id)
+e_cal_backend_get_changes (ECalBackend *backend, EDataCal *cal, const gchar *change_id)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
@@ -888,7 +895,7 @@ e_cal_backend_get_changes (ECalBackend *backend, EDataCal *cal, const char *chan
  * to do whatever is needed to really discard the alarm.
  */
 void
-e_cal_backend_discard_alarm (ECalBackend *backend, EDataCal *cal, const char *uid, const char *auid)
+e_cal_backend_discard_alarm (ECalBackend *backend, EDataCal *cal, const gchar *uid, const gchar *auid)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
@@ -908,7 +915,7 @@ e_cal_backend_discard_alarm (ECalBackend *backend, EDataCal *cal, const char *ui
  * Calls the create_object method on the given backend.
  */
 void
-e_cal_backend_create_object (ECalBackend *backend, EDataCal *cal, const char *calobj)
+e_cal_backend_create_object (ECalBackend *backend, EDataCal *cal, const gchar *calobj)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
@@ -930,7 +937,7 @@ e_cal_backend_create_object (ECalBackend *backend, EDataCal *cal, const char *ca
  * Calls the modify_object method on the given backend.
  */
 void
-e_cal_backend_modify_object (ECalBackend *backend, EDataCal *cal, const char *calobj, CalObjModType mod)
+e_cal_backend_modify_object (ECalBackend *backend, EDataCal *cal, const gchar *calobj, CalObjModType mod)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
@@ -954,7 +961,7 @@ e_cal_backend_modify_object (ECalBackend *backend, EDataCal *cal, const char *ca
  * clients about the change.
  */
 void
-e_cal_backend_remove_object (ECalBackend *backend, EDataCal *cal, const char *uid, const char *rid, CalObjModType mod)
+e_cal_backend_remove_object (ECalBackend *backend, EDataCal *cal, const gchar *uid, const gchar *rid, CalObjModType mod)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
@@ -973,7 +980,7 @@ e_cal_backend_remove_object (ECalBackend *backend, EDataCal *cal, const char *ui
  * Calls the receive_objects method on the given backend.
  */
 void
-e_cal_backend_receive_objects (ECalBackend *backend, EDataCal *cal, const char *calobj)
+e_cal_backend_receive_objects (ECalBackend *backend, EDataCal *cal, const gchar *calobj)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
@@ -992,7 +999,7 @@ e_cal_backend_receive_objects (ECalBackend *backend, EDataCal *cal, const char *
  * Calls the send_objects method on the given backend.
  */
 void
-e_cal_backend_send_objects (ECalBackend *backend, EDataCal *cal, const char *calobj)
+e_cal_backend_send_objects (ECalBackend *backend, EDataCal *cal, const gchar *calobj)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
@@ -1013,7 +1020,7 @@ e_cal_backend_send_objects (ECalBackend *backend, EDataCal *cal, const char *cal
  * can't be found.
  */
 void
-e_cal_backend_get_timezone (ECalBackend *backend, EDataCal *cal, const char *tzid)
+e_cal_backend_get_timezone (ECalBackend *backend, EDataCal *cal, const gchar *tzid)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
@@ -1033,7 +1040,7 @@ e_cal_backend_get_timezone (ECalBackend *backend, EDataCal *cal, const char *tzi
  * DATE and floating DATE-TIME values.
  */
 void
-e_cal_backend_set_default_zone (ECalBackend *backend, EDataCal *cal, const char *tzobj)
+e_cal_backend_set_default_zone (ECalBackend *backend, EDataCal *cal, const gchar *tzobj)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
@@ -1057,7 +1064,7 @@ e_cal_backend_set_default_zone (ECalBackend *backend, EDataCal *cal, const char
  *
  */
 void
-e_cal_backend_set_default_timezone (ECalBackend *backend, EDataCal *cal, const char *tzid)
+e_cal_backend_set_default_timezone (ECalBackend *backend, EDataCal *cal, const gchar *tzid)
 {
 	g_return_if_fail (backend != NULL);
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
@@ -1075,7 +1082,7 @@ e_cal_backend_set_default_timezone (ECalBackend *backend, EDataCal *cal, const c
  * Add a timezone object to the given backend.
  */
 void
-e_cal_backend_add_timezone (ECalBackend *backend, EDataCal *cal, const char *tzobj)
+e_cal_backend_add_timezone (ECalBackend *backend, EDataCal *cal, const gchar *tzobj)
 {
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
 	g_return_if_fail (tzobj != NULL);
@@ -1107,7 +1114,7 @@ e_cal_backend_internal_get_default_timezone (ECalBackend *backend)
  * Calls the internal_get_timezone method on the given backend.
  */
 icaltimezone *
-e_cal_backend_internal_get_timezone (ECalBackend *backend, const char *tzid)
+e_cal_backend_internal_get_timezone (ECalBackend *backend, const gchar *tzid)
 {
 	g_return_val_if_fail (E_IS_CAL_BACKEND (backend), NULL);
 	g_return_val_if_fail (tzid != NULL, NULL);
@@ -1147,7 +1154,7 @@ e_cal_backend_set_notification_proxy (ECalBackend *backend, ECalBackend *proxy)
  * created by non-EDS clients.
  **/
 void
-e_cal_backend_notify_object_created (ECalBackend *backend, const char *calobj)
+e_cal_backend_notify_object_created (ECalBackend *backend, const gchar *calobj)
 {
 	ECalBackendPrivate *priv;
 	EList *queries;
@@ -1178,7 +1185,7 @@ e_cal_backend_notify_object_created (ECalBackend *backend, const char *calobj)
 }
 
 static void
-match_query_and_notify (EDataCalView *query, const char *old_object, const char *object)
+match_query_and_notify (EDataCalView *query, const gchar *old_object, const gchar *object)
 {
 	gboolean old_match = FALSE, new_match = FALSE;
 
@@ -1231,7 +1238,7 @@ e_cal_backend_notify_view_progress_start (ECalBackend *backend)
  * Notifies each of the backend's listeners about the view_progress in downloading the items.
  **/
 void
-e_cal_backend_notify_view_progress (ECalBackend *backend, const char *message, int percent)
+e_cal_backend_notify_view_progress (ECalBackend *backend, const gchar *message, gint percent)
 {
 	ECalBackendPrivate *priv;
 	EList *queries;
@@ -1320,7 +1327,7 @@ e_cal_backend_notify_view_done (ECalBackend *backend, GNOME_Evolution_Calendar_C
  **/
 void
 e_cal_backend_notify_object_modified (ECalBackend *backend,
-				      const char *old_object, const char *object)
+				      const gchar *old_object, const gchar *object)
 {
 	ECalBackendPrivate *priv;
 	EList *queries;
@@ -1366,7 +1373,7 @@ e_cal_backend_notify_object_modified (ECalBackend *backend,
  **/
 void
 e_cal_backend_notify_object_removed (ECalBackend *backend, const ECalComponentId *id,
-				     const char *old_object, const char *object)
+				     const gchar *old_object, const gchar *object)
 {
 	ECalBackendPrivate *priv;
 	EList *queries;
@@ -1403,6 +1410,25 @@ e_cal_backend_notify_object_removed (ECalBackend *backend, const ECalComponentId
 	g_object_unref (iter);
 }
 
+
+void
+e_cal_backend_notify_objects_added (ECalBackend *backend, EDataCalView *query, const GList *objects)
+{
+	e_data_cal_view_notify_objects_added (query, objects);
+}
+
+void
+e_cal_backend_notify_objects_removed (ECalBackend *backend, EDataCalView *query, const GList *ids)
+{
+	e_data_cal_view_notify_objects_removed (query, ids);
+}
+
+void
+e_cal_backend_notify_objects_modified (ECalBackend *backend, EDataCalView *query, const GList *objects)
+{
+	e_data_cal_view_notify_objects_modified (query, objects);
+}
+
 /**
  * e_cal_backend_notify_mode:
  * @backend: A calendar backend.
@@ -1454,7 +1480,7 @@ e_cal_backend_notify_auth_required (ECalBackend *backend)
  * Notifies each of the backend's listeners about an error
  **/
 void
-e_cal_backend_notify_error (ECalBackend *backend, const char *message)
+e_cal_backend_notify_error (ECalBackend *backend, const gchar *message)
 {
 	ECalBackendPrivate *priv = backend->priv;
 	GList *l;
@@ -1467,3 +1493,49 @@ e_cal_backend_notify_error (ECalBackend *backend, const char *message)
 	for (l = priv->clients; l; l = l->next)
 		e_data_cal_notify_error (l->data, message);
 }
+
+/**
+ * e_cal_backend_empty_cache:
+ * @backend: A calendar backend.
+ * @cache: Backend's cache to empty.
+ *
+ * Empties backend's cache with all notifications and so on, thus all listening
+ * will know there is nothing in this backend.
+ **/
+void
+e_cal_backend_empty_cache (ECalBackend *backend, ECalBackendCache *cache)
+{
+	GList *comps_in_cache;
+
+	g_return_if_fail (backend != NULL);
+	g_return_if_fail (E_IS_CAL_BACKEND (backend));
+
+	if (!cache)
+		return;
+
+	g_return_if_fail (E_IS_CAL_BACKEND_CACHE (cache));
+
+	e_file_cache_freeze_changes (E_FILE_CACHE (cache));
+
+	for (comps_in_cache = e_cal_backend_cache_get_components (cache);
+	     comps_in_cache;
+	     comps_in_cache = comps_in_cache->next) {
+		gchar *comp_str;
+		ECalComponentId *id;
+		ECalComponent *comp = comps_in_cache->data;
+
+		id = e_cal_component_get_id (comp);
+		comp_str = e_cal_component_get_as_string (comp);
+
+		e_cal_backend_cache_remove_component (cache, id->uid, id->rid);
+		e_cal_backend_notify_object_removed (backend, id, comp_str, NULL);
+
+		g_free (comp_str);
+		e_cal_component_free_id (id);
+		g_object_unref (comp);
+	}
+
+	g_list_free (comps_in_cache);
+
+	e_file_cache_thaw_changes (E_FILE_CACHE (cache));
+}
