@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2001-2003 Ximian Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Authors: Michael Zucchi <notzed@ximian.com>
  *
@@ -35,10 +35,9 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 
-#include <libedataserver/e-msgport.h>
-
 #include "camel-block-file.h"
 #include "camel-file-utils.h"
+#include "camel-list-utils.h"
 #include "camel-private.h"
 
 #define d(x) /*(printf("%s(%d):%s: ",  __FILE__, __LINE__, __PRETTY_FUNCTION__),(x))*/
@@ -51,12 +50,12 @@ struct _CamelBlockFilePrivate {
 	struct _CamelBlockFilePrivate *prev;
 
 	struct _CamelBlockFile *base;
-	
+
 	pthread_mutex_t root_lock; /* for modifying the root block */
 	pthread_mutex_t cache_lock; /* for refcounting, flag manip, cache manip */
 	pthread_mutex_t io_lock; /* for all io ops */
-	
-	unsigned int deleted:1;
+
+	guint deleted:1;
 };
 
 
@@ -70,35 +69,35 @@ struct _CamelBlockFilePrivate {
 static pthread_mutex_t block_file_lock = PTHREAD_MUTEX_INITIALIZER;
 
 /* lru cache of block files */
-static EDList block_file_list = E_DLIST_INITIALISER(block_file_list);
+static CamelDList block_file_list = CAMEL_DLIST_INITIALISER(block_file_list);
 /* list to store block files that are actually intialised */
-static EDList block_file_active_list = E_DLIST_INITIALISER(block_file_active_list);
-static int block_file_count = 0;
-static int block_file_threshhold = 10;
+static CamelDList block_file_active_list = CAMEL_DLIST_INITIALISER(block_file_active_list);
+static gint block_file_count = 0;
+static gint block_file_threshhold = 10;
 
 #define CBF_CLASS(o) ((CamelBlockFileClass *)(((CamelObject *)o)->klass))
 
-static int sync_nolock(CamelBlockFile *bs);
-static int sync_block_nolock(CamelBlockFile *bs, CamelBlock *bl);
+static gint sync_nolock(CamelBlockFile *bs);
+static gint sync_block_nolock(CamelBlockFile *bs, CamelBlock *bl);
 
-static int
+static gint
 block_file_validate_root(CamelBlockFile *bs)
 {
 	CamelBlockRoot *br;
 	struct stat st;
-	int retval;
-	
+	gint retval;
+
 	br = bs->root;
-	
+
 	retval = fstat (bs->fd, &st);
-	
+
 	d(printf("Validate root: '%s'\n", bs->path));
 	d(printf("version: %.8s (%.8s)\n", bs->root->version, bs->version));
 	d(printf("block size: %d (%d)%s\n", br->block_size, bs->block_size,
 		br->block_size != bs->block_size ? " BAD":" OK"));
-	d(printf("free: %ld (%d add size < %ld)%s\n", (long)br->free, br->free / bs->block_size * bs->block_size, (long)st.st_size,
+	d(printf("free: %ld (%d add size < %ld)%s\n", (glong)br->free, br->free / bs->block_size * bs->block_size, (glong)st.st_size,
 		(br->free > st.st_size) || (br->free % bs->block_size) != 0 ? " BAD":" OK"));
-	d(printf("last: %ld (%d and size: %ld)%s\n", (long)br->last, br->last / bs->block_size * bs->block_size, (long)st.st_size,
+	d(printf("last: %ld (%d and size: %ld)%s\n", (glong)br->last, br->last / bs->block_size * bs->block_size, (glong)st.st_size,
 		(br->last != st.st_size) || ((br->last % bs->block_size) != 0) ? " BAD": " OK"));
 	d(printf("flags: %s\n", (br->flags & CAMEL_BLOCK_FILE_SYNC)?"SYNC":"unSYNC"));
 
@@ -117,9 +116,9 @@ block_file_validate_root(CamelBlockFile *bs)
 			g_warning("version: %.8s (%.8s)", bs->root->version, bs->version);
 			g_warning("block size: %d (%d)%s", br->block_size, bs->block_size,
 				  br->block_size != bs->block_size ? " BAD":" OK");
-			g_warning("free: %ld (%d add size < %ld)%s", (long)br->free, br->free / bs->block_size * bs->block_size, (long)st.st_size,
+			g_warning("free: %ld (%d add size < %ld)%s", (glong)br->free, br->free / bs->block_size * bs->block_size, (glong)st.st_size,
 				  (br->free > st.st_size) || (br->free % bs->block_size) != 0 ? " BAD":" OK");
-			g_warning("last: %ld (%d and size: %ld)%s", (long)br->last, br->last / bs->block_size * bs->block_size, (long)st.st_size,
+			g_warning("last: %ld (%d and size: %ld)%s", (glong)br->last, br->last / bs->block_size * bs->block_size, (glong)st.st_size,
 				  (br->last != st.st_size) || ((br->last % bs->block_size) != 0) ? " BAD": " OK");
 			g_warning("flags: %s", (br->flags & CAMEL_BLOCK_FILE_SYNC)?"SYNC":"unSYNC");
 		}
@@ -130,7 +129,7 @@ block_file_validate_root(CamelBlockFile *bs)
 	return 0;
 }
 
-static int
+static gint
 block_file_init_root(CamelBlockFile *bs)
 {
 	CamelBlockRoot *br = bs->root;
@@ -153,7 +152,7 @@ camel_block_file_class_init(CamelBlockFileClass *klass)
 }
 
 static guint
-block_hash_func(const void *v)
+block_hash_func(gconstpointer v)
 {
 	return ((camel_block_t) GPOINTER_TO_UINT(v)) >> CAMEL_BLOCK_SIZE_BITS;
 }
@@ -165,7 +164,7 @@ camel_block_file_init(CamelBlockFile *bs)
 
 	bs->fd = -1;
 	bs->block_size = CAMEL_BLOCK_SIZE;
-	e_dlist_init(&bs->block_cache);
+	camel_dlist_init(&bs->block_cache);
 	bs->blocks = g_hash_table_new((GHashFunc)block_hash_func, NULL);
 	/* this cache size and the text index size have been tuned for about the best
 	   with moderate memory usage.  Doubling the memory usage barely affects performance. */
@@ -173,14 +172,14 @@ camel_block_file_init(CamelBlockFile *bs)
 
 	p = bs->priv = g_malloc0(sizeof(*bs->priv));
 	p->base = bs;
-	
+
 	pthread_mutex_init(&p->root_lock, NULL);
 	pthread_mutex_init(&p->cache_lock, NULL);
 	pthread_mutex_init(&p->io_lock, NULL);
-	
+
 	/* link into lru list */
 	LOCK(block_file_lock);
-	e_dlist_addhead(&block_file_list, (EDListNode *)p);
+	camel_dlist_addhead(&block_file_list, (CamelDListNode *)p);
 
 #if 0
 	{
@@ -212,7 +211,7 @@ camel_block_file_finalise(CamelBlockFile *bs)
 	LOCK(block_file_lock);
 	if (bs->fd != -1)
 		block_file_count--;
-	e_dlist_remove((EDListNode *)p);
+	camel_dlist_remove((CamelDListNode *)p);
 	UNLOCK(block_file_lock);
 
 	bl = (CamelBlock *)bs->block_cache.head;
@@ -224,19 +223,19 @@ camel_block_file_finalise(CamelBlockFile *bs)
 		bl = bn;
 		bn = bn->next;
 	}
-	
+
 	g_hash_table_destroy (bs->blocks);
-	
+
 	if (bs->root_block)
 		camel_block_file_unref_block(bs, bs->root_block);
 	g_free(bs->path);
 	if (bs->fd != -1)
 		close(bs->fd);
-	
+
 	pthread_mutex_destroy(&p->io_lock);
 	pthread_mutex_destroy(&p->cache_lock);
 	pthread_mutex_destroy(&p->root_lock);
-	
+
 	g_free(p);
 }
 
@@ -244,7 +243,7 @@ CamelType
 camel_block_file_get_type(void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register(camel_object_get_type(), "CamelBlockFile",
 					   sizeof (CamelBlockFile),
@@ -254,17 +253,17 @@ camel_block_file_get_type(void)
 					   (CamelObjectInitFunc) camel_block_file_init,
 					   (CamelObjectFinalizeFunc) camel_block_file_finalise);
 	}
-	
+
 	return type;
 }
 
 /* 'use' a block file for io */
-static int
+static gint
 block_file_use(CamelBlockFile *bs)
 {
 	struct _CamelBlockFilePrivate *nw, *nn, *p = bs->priv;
 	CamelBlockFile *bf;
-	int err;
+	gint err;
 
 	/* We want to:
 	    remove file from active list
@@ -283,8 +282,9 @@ block_file_use(CamelBlockFile *bs)
 		CAMEL_BLOCK_FILE_UNLOCK(bs, io_lock);
 		errno = ENOENT;
 		return -1;
-	} else
+	} else {
 		d(printf("Turning block file online: %s\n", bs->path));
+	}
 
 	if ((bs->fd = g_open(bs->path, bs->flags|O_BINARY, 0600)) == -1) {
 		err = errno;
@@ -294,8 +294,8 @@ block_file_use(CamelBlockFile *bs)
 	}
 
 	LOCK(block_file_lock);
-	e_dlist_remove((EDListNode *)p);
-	e_dlist_addtail(&block_file_active_list, (EDListNode *)p);
+	camel_dlist_remove((CamelDListNode *)p);
+	camel_dlist_addtail(&block_file_active_list, (CamelDListNode *)p);
 
 	block_file_count++;
 
@@ -335,8 +335,8 @@ static void
 block_file_unuse(CamelBlockFile *bs)
 {
 	LOCK(block_file_lock);
-	e_dlist_remove((EDListNode *)bs->priv);
-	e_dlist_addtail(&block_file_list, (EDListNode *)bs->priv);
+	camel_dlist_remove((CamelDListNode *)bs->priv);
+	camel_dlist_addtail(&block_file_list, (CamelDListNode *)bs->priv);
 	UNLOCK(block_file_lock);
 
 	CAMEL_BLOCK_FILE_UNLOCK(bs, io_lock);
@@ -351,19 +351,19 @@ camel_cache_remove(c, key);
 
 /**
  * camel_block_file_new:
- * @path: 
- * @: 
- * @block_size: 
- * 
+ * @path:
+ * @:
+ * @block_size:
+ *
  * Allocate a new block file, stored at @path.  @version contains an 8 character
  * version string which must match the head of the file, or the file will be
  * intitialised.
- * 
+ *
  * @block_size is currently ignored and is set to CAMEL_BLOCK_SIZE.
  *
  * Return value: The new block file, or NULL if it could not be created.
  **/
-CamelBlockFile *camel_block_file_new(const char *path, int flags, const char version[8], size_t block_size)
+CamelBlockFile *camel_block_file_new(const gchar *path, gint flags, const gchar version[8], gsize block_size)
 {
 	CamelBlockFile *bs;
 
@@ -405,12 +405,12 @@ CamelBlockFile *camel_block_file_new(const char *path, int flags, const char ver
 	return bs;
 }
 
-int
-camel_block_file_rename(CamelBlockFile *bs, const char *path)
+gint
+camel_block_file_rename(CamelBlockFile *bs, const gchar *path)
 {
-	int ret;
+	gint ret;
 	struct stat st;
-	int err;
+	gint err;
 
 	CAMEL_BLOCK_FILE_LOCK(bs, io_lock);
 
@@ -435,10 +435,10 @@ camel_block_file_rename(CamelBlockFile *bs, const char *path)
 	return ret;
 }
 
-int
+gint
 camel_block_file_delete(CamelBlockFile *bs)
 {
-	int ret;
+	gint ret;
 	struct _CamelBlockFilePrivate *p = bs->priv;
 
 	CAMEL_BLOCK_FILE_LOCK(bs, io_lock);
@@ -457,16 +457,16 @@ camel_block_file_delete(CamelBlockFile *bs)
 	CAMEL_BLOCK_FILE_UNLOCK(bs, io_lock);
 
 	return ret;
-	
+
 }
 
 /**
  * camel_block_file_new_block:
- * @bs: 
- * 
+ * @bs:
+ *
  * Allocate a new block, return a pointer to it.  Old blocks
  * may be flushed to disk during this call.
- * 
+ *
  * Return value: The block, or NULL if an error occured.
  **/
 CamelBlock *camel_block_file_new_block(CamelBlockFile *bs)
@@ -499,12 +499,12 @@ fail:
 
 /**
  * camel_block_file_free_block:
- * @bs: 
- * @id: 
- * 
- * 
+ * @bs:
+ * @id:
+ *
+ *
  **/
-int camel_block_file_free_block(CamelBlockFile *bs, camel_block_t id)
+gint camel_block_file_free_block(CamelBlockFile *bs, camel_block_t id)
 {
 	CamelBlock *bl;
 
@@ -527,11 +527,11 @@ int camel_block_file_free_block(CamelBlockFile *bs, camel_block_t id)
 
 /**
  * camel_block_file_get_block:
- * @bs: 
- * @id: 
- * 
+ * @bs:
+ * @id:
+ *
  * Retreive a block @id.
- * 
+ *
  * Return value: The block, or NULL if blockid is invalid or a file error
  * occured.
  **/
@@ -564,7 +564,7 @@ CamelBlock *camel_block_file_get_block(CamelBlockFile *bs, camel_block_t id)
 		bl = g_malloc0(sizeof(*bl));
 		bl->id = id;
 		if (lseek(bs->fd, id, SEEK_SET) == -1 ||
-		    camel_read (bs->fd, (char *) bl->data, CAMEL_BLOCK_SIZE) == -1) {
+		    camel_read (bs->fd, (gchar *) bl->data, CAMEL_BLOCK_SIZE) == -1) {
 			block_file_unuse(bs);
 			CAMEL_BLOCK_FILE_UNLOCK(bs, cache_lock);
 			g_free(bl);
@@ -581,7 +581,7 @@ CamelBlock *camel_block_file_get_block(CamelBlockFile *bs, camel_block_t id)
 			if (flush->refcount == 0) {
 				if (sync_block_nolock(bs, flush) != -1) {
 					g_hash_table_remove(bs->blocks, GUINT_TO_POINTER(flush->id));
-					e_dlist_remove((EDListNode *)flush);
+					camel_dlist_remove((CamelDListNode *)flush);
 					g_free(flush);
 					bs->block_cache_count--;
 				}
@@ -592,10 +592,10 @@ CamelBlock *camel_block_file_get_block(CamelBlockFile *bs, camel_block_t id)
 		/* UNLOCK io_lock */
 		block_file_unuse(bs);
 	} else {
-		e_dlist_remove((EDListNode *)bl);
+		camel_dlist_remove((CamelDListNode *)bl);
 	}
 
-	e_dlist_addhead(&bs->block_cache, (EDListNode *)bl);
+	camel_dlist_addhead(&bs->block_cache, (CamelDListNode *)bl);
 	bl->refcount++;
 
 	CAMEL_BLOCK_FILE_UNLOCK(bs, cache_lock);
@@ -607,9 +607,9 @@ CamelBlock *camel_block_file_get_block(CamelBlockFile *bs, camel_block_t id)
 
 /**
  * camel_block_file_detach_block:
- * @bs: 
- * @bl: 
- * 
+ * @bs:
+ * @bl:
+ *
  * Detatch a block from the block file's cache.  The block should
  * be unref'd or attached when finished with.  The block file will
  * perform no writes of this block or flushing of it if the cache
@@ -620,7 +620,7 @@ void camel_block_file_detach_block(CamelBlockFile *bs, CamelBlock *bl)
 	CAMEL_BLOCK_FILE_LOCK(bs, cache_lock);
 
 	g_hash_table_remove(bs->blocks, GUINT_TO_POINTER(bl->id));
-	e_dlist_remove((EDListNode *)bl);
+	camel_dlist_remove((CamelDListNode *)bl);
 	bl->flags |= CAMEL_BLOCK_DETACHED;
 
 	CAMEL_BLOCK_FILE_UNLOCK(bs, cache_lock);
@@ -628,9 +628,9 @@ void camel_block_file_detach_block(CamelBlockFile *bs, CamelBlock *bl)
 
 /**
  * camel_block_file_attach_block:
- * @bs: 
- * @bl: 
- * 
+ * @bs:
+ * @bl:
+ *
  * Reattach a block that has been detached.
  **/
 void camel_block_file_attach_block(CamelBlockFile *bs, CamelBlock *bl)
@@ -638,7 +638,7 @@ void camel_block_file_attach_block(CamelBlockFile *bs, CamelBlock *bl)
 	CAMEL_BLOCK_FILE_LOCK(bs, cache_lock);
 
 	g_hash_table_insert(bs->blocks, GUINT_TO_POINTER(bl->id), bl);
-	e_dlist_addtail(&bs->block_cache, (EDListNode *)bl);
+	camel_dlist_addtail(&bs->block_cache, (CamelDListNode *)bl);
 	bl->flags &= ~CAMEL_BLOCK_DETACHED;
 
 	CAMEL_BLOCK_FILE_UNLOCK(bs, cache_lock);
@@ -646,9 +646,9 @@ void camel_block_file_attach_block(CamelBlockFile *bs, CamelBlock *bl)
 
 /**
  * camel_block_file_touch_block:
- * @bs: 
- * @bl: 
- * 
+ * @bs:
+ * @bl:
+ *
  * Mark a block as dirty.  The block will be written to disk if
  * it ever expires from the cache.
  **/
@@ -672,9 +672,9 @@ void camel_block_file_touch_block(CamelBlockFile *bs, CamelBlock *bl)
 
 /**
  * camel_block_file_unref_block:
- * @bs: 
- * @bl: 
- * 
+ * @bs:
+ * @bl:
+ *
  * Mark a block as unused.  If a block is used it will not be
  * written to disk, or flushed from memory.
  *
@@ -693,7 +693,7 @@ void camel_block_file_unref_block(CamelBlockFile *bs, CamelBlock *bl)
 	CAMEL_BLOCK_FILE_UNLOCK(bs, cache_lock);
 }
 
-static int
+static gint
 sync_block_nolock(CamelBlockFile *bs, CamelBlock *bl)
 {
 	d(printf("Sync block %08x: %s\n", bl->id, (bl->flags & CAMEL_BLOCK_DIRTY)?"dirty":"clean"));
@@ -709,11 +709,11 @@ sync_block_nolock(CamelBlockFile *bs, CamelBlock *bl)
 	return 0;
 }
 
-static int
+static gint
 sync_nolock(CamelBlockFile *bs)
 {
 	CamelBlock *bl, *bn;
-	int work = FALSE;
+	gint work = FALSE;
 
 	bl = (CamelBlock *)bs->block_cache.head;
 	bn = bl->next;
@@ -742,17 +742,17 @@ sync_nolock(CamelBlockFile *bs)
 
 /**
  * camel_block_file_sync_block:
- * @bs: 
- * @bl: 
- * 
+ * @bs:
+ * @bl:
+ *
  * Flush a block to disk immediately.  The block will only
  * be flushed to disk if it is marked as dirty (touched).
- * 
+ *
  * Return value: -1 on io error.
  **/
-int camel_block_file_sync_block(CamelBlockFile *bs, CamelBlock *bl)
+gint camel_block_file_sync_block(CamelBlockFile *bs, CamelBlock *bl)
 {
-	int ret;
+	gint ret;
 
 	/* LOCK io_lock */
 	if (block_file_use(bs) == -1)
@@ -767,15 +767,15 @@ int camel_block_file_sync_block(CamelBlockFile *bs, CamelBlock *bl)
 
 /**
  * camel_block_file_sync:
- * @bs: 
- * 
+ * @bs:
+ *
  * Sync all dirty blocks to disk, including the root block.
- * 
+ *
  * Return value: -1 on io error.
  **/
-int camel_block_file_sync(CamelBlockFile *bs)
+gint camel_block_file_sync(CamelBlockFile *bs)
 {
-	int ret;
+	gint ret;
 
 	CAMEL_BLOCK_FILE_LOCK(bs, root_lock);
 	CAMEL_BLOCK_FILE_LOCK(bs, cache_lock);
@@ -802,7 +802,7 @@ struct _CamelKeyFilePrivate {
 
 	struct _CamelKeyFile *base;
 	pthread_mutex_t lock;
-	unsigned int deleted:1;
+	guint deleted:1;
 };
 
 #define CAMEL_KEY_FILE_LOCK(kf, lock) (pthread_mutex_lock(&(kf)->priv->lock))
@@ -812,10 +812,10 @@ struct _CamelKeyFilePrivate {
 static pthread_mutex_t key_file_lock = PTHREAD_MUTEX_INITIALIZER;
 
 /* lru cache of block files */
-static EDList key_file_list = E_DLIST_INITIALISER(key_file_list);
-static EDList key_file_active_list = E_DLIST_INITIALISER(key_file_active_list);
-static int key_file_count = 0;
-static const int key_file_threshhold = 10;
+static CamelDList key_file_list = CAMEL_DLIST_INITIALISER(key_file_list);
+static CamelDList key_file_active_list = CAMEL_DLIST_INITIALISER(key_file_active_list);
+static gint key_file_count = 0;
+static const gint key_file_threshhold = 10;
 
 static void
 camel_key_file_class_init(CamelKeyFileClass *klass)
@@ -829,11 +829,11 @@ camel_key_file_init(CamelKeyFile *bs)
 
 	p = bs->priv = g_malloc0(sizeof(*bs->priv));
 	p->base = bs;
-	
+
 	pthread_mutex_init(&p->lock, NULL);
-	
+
 	LOCK(key_file_lock);
-	e_dlist_addhead(&key_file_list, (EDListNode *)p);
+	camel_dlist_addhead(&key_file_list, (CamelDListNode *)p);
 	UNLOCK(key_file_lock);
 }
 
@@ -843,7 +843,7 @@ camel_key_file_finalise(CamelKeyFile *bs)
 	struct _CamelKeyFilePrivate *p = bs->priv;
 
 	LOCK(key_file_lock);
-	e_dlist_remove((EDListNode *)p);
+	camel_dlist_remove((CamelDListNode *)p);
 
 	if (bs-> fp) {
 		key_file_count--;
@@ -853,9 +853,9 @@ camel_key_file_finalise(CamelKeyFile *bs)
 	UNLOCK(key_file_lock);
 
 	g_free(bs->path);
-	
+
 	pthread_mutex_destroy(&p->lock);
-	
+
 	g_free(p);
 }
 
@@ -863,7 +863,7 @@ CamelType
 camel_key_file_get_type(void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register(camel_object_get_type(), "CamelKeyFile",
 					   sizeof (CamelKeyFile),
@@ -873,18 +873,18 @@ camel_key_file_get_type(void)
 					   (CamelObjectInitFunc) camel_key_file_init,
 					   (CamelObjectFinalizeFunc) camel_key_file_finalise);
 	}
-	
+
 	return type;
 }
 
 /* 'use' a key file for io */
-static int
+static gint
 key_file_use(CamelKeyFile *bs)
 {
 	struct _CamelKeyFilePrivate *nw, *nn, *p = bs->priv;
 	CamelKeyFile *bf;
-	int err, fd;
-	char *flag;
+	gint err, fd;
+	const gchar *flag;
 
 	/* We want to:
 	    remove file from active list
@@ -905,8 +905,9 @@ key_file_use(CamelKeyFile *bs)
 		CAMEL_KEY_FILE_UNLOCK(bs, lock);
 		errno = ENOENT;
 		return -1;
-	} else
+	} else {
 		d(printf("Turning key file online: '%s'\n", bs->path));
+	}
 
 	if ((bs->flags & O_ACCMODE) == O_RDONLY)
 		flag = "rb";
@@ -924,8 +925,8 @@ key_file_use(CamelKeyFile *bs)
 	}
 
 	LOCK(key_file_lock);
-	e_dlist_remove((EDListNode *)p);
-	e_dlist_addtail(&key_file_active_list, (EDListNode *)p);
+	camel_dlist_remove((CamelDListNode *)p);
+	camel_dlist_addtail(&key_file_active_list, (CamelDListNode *)p);
 
 	key_file_count++;
 
@@ -958,8 +959,8 @@ static void
 key_file_unuse(CamelKeyFile *bs)
 {
 	LOCK(key_file_lock);
-	e_dlist_remove((EDListNode *)bs->priv);
-	e_dlist_addtail(&key_file_list, (EDListNode *)bs->priv);
+	camel_dlist_remove((CamelDListNode *)bs->priv);
+	camel_dlist_addtail(&key_file_list, (CamelDListNode *)bs->priv);
 	UNLOCK(key_file_lock);
 
 	CAMEL_KEY_FILE_UNLOCK(bs, lock);
@@ -967,22 +968,22 @@ key_file_unuse(CamelKeyFile *bs)
 
 /**
  * camel_key_file_new:
- * @path: 
+ * @path:
  * @flags: open flags
  * @version: Version string (header) of file.  Currently
  * written but not checked.
- * 
+ *
  * Create a new key file.  A linked list of record blocks.
- * 
+ *
  * Return value: A new key file, or NULL if the file could not
  * be opened/created/initialised.
  **/
 CamelKeyFile *
-camel_key_file_new(const char *path, int flags, const char version[8])
+camel_key_file_new(const gchar *path, gint flags, const gchar version[8])
 {
 	CamelKeyFile *kf;
 	off_t last;
-	int err;
+	gint err;
 
 	d(printf("New key file '%s'\n", path));
 
@@ -1019,12 +1020,12 @@ camel_key_file_new(const char *path, int flags, const char version[8])
 	return kf;
 }
 
-int
-camel_key_file_rename(CamelKeyFile *kf, const char *path)
+gint
+camel_key_file_rename(CamelKeyFile *kf, const gchar *path)
 {
-	int ret;
+	gint ret;
 	struct stat st;
-	int err;
+	gint err;
 
 	CAMEL_KEY_FILE_LOCK(kf, lock);
 
@@ -1049,10 +1050,10 @@ camel_key_file_rename(CamelKeyFile *kf, const char *path)
 	return ret;
 }
 
-int
+gint
 camel_key_file_delete(CamelKeyFile *kf)
 {
-	int ret;
+	gint ret;
 	struct _CamelKeyFilePrivate *p = kf->priv;
 
 	CAMEL_KEY_FILE_LOCK(kf, lock);
@@ -1071,26 +1072,26 @@ camel_key_file_delete(CamelKeyFile *kf)
 	CAMEL_KEY_FILE_UNLOCK(kf, lock);
 
 	return ret;
-	
+
 }
 
 /**
  * camel_key_file_write:
- * @kf: 
- * @parent: 
- * @len: 
- * @records: 
- * 
+ * @kf:
+ * @parent:
+ * @len:
+ * @records:
+ *
  * Write a new list of records to the key file.
- * 
+ *
  * Return value: -1 on io error.  The key file will remain unchanged.
  **/
-int
-camel_key_file_write(CamelKeyFile *kf, camel_block_t *parent, size_t len, camel_key_t *records)
+gint
+camel_key_file_write(CamelKeyFile *kf, camel_block_t *parent, gsize len, camel_key_t *records)
 {
 	camel_block_t next;
 	guint32 size;
-	int ret = -1;
+	gint ret = -1;
 
 	d(printf("write key %08x len = %d\n", *parent, len));
 
@@ -1130,23 +1131,23 @@ camel_key_file_write(CamelKeyFile *kf, camel_block_t *parent, size_t len, camel_
 
 /**
  * camel_key_file_read:
- * @kf: 
+ * @kf:
  * @start: The record pointer.  This will be set to the next record pointer on success.
  * @len: Number of records read, if != NULL.
  * @records: Records, allocated, must be freed with g_free, if != NULL.
- * 
+ *
  * Read the next block of data from the key file.  Returns the number of
  * records.
- * 
+ *
  * Return value: -1 on io error.
  **/
-int
-camel_key_file_read(CamelKeyFile *kf, camel_block_t *start, size_t *len, camel_key_t **records)
+gint
+camel_key_file_read(CamelKeyFile *kf, camel_block_t *start, gsize *len, camel_key_t **records)
 {
 	guint32 size;
-	long pos = *start;
+	glong pos = *start;
 	camel_block_t next;
-	int ret = -1;
+	gint ret = -1;
 
 	if (pos == 0)
 		return 0;
