@@ -5,8 +5,8 @@
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -44,7 +44,7 @@
 #include "camel-stream-mem.h"
 #include "camel-file-utils.h"
 
-extern int camel_verbose_debug;
+extern gint camel_verbose_debug;
 #define dd(x) (camel_verbose_debug?(x):0)
 #define d(x)
 
@@ -92,7 +92,7 @@ static void data_cache_finalise(CamelDataCache *cdc)
 	p = cdc->priv;
 	camel_object_bag_destroy(p->busy_bag);
 	g_free(p);
-	
+
 	g_free (cdc->path);
 }
 
@@ -100,7 +100,7 @@ CamelType
 camel_data_cache_get_type(void)
 {
 	static CamelType camel_data_cache_type = CAMEL_INVALID_TYPE;
-	
+
 	if (camel_data_cache_type == CAMEL_INVALID_TYPE) {
 		camel_data_cache_type = camel_type_register(
 			CAMEL_OBJECT_TYPE, "CamelDataCache",
@@ -119,15 +119,15 @@ camel_data_cache_get_type(void)
  * camel_data_cache_new:
  * @path: Base path of cache, subdirectories will be created here.
  * @flags: Open flags, none defined.
- * @ex: 
- * 
+ * @ex:
+ *
  * Create a new data cache.
- * 
+ *
  * Return value: A new cache object, or NULL if the base path cannot
  * be written to.
  **/
 CamelDataCache *
-camel_data_cache_new(const char *path, guint32 flags, CamelException *ex)
+camel_data_cache_new(const gchar *path, guint32 flags, CamelException *ex)
 {
 	CamelDataCache *cdc;
 
@@ -151,9 +151,9 @@ camel_data_cache_new(const char *path, guint32 flags, CamelException *ex)
  * camel_data_cache_set_expire_age:
  * @cdc: A #CamelDataCache
  * @when: Timeout for age expiry, or -1 to disable.
- * 
+ *
  * Set the cache expiration policy for aged entries.
- * 
+ *
  * Items in the cache older than @when seconds may be
  * flushed at any time.  Items are expired in a lazy
  * manner, so it is indeterminate when the items will
@@ -172,7 +172,7 @@ camel_data_cache_set_expire_age(CamelDataCache *cdc, time_t when)
  * camel_data_cache_set_expire_access:
  * @cdc: A #CamelDataCache
  * @when: Timeout for access, or -1 to disable access expiry.
- * 
+ *
  * Set the cache expiration policy for access times.
  *
  * Items in the cache which haven't been accessed for @when
@@ -190,10 +190,10 @@ camel_data_cache_set_expire_access(CamelDataCache *cdc, time_t when)
 }
 
 static void
-data_cache_expire(CamelDataCache *cdc, const char *path, const char *keep, time_t now)
+data_cache_expire(CamelDataCache *cdc, const gchar *path, const gchar *keep, time_t now)
 {
 	GDir *dir;
-	const char *dname;
+	const gchar *dname;
 	GString *s;
 	struct stat st;
 	CamelStream *stream;
@@ -206,7 +206,7 @@ data_cache_expire(CamelDataCache *cdc, const char *path, const char *keep, time_
 	while ( (dname = g_dir_read_name(dir)) ) {
 		if (strcmp(dname, keep) == 0)
 			continue;
-		
+
 		g_string_printf (s, "%s/%s", path, dname);
 		dd(printf("Checking '%s' for expiry\n", s->str));
 		if (g_stat(s->str, &st) == 0
@@ -230,18 +230,18 @@ data_cache_expire(CamelDataCache *cdc, const char *path, const char *keep, time_
    lazily expire old data.
    If it is this directories 'turn', and we haven't done it for CYCLE_TIME seconds,
    then we perform an expiry run */
-static char *
-data_cache_path(CamelDataCache *cdc, int create, const char *path, const char *key)
+static gchar *
+data_cache_path(CamelDataCache *cdc, gint create, const gchar *path, const gchar *key)
 {
-	char *dir, *real, *tmp;
+	gchar *dir, *real, *tmp;
 	guint32 hash;
 
 	hash = g_str_hash(key);
 	hash = (hash>>5)&CAMEL_DATA_CACHE_MASK;
 	dir = alloca(strlen(cdc->path) + strlen(path) + 8);
 	sprintf(dir, "%s/%s/%02x", cdc->path, path, hash);
-	
-#ifdef G_OS_WIN32 
+
+#ifdef G_OS_WIN32
 	if (g_access(dir, F_OK) == -1) {
 #else
 	if (access (dir, F_OK) == -1) {
@@ -273,13 +273,13 @@ data_cache_path(CamelDataCache *cdc, int create, const char *path, const char *k
  * @cdc: A #CamelDataCache
  * @path: Relative path of item to add.
  * @key: Key of item to add.
- * @ex: 
- * 
+ * @ex:
+ *
  * Add a new item to the cache.
  *
  * The key and the path combine to form a unique key used to store
  * the item.
- * 
+ *
  * Potentially, expiry processing will be performed while this call
  * is executing.
  *
@@ -287,9 +287,9 @@ data_cache_path(CamelDataCache *cdc, int create, const char *path, const char *k
  * The caller must unref this when finished.
  **/
 CamelStream *
-camel_data_cache_add(CamelDataCache *cdc, const char *path, const char *key, CamelException *ex)
+camel_data_cache_add(CamelDataCache *cdc, const gchar *path, const gchar *key, CamelException *ex)
 {
-	char *real;
+	gchar *real;
 	CamelStream *stream;
 
 	real = data_cache_path(cdc, TRUE, path, key);
@@ -321,19 +321,19 @@ camel_data_cache_add(CamelDataCache *cdc, const char *path, const char *key, Cam
  * @cdc: A #CamelDataCache
  * @path: Path to the (sub) cache the item exists in.
  * @key: Key for the cache item.
- * @ex: 
- * 
+ * @ex:
+ *
  * Lookup an item in the cache.  If the item exists, a stream
  * is returned for the item.  The stream may be shared by
  * multiple callers, so ensure the stream is in a valid state
  * through external locking.
- * 
+ *
  * Return value: A cache item, or NULL if the cache item does not exist.
  **/
 CamelStream *
-camel_data_cache_get(CamelDataCache *cdc, const char *path, const char *key, CamelException *ex)
+camel_data_cache_get(CamelDataCache *cdc, const gchar *path, const gchar *key, CamelException *ex)
 {
-	char *real;
+	gchar *real;
 	CamelStream *stream;
 
 	real = data_cache_path(cdc, FALSE, path, key);
@@ -350,23 +350,45 @@ camel_data_cache_get(CamelDataCache *cdc, const char *path, const char *key, Cam
 	return stream;
 }
 
+
+/**
+ * camel_data_cache_get_filename:
+ * @cdc: A #CamelDataCache
+ * @path: Path to the (sub) cache the item exists in.
+ * @key: Key for the cache item.
+ * @ex:
+ *
+ * Lookup the filename for an item in the cache
+ *
+ * Return value: The filename for a cache item
+ **/
+gchar *
+camel_data_cache_get_filename (CamelDataCache *cdc, const gchar *path, const gchar *key, CamelException *ex)
+{
+	gchar *real;
+
+	real = data_cache_path(cdc, FALSE, path, key);
+
+	return real;
+}
+
 /**
  * camel_data_cache_remove:
  * @cdc: A #CamelDataCache
- * @path: 
- * @key: 
- * @ex: 
- * 
+ * @path:
+ * @key:
+ * @ex:
+ *
  * Remove/expire a cache item.
- * 
- * Return value: 
+ *
+ * Return value:
  **/
-int
-camel_data_cache_remove(CamelDataCache *cdc, const char *path, const char *key, CamelException *ex)
+gint
+camel_data_cache_remove(CamelDataCache *cdc, const gchar *path, const gchar *key, CamelException *ex)
 {
 	CamelStream *stream;
-	char *real;
-	int ret;
+	gchar *real;
+	gint ret;
 
 	real = data_cache_path(cdc, FALSE, path, key);
 	stream = camel_object_bag_get(cdc->priv->busy_bag, real);
@@ -392,20 +414,20 @@ camel_data_cache_remove(CamelDataCache *cdc, const char *path, const char *key,
 
 /**
  * camel_data_cache_rename:
- * @cache: 
- * @old: 
- * @new: 
- * @ex: 
- * 
+ * @cache:
+ * @old:
+ * @new:
+ * @ex:
+ *
  * Rename a cache path.  All cache items accessed from the old path
  * are accessible using the new path.
  *
  * CURRENTLY UNIMPLEMENTED
- * 
+ *
  * Return value: -1 on error.
  **/
-int camel_data_cache_rename(CamelDataCache *cache,
-			    const char *old, const char *new, CamelException *ex)
+gint camel_data_cache_rename(CamelDataCache *cache,
+			    const gchar *old, const gchar *new, CamelException *ex)
 {
 	/* blah dont care yet */
 	return -1;
@@ -413,19 +435,18 @@ int camel_data_cache_rename(CamelDataCache *cache,
 
 /**
  * camel_data_cache_clear:
- * @cache: 
- * @path: Path to clear, or NULL to clear all items in
- * all paths.
- * @ex: 
- * 
+ * @cache:
+ * @path: Path to clear, or NULL to clear all items in all paths.
+ * @ex:
+ *
  * Clear all items in a given cache path or all items in the cache.
- * 
+ *
  * CURRENTLY_UNIMPLEMENTED
  *
  * Return value: -1 on error.
  **/
-int
-camel_data_cache_clear(CamelDataCache *cache, const char *path, CamelException *ex)
+gint
+camel_data_cache_clear(CamelDataCache *cache, const gchar *path, CamelException *ex)
 {
 	/* nor for this? */
 	return -1;
