@@ -42,10 +42,10 @@ static CamelObjectClass *parent_class = NULL;
 /* Returns the class for a CamelDataWrapper */
 #define CDW_CLASS(so) CAMEL_DATA_WRAPPER_CLASS (CAMEL_OBJECT_GET_CLASS(so))
 
-static int construct_from_stream(CamelDataWrapper *, CamelStream *);
-static ssize_t write_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream);
-static ssize_t decode_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream);
-static void set_mime_type (CamelDataWrapper *data_wrapper, const char *mime_type);
+static gint construct_from_stream(CamelDataWrapper *, CamelStream *);
+static gssize write_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream);
+static gssize decode_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream);
+static void set_mime_type (CamelDataWrapper *data_wrapper, const gchar *mime_type);
 static gchar *get_mime_type (CamelDataWrapper *data_wrapper);
 static CamelContentType *get_mime_type_field (CamelDataWrapper *data_wrapper);
 static void set_mime_type_field (CamelDataWrapper *data_wrapper, CamelContentType *mime_type);
@@ -71,10 +71,10 @@ static void
 camel_data_wrapper_init (gpointer object, gpointer klass)
 {
 	CamelDataWrapper *camel_data_wrapper = CAMEL_DATA_WRAPPER (object);
-	
+
 	camel_data_wrapper->priv = g_malloc (sizeof (struct _CamelDataWrapperPrivate));
 	pthread_mutex_init (&camel_data_wrapper->priv->stream_lock, NULL);
-	
+
 	camel_data_wrapper->mime_type = camel_content_type_new ("application", "octet-stream");
 	camel_data_wrapper->encoding = CAMEL_TRANSFER_ENCODING_DEFAULT;
 	camel_data_wrapper->offline = FALSE;
@@ -84,14 +84,14 @@ static void
 camel_data_wrapper_finalize (CamelObject *object)
 {
 	CamelDataWrapper *camel_data_wrapper = CAMEL_DATA_WRAPPER (object);
-	
+
 	pthread_mutex_destroy (&camel_data_wrapper->priv->stream_lock);
-	
+
 	g_free (camel_data_wrapper->priv);
-	
+
 	if (camel_data_wrapper->mime_type)
 		camel_content_type_unref (camel_data_wrapper->mime_type);
-	
+
 	if (camel_data_wrapper->stream)
 		camel_object_unref (camel_data_wrapper->stream);
 }
@@ -100,7 +100,7 @@ CamelType
 camel_data_wrapper_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (CAMEL_OBJECT_TYPE,
 					    "CamelDataWrapper",
@@ -111,7 +111,7 @@ camel_data_wrapper_get_type (void)
 					    (CamelObjectInitFunc) camel_data_wrapper_init,
 					    (CamelObjectFinalizeFunc) camel_data_wrapper_finalize);
 	}
-	
+
 	return type;
 }
 
@@ -121,7 +121,7 @@ camel_data_wrapper_get_type (void)
  *
  * Create a new #CamelDataWrapper object.
  *
- * Returns a new #CamelDataWrapper object
+ * Returns: a new #CamelDataWrapper object
  **/
 CamelDataWrapper *
 camel_data_wrapper_new (void)
@@ -129,25 +129,25 @@ camel_data_wrapper_new (void)
 	return (CamelDataWrapper *) camel_object_new (CAMEL_DATA_WRAPPER_TYPE);
 }
 
-static ssize_t
+static gssize
 write_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream)
 {
-	ssize_t ret;
-	
+	gssize ret;
+
 	if (data_wrapper->stream == NULL) {
 		return -1;
 	}
-	
+
 	CAMEL_DATA_WRAPPER_LOCK (data_wrapper, stream_lock);
 	if (camel_stream_reset (data_wrapper->stream) == -1) {
 		CAMEL_DATA_WRAPPER_UNLOCK (data_wrapper, stream_lock);
 		return -1;
 	}
-	
+
 	ret = camel_stream_write_to_stream (data_wrapper->stream, stream);
-	
+
 	CAMEL_DATA_WRAPPER_UNLOCK (data_wrapper, stream_lock);
-	
+
 	return ret;
 }
 
@@ -162,9 +162,9 @@ write_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream)
  * equivalent data wrapper object later by passing this stream to
  * #camel_data_wrapper_construct_from_stream.
  *
- * Returns the number of bytes written, or %-1 on fail
+ * Returns: the number of bytes written, or %-1 on fail
  **/
-ssize_t
+gssize
 camel_data_wrapper_write_to_stream (CamelDataWrapper *data_wrapper,
 				    CamelStream *stream)
 {
@@ -175,15 +175,15 @@ camel_data_wrapper_write_to_stream (CamelDataWrapper *data_wrapper,
 }
 
 
-static ssize_t
+static gssize
 decode_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream)
 {
 	CamelMimeFilter *filter;
 	CamelStream *fstream;
-	ssize_t ret;
-	
+	gssize ret;
+
 	fstream = (CamelStream *) camel_stream_filter_new_with_stream (stream);
-	
+
 	switch (data_wrapper->encoding) {
 	case CAMEL_TRANSFER_ENCODING_BASE64:
 		filter = (CamelMimeFilter *) camel_mime_filter_basic_new_type (CAMEL_MIME_FILTER_BASIC_BASE64_DEC);
@@ -203,18 +203,18 @@ decode_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream)
 	default:
 		break;
 	}
-	
+
 	if (camel_content_type_is (data_wrapper->mime_type, "text", "*")) {
 		filter = camel_mime_filter_crlf_new (CAMEL_MIME_FILTER_CRLF_DECODE,
 						     CAMEL_MIME_FILTER_CRLF_MODE_CRLF_ONLY);
 		camel_stream_filter_add (CAMEL_STREAM_FILTER (fstream), filter);
 		camel_object_unref (filter);
 	}
-	
+
 	ret = camel_data_wrapper_write_to_stream (data_wrapper, fstream);
 	camel_stream_flush (fstream);
 	camel_object_unref (fstream);
-	
+
 	return ret;
 }
 
@@ -226,25 +226,25 @@ decode_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream)
  *
  * Writes the decoded data content to @stream.
  *
- * Returns the number of bytes written, or %-1 on fail
+ * Returns: the number of bytes written, or %-1 on fail
  **/
-ssize_t
+gssize
 camel_data_wrapper_decode_to_stream (CamelDataWrapper *data_wrapper,
 				     CamelStream *stream)
 {
 	g_return_val_if_fail (CAMEL_IS_DATA_WRAPPER (data_wrapper), -1);
 	g_return_val_if_fail (CAMEL_IS_STREAM (stream), -1);
-	
+
 	return CDW_CLASS (data_wrapper)->decode_to_stream (data_wrapper, stream);
 }
 
 
-static int
+static gint
 construct_from_stream (CamelDataWrapper *data_wrapper, CamelStream *stream)
 {
 	if (data_wrapper->stream)
 		camel_object_unref (data_wrapper->stream);
-	
+
 	data_wrapper->stream = stream;
 	camel_object_ref (stream);
 	return 0;
@@ -258,21 +258,21 @@ construct_from_stream (CamelDataWrapper *data_wrapper, CamelStream *stream)
  *
  * Constructs the content of @data_wrapper from the supplied @stream.
  *
- * Returns %0 on success or %-1 on fail
+ * Returns: %0 on success or %-1 on fail
  **/
-int
+gint
 camel_data_wrapper_construct_from_stream (CamelDataWrapper *data_wrapper,
 					  CamelStream *stream)
 {
 	g_return_val_if_fail (CAMEL_IS_DATA_WRAPPER (data_wrapper), -1);
 	g_return_val_if_fail (CAMEL_IS_STREAM (stream), -1);
-	
+
 	return CDW_CLASS (data_wrapper)->construct_from_stream (data_wrapper, stream);
 }
 
 
 static void
-set_mime_type (CamelDataWrapper *data_wrapper, const char *mime_type)
+set_mime_type (CamelDataWrapper *data_wrapper, const gchar *mime_type)
 {
 	if (data_wrapper->mime_type)
 		camel_content_type_unref (data_wrapper->mime_type);
@@ -295,7 +295,7 @@ set_mime_type (CamelDataWrapper *data_wrapper, const char *mime_type)
  **/
 void
 camel_data_wrapper_set_mime_type (CamelDataWrapper *data_wrapper,
-				  const char *mime_type)
+				  const gchar *mime_type)
 {
 	g_return_if_fail (CAMEL_IS_DATA_WRAPPER (data_wrapper));
 	g_return_if_fail (mime_type != NULL);
@@ -303,7 +303,7 @@ camel_data_wrapper_set_mime_type (CamelDataWrapper *data_wrapper,
 	CDW_CLASS (data_wrapper)->set_mime_type (data_wrapper, mime_type);
 }
 
-static char *
+static gchar *
 get_mime_type (CamelDataWrapper *data_wrapper)
 {
 	return camel_content_type_simple (data_wrapper->mime_type);
@@ -314,9 +314,9 @@ get_mime_type (CamelDataWrapper *data_wrapper)
  * camel_data_wrapper_get_mime_type:
  * @data_wrapper: a #CamelDataWrapper object
  *
- * Returns the MIME type which must be freed by the caller
+ * Returns: the MIME type which must be freed by the caller
  **/
-char *
+gchar *
 camel_data_wrapper_get_mime_type (CamelDataWrapper *data_wrapper)
 {
 	g_return_val_if_fail (CAMEL_IS_DATA_WRAPPER (data_wrapper), NULL);
@@ -336,7 +336,7 @@ get_mime_type_field (CamelDataWrapper *data_wrapper)
  * camel_data_wrapper_get_mime_type_field:
  * @data_wrapper: a #CamelDataWrapper object
  *
- * Returns the parsed form of the data wrapper's MIME type
+ * Returns: the parsed form of the data wrapper's MIME type
  **/
 CamelContentType *
 camel_data_wrapper_get_mime_type_field (CamelDataWrapper *data_wrapper)
@@ -388,7 +388,7 @@ is_offline (CamelDataWrapper *data_wrapper)
  * camel_data_wrapper_is_offline:
  * @data_wrapper: a #CamelDataWrapper object
  *
- * Returns whether @data_wrapper is "offline" (data stored
+ * Returns: whether @data_wrapper is "offline" (data stored
  * remotely) or not. Some optional code paths may choose to not
  * operate on offline data.
  **/
