@@ -4,8 +4,8 @@
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -31,13 +31,13 @@
 G_BEGIN_DECLS
 
 void camel_debug_init(void);
-gboolean camel_debug(const char *mode);
+gboolean camel_debug(const gchar *mode);
 
-gboolean camel_debug_start(const char *mode);
+gboolean camel_debug_start(const gchar *mode);
 void camel_debug_end(void);
 
 #ifndef CAMEL_DISABLE_DEPRECATED
-extern int camel_verbose_debug;
+extern gint camel_verbose_debug;
 #endif
 
 G_END_DECLS
