@@ -4,10 +4,10 @@
  *
  * Authors: Dan Winship <danw@ximian.com>
  *
- * Copyright 2001 Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -21,6 +21,8 @@
  * USA
  */
 
+#ifndef CAMEL_DISABLE_DEPRECATED
+
 #ifndef CAMEL_DISCO_DIARY_H
 #define CAMEL_DISCO_DIARY_H 1
 
@@ -67,7 +69,7 @@ typedef struct {
 
 /* public methods */
 CamelDiscoDiary *camel_disco_diary_new    (CamelDiscoStore *store,
-					   const char *filename,
+					   const gchar *filename,
 					   CamelException *ex);
 
 gboolean         camel_disco_diary_empty  (CamelDiscoDiary *diary);
@@ -80,10 +82,10 @@ void             camel_disco_diary_replay (CamelDiscoDiary *diary,
 
 /* Temporary->Permanent UID map stuff */
 void        camel_disco_diary_uidmap_add    (CamelDiscoDiary *diary,
-					     const char *old_uid,
-					     const char *new_uid);
-const char *camel_disco_diary_uidmap_lookup (CamelDiscoDiary *diary,
-					     const char *uid);
+					     const gchar *old_uid,
+					     const gchar *new_uid);
+const gchar *camel_disco_diary_uidmap_lookup (CamelDiscoDiary *diary,
+					     const gchar *uid);
 
 /* Standard Camel function */
 CamelType camel_disco_diary_get_type (void);
@@ -91,3 +93,5 @@ CamelType camel_disco_diary_get_type (void);
 G_END_DECLS
 
 #endif /* CAMEL_DISCO_DIARY_H */
+
+#endif /* CAMEL_DISABLE_DEPRECATED */
