@@ -1,13 +1,13 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-disco-store.h: abstruct class for a disconnectable store */
 
-/* 
+/*
  * Authors: Dan Winship <danw@ximian.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -21,6 +21,7 @@
  * USA
  */
 
+#ifndef CAMEL_DISABLE_DEPRECATED
 
 #ifndef CAMEL_DISCO_STORE_H
 #define CAMEL_DISCO_STORE_H 1
@@ -45,7 +46,7 @@ typedef enum {
 } CamelDiscoStoreStatus;
 
 struct _CamelDiscoStore {
-	CamelStore parent_object;	
+	CamelStore parent_object;
 
 	CamelDiscoStoreStatus status;
 	CamelDiscoDiary *diary;
@@ -72,28 +73,28 @@ typedef struct {
 						      CamelException *);
 
 	CamelFolder *     (*get_folder_online)       (CamelStore *store,
-						      const char *name,
+						      const gchar *name,
 						      guint32 flags,
 						      CamelException *ex);
 	CamelFolder *     (*get_folder_offline)      (CamelStore *store,
-						      const char *name,
+						      const gchar *name,
 						      guint32 flags,
 						      CamelException *ex);
 	CamelFolder *     (*get_folder_resyncing)    (CamelStore *store,
-						      const char *name,
+						      const gchar *name,
 						      guint32 flags,
 						      CamelException *ex);
 
 	CamelFolderInfo * (*get_folder_info_online)    (CamelStore *store,
-							const char *top,
+							const gchar *top,
 							guint32 flags,
 							CamelException *ex);
 	CamelFolderInfo * (*get_folder_info_offline)   (CamelStore *store,
-							const char *top,
+							const gchar *top,
 							guint32 flags,
 							CamelException *ex);
 	CamelFolderInfo * (*get_folder_info_resyncing) (CamelStore *store,
-							const char *top,
+							const gchar *top,
 							guint32 flags,
 							CamelException *ex);
 
@@ -104,11 +105,11 @@ typedef struct {
 CamelType camel_disco_store_get_type (void);
 
 /* Public methods */
-CamelDiscoStoreStatus camel_disco_store_status           (CamelDiscoStore *);
-void                  camel_disco_store_set_status       (CamelDiscoStore *,
-							  CamelDiscoStoreStatus,
-							  CamelException *);
-gboolean              camel_disco_store_can_work_offline (CamelDiscoStore *);
+CamelDiscoStoreStatus camel_disco_store_status           (CamelDiscoStore *store);
+void                  camel_disco_store_set_status       (CamelDiscoStore *store,
+							  CamelDiscoStoreStatus status,
+							  CamelException *ex);
+gboolean              camel_disco_store_can_work_offline (CamelDiscoStore *store);
 
 
 /* Convenience functions */
@@ -118,3 +119,5 @@ void camel_disco_store_prepare_for_offline(CamelDiscoStore *store, CamelExceptio
 G_END_DECLS
 
 #endif /* CAMEL_DISCO_STORE_H */
+
+#endif /* CAMEL_DISABLE_DEPRECATED */
