@@ -1,13 +1,13 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  *
- * Author : 
+ * Author :
  *  Bertrand Guiheneuf <bertrand@helixcode.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -31,8 +31,6 @@
 #include <glib.h>
 #include <glib/gi18n-lib.h>
 
-#include <libedataserver/e-memory.h>
-
 #include "camel-debug.h"
 #include "camel-exception.h"
 
@@ -41,11 +39,11 @@
 
 
 /**
- * camel_exception_new: allocate a new exception object. 
- * 
+ * camel_exception_new: allocate a new exception object.
+ *
  * Create and returns a new exception object.
- * 
- * Returns the newly allocated exception object
+ *
+ * Returns: the newly allocated exception object
  **/
 CamelException *
 camel_exception_new (void)
@@ -64,7 +62,7 @@ camel_exception_new (void)
 /**
  * camel_exception_init:
  * @ex: a #CamelException
- * 
+ *
  * Init an exception. This routine is mainly useful when using a
  * statically allocated exception.
  **/
@@ -81,12 +79,12 @@ camel_exception_init (CamelException *ex)
 /**
  * camel_exception_clear:
  * @ex: a #CamelException
- * 
+ *
  * Clear an exception, that is, set the exception ID to
  * #CAMEL_EXCEPTION_NONE and free the description text.  If the
  * exception is %NULL, this funtion just returns.
  **/
-void 
+void
 camel_exception_clear (CamelException *exception)
 {
 	if (!exception)
@@ -101,16 +99,16 @@ camel_exception_clear (CamelException *exception)
 /**
  * camel_exception_free:
  * @ex: a #CamelException
- * 
+ *
  * Free an exception object. If the exception is %NULL, nothing is
  * done, the routine simply returns.
  **/
-void 
+void
 camel_exception_free (CamelException *exception)
 {
 	if (!exception)
 		return;
-	
+
 	if (exception->desc)
 		g_free (exception->desc);
 
@@ -118,24 +116,24 @@ camel_exception_free (CamelException *exception)
 }
 
 /**
- * camel_exception_set: set an exception 
+ * camel_exception_set: set an exception
  * @ex: a #CamelException
- * @id: exception id 
+ * @id: exception id
  * @desc: textual description of the exception
- * 
- * Set the value of an exception. The exception id is 
- * a unique number representing the exception. The 
- * textual description is a small text explaining 
+ *
+ * Set the value of an exception. The exception id is
+ * a unique number representing the exception. The
+ * textual description is a small text explaining
  * what happened and provoked the exception.
  *
  * When @ex is %NULL, nothing is done, this routine
  * simply returns.
  **/
 void
-camel_exception_set (CamelException *ex, ExceptionId id, const char *desc)
+camel_exception_set (CamelException *ex, ExceptionId id, const gchar *desc)
 {
 	if (camel_debug("exception"))
-		printf("CamelException.set(%p, %u, '%s')\n", (void *) ex, id, desc);
+		printf("CamelException.set(%p, %u, '%s')\n", (gpointer) ex, id, desc);
 	if (!ex)
 		return;
 	ex->id = id;
@@ -146,17 +144,17 @@ camel_exception_set (CamelException *ex, ExceptionId id, const char *desc)
 }
 
 /**
- * camel_exception_setv: set an exception 
+ * camel_exception_setv: set an exception
  * @ex: a #CamelException
- * @id: exception id 
+ * @id: exception id
  * @format: format of the description string. The format string is
  * used as in printf().
- * 
- * Set the value of an exception. The exception id is 
- * a unique number representing the exception. The 
- * textual description is a small text explaining 
- * what happened and provoked the exception. 
- * In this version, the string is created from the format 
+ *
+ * Set the value of an exception. The exception id is
+ * a unique number representing the exception. The
+ * textual description is a small text explaining
+ * what happened and provoked the exception.
+ * In this version, the string is created from the format
  * string and the variable argument list.
  *
  * It is safe to say:
@@ -166,17 +164,17 @@ camel_exception_set (CamelException *ex, ExceptionId id, const char *desc)
  * simply returns.
  **/
 void
-camel_exception_setv (CamelException *ex, ExceptionId id, const char *format, ...)
+camel_exception_setv (CamelException *ex, ExceptionId id, const gchar *format, ...)
 {
 	va_list args;
-	char *desc;
+	gchar *desc;
 
 	va_start(args, format);
 	desc = g_strdup_vprintf (format, args);
 	va_end (args);
 
 	if (camel_debug("exception"))
-		printf("CamelException.setv(%p, %u, '%s')\n", (void *) ex, id, desc);
+		printf("CamelException.setv(%p, %u, '%s')\n", (gpointer) ex, id, desc);
 
 	if (!ex) {
 		g_free(desc);
@@ -190,19 +188,19 @@ camel_exception_setv (CamelException *ex, ExceptionId id, const char *format, ..
 
 /**
  * camel_exception_xfer:
- * @ex_dst: Destination exception object 
+ * @ex_dst: Destination exception object
  * @ex_src: Source exception object
- * 
+ *
  * Transfer the content of an exception from an exception object to
  * another.  The destination exception receives the id and the
  * description text of the source exception.
  **/
-void 
+void
 camel_exception_xfer (CamelException *ex_dst,
 		      CamelException *ex_src)
 {
 	if (ex_src == NULL) {
-		w(g_warning ("camel_exception_xfer: trying to transfer NULL exception to %p\n", ex_dst));
+		w(g_warning ("camel_exception_xfer: trying to transfer NULL exception to %p\n", (gpointer) ex_dst));
 		return;
 	}
 
@@ -225,10 +223,10 @@ camel_exception_xfer (CamelException *ex_dst,
 /**
  * camel_exception_get_id:
  * @ex: a #CamelException
- * 
+ *
  * Get the id of an exception.
- * 
- * Returns the exception id (#CAMEL_EXCEPTION_NONE will be returned if
+ *
+ * Returns: the exception id (#CAMEL_EXCEPTION_NONE will be returned if
  * @ex is %NULL or unset)
  **/
 ExceptionId
@@ -236,25 +234,25 @@ camel_exception_get_id (CamelException *ex)
 {
 	if (ex)
 		return ex->id;
-	
+
 	w(g_warning ("camel_exception_get_id called with NULL parameter."));
-	
+
 	return CAMEL_EXCEPTION_NONE;
 }
 
 /**
  * camel_exception_get_description:
  * @ex: a #CamelException
- * 
+ *
  * Get the exception description text.
- * 
- * Returns the exception description text (%NULL will be returned if
+ *
+ * Returns: the exception description text (%NULL will be returned if
  * @ex is %NULL or unset)
  **/
 const gchar *
 camel_exception_get_description (CamelException *ex)
 {
-	char *ret = NULL;
+	gchar *ret = NULL;
 
 	if (ex)
 		ret = ex->desc;
