@@ -1,15 +1,15 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-execpetion.h : exception utils */
 
-/* 
+/*
  *
- * Author : 
+ * Author :
  *  Bertrand Guiheneuf <bertrand@helixcode.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -40,7 +40,7 @@ typedef enum {
 struct _CamelException {
 	/* do not access the fields directly */
 	ExceptionId id;
-	char *desc;
+	gchar *desc;
 };
 
 #define CAMEL_EXCEPTION_INITIALISER { 0, NULL }
@@ -55,10 +55,10 @@ void                      camel_exception_init          (CamelException *ex);
 void                      camel_exception_clear         (CamelException *ex);
 void                      camel_exception_set           (CamelException *ex,
 							 ExceptionId id,
-							 const char *desc);
+							 const gchar *desc);
 void                      camel_exception_setv          (CamelException *ex,
 							 ExceptionId id,
-							 const char *format,  
+							 const gchar *format,
 							 ...);
 
 /* exception content transfer */
@@ -68,7 +68,7 @@ void                      camel_exception_xfer          (CamelException *ex_dst,
 
 /* exception content retrieval */
 ExceptionId               camel_exception_get_id        (CamelException *ex);
-const char *             camel_exception_get_description (CamelException *ex);
+const gchar *             camel_exception_get_description (CamelException *ex);
 
 #define camel_exception_is_set(ex) (camel_exception_get_id (ex) != CAMEL_EXCEPTION_NONE)
 
