@@ -7,8 +7,8 @@
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -53,19 +53,19 @@
  * camel_file_util_encode_uint32:
  * @out: file to output to
  * @value: value to output
- * 
+ *
  * Utility function to save an uint32 to a file.
- * 
+ *
  * Return value: %0 on success, %-1 on error.
  **/
-int
+gint
 camel_file_util_encode_uint32 (FILE *out, guint32 value)
 {
-	int i;
+	gint i;
 
 	for (i = 28; i > 0; i -= 7) {
 		if (value >= (1 << i)) {
-			unsigned int c = (value >> i) & 0x7f;
+			guint c = (value >> i) & 0x7f;
 			if (fputc (c, out) == -1)
 				return -1;
 		}
@@ -78,17 +78,17 @@ camel_file_util_encode_uint32 (FILE *out, guint32 value)
  * camel_file_util_decode_uint32:
  * @in: file to read from
  * @dest: pointer to a variable to store the value in
- * 
+ *
  * Retrieve an encoded uint32 from a file.
- * 
+ *
  * Return value: %0 on success, %-1 on error.  @*dest will contain the
  * decoded value.
  **/
-int
+gint
 camel_file_util_decode_uint32 (FILE *in, guint32 *dest)
 {
         guint32 value = 0;
-	int v;
+	gint v;
 
         /* until we get the last byte, keep decoding 7 bits at a time */
         while ( ((v = fgetc (in)) & 0x80) == 0 && v!=EOF) {
@@ -109,13 +109,13 @@ camel_file_util_decode_uint32 (FILE *in, guint32 *dest)
  * camel_file_util_encode_fixed_int32:
  * @out: file to output to
  * @value: value to output
- * 
+ *
  * Encode a gint32, performing no compression, but converting
  * to network order.
- * 
+ *
  * Return value: %0 on success, %-1 on error.
  **/
-int
+gint
 camel_file_util_encode_fixed_int32 (FILE *out, gint32 value)
 {
 	guint32 save;
@@ -131,12 +131,12 @@ camel_file_util_encode_fixed_int32 (FILE *out, gint32 value)
  * camel_file_util_decode_fixed_int32:
  * @in: file to read from
  * @dest: pointer to a variable to store the value in
- * 
+ *
  * Retrieve a gint32.
- * 
+ *
  * Return value: %0 on success, %-1 on error.
  **/
-int
+gint
 camel_file_util_decode_fixed_int32 (FILE *in, gint32 *dest)
 {
 	guint32 save;
@@ -150,10 +150,10 @@ camel_file_util_decode_fixed_int32 (FILE *in, gint32 *dest)
 }
 
 #define CFU_ENCODE_T(type)						\
-int									\
+gint									\
 camel_file_util_encode_##type(FILE *out, type value)			\
 {									\
-	int i;								\
+	gint i;								\
 									\
 	for (i = sizeof (type) - 1; i >= 0; i--) {			\
 		if (fputc((value >> (i * 8)) & 0xff, out) == -1)	\
@@ -163,12 +163,12 @@ camel_file_util_encode_##type(FILE *out, type value)			\
 }
 
 #define CFU_DECODE_T(type)				\
-int							\
+gint							\
 camel_file_util_decode_##type(FILE *in, type *dest)	\
 {							\
 	type save = 0;					\
-	int i = sizeof(type) - 1;			\
-	int v = EOF;					\
+	gint i = sizeof(type) - 1;			\
+	gint v = EOF;					\
 							\
         while (i >= 0 && (v = fgetc (in)) != EOF) {	\
 		save |= ((type)v) << (i * 8);		\
@@ -185,9 +185,9 @@ camel_file_util_decode_##type(FILE *in, type *dest)	\
  * camel_file_util_encode_time_t:
  * @out: file to output to
  * @value: value to output
- * 
+ *
  * Encode a time_t value to the file.
- * 
+ *
  * Return value: %0 on success, %-1 on error.
  **/
 CFU_ENCODE_T(time_t)
@@ -196,9 +196,9 @@ CFU_ENCODE_T(time_t)
  * camel_file_util_decode_time_t:
  * @in: file to read from
  * @dest: pointer to a variable to store the value in
- * 
+ *
  * Decode a time_t value.
- * 
+ *
  * Return value: %0 on success, %-1 on error.
  **/
 CFU_DECODE_T(time_t)
@@ -207,9 +207,9 @@ CFU_DECODE_T(time_t)
  * camel_file_util_encode_off_t:
  * @out: file to output to
  * @value: value to output
- * 
+ *
  * Encode an off_t type.
- * 
+ *
  * Return value: %0 on success, %-1 on error.
  **/
 CFU_ENCODE_T(off_t)
@@ -219,57 +219,57 @@ CFU_ENCODE_T(off_t)
  * camel_file_util_decode_off_t:
  * @in: file to read from
  * @dest: pointer to a variable to put the value in
- * 
+ *
  * Decode an off_t type.
- * 
+ *
  * Return value: %0 on success, %-1 on failure.
  **/
 CFU_DECODE_T(off_t)
 
 /**
- * camel_file_util_encode_size_t:
+ * camel_file_util_encode_gsize:
  * @out: file to output to
  * @value: value to output
- * 
- * Encode an size_t type.
- * 
+ *
+ * Encode an gsize type.
+ *
  * Return value: %0 on success, %-1 on error.
  **/
-CFU_ENCODE_T(size_t)
+CFU_ENCODE_T(gsize)
 
 
 /**
- * camel_file_util_decode_size_t:
+ * camel_file_util_decode_gsize:
  * @in: file to read from
  * @dest: pointer to a variable to put the value in
- * 
- * Decode an size_t type.
- * 
+ *
+ * Decode an gsize type.
+ *
  * Return value: %0 on success, %-1 on failure.
  **/
-CFU_DECODE_T(size_t)
+CFU_DECODE_T(gsize)
 
 
 /**
  * camel_file_util_encode_string:
  * @out: file to output to
  * @str: value to output
- * 
+ *
  * Encode a normal string and save it in the output file.
- * 
+ *
  * Return value: %0 on success, %-1 on error.
  **/
-int
-camel_file_util_encode_string (FILE *out, const char *str)
+gint
+camel_file_util_encode_string (FILE *out, const gchar *str)
 {
-	register int len;
+	register gint len;
 
 	if (str == NULL)
 		return camel_file_util_encode_uint32 (out, 1);
-	
+
 	if ((len = strlen (str)) > 65536)
 		len = 65536;
-	
+
 	if (camel_file_util_encode_uint32 (out, len+1) == -1)
 		return -1;
 	if (len == 0 || fwrite (str, len, 1, out) == 1)
@@ -282,16 +282,16 @@ camel_file_util_encode_string (FILE *out, const char *str)
  * camel_file_util_decode_string:
  * @in: file to read from
  * @str: pointer to a variable to store the value in
- * 
+ *
  * Decode a normal string from the input file.
- * 
+ *
  * Return value: %0 on success, %-1 on error.
  **/
-int
-camel_file_util_decode_string (FILE *in, char **str)
+gint
+camel_file_util_decode_string (FILE *in, gchar **str)
 {
 	guint32 len;
-	register char *ret;
+	register gchar *ret;
 
 	if (camel_file_util_decode_uint32 (in, &len) == -1) {
 		*str = NULL;
@@ -321,17 +321,17 @@ camel_file_util_decode_string (FILE *in, char **str)
  * @out: file to output to
  * @str: value to output
  * @len: total-len of str to store
- * 
+ *
  * Encode a normal string and save it in the output file.
  * Unlike @camel_file_util_encode_string, it pads the
  * @str with "NULL" bytes, if @len is > strlen(str)
- * 
+ *
  * Return value: %0 on success, %-1 on error.
  **/
-int
-camel_file_util_encode_fixed_string (FILE *out, const char *str, size_t len)
+gint
+camel_file_util_encode_fixed_string (FILE *out, const gchar *str, gsize len)
 {
-	char buf[len];
+	gchar buf[len];
 
 	/* Don't allow empty strings to be written */
 	if (len < 1)
@@ -340,7 +340,7 @@ camel_file_util_encode_fixed_string (FILE *out, const char *str, size_t len)
 	/* Max size is 64K */
 	if (len > 65536)
 		len = 65536;
-		
+
 	memset(buf, 0x00, len);
 	g_strlcpy(buf, str, len);
 
@@ -355,16 +355,16 @@ camel_file_util_encode_fixed_string (FILE *out, const char *str, size_t len)
  * camel_file_util_decode_fixed_string:
  * @in: file to read from
  * @str: pointer to a variable to store the value in
- * @len: total-len to decode.  
- * 
+ * @len: total-len to decode.
+ *
  * Decode a normal string from the input file.
- * 
+ *
  * Return value: %0 on success, %-1 on error.
  **/
-int
-camel_file_util_decode_fixed_string (FILE *in, char **str, size_t len)
+gint
+camel_file_util_decode_fixed_string (FILE *in, gchar **str, gsize len)
 {
-	register char *ret;
+	register gchar *ret;
 
 	if (len > 65536) {
 		*str = NULL;
@@ -392,18 +392,18 @@ camel_file_util_decode_fixed_string (FILE *in, char **str, size_t len)
  *
  * Returns: a safe filename string.
  **/
-char *
-camel_file_util_safe_filename (const char *name)
+gchar *
+camel_file_util_safe_filename (const gchar *name)
 {
 #ifdef G_OS_WIN32
-	const char *unsafe_chars = "/?()'*<>:\"\\|";
+	const gchar *unsafe_chars = "/?()'*<>:\"\\|";
 #else
-	const char *unsafe_chars = "/?()'*";
+	const gchar *unsafe_chars = "/?()'*";
 #endif
 
 	if (name == NULL)
 		return NULL;
-	
+
 	return camel_url_encode(name, unsafe_chars);
 }
 
@@ -424,12 +424,12 @@ camel_file_util_safe_filename (const char *name)
  * Returns: number of bytes read or -1 on fail. On failure, errno will
  * be set appropriately.
  **/
-ssize_t
-camel_read (int fd, char *buf, size_t n)
+gssize
+camel_read (gint fd, gchar *buf, gsize n)
 {
-	ssize_t nread;
-	int cancel_fd;
-	
+	gssize nread;
+	gint cancel_fd;
+
 	if (camel_operation_cancel_check (NULL)) {
 		errno = EINTR;
 		return -1;
@@ -445,15 +445,15 @@ camel_read (int fd, char *buf, size_t n)
 		} while (nread == -1 && (errno == EINTR || errno == EAGAIN || errno == EWOULDBLOCK));
 	} else {
 #ifndef G_OS_WIN32
-		int errnosav, flags, fdmax;
+		gint errnosav, flags, fdmax;
 		fd_set rdset;
-		
+
 		flags = fcntl (fd, F_GETFL);
 		fcntl (fd, F_SETFL, flags | O_NONBLOCK);
-		
+
 		do {
 			struct timeval tv;
-			int res;
+			gint res;
 
 			FD_ZERO (&rdset);
 			FD_SET (fd, &rdset);
@@ -471,7 +471,7 @@ camel_read (int fd, char *buf, size_t n)
 			else if (FD_ISSET (cancel_fd, &rdset)) {
 				errno = EINTR;
 				goto failed;
-			} else {				
+			} else {
 				do {
 					nread = read (fd, buf, n);
 				} while (nread == -1 && errno == EINTR);
@@ -483,7 +483,7 @@ camel_read (int fd, char *buf, size_t n)
 		errno = errnosav;
 #endif
 	}
-	
+
 	return nread;
 }
 
@@ -502,12 +502,12 @@ camel_read (int fd, char *buf, size_t n)
  * Returns: number of bytes written or -1 on fail. On failure, errno will
  * be set appropriately.
  **/
-ssize_t
-camel_write (int fd, const char *buf, size_t n)
+gssize
+camel_write (gint fd, const gchar *buf, gsize n)
 {
-	ssize_t w, written = 0;
-	int cancel_fd;
-	
+	gssize w, written = 0;
+	gint cancel_fd;
+
 	if (camel_operation_cancel_check (NULL)) {
 		errno = EINTR;
 		return -1;
@@ -527,23 +527,23 @@ camel_write (int fd, const char *buf, size_t n)
 		} while (w != -1 && written < n);
 	} else {
 #ifndef G_OS_WIN32
-		int errnosav, flags, fdmax;
+		gint errnosav, flags, fdmax;
 		fd_set rdset, wrset;
-		
+
 		flags = fcntl (fd, F_GETFL);
 		fcntl (fd, F_SETFL, flags | O_NONBLOCK);
-		
+
 		fdmax = MAX (fd, cancel_fd) + 1;
 		do {
 			struct timeval tv;
-			int res;
+			gint res;
 
 			FD_ZERO (&rdset);
 			FD_ZERO (&wrset);
 			FD_SET (fd, &wrset);
 			FD_SET (cancel_fd, &rdset);
 			tv.tv_sec = IO_TIMEOUT;
-			tv.tv_usec = 0;			
+			tv.tv_usec = 0;
 			w = -1;
 
 			res = select (fdmax, &rdset, &wrset, 0, &tv);
@@ -558,7 +558,7 @@ camel_write (int fd, const char *buf, size_t n)
 				do {
 					w = write (fd, buf + written, n - written);
 				} while (w == -1 && errno == EINTR);
-				
+
 				if (w == -1) {
 					if (errno == EAGAIN || errno == EWOULDBLOCK)
 						w = 0;
@@ -566,16 +566,16 @@ camel_write (int fd, const char *buf, size_t n)
 					written += w;
 			}
 		} while (w != -1 && written < n);
-		
+
 		errnosav = errno;
 		fcntl (fd, F_SETFL, flags);
 		errno = errnosav;
 #endif
 	}
-	
+
 	if (w == -1)
 		return -1;
-	
+
 	return written;
 }
 
@@ -593,15 +593,15 @@ camel_write (int fd, const char *buf, size_t n)
  * be set appropriately. If the socket is nonblocking
  * camel_read_socket() will retry the read until it gets something.
  **/
-ssize_t
-camel_read_socket (int fd, char *buf, size_t n)
+gssize
+camel_read_socket (gint fd, gchar *buf, gsize n)
 {
 #ifndef G_OS_WIN32
 	return camel_read (fd, buf, n);
 #else
-	ssize_t nread;
-	int cancel_fd;
-	
+	gssize nread;
+	gint cancel_fd;
+
 	if (camel_operation_cancel_check (NULL)) {
 		errno = EINTR;
 		return -1;
@@ -613,7 +613,7 @@ camel_read_socket (int fd, char *buf, size_t n)
 			nread = recv (fd, buf, n, 0);
 		} while (nread == SOCKET_ERROR && WSAGetLastError () == WSAEWOULDBLOCK);
 	} else {
-		int fdmax;
+		gint fdmax;
 		fd_set rdset;
 		u_long yes = 1;
 
@@ -621,7 +621,7 @@ camel_read_socket (int fd, char *buf, size_t n)
 		fdmax = MAX (fd, cancel_fd) + 1;
 		do {
 			struct timeval tv;
-			int res;
+			gint res;
 
 			FD_ZERO (&rdset);
 			FD_SET (fd, &rdset);
@@ -638,14 +638,14 @@ camel_read_socket (int fd, char *buf, size_t n)
 			else if (FD_ISSET (cancel_fd, &rdset)) {
 				errno = EINTR;
 				goto failed;
-			} else {				
+			} else {
 				nread = recv (fd, buf, n, 0);
 			}
 		} while (nread == -1 && WSAGetLastError () == WSAEWOULDBLOCK);
 	failed:
 		;
 	}
-	
+
 	return nread;
 #endif
 }
@@ -663,15 +663,15 @@ camel_read_socket (int fd, char *buf, size_t n)
  * Returns: number of bytes written or -1 on fail. On failure, errno will
  * be set appropriately.
  **/
-ssize_t
-camel_write_socket (int fd, const char *buf, size_t n)
+gssize
+camel_write_socket (gint fd, const gchar *buf, gsize n)
 {
 #ifndef G_OS_WIN32
 	return camel_write (fd, buf, n);
 #else
-	ssize_t w, written = 0;
-	int cancel_fd;
-	
+	gssize w, written = 0;
+	gint cancel_fd;
+
 	if (camel_operation_cancel_check (NULL)) {
 		errno = EINTR;
 		return -1;
@@ -687,7 +687,7 @@ camel_write_socket (int fd, const char *buf, size_t n)
 				written += w;
 		} while (w != -1 && written < n);
 	} else {
-		int fdmax;
+		gint fdmax;
 		fd_set rdset, wrset;
 		u_long arg = 1;
 
@@ -695,14 +695,14 @@ camel_write_socket (int fd, const char *buf, size_t n)
 		fdmax = MAX (fd, cancel_fd) + 1;
 		do {
 			struct timeval tv;
-			int res;
+			gint res;
 
 			FD_ZERO (&rdset);
 			FD_ZERO (&wrset);
 			FD_SET (fd, &wrset);
 			FD_SET (cancel_fd, &rdset);
 			tv.tv_sec = IO_TIMEOUT;
-			tv.tv_usec = 0;			
+			tv.tv_usec = 0;
 			w = -1;
 
 			res = select (fdmax, &rdset, &wrset, 0, &tv);
@@ -724,10 +724,10 @@ camel_write_socket (int fd, const char *buf, size_t n)
 		arg = 0;
 		ioctlsocket (fd, FIONBIO, &arg);
 	}
-	
+
 	if (w == -1)
 		return -1;
-	
+
 	return written;
 #endif
 }
@@ -736,25 +736,25 @@ camel_write_socket (int fd, const char *buf, size_t n)
 /**
  * camel_file_util_savename:
  * @filename: a pathname
- * 
+ *
  * Builds a pathname where the basename is of the form ".#" + the
  * basename of @filename, for instance used in a two-stage commit file
  * write.
- * 
+ *
  * Return value: The new pathname.  It must be free'd with g_free().
  **/
-char *
-camel_file_util_savename(const char *filename)
+gchar *
+camel_file_util_savename(const gchar *filename)
 {
-	char *dirname, *retval;
+	gchar *dirname, *retval;
 
 	dirname = g_path_get_dirname(filename);
 
 	if (strcmp (dirname, ".") == 0) {
 		retval = g_strconcat (".#", filename, NULL);
 	} else {
-		char *basename = g_path_get_basename(filename);
-		char *newbasename = g_strconcat (".#", basename, NULL);
+		gchar *basename = g_path_get_basename(filename);
+		gchar *newbasename = g_strconcat (".#", basename, NULL);
 
 		retval = g_build_filename (dirname, newbasename, NULL);
 
