@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2002 Ximian, Inc. (www.ximian.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -39,7 +39,7 @@ G_BEGIN_DECLS
 typedef enum {
 	/*CAMEL_HTTP_METHOD_OPTIONS,*/
 	CAMEL_HTTP_METHOD_GET,
-	CAMEL_HTTP_METHOD_HEAD,
+	CAMEL_HTTP_METHOD_HEAD
 	/*CAMEL_HTTP_METHOD_POST,*/
 	/*CAMEL_HTTP_METHOD_PUT,*/
 	/*CAMEL_HTTP_METHOD_DELETE,*/
@@ -52,32 +52,32 @@ typedef struct _CamelHttpStreamClass CamelHttpStreamClass;
 
 struct _CamelHttpStream {
 	CamelStream parent_object;
-	
+
 	CamelMimeParser *parser;
-	
+
 	CamelContentType *content_type;
 	struct _camel_header_raw *headers;
-	
+
 	CamelHttpMethod method;
 	struct _CamelSession *session;
 	CamelURL *url;
-	
-	char *user_agent;
-	
+
+	gchar *user_agent;
+
 	/* proxy info */
 	CamelURL *proxy;
-	char *authrealm;
-	char *authpass;
-	
-	int statuscode;
-	
+	gchar *authrealm;
+	gchar *authpass;
+
+	gint statuscode;
+
 	CamelStream *raw;
 	CamelStream *read;
 };
 
 struct _CamelHttpStreamClass {
 	CamelStreamClass parent_class;
-	
+
 	/* Virtual methods */
 };
 
@@ -87,11 +87,11 @@ CamelType camel_http_stream_get_type (void);
 /* public methods */
 CamelStream *camel_http_stream_new (CamelHttpMethod method, struct _CamelSession *session, CamelURL *url);
 
-void camel_http_stream_set_user_agent (CamelHttpStream *http_stream, const char *user_agent);
+void camel_http_stream_set_user_agent (CamelHttpStream *http_stream, const gchar *user_agent);
 
-void camel_http_stream_set_proxy (CamelHttpStream *http_stream, const char *proxy_url);
-void camel_http_stream_set_proxy_authrealm (CamelHttpStream *http_stream, const char *proxy_authrealm);
-void camel_http_stream_set_proxy_authpass (CamelHttpStream *http_stream, const char *proxy_authpass);
+void camel_http_stream_set_proxy (CamelHttpStream *http_stream, const gchar *proxy_url);
+void camel_http_stream_set_proxy_authrealm (CamelHttpStream *http_stream, const gchar *proxy_authrealm);
+void camel_http_stream_set_proxy_authpass (CamelHttpStream *http_stream, const gchar *proxy_authpass);
 
 CamelContentType *camel_http_stream_get_content_type (CamelHttpStream *http_stream);
 
