@@ -26,12 +26,12 @@
 
 #define d(x)
 
-static int    internet_decode		(CamelAddress *, const char *raw);
-static char * internet_encode		(CamelAddress *);
-static int    internet_unformat		(CamelAddress *, const char *raw);
-static char * internet_format		(CamelAddress *);
-static int    internet_cat		(CamelAddress *dest, const CamelAddress *source);
-static void   internet_remove		(CamelAddress *, int index);
+static gint    internet_decode		(CamelAddress *, const gchar *raw);
+static gchar * internet_encode		(CamelAddress *);
+static gint    internet_unformat		(CamelAddress *, const gchar *raw);
+static gchar * internet_format		(CamelAddress *);
+static gint    internet_cat		(CamelAddress *dest, const CamelAddress *source);
+static void   internet_remove		(CamelAddress *, gint index);
 
 static void camel_internet_address_class_init (CamelInternetAddressClass *klass);
 static void camel_internet_address_init       (CamelInternetAddress *obj);
@@ -39,8 +39,8 @@ static void camel_internet_address_init       (CamelInternetAddress *obj);
 static CamelAddressClass *camel_internet_address_parent;
 
 struct _address {
-	char *name;
-	char *address;
+	gchar *name;
+	gchar *address;
 };
 
 static void
@@ -67,7 +67,7 @@ CamelType
 camel_internet_address_get_type(void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register(camel_address_get_type(), "CamelInternetAddress",
 					   sizeof (CamelInternetAddress),
@@ -77,15 +77,15 @@ camel_internet_address_get_type(void)
 					   (CamelObjectInitFunc) camel_internet_address_init,
 					   NULL);
 	}
-	
+
 	return type;
 }
 
-static int
-internet_decode	(CamelAddress *a, const char *raw)
+static gint
+internet_decode	(CamelAddress *a, const gchar *raw)
 {
 	struct _camel_header_address *ha, *n;
-	int count = a->addresses->len;
+	gint count = a->addresses->len;
 
 	/* Should probably use its own decoder or something */
 	ha = camel_header_address_decode(raw, NULL);
@@ -107,26 +107,26 @@ internet_decode	(CamelAddress *a, const char *raw)
 		}
 		camel_header_address_list_clear(&ha);
 	}
-	
+
 	return a->addresses->len - count;
 }
 
-static char *
+static gchar *
 internet_encode	(CamelAddress *a)
 {
-	int i;
+	gint i;
 	GString *out;
-	char *ret;
-	int len = 6;		/* "From: ", assume longer of the address headers */
+	gchar *ret;
+	gint len = 6;		/* "From: ", assume longer of the address headers */
 
 	if (a->addresses->len == 0)
 		return NULL;
-	
+
 	out = g_string_new("");
-	
+
 	for (i = 0;i < a->addresses->len; i++) {
 		struct _address *addr = g_ptr_array_index(a->addresses, i);
-		char *enc;
+		gchar *enc;
 
 		if (i != 0)
 			g_string_append(out, ", ");
@@ -135,19 +135,19 @@ internet_encode	(CamelAddress *a)
 		g_string_append(out, enc);
 		g_free(enc);
 	}
-	
+
 	ret = out->str;
 	g_string_free(out, FALSE);
-	
+
 	return ret;
 }
 
-static int
-internet_unformat(CamelAddress *a, const char *raw)
+static gint
+internet_unformat(CamelAddress *a, const gchar *raw)
 {
-	char *buffer, *p, *name, *addr;
-	int c;
-	int count = a->addresses->len;
+	gchar *buffer, *p, *name, *addr;
+	gint c;
+	gint count = a->addresses->len;
 
 	if (raw == NULL)
 		return 0;
@@ -162,7 +162,7 @@ internet_unformat(CamelAddress *a, const char *raw)
 	name = NULL;
 	addr = p;
 	do {
-		c = (unsigned char)*p++;
+		c = (guchar)*p++;
 		switch (c) {
 			/* removes quotes, they should only be around the total name anyway */
 		case '"':
@@ -208,21 +208,21 @@ internet_unformat(CamelAddress *a, const char *raw)
 	return a->addresses->len - count;
 }
 
-static char *
+static gchar *
 internet_format	(CamelAddress *a)
 {
-	int i;
+	gint i;
 	GString *out;
-	char *ret;
-	
+	gchar *ret;
+
 	if (a->addresses->len == 0)
 		return NULL;
-	
+
 	out = g_string_new("");
-	
+
 	for (i = 0;i < a->addresses->len; i++) {
 		struct _address *addr = g_ptr_array_index(a->addresses, i);
-		char *enc;
+		gchar *enc;
 
 		if (i != 0)
 			g_string_append(out, ", ");
@@ -231,17 +231,17 @@ internet_format	(CamelAddress *a)
 		g_string_append(out, enc);
 		g_free(enc);
 	}
-	
+
 	ret = out->str;
 	g_string_free(out, FALSE);
-	
+
 	return ret;
 }
 
-static int
+static gint
 internet_cat (CamelAddress *dest, const CamelAddress *source)
 {
-	int i;
+	gint i;
 
 	g_assert(CAMEL_IS_INTERNET_ADDRESS(source));
 
@@ -254,13 +254,13 @@ internet_cat (CamelAddress *dest, const CamelAddress *source)
 }
 
 static void
-internet_remove	(CamelAddress *a, int index)
+internet_remove	(CamelAddress *a, gint index)
 {
 	struct _address *addr;
-	
+
 	if (index < 0 || index >= a->addresses->len)
 		return;
-	
+
 	addr = g_ptr_array_index(a->addresses, index);
 	g_free(addr->name);
 	g_free(addr->address);
@@ -273,7 +273,7 @@ internet_remove	(CamelAddress *a, int index)
  * camel_internet_address_new:
  *
  * Create a new #CamelInternetAddress object.
- * 
+ *
  * Returns: a new #CamelInternetAddress object
  **/
 CamelInternetAddress *
@@ -289,16 +289,16 @@ camel_internet_address_new (void)
  * @addr: a #CamelInternetAddress object
  * @name: name associated with the new address
  * @address: routing address associated with the new address
- * 
+ *
  * Add a new internet address to @addr.
- * 
+ *
  * Returns: the index of added entry
  **/
-int
-camel_internet_address_add (CamelInternetAddress *addr, const char *name, const char *address)
+gint
+camel_internet_address_add (CamelInternetAddress *addr, const gchar *name, const gchar *address)
 {
 	struct _address *new;
-	int index;
+	gint index;
 
 	g_assert(CAMEL_IS_INTERNET_ADDRESS(addr));
 
@@ -318,13 +318,13 @@ camel_internet_address_add (CamelInternetAddress *addr, const char *name, const
  * @index: address's array index
  * @namep: holder for the returned name, or %NULL, if not required.
  * @addressp: holder for the returned address, or %NULL, if not required.
- * 
+ *
  * Get the address at @index.
- * 
+ *
  * Returns: %TRUE if such an address exists, or %FALSE otherwise
  **/
 gboolean
-camel_internet_address_get (const CamelInternetAddress *addr, int index, const char **namep, const char **addressp)
+camel_internet_address_get (const CamelInternetAddress *addr, gint index, const gchar **namep, const gchar **addressp)
 {
 	struct _address *a;
 
@@ -347,17 +347,17 @@ camel_internet_address_get (const CamelInternetAddress *addr, int index, const c
  * @addr: a #CamelInternetAddress object
  * @name: name to lookup
  * @addressp: holder for address part, or %NULL, if not required.
- * 
+ *
  * Find address by real name.
- * 
+ *
  * Returns: the index of the address matching the name, or %-1 if no
  * match was found
  **/
-int
-camel_internet_address_find_name(CamelInternetAddress *addr, const char *name, const char **addressp)
+gint
+camel_internet_address_find_name(CamelInternetAddress *addr, const gchar *name, const gchar **addressp)
 {
 	struct _address *a;
-	int i, len;
+	gint i, len;
 
 	g_assert(CAMEL_IS_INTERNET_ADDRESS(addr));
 
@@ -379,16 +379,16 @@ camel_internet_address_find_name(CamelInternetAddress *addr, const char *name, c
  * @addr: a #CamelInternetAddress object
  * @address: address to lookup
  * @namep: holder for the matching name, or %NULL, if not required.
- * 
+ *
  * Find an address by address.
- * 
+ *
  * Returns: the index of the address, or %-1 if not found
  **/
-int
-camel_internet_address_find_address(CamelInternetAddress *addr, const char *address, const char **namep)
+gint
+camel_internet_address_find_address(CamelInternetAddress *addr, const gchar *address, const gchar **namep)
 {
 	struct _address *a;
-	int i, len;
+	gint i, len;
 
 	g_assert(CAMEL_IS_INTERNET_ADDRESS(addr));
 
@@ -405,9 +405,9 @@ camel_internet_address_find_address(CamelInternetAddress *addr, const char *addr
 }
 
 static void
-cia_encode_addrspec(GString *out, const char *addr)
+cia_encode_addrspec(GString *out, const gchar *addr)
 {
-	const char *at, *p;
+	const gchar *at, *p;
 
 	at = strchr(addr, '@');
 	if (at == NULL)
@@ -415,7 +415,7 @@ cia_encode_addrspec(GString *out, const char *addr)
 
 	p = addr;
 	while (p < at) {
-		char c = *p++;
+		gchar c = *p++;
 
 		/* strictly by rfc, we should split local parts on dots.
 		   however i think 2822 changes this, and not many clients grok it, so
@@ -447,21 +447,21 @@ append:
  * @len: the length of the line the address is being appended to
  * @name: the unencoded real name associated with the address
  * @addr: the routing address
- * 
+ *
  * Encode a single address ready for internet usage.  Header folding
  * as per rfc822 is also performed, based on the length *@len.  If @len
  * is %NULL, then no folding will occur.
  *
  * Note: The value at *@in will be updated based on any linewrapping done
- * 
+ *
  * Returns: the encoded address
  **/
-char *
-camel_internet_address_encode_address(int *inlen, const char *real, const char *addr)
+gchar *
+camel_internet_address_encode_address(gint *inlen, const gchar *real, const gchar *addr)
 {
-	char *name = camel_header_encode_phrase ((const unsigned char *) real);
-	char *ret = NULL;
-	int len = 0;
+	gchar *name = camel_header_encode_phrase ((const guchar *) real);
+	gchar *ret = NULL;
+	gint len = 0;
 	GString *out = g_string_new("");
 
 	g_assert(addr);
@@ -471,8 +471,8 @@ camel_internet_address_encode_address(int *inlen, const char *real, const char *
 
 	if (name && name[0]) {
 		if (inlen != NULL && (strlen(name) + len) > CAMEL_FOLD_SIZE) {
-			char *folded = camel_header_address_fold(name, len);
-			char *last;
+			gchar *folded = camel_header_address_fold(name, len);
+			gchar *last;
 			g_string_append(out, folded);
 			g_free(folded);
 			last = strrchr(out->str, '\n');
@@ -505,12 +505,12 @@ camel_internet_address_encode_address(int *inlen, const char *real, const char *
 		g_string_append_printf(out, ">");
 
 	len += out->len;
-	
+
 	if (inlen != NULL)
 		*inlen = len;
 
 	g_free(name);
-	
+
 	ret = out->str;
 	g_string_free(out, FALSE);
 
@@ -522,21 +522,21 @@ camel_internet_address_encode_address(int *inlen, const char *real, const char *
  * camel_internet_address_format_address:
  * @name: a name, quotes may be stripped from it
  * @addr: an rfc822 routing address
- * 
+ *
  * Function to format a single address, suitable for display.
- * 
+ *
  * Returns: a nicely formatted string containing the rfc822 address
  **/
-char *
-camel_internet_address_format_address(const char *name, const char *addr)
+gchar *
+camel_internet_address_format_address(const gchar *name, const gchar *addr)
 {
-	char *ret = NULL;
+	gchar *ret = NULL;
 
 	g_assert(addr);
 
 	if (name && name[0]) {
-		const char *p = name;
-		char *o, c;
+		const gchar *p = name;
+		gchar *o, c;
 
 		while ((c = *p++)) {
 			if (c == '\"' || c == ',') {
