@@ -1,11 +1,11 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2001-2003 Ximian Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Authors: Michael Zucchi <notzed@ximian.com>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -40,7 +40,7 @@
 
 #define d(x)
 
-/* dunno where this fucking thing is got from */
+/* dunno where this thing is got from */
 /* see also camel-lock.c */
 #define _(x) (x)
 
@@ -48,14 +48,14 @@ static pthread_mutex_t lock_lock = PTHREAD_MUTEX_INITIALIZER;
 #define LOCK() pthread_mutex_lock(&lock_lock)
 #define UNLOCK() pthread_mutex_unlock(&lock_lock)
 
-static int lock_sequence;
-static int lock_helper_pid = -1;
-static int lock_stdin_pipe[2], lock_stdout_pipe[2];
+static gint lock_sequence;
+static gint lock_helper_pid = -1;
+static gint lock_stdin_pipe[2], lock_stdout_pipe[2];
 
-static int read_n(int fd, void *buffer, int inlen)
+static gint read_n(gint fd, gpointer buffer, gint inlen)
 {
-	char *p = buffer;
-	int len, left = inlen;
+	gchar *p = buffer;
+	gint len, left = inlen;
 
 	do {
 		len = read(fd, p, left);
@@ -71,10 +71,10 @@ static int read_n(int fd, void *buffer, int inlen)
 	return inlen - left;
 }
 
-static int write_n(int fd, void *buffer, int inlen)
+static gint write_n(gint fd, gpointer buffer, gint inlen)
 {
-	char *p = buffer;
-	int len, left = inlen;
+	gchar *p = buffer;
+	gint len, left = inlen;
 
 	do {
 		len = write(fd, p, left);
@@ -90,9 +90,9 @@ static int write_n(int fd, void *buffer, int inlen)
 	return inlen;
 }
 
-static int camel_lock_helper_init(CamelException *ex)
+static gint camel_lock_helper_init(CamelException *ex)
 {
-	int i;
+	gint i;
 
 	lock_stdin_pipe[0] = -1;
 	lock_stdin_pipe[1] = -1;
@@ -138,7 +138,6 @@ static int camel_lock_helper_init(CamelException *ex)
 		for (i=3;i<255;i++)
 			     close(i);
 		execl(CAMEL_LIBEXECDIR "/camel-lock-helper-" API_VERSION, "camel-lock-helper", NULL);
-		d(fprintf(stderr, "shit, couldn't exec lock helper!\n"));
 		/* it'll pick this up when it tries to use us */
 		exit(255);
 	default:
@@ -153,12 +152,12 @@ static int camel_lock_helper_init(CamelException *ex)
 	return 0;
 }
 
-int camel_lock_helper_lock(const char *path, CamelException *ex)
+gint camel_lock_helper_lock(const gchar *path, CamelException *ex)
 {
 	struct _CamelLockHelperMsg *msg;
-	int len = strlen(path);
-	int res = -1;
-	int retry = 3;
+	gint len = strlen(path);
+	gint res = -1;
+	gint retry = 3;
 
 	LOCK();
 
@@ -235,12 +234,12 @@ fail:
 	return res;
 }
 
-int camel_lock_helper_unlock(int lockid)
+gint camel_lock_helper_unlock(gint lockid)
 {
 	struct _CamelLockHelperMsg *msg;
-	int res = -1;
-	int retry = 3;
-	int len;
+	gint res = -1;
+	gint retry = 3;
+	gint len;
 
 	d(printf("unlocking lock id %d\n", lockid));
 
@@ -309,9 +308,9 @@ fail:
 }
 
 #if 0
-int main(int argc, char **argv)
+gint main(gint argc, gchar **argv)
 {
-	int id1, id2;
+	gint id1, id2;
 
 	d(printf("locking started\n"));
 	camel_lock_helper_init();
