@@ -2,10 +2,10 @@
  *
  * Author: Michael Zucchi <notzed@ximian.com>
  *
- * Copyright (C) 2001 Ximian Inc (www.ximian.com/)
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -28,8 +28,8 @@
 
 G_BEGIN_DECLS
 
-int camel_lock_helper_lock(const char *path , CamelException *ex);
-int camel_lock_helper_unlock(int lockid);
+gint camel_lock_helper_lock(const gchar *path , CamelException *ex);
+gint camel_lock_helper_unlock(gint lockid);
 
 G_END_DECLS
 
