@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2002 Ximian, Inc. (www.ximian.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -40,20 +40,20 @@ typedef struct _CamelMimeFilterEnrichedClass CamelMimeFilterEnrichedClass;
 
 struct _CamelMimeFilterEnriched {
 	CamelMimeFilter parent_object;
-	
+
 	guint32 flags;
-	int nofill;
+	gint nofill;
 };
 
 struct _CamelMimeFilterEnrichedClass {
 	CamelMimeFilterClass parent_class;
-	
+
 };
 
 CamelType        camel_mime_filter_enriched_get_type (void);
 
 CamelMimeFilter *camel_mime_filter_enriched_new (guint32 flags);
-char *camel_enriched_to_html(const char *in, guint32 flags);
+gchar *camel_enriched_to_html(const gchar *in, guint32 flags);
 
 G_END_DECLS
 
