@@ -28,11 +28,11 @@
 #include "camel-mime-filter-save.h"
 #include "camel-stream-mem.h"
 
-static void filter (CamelMimeFilter *f, char *in, size_t len, size_t prespace,
-		    char **out, size_t *outlen, size_t *outprespace);
-static void complete (CamelMimeFilter *f, char *in, size_t len,
-		      size_t prespace, char **out, size_t *outlen,
-		      size_t *outprespace);
+static void filter (CamelMimeFilter *f, const gchar *in, gsize len, gsize prespace,
+		    gchar **out, gsize *outlen, gsize *outprespace);
+static void complete (CamelMimeFilter *f, const gchar *in, gsize len,
+		      gsize prespace, gchar **out, gsize *outlen,
+		      gsize *outprespace);
 static void reset (CamelMimeFilter *f);
 
 
@@ -41,7 +41,7 @@ camel_mime_filter_save_class_init (CamelMimeFilterSaveClass *klass)
 {
 	CamelMimeFilterClass *mime_filter_class =
 		(CamelMimeFilterClass *) klass;
-	
+
 	mime_filter_class->filter = filter;
 	mime_filter_class->complete = complete;
 	mime_filter_class->reset = reset;
@@ -51,7 +51,7 @@ CamelType
 camel_mime_filter_save_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (camel_mime_filter_get_type(), "CamelMimeFilterSave",
 					    sizeof (CamelMimeFilterSave),
@@ -61,27 +61,27 @@ camel_mime_filter_save_get_type (void)
 					    NULL,
 					    NULL);
 	}
-	
+
 	return type;
 }
 
 static void
-filter (CamelMimeFilter *f, char *in, size_t len, size_t prespace,
-	char **out, size_t *outlen, size_t *outprespace)
+filter (CamelMimeFilter *f, const gchar *in, gsize len, gsize prespace,
+	gchar **out, gsize *outlen, gsize *outprespace)
 {
 	CamelMimeFilterSave *save = (CamelMimeFilterSave *) f;
-	
+
 	if (save->stream)
 		camel_stream_write (save->stream, in, len);
-	
-	*out = in;
+
+	*out = (gchar *) in;
 	*outlen = len;
 	*outprespace = f->outpre;
 }
 
-static void 
-complete (CamelMimeFilter *f, char *in, size_t len, size_t prespace,
-	  char **out, size_t *outlen, size_t *outprespace)
+static void
+complete (CamelMimeFilter *f, const gchar *in, gsize len, gsize prespace,
+	  gchar **out, gsize *outlen, gsize *outprespace)
 {
 	if (len)
 		filter (f, in, len, prespace, out, outlen, outprespace);
@@ -105,9 +105,9 @@ CamelMimeFilter *
 camel_mime_filter_save_new (void)
 {
 	CamelMimeFilterSave *save = CAMEL_MIME_FILTER_SAVE (camel_object_new (CAMEL_MIME_FILTER_SAVE_TYPE));
-	
+
 	save->stream = camel_stream_mem_new ();
-	
+
 	return (CamelMimeFilter *) save;
 }
 
@@ -125,9 +125,9 @@ CamelMimeFilter *
 camel_mime_filter_save_new_with_stream (CamelStream *stream)
 {
 	CamelMimeFilterSave *save = CAMEL_MIME_FILTER_SAVE (camel_object_new (CAMEL_MIME_FILTER_SAVE_TYPE));
-	
+
 	save->stream = stream;
 	camel_object_ref (stream);
-	
+
 	return (CamelMimeFilter *) save;
 }
