@@ -30,8 +30,8 @@
 #endif
 
 struct _CamelMimeFilterPrivate {
-	char *inbuf;
-	size_t inlen;
+	gchar *inbuf;
+	gsize inlen;
 };
 
 #define PRE_HEAD (64)
@@ -41,9 +41,9 @@ struct _CamelMimeFilterPrivate {
 
 static CamelObjectClass *camel_mime_filter_parent;
 
-static void complete (CamelMimeFilter *mf, char *in, size_t len, 
-		      size_t prespace, char **out, size_t *outlen, 
-		      size_t *outprespace);
+static void complete (CamelMimeFilter *mf, const gchar *in, gsize len,
+		      gsize prespace, gchar **out, gsize *outlen,
+		      gsize *outprespace);
 
 static void
 camel_mime_filter_class_init (CamelMimeFilterClass *klass)
@@ -83,7 +83,7 @@ CamelType
 camel_mime_filter_get_type (void)
 {
 	static CamelType camel_mime_filter_type = CAMEL_INVALID_TYPE;
-	
+
 	if (camel_mime_filter_type == CAMEL_INVALID_TYPE) {
 		camel_mime_filter_type = camel_type_register (CAMEL_OBJECT_TYPE, "CamelMimeFilter",
 							      sizeof (CamelMimeFilter),
@@ -93,12 +93,12 @@ camel_mime_filter_get_type (void)
 							      (CamelObjectInitFunc) camel_mime_filter_init,
 							      (CamelObjectFinalizeFunc) camel_mime_filter_finalize);
 	}
-	
+
 	return camel_mime_filter_type;
 }
 
 static void
-complete(CamelMimeFilter *mf, char *in, size_t len, size_t prespace, char **out, size_t *outlen, size_t *outprespace)
+complete(CamelMimeFilter *mf, const gchar *in, gsize len, gsize prespace, gchar **out, gsize *outlen, gsize *outprespace)
 {
 	/* default - do nothing */
 }
@@ -108,7 +108,7 @@ complete(CamelMimeFilter *mf, char *in, size_t len, size_t prespace, char **out,
  * camel_mime_filter_new:
  *
  * Create a new #CamelMimeFilter object.
- * 
+ *
  * Returns: a new #CamelMimeFilter
  **/
 CamelMimeFilter *
@@ -120,10 +120,10 @@ camel_mime_filter_new (void)
 
 #ifdef MALLOC_CHECK
 static void
-checkmem(void *p)
+checkmem(gpointer p)
 {
 	if (p) {
-		int status = mprobe(p);
+		gint status = mprobe(p);
 
 		switch (status) {
 		case MCHECK_HEAD:
@@ -141,11 +141,11 @@ checkmem(void *p)
 #endif
 
 static void filter_run(CamelMimeFilter *f,
-		       char *in, size_t len, size_t prespace,
-		       char **out, size_t *outlen, size_t *outprespace,
+		       const gchar *in, gsize len, gsize prespace,
+		       gchar **out, gsize *outlen, gsize *outprespace,
 		       void (*filterfunc)(CamelMimeFilter *f,
-					  char *in, size_t len, size_t prespace,
-					  char **out, size_t *outlen, size_t *outprespace))
+					  const gchar *in, gsize len, gsize prespace,
+					  gchar **out, gsize *outlen, gsize *outprespace))
 {
 	struct _CamelMimeFilterPrivate *p;
 
@@ -158,7 +158,7 @@ static void filter_run(CamelMimeFilter *f,
 	  have the pre-space required.  We make a buffer that does ...
 	*/
 	if (prespace < f->backlen) {
-		int newlen = len+prespace+f->backlen;
+		gint newlen = len+prespace+f->backlen;
 		p = _PRIVATE(f);
 		if (p->inlen < newlen) {
 			/* NOTE: g_realloc copies data, we dont need that (slower) */
@@ -179,13 +179,13 @@ static void filter_run(CamelMimeFilter *f,
 
 	/* preload any backed up data */
 	if (f->backlen > 0) {
-		memcpy(in-f->backlen, f->backbuf, f->backlen);
+		memcpy((gchar *) in-f->backlen, f->backbuf, f->backlen);
 		in -= f->backlen;
 		len += f->backlen;
 		prespace -= f->backlen;
 		f->backlen = 0;
 	}
-	
+
 	filterfunc(f, in, len, prespace, out, outlen, outprespace);
 
 #ifdef MALLOC_CHECK
@@ -211,8 +211,8 @@ static void filter_run(CamelMimeFilter *f,
  **/
 void
 camel_mime_filter_filter (CamelMimeFilter *filter,
-			  char *in, size_t len, size_t prespace,
-			  char **out, size_t *outlen, size_t *outprespace)
+			  const gchar *in, gsize len, gsize prespace,
+			  gchar **out, gsize *outlen, gsize *outprespace)
 {
 	if (FCLASS(filter)->filter)
 		filter_run(filter, in, len, prespace, out, outlen, outprespace, FCLASS(filter)->filter);
@@ -239,8 +239,8 @@ camel_mime_filter_filter (CamelMimeFilter *filter,
  **/
 void
 camel_mime_filter_complete (CamelMimeFilter *filter,
-			    char *in, size_t len, size_t prespace,
-			    char **out, size_t *outlen, size_t *outprespace)
+			    const gchar *in, gsize len, gsize prespace,
+			    gchar **out, gsize *outlen, gsize *outprespace)
 {
 	if (FCLASS(filter)->complete)
 		filter_run(filter, in, len, prespace, out, outlen, outprespace, FCLASS(filter)->complete);
@@ -277,7 +277,7 @@ camel_mime_filter_reset(CamelMimeFilter *filter)
  * Note: New calls replace old data.
  **/
 void
-camel_mime_filter_backup(CamelMimeFilter *filter, const char *data, size_t length)
+camel_mime_filter_backup(CamelMimeFilter *filter, const gchar *data, gsize length)
 {
 	if (filter->backsize < length) {
 		/* g_realloc copies data, unnecessary overhead */
@@ -300,10 +300,10 @@ camel_mime_filter_backup(CamelMimeFilter *filter, const char *data, size_t lengt
  * for filter output.
  **/
 void
-camel_mime_filter_set_size(CamelMimeFilter *filter, size_t size, int keep)
+camel_mime_filter_set_size(CamelMimeFilter *filter, gsize size, gint keep)
 {
 	if (filter->outsize < size) {
-		int offset = filter->outptr - filter->outreal;
+		gint offset = filter->outptr - filter->outreal;
 		if (keep) {
 			filter->outreal = g_realloc(filter->outreal, size + PRE_HEAD*4);
 		} else {
@@ -313,7 +313,7 @@ camel_mime_filter_set_size(CamelMimeFilter *filter, size_t size, int keep)
 		filter->outptr = filter->outreal + offset;
 		filter->outbuf = filter->outreal + PRE_HEAD*4;
 		filter->outsize = size;
-		/* this could be offset from the end of the structure, but 
+		/* this could be offset from the end of the structure, but
 		   this should be good enough */
 		filter->outpre = PRE_HEAD*4;
 	}
