@@ -1,15 +1,15 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; fill-column: 160 -*- */
 /* camel-mime-message.c : class for a mime_message */
 
-/* 
+/*
  * Authors: Bertrand Guiheneuf <bertrand@helixcode.com>
  *	    Michael Zucchi <notzed@ximian.com>
  *          Jeffrey Stedfast <fejj@ximian.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -56,7 +56,7 @@
 #endif
 #define d(x)
 
-extern int camel_verbose_debug;
+extern gint camel_verbose_debug;
 
 /* these 2 below should be kept in sync */
 typedef enum {
@@ -74,7 +74,7 @@ typedef enum {
 	HEADER_MESSAGE_ID
 } CamelHeaderType;
 
-static char *header_names[] = {
+static const gchar *header_names[] = {
 	/* dont include HEADER_UNKNOWN string */
 	"From", "Reply-To", "Subject", "To", "Resent-To", "Cc", "Resent-Cc",
 	"Bcc", "Resent-Bcc", "Date", "Message-Id", NULL
@@ -84,15 +84,15 @@ static GHashTable *header_name_table;
 
 static CamelMimePartClass *parent_class = NULL;
 
-static char *recipient_names[] = {
+static const gchar *recipient_names[] = {
 	"To", "Cc", "Bcc", "Resent-To", "Resent-Cc", "Resent-Bcc", NULL
 };
 
-static ssize_t write_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream);
-static void add_header (CamelMedium *medium, const char *name, const void *value);
-static void set_header (CamelMedium *medium, const char *name, const void *value);
-static void remove_header (CamelMedium *medium, const char *name);
-static int construct_from_parser (CamelMimePart *, CamelMimeParser *);
+static gssize write_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream);
+static void add_header (CamelMedium *medium, const gchar *name, gconstpointer value);
+static void set_header (CamelMedium *medium, const gchar *name, gconstpointer value);
+static void remove_header (CamelMedium *medium, const gchar *name);
+static gint construct_from_parser (CamelMimePart *, CamelMimeParser *);
 static void unref_recipient (gpointer key, gpointer value, gpointer user_data);
 
 /* Returns the class for a CamelMimeMessage */
@@ -106,13 +106,16 @@ camel_mime_message_class_init (CamelMimeMessageClass *camel_mime_message_class)
 	CamelDataWrapperClass *camel_data_wrapper_class = CAMEL_DATA_WRAPPER_CLASS (camel_mime_message_class);
 	CamelMimePartClass *camel_mime_part_class = CAMEL_MIME_PART_CLASS (camel_mime_message_class);
 	CamelMediumClass *camel_medium_class = CAMEL_MEDIUM_CLASS (camel_mime_message_class);
-	int i;
-	
+	gint i;
+
 	parent_class = CAMEL_MIME_PART_CLASS (camel_type_get_global_classfuncs (camel_mime_part_get_type ()));
-	
+
 	header_name_table = g_hash_table_new (camel_strcase_hash, camel_strcase_equal);
 	for (i = 0;header_names[i]; i++)
-		g_hash_table_insert (header_name_table, header_names[i], GINT_TO_POINTER(i+1));
+		g_hash_table_insert (
+			header_name_table,
+			(gpointer) header_names[i],
+			GINT_TO_POINTER(i+1));
 
 	/* virtual method overload */
 	camel_data_wrapper_class->write_to_stream = write_to_stream;
@@ -129,11 +132,14 @@ static void
 camel_mime_message_init (gpointer object, gpointer klass)
 {
 	CamelMimeMessage *mime_message = (CamelMimeMessage *)object;
-	int i;
-	
+	gint i;
+
 	mime_message->recipients =  g_hash_table_new (camel_strcase_hash, camel_strcase_equal);
 	for (i=0;recipient_names[i];i++) {
-		g_hash_table_insert(mime_message->recipients, recipient_names[i], camel_internet_address_new());
+		g_hash_table_insert (
+			mime_message->recipients,
+			(gpointer) recipient_names[i],
+			camel_internet_address_new ());
 	}
 
 	mime_message->subject = NULL;
@@ -146,21 +152,21 @@ camel_mime_message_init (gpointer object, gpointer klass)
 	mime_message->message_id = NULL;
 }
 
-static void           
+static void
 camel_mime_message_finalize (CamelObject *object)
 {
 	CamelMimeMessage *message = CAMEL_MIME_MESSAGE (object);
-	
+
 	g_free (message->subject);
-	
+
 	g_free (message->message_id);
-	
+
 	if (message->reply_to)
 		camel_object_unref ((CamelObject *)message->reply_to);
-	
+
 	if (message->from)
 		camel_object_unref ((CamelObject *)message->from);
-	
+
 	g_hash_table_foreach (message->recipients, unref_recipient, NULL);
 	g_hash_table_destroy (message->recipients);
 }
@@ -169,7 +175,7 @@ CamelType
 camel_mime_message_get_type (void)
 {
 	static CamelType camel_mime_message_type = CAMEL_INVALID_TYPE;
-	
+
 	if (camel_mime_message_type == CAMEL_INVALID_TYPE)	{
 		camel_mime_message_type = camel_type_register (camel_mime_part_get_type(), "CamelMimeMessage",
 							       sizeof (CamelMimeMessage),
@@ -179,7 +185,7 @@ camel_mime_message_get_type (void)
 							       (CamelObjectInitFunc) camel_mime_message_init,
 							       (CamelObjectFinalizeFunc) camel_mime_message_finalize);
 	}
-	
+
 	return camel_mime_message_type;
 }
 
@@ -198,11 +204,11 @@ unref_recipient (gpointer key, gpointer value, gpointer user_data)
  * Returns: a new #CamelMimeMessage object
  **/
 CamelMimeMessage *
-camel_mime_message_new (void) 
+camel_mime_message_new (void)
 {
 	CamelMimeMessage *mime_message;
 	mime_message = CAMEL_MIME_MESSAGE (camel_object_new (CAMEL_MIME_MESSAGE_TYPE));
-	
+
 	return mime_message;
 }
 
@@ -218,23 +224,23 @@ camel_mime_message_new (void)
  * Set the date on a message.
  **/
 void
-camel_mime_message_set_date (CamelMimeMessage *message,  time_t date, int offset)
+camel_mime_message_set_date (CamelMimeMessage *message,  time_t date, gint offset)
 {
-	char *datestr;
-	
+	gchar *datestr;
+
 	g_assert(message);
-	
+
 	if (date == CAMEL_MESSAGE_DATE_CURRENT) {
 		struct tm local;
-		int tz;
-		
+		gint tz;
+
 		date = time(NULL);
 		e_localtime_with_offset(date, &local, &tz);
 		offset = (((tz/60/60) * 100) + (tz/60 % 60));
 	}
 	message->date = date;
 	message->date_offset = offset;
-	
+
 	datestr = camel_header_format_date (date, offset);
 	CAMEL_MEDIUM_CLASS (parent_class)->set_header ((CamelMedium *)message, "Date", datestr);
 	g_free (datestr);
@@ -251,11 +257,11 @@ camel_mime_message_set_date (CamelMimeMessage *message,  time_t date, int offset
  * Returns: the date of the message
  **/
 time_t
-camel_mime_message_get_date (CamelMimeMessage *msg, int *offset)
+camel_mime_message_get_date (CamelMimeMessage *msg, gint *offset)
 {
 	if (offset)
 		*offset = msg->date_offset;
-	
+
 	return msg->date;
 }
 
@@ -270,21 +276,21 @@ camel_mime_message_get_date (CamelMimeMessage *msg, int *offset)
  * Returns: the received date of the message
  **/
 time_t
-camel_mime_message_get_date_received (CamelMimeMessage *msg, int *offset)
+camel_mime_message_get_date_received (CamelMimeMessage *msg, gint *offset)
 {
 	if (msg->date_received == CAMEL_MESSAGE_DATE_CURRENT) {
-		const char *received;
-		
+		const gchar *received;
+
 		received = camel_medium_get_header ((CamelMedium *)msg, "received");
 		if (received)
 			received = strrchr (received, ';');
 		if (received)
 			msg->date_received = camel_header_decode_date (received + 1, &msg->date_received_offset);
 	}
-	
+
 	if (offset)
 		*offset = msg->date_received_offset;
-	
+
 	return msg->date_received;
 }
 
@@ -298,20 +304,20 @@ camel_mime_message_get_date_received (CamelMimeMessage *msg, int *offset)
  * Set the message-id on a message.
  **/
 void
-camel_mime_message_set_message_id (CamelMimeMessage *mime_message, const char *message_id)
+camel_mime_message_set_message_id (CamelMimeMessage *mime_message, const gchar *message_id)
 {
-	char *id;
-	
+	gchar *id;
+
 	g_assert (mime_message);
-	
+
 	g_free (mime_message->message_id);
-	
+
 	if (message_id) {
 		id = g_strstrip (g_strdup (message_id));
 	} else {
 		id = camel_header_msgid_generate ();
 	}
-	
+
 	mime_message->message_id = id;
 	id = g_strdup_printf ("<%s>", mime_message->message_id);
 	CAMEL_MEDIUM_CLASS (parent_class)->set_header (CAMEL_MEDIUM (mime_message), "Message-Id", id);
@@ -327,11 +333,11 @@ camel_mime_message_set_message_id (CamelMimeMessage *mime_message, const char *m
  *
  * Returns: the message-id of a message
  **/
-const char *
+const gchar *
 camel_mime_message_get_message_id (CamelMimeMessage *mime_message)
 {
 	g_assert (mime_message);
-	
+
 	return mime_message->message_id;
 }
 
@@ -348,20 +354,20 @@ camel_mime_message_get_message_id (CamelMimeMessage *mime_message)
 void
 camel_mime_message_set_reply_to (CamelMimeMessage *msg, const CamelInternetAddress *reply_to)
 {
-	char *addr;
-	
+	gchar *addr;
+
 	g_assert(msg);
-	
+
 	if (msg->reply_to) {
 		camel_object_unref ((CamelObject *)msg->reply_to);
 		msg->reply_to = NULL;
 	}
-	
+
 	if (reply_to == NULL) {
 		CAMEL_MEDIUM_CLASS (parent_class)->remove_header (CAMEL_MEDIUM (msg), "Reply-To");
 		return;
 	}
-	
+
 	msg->reply_to = (CamelInternetAddress *)camel_address_new_clone ((CamelAddress *)reply_to);
 	addr = camel_address_encode ((CamelAddress *)msg->reply_to);
 	CAMEL_MEDIUM_CLASS (parent_class)->set_header (CAMEL_MEDIUM (msg), "Reply-To", addr);
@@ -381,9 +387,9 @@ const CamelInternetAddress *
 camel_mime_message_get_reply_to (CamelMimeMessage *mime_message)
 {
 	g_assert (mime_message);
-	
+
 	/* TODO: ref for threading? */
-	
+
 	return mime_message->reply_to;
 }
 
@@ -397,22 +403,22 @@ camel_mime_message_get_reply_to (CamelMimeMessage *mime_message)
  * Set the subject text of a message.
  **/
 void
-camel_mime_message_set_subject (CamelMimeMessage *message, const char *subject)
+camel_mime_message_set_subject (CamelMimeMessage *message, const gchar *subject)
 {
-	char *text;
-	
+	gchar *text;
+
 	g_assert(message);
-	
+
 	g_free (message->subject);
-	
+
 	if (subject) {
 		message->subject = g_strstrip (g_strdup (subject));
-		text = camel_header_encode_string ((unsigned char *) message->subject);
+		text = camel_header_encode_string ((guchar *) message->subject);
 	} else {
 		message->subject = NULL;
 		text = NULL;
 	}
-	
+
 	CAMEL_MEDIUM_CLASS (parent_class)->set_header (CAMEL_MEDIUM (message), "Subject", text);
 	g_free (text);
 }
@@ -426,11 +432,11 @@ camel_mime_message_set_subject (CamelMimeMessage *message, const char *subject)
  *
  * Returns: the message subject
  **/
-const char *
+const gchar *
 camel_mime_message_get_subject (CamelMimeMessage *mime_message)
 {
 	g_assert(mime_message);
-	
+
 	return mime_message->subject;
 }
 
@@ -450,20 +456,20 @@ camel_mime_message_get_subject (CamelMimeMessage *mime_message)
 void
 camel_mime_message_set_from (CamelMimeMessage *msg, const CamelInternetAddress *from)
 {
-	char *addr;
-	
+	gchar *addr;
+
 	g_assert(msg);
-	
+
 	if (msg->from) {
 		camel_object_unref((CamelObject *)msg->from);
 		msg->from = NULL;
 	}
-	
+
 	if (from == NULL || camel_address_length((CamelAddress *)from) == 0) {
 		CAMEL_MEDIUM_CLASS(parent_class)->remove_header(CAMEL_MEDIUM(msg), "From");
 		return;
 	}
-	
+
 	msg->from = (CamelInternetAddress *)camel_address_new_clone((CamelAddress *)from);
 	addr = camel_address_encode((CamelAddress *)msg->from);
 	CAMEL_MEDIUM_CLASS (parent_class)->set_header(CAMEL_MEDIUM(msg), "From", addr);
@@ -483,9 +489,9 @@ const CamelInternetAddress *
 camel_mime_message_get_from (CamelMimeMessage *mime_message)
 {
 	g_assert (mime_message);
-	
+
 	/* TODO: we should really ref this for multi-threading to work */
-	
+
 	return mime_message->from;
 }
 
@@ -500,28 +506,28 @@ camel_mime_message_get_from (CamelMimeMessage *mime_message)
  * Set the recipients of a message.
  **/
 void
-camel_mime_message_set_recipients(CamelMimeMessage *mime_message, const char *type, const CamelInternetAddress *r)
+camel_mime_message_set_recipients(CamelMimeMessage *mime_message, const gchar *type, const CamelInternetAddress *r)
 {
-	char *text;
+	gchar *text;
 	CamelInternetAddress *addr;
-	
+
 	g_assert(mime_message);
-	
+
 	addr = g_hash_table_lookup (mime_message->recipients, type);
 	if (addr == NULL) {
 		g_warning ("trying to set a non-valid receipient type: %s", type);
 		return;
 	}
-	
+
 	if (r == NULL || camel_address_length ((CamelAddress *)r) == 0) {
 		camel_address_remove ((CamelAddress *)addr, -1);
 		CAMEL_MEDIUM_CLASS (parent_class)->remove_header (CAMEL_MEDIUM (mime_message), type);
 		return;
 	}
-	
+
 	/* note this does copy, and not append (cat) */
 	camel_address_copy ((CamelAddress *)addr, (const CamelAddress *)r);
-	
+
 	/* and sync our headers */
 	text = camel_address_encode (CAMEL_ADDRESS (addr));
 	CAMEL_MEDIUM_CLASS (parent_class)->set_header (CAMEL_MEDIUM (mime_message), type, text);
@@ -539,22 +545,22 @@ camel_mime_message_set_recipients(CamelMimeMessage *mime_message, const char *ty
  * Returns: the requested recipients
  **/
 const CamelInternetAddress *
-camel_mime_message_get_recipients (CamelMimeMessage *mime_message, const char *type)
+camel_mime_message_get_recipients (CamelMimeMessage *mime_message, const gchar *type)
 {
 	g_assert(mime_message);
-	
+
 	return g_hash_table_lookup (mime_message->recipients, type);
 }
 
 
 void
-camel_mime_message_set_source (CamelMimeMessage *mime_message, const char *src)
+camel_mime_message_set_source (CamelMimeMessage *mime_message, const gchar *src)
 {
 	CamelURL *url;
-	char *uri;
-	
+	gchar *uri;
+
 	g_assert (mime_message);
-	
+
 	url = camel_url_new (src, NULL);
 	if (url) {
 		uri = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
@@ -564,13 +570,13 @@ camel_mime_message_set_source (CamelMimeMessage *mime_message, const char *src)
 	}
 }
 
-const char *
+const gchar *
 camel_mime_message_get_source (CamelMimeMessage *mime_message)
 {
-	const char *src;
-	
+	const gchar *src;
+
 	g_assert(mime_message);
-	
+
 	src = camel_medium_get_header (CAMEL_MEDIUM (mime_message), "X-Evolution-Source");
 	if (src) {
 		while (*src && isspace ((unsigned) *src))
@@ -580,14 +586,14 @@ camel_mime_message_get_source (CamelMimeMessage *mime_message)
 }
 
 /* mime_message */
-static int
+static gint
 construct_from_parser (CamelMimePart *dw, CamelMimeParser *mp)
 {
-	char *buf;
-	size_t len;
-	int state;
-	int ret;
-	int err;
+	gchar *buf;
+	gsize len;
+	gint state;
+	gint ret;
+	gint err;
 
 	d(printf("constructing mime-message\n"));
 
@@ -624,11 +630,11 @@ construct_from_parser (CamelMimePart *dw, CamelMimeParser *mp)
 	return ret;
 }
 
-static ssize_t
+static gssize
 write_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream)
 {
 	CamelMimeMessage *mm = CAMEL_MIME_MESSAGE (data_wrapper);
-	
+
 	/* force mandatory headers ... */
 	if (mm->from == NULL) {
 		/* FIXME: should we just abort?  Should we make one up? */
@@ -637,31 +643,31 @@ write_to_stream (CamelDataWrapper *data_wrapper, CamelStream *stream)
 	}
 	if (!camel_medium_get_header ((CamelMedium *)mm, "Date"))
 		camel_mime_message_set_date (mm, CAMEL_MESSAGE_DATE_CURRENT, 0);
-	
+
 	if (mm->subject == NULL)
 		camel_mime_message_set_subject (mm, "No Subject");
-	
+
 	if (mm->message_id == NULL)
 		camel_mime_message_set_message_id (mm, NULL);
-	
+
 	/* FIXME: "To" header needs to be set explicitly as well ... */
-	
+
 	if (!camel_medium_get_header ((CamelMedium *)mm, "Mime-Version"))
 		camel_medium_set_header ((CamelMedium *)mm, "Mime-Version", "1.0");
-	
+
 	return CAMEL_DATA_WRAPPER_CLASS (parent_class)->write_to_stream (data_wrapper, stream);
 }
 
 /* FIXME: check format of fields. */
 static gboolean
-process_header (CamelMedium *medium, const char *name, const char *value)
+process_header (CamelMedium *medium, const gchar *name, const gchar *value)
 {
 	CamelHeaderType header_type;
 	CamelMimeMessage *message = CAMEL_MIME_MESSAGE (medium);
 	CamelInternetAddress *addr;
-	const char *charset;
-	char *unfolded;
-	
+	const gchar *charset;
+	gchar *unfolded;
+
 	header_type = (CamelHeaderType) g_hash_table_lookup (header_name_table, name);
 	switch (header_type) {
 	case HEADER_FROM:
@@ -695,7 +701,7 @@ process_header (CamelMedium *medium, const char *name, const char *value)
 			charset = camel_iconv_charset_name (charset);
 		} else
 			charset = NULL;
-		
+
 		unfolded = camel_header_unfold (value);
 		message->subject = g_strstrip (camel_header_decode_string (unfolded, charset));
 		g_free (unfolded);
@@ -733,19 +739,19 @@ process_header (CamelMedium *medium, const char *name, const char *value)
 	default:
 		return FALSE;
 	}
-	
+
 	return TRUE;
 }
 
 static void
-set_header (CamelMedium *medium, const char *name, const void *value)
+set_header (CamelMedium *medium, const gchar *name, gconstpointer value)
 {
 	process_header (medium, name, value);
 	parent_class->parent_class.set_header (medium, name, value);
 }
 
 static void
-add_header (CamelMedium *medium, const char *name, const void *value)
+add_header (CamelMedium *medium, const gchar *name, gconstpointer value)
 {
 	/* if we process it, then it must be forced unique as well ... */
 	if (process_header (medium, name, value))
@@ -755,63 +761,63 @@ add_header (CamelMedium *medium, const char *name, const void *value)
 }
 
 static void
-remove_header (CamelMedium *medium, const char *name)
+remove_header (CamelMedium *medium, const gchar *name)
 {
 	process_header (medium, name, NULL);
 	parent_class->parent_class.remove_header (medium, name);
 }
 
-typedef gboolean (*CamelPartFunc)(CamelMimeMessage *, CamelMimePart *, void *data);
+typedef gboolean (*CamelPartFunc)(CamelMimeMessage *, CamelMimePart *, gpointer data);
 
 static gboolean
-message_foreach_part_rec (CamelMimeMessage *msg, CamelMimePart *part, CamelPartFunc callback, void *data)
+message_foreach_part_rec (CamelMimeMessage *msg, CamelMimePart *part, CamelPartFunc callback, gpointer data)
 {
 	CamelDataWrapper *containee;
-	int parts, i;
-	int go = TRUE;
-	
+	gint parts, i;
+	gint go = TRUE;
+
 	if (callback (msg, part, data) == FALSE)
 		return FALSE;
-	
+
 	containee = camel_medium_get_content_object (CAMEL_MEDIUM (part));
-	
+
 	if (containee == NULL)
 		return go;
-	
+
 	/* using the object types is more accurate than using the mime/types */
 	if (CAMEL_IS_MULTIPART (containee)) {
 		parts = camel_multipart_get_number (CAMEL_MULTIPART (containee));
 		for (i = 0; go && i < parts; i++) {
 			CamelMimePart *mpart = camel_multipart_get_part (CAMEL_MULTIPART (containee), i);
-			
+
 			go = message_foreach_part_rec (msg, mpart, callback, data);
 		}
 	} else if (CAMEL_IS_MIME_MESSAGE (containee)) {
 		go = message_foreach_part_rec (msg, (CamelMimePart *)containee, callback, data);
 	}
-	
+
 	return go;
 }
 
 /* dont make this public yet, it might need some more thinking ... */
 /* MPZ */
 static void
-camel_mime_message_foreach_part (CamelMimeMessage *msg, CamelPartFunc callback, void *data)
+camel_mime_message_foreach_part (CamelMimeMessage *msg, CamelPartFunc callback, gpointer data)
 {
 	message_foreach_part_rec (msg, (CamelMimePart *)msg, callback, data);
 }
 
 static gboolean
-check_8bit (CamelMimeMessage *msg, CamelMimePart *part, void *data)
+check_8bit (CamelMimeMessage *msg, CamelMimePart *part, gpointer data)
 {
 	CamelTransferEncoding encoding;
-	int *has8bit = data;
-	
+	gint *has8bit = data;
+
 	/* check this part, and stop as soon as we are done */
 	encoding = camel_mime_part_get_encoding (part);
-	
+
 	*has8bit = encoding == CAMEL_TRANSFER_ENCODING_8BIT || encoding == CAMEL_TRANSFER_ENCODING_BINARY;
-	
+
 	return !(*has8bit);
 }
 
@@ -827,35 +833,35 @@ check_8bit (CamelMimeMessage *msg, CamelMimePart *part, void *data)
 gboolean
 camel_mime_message_has_8bit_parts (CamelMimeMessage *msg)
 {
-	int has8bit = FALSE;
-	
+	gint has8bit = FALSE;
+
 	camel_mime_message_foreach_part (msg, check_8bit, &has8bit);
-	
+
 	return has8bit;
 }
 
 /* finds the best charset and transfer encoding for a given part */
 static CamelTransferEncoding
-find_best_encoding (CamelMimePart *part, CamelBestencRequired required, CamelBestencEncoding enctype, char **charsetp)
+find_best_encoding (CamelMimePart *part, CamelBestencRequired required, CamelBestencEncoding enctype, gchar **charsetp)
 {
 	CamelMimeFilterCharset *charenc = NULL;
 	CamelTransferEncoding encoding;
 	CamelMimeFilterBestenc *bestenc;
-	unsigned int flags, callerflags;
+	guint flags, callerflags;
 	CamelDataWrapper *content;
 	CamelStreamFilter *filter;
-	const char *charsetin = NULL;
-	char *charset = NULL;
+	const gchar *charsetin = NULL;
+	gchar *charset = NULL;
 	CamelStream *null;
-	int idb, idc = -1;
+	gint idb, idc = -1;
 	gboolean istext;
-	
+
 	/* we use all these weird stream things so we can do it with streams, and
 	   not have to read the whole lot into memory - although i have a feeling
 	   it would make things a fair bit simpler to do so ... */
-	
+
 	d(printf("starting to check part\n"));
-	
+
 	content = camel_medium_get_content_object ((CamelMedium *)part);
 	if (content == NULL) {
 		/* charset might not be right here, but it'll get the right stuff
@@ -863,7 +869,7 @@ find_best_encoding (CamelMimePart *part, CamelBestencRequired required, CamelBes
 		*charsetp = NULL;
 		return CAMEL_TRANSFER_ENCODING_DEFAULT;
 	}
-	
+
 	istext = camel_content_type_is (((CamelDataWrapper *) part)->mime_type, "text", "*");
 	if (istext) {
 		flags = CAMEL_BESTENC_GET_CHARSET | CAMEL_BESTENC_GET_ENCODING;
@@ -871,17 +877,17 @@ find_best_encoding (CamelMimePart *part, CamelBestencRequired required, CamelBes
 	} else {
 		flags = CAMEL_BESTENC_GET_ENCODING;
 	}
-	
+
 	/* when building the message, any encoded parts are translated already */
 	flags |= CAMEL_BESTENC_LF_IS_CRLF;
 	/* and get any flags the caller passed in */
 	callerflags = (required & CAMEL_BESTENC_NO_FROM);
 	flags |= callerflags;
-	
+
 	/* first a null stream, so any filtering is thrown away; we only want the sideeffects */
 	null = (CamelStream *)camel_stream_null_new ();
 	filter = camel_stream_filter_new_with_stream (null);
-	
+
 	/* if we're looking for the best charset, then we need to convert to UTF-8 */
 	if (istext && (required & CAMEL_BESTENC_GET_CHARSET) != 0
 	    && (charsetin = camel_content_type_param (content->mime_type, "charset"))) {
@@ -890,7 +896,7 @@ find_best_encoding (CamelMimePart *part, CamelBestencRequired required, CamelBes
 			idc = camel_stream_filter_add (filter, (CamelMimeFilter *)charenc);
 		charsetin = NULL;
 	}
-	
+
 	bestenc = camel_mime_filter_bestenc_new (flags);
 	idb = camel_stream_filter_add (filter, (CamelMimeFilter *)bestenc);
 	d(printf("writing to checking stream\n"));
@@ -901,56 +907,56 @@ find_best_encoding (CamelMimePart *part, CamelBestencRequired required, CamelBes
 		camel_object_unref (charenc);
 		charenc = NULL;
 	}
-	
+
 	if (istext && (required & CAMEL_BESTENC_GET_CHARSET) != 0) {
 		charsetin = camel_mime_filter_bestenc_get_best_charset (bestenc);
 		d(printf("best charset = %s\n", charsetin ? charsetin : "(null)"));
 		charset = g_strdup (charsetin);
-		
+
 		charsetin = camel_content_type_param (content->mime_type, "charset");
 	} else {
 		charset = NULL;
 	}
-	
+
 	/* if we have US-ASCII, or we're not doing text, we dont need to bother with the rest */
 	if (istext && charsetin && charset && (required & CAMEL_BESTENC_GET_CHARSET) != 0) {
 		d(printf("have charset, trying conversion/etc\n"));
-		
+
 		/* now that 'bestenc' has told us what the best encoding is, we can use that to create
 		   a charset conversion filter as well, and then re-add the bestenc to filter the
 		   result to find the best encoding to use as well */
-		
+
 		charenc = camel_mime_filter_charset_new_convert (charsetin, charset);
 		if (charenc != NULL) {
 			/* otherwise, try another pass, converting to the real charset */
-			
+
 			camel_mime_filter_reset ((CamelMimeFilter *)bestenc);
 			camel_mime_filter_bestenc_set_flags (bestenc, CAMEL_BESTENC_GET_ENCODING |
 							     CAMEL_BESTENC_LF_IS_CRLF | callerflags);
-			
+
 			camel_stream_filter_add (filter, (CamelMimeFilter *)charenc);
 			camel_stream_filter_add (filter, (CamelMimeFilter *)bestenc);
-			
+
 			/* and write it to the new stream */
 			camel_data_wrapper_write_to_stream (content, (CamelStream *)filter);
-			
+
 			camel_object_unref (charenc);
 		}
 	}
-	
+
 	encoding = camel_mime_filter_bestenc_get_best_encoding (bestenc, enctype);
-	
+
 	camel_object_unref (filter);
 	camel_object_unref (bestenc);
 	camel_object_unref (null);
-	
+
 	d(printf("done, best encoding = %d\n", encoding));
-	
+
 	if (charsetp)
 		*charsetp = charset;
 	else
 		g_free (charset);
-	
+
 	return encoding;
 }
 
@@ -960,44 +966,44 @@ struct _enc_data {
 };
 
 static gboolean
-best_encoding (CamelMimeMessage *msg, CamelMimePart *part, void *datap)
+best_encoding (CamelMimeMessage *msg, CamelMimePart *part, gpointer datap)
 {
 	struct _enc_data *data = datap;
 	CamelTransferEncoding encoding;
 	CamelDataWrapper *wrapper;
-	char *charset;
-	
+	gchar *charset;
+
 	wrapper = camel_medium_get_content_object (CAMEL_MEDIUM (part));
 	if (!wrapper)
 		return FALSE;
-	
+
 	/* we only care about actual content objects */
 	if (!CAMEL_IS_MULTIPART (wrapper) && !CAMEL_IS_MIME_MESSAGE (wrapper)) {
 		encoding = find_best_encoding (part, data->required, data->enctype, &charset);
 		/* we always set the encoding, if we got this far.  GET_CHARSET implies
 		   also GET_ENCODING */
 		camel_mime_part_set_encoding (part, encoding);
-		
+
 		if ((data->required & CAMEL_BESTENC_GET_CHARSET) != 0) {
 			if (camel_content_type_is (((CamelDataWrapper *) part)->mime_type, "text", "*")) {
-				char *newct;
-				
+				gchar *newct;
+
 				/* FIXME: ick, the part content_type interface needs fixing bigtime */
 				camel_content_type_set_param (((CamelDataWrapper *) part)->mime_type, "charset",
 							       charset ? charset : "us-ascii");
 				newct = camel_content_type_format (((CamelDataWrapper *) part)->mime_type);
 				if (newct) {
 					d(printf("Setting content-type to %s\n", newct));
-					
+
 					camel_mime_part_set_content_type (part, newct);
 					g_free (newct);
 				}
 			}
 		}
-		
+
 		g_free (charset);
 	}
-	
+
 	return TRUE;
 }
 
@@ -1020,13 +1026,13 @@ void
 camel_mime_message_set_best_encoding (CamelMimeMessage *msg, CamelBestencRequired required, CamelBestencEncoding enctype)
 {
 	struct _enc_data data;
-	
+
 	if ((required & (CAMEL_BESTENC_GET_ENCODING|CAMEL_BESTENC_GET_CHARSET)) == 0)
 		return;
-	
+
 	data.required = required;
 	data.enctype = enctype;
-	
+
 	camel_mime_message_foreach_part (msg, best_encoding, &data);
 }
 
@@ -1046,24 +1052,24 @@ camel_mime_message_encode_8bit_parts (CamelMimeMessage *mime_message)
 
 struct _check_content_id {
 	CamelMimePart *part;
-	const char *content_id;
+	const gchar *content_id;
 };
 
 static gboolean
-check_content_id (CamelMimeMessage *message, CamelMimePart *part, void *data)
+check_content_id (CamelMimeMessage *message, CamelMimePart *part, gpointer data)
 {
 	struct _check_content_id *check = (struct _check_content_id *) data;
-	const char *content_id;
+	const gchar *content_id;
 	gboolean found;
-	
+
 	content_id = camel_mime_part_get_content_id (part);
-	
+
 	found = content_id && !strcmp (content_id, check->content_id) ? TRUE : FALSE;
 	if (found) {
 		check->part = part;
 		camel_object_ref (part);
 	}
-	
+
 	return !found;
 }
 
@@ -1078,29 +1084,29 @@ check_content_id (CamelMimeMessage *message, CamelMimePart *part, void *data)
  * Returns: the MIME part with the requested id or %NULL if not found
  **/
 CamelMimePart *
-camel_mime_message_get_part_by_content_id (CamelMimeMessage *message, const char *id)
+camel_mime_message_get_part_by_content_id (CamelMimeMessage *message, const gchar *id)
 {
 	struct _check_content_id check;
-	
+
 	g_return_val_if_fail (CAMEL_IS_MIME_MESSAGE (message), NULL);
-	
+
 	if (id == NULL)
 		return NULL;
-	
+
 	check.content_id = id;
 	check.part = NULL;
-	
+
 	camel_mime_message_foreach_part (message, check_content_id, &check);
-	
+
 	return check.part;
 }
 
-static const char tz_months[][4] = {
+static const gchar tz_months[][4] = {
 	"Jan", "Feb", "Mar", "Apr", "May", "Jun",
 	"Jul", "Aug", "Sep", "Oct", "Nov", "Dec"
 };
 
-static const char tz_days[][4] = {
+static const gchar tz_days[][4] = {
 	"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"
 };
 
@@ -1113,23 +1119,23 @@ static const char tz_days[][4] = {
  *
  * Returns: an MBox from-line suitable for use in an mbox file
  **/
-char *
+gchar *
 camel_mime_message_build_mbox_from (CamelMimeMessage *message)
 {
 	struct _camel_header_raw *header = ((CamelMimePart *)message)->headers;
 	GString *out = g_string_new("From ");
-	char *ret;
-	const char *tmp;
+	gchar *ret;
+	const gchar *tmp;
 	time_t thetime;
-	int offset;
+	gint offset;
 	struct tm tm;
-	
+
 	tmp = camel_header_raw_find (&header, "Sender", NULL);
 	if (tmp == NULL)
 		tmp = camel_header_raw_find (&header, "From", NULL);
 	if (tmp != NULL) {
 		struct _camel_header_address *addr = camel_header_address_decode (tmp, NULL);
-		
+
 		tmp = NULL;
 		if (addr) {
 			if (addr->type == CAMEL_HEADER_ADDRESS_NAME) {
@@ -1139,10 +1145,10 @@ camel_mime_message_build_mbox_from (CamelMimeMessage *message)
 			camel_header_address_unref (addr);
 		}
 	}
-	
+
 	if (tmp == NULL)
 		g_string_append (out, "unknown@nodomain.now.au");
-	
+
 	/* try use the received header to get the date */
 	tmp = camel_header_raw_find (&header, "Received", NULL);
 	if (tmp) {
@@ -1150,11 +1156,11 @@ camel_mime_message_build_mbox_from (CamelMimeMessage *message)
 		if (tmp)
 			tmp++;
 	}
-	
+
 	/* if there isn't one, try the Date field */
 	if (tmp == NULL)
 		tmp = camel_header_raw_find (&header, "Date", NULL);
-	
+
 	thetime = camel_header_decode_date (tmp, &offset);
 	thetime += ((offset / 100) * (60 * 60)) + (offset % 100) * 60;
 	gmtime_r (&thetime, &tm);
@@ -1162,17 +1168,17 @@ camel_mime_message_build_mbox_from (CamelMimeMessage *message)
 				tz_days[tm.tm_wday], tz_months[tm.tm_mon],
 				tm.tm_mday, tm.tm_hour, tm.tm_min, tm.tm_sec,
 				tm.tm_year + 1900);
-	
+
 	ret = out->str;
 	g_string_free (out, FALSE);
-	
+
 	return ret;
 }
 
 static gboolean
-find_attachment (CamelMimeMessage *msg, CamelMimePart *part, void *data)
+find_attachment (CamelMimeMessage *msg, CamelMimePart *part, gpointer data)
 {
-	const char *disp;
+	const gchar *disp;
 	gboolean *found = (gboolean *)data;
 
 	g_return_val_if_fail (part != NULL, FALSE);
@@ -1211,12 +1217,12 @@ camel_mime_message_has_attachment (CamelMimeMessage *message)
 }
 
 static void
-cmm_dump_rec(CamelMimeMessage *msg, CamelMimePart *part, int body, int depth)
+cmm_dump_rec(CamelMimeMessage *msg, CamelMimePart *part, gint body, gint depth)
 {
 	CamelDataWrapper *containee;
-	int parts, i;
-	int go = TRUE;
-	char *s;
+	gint parts, i;
+	gint go = TRUE;
+	gchar *s;
 
 	s = alloca(depth+1);
 	memset(s, ' ', depth);
@@ -1226,19 +1232,19 @@ cmm_dump_rec(CamelMimeMessage *msg, CamelMimePart *part, int body, int depth)
 	printf("%smime-type: %s\n", s, camel_content_type_format(((CamelDataWrapper *)part)->mime_type));
 
 	containee = camel_medium_get_content_object((CamelMedium *)part);
-	
+
 	if (containee == NULL)
 		return;
 
 	printf("%scontent class: %s\n", s, ((CamelObject *)containee)->klass->name);
 	printf("%scontent mime-type: %s\n", s, camel_content_type_format(((CamelDataWrapper *)containee)->mime_type));
-	
+
 	/* using the object types is more accurate than using the mime/types */
 	if (CAMEL_IS_MULTIPART(containee)) {
 		parts = camel_multipart_get_number((CamelMultipart *)containee);
 		for (i = 0; go && i < parts; i++) {
 			CamelMimePart *mpart = camel_multipart_get_part((CamelMultipart *)containee, i);
-			
+
 			cmm_dump_rec(msg, mpart, body, depth+2);
 		}
 	} else if (CAMEL_IS_MIME_MESSAGE(containee)) {
@@ -1248,15 +1254,15 @@ cmm_dump_rec(CamelMimeMessage *msg, CamelMimePart *part, int body, int depth)
 
 /**
  * camel_mime_message_dump:
- * @msg: 
- * @body: 
- * 
+ * @msg:
+ * @body:
+ *
  * Dump information about the mime message to stdout.
  *
  * If body is TRUE, then dump body content of the message as well (currently unimplemented).
  **/
 void
-camel_mime_message_dump(CamelMimeMessage *msg, int body)
+camel_mime_message_dump(CamelMimeMessage *msg, gint body)
 {
 	cmm_dump_rec(msg, (CamelMimePart *)msg, body, 0);
 }
