@@ -44,10 +44,10 @@
 #include "camel-seekable-stream.h"
 #include "camel-stream.h"
 
-#define r(x) 
-#define h(x) 
-#define c(x) 
-#define d(x) 
+#define r(x)
+#define h(x)
+#define c(x)
+#define d(x)
 
 /*#define PRESERVE_HEADERS*/
 
@@ -56,7 +56,7 @@
 #define MEMPOOL
 
 #ifdef PURIFY
-int inend_id = -1,
+gint inend_id = -1,
   inbuffer_id = -1;
 #endif
 
@@ -74,30 +74,30 @@ struct _header_scan_state {
 	camel_mime_parser_state_t state;
 
 	/* for building headers during scanning */
-	char *outbuf;
-	char *outptr;
-	char *outend;
+	gchar *outbuf;
+	gchar *outptr;
+	gchar *outend;
 
-	int fd;			/* input for a fd input */
+	gint fd;			/* input for a fd input */
 	CamelStream *stream;	/* or for a stream */
 
-	int ioerrno;		/* io error state */
+	gint ioerrno;		/* io error state */
 
 	/* for scanning input buffers */
-	char *realbuf;		/* the real buffer, SCAN_HEAD*2 + SCAN_BUF bytes */
-	char *inbuf;		/* points to a subset of the allocated memory, the underflow */
-	char *inptr;		/* (upto SCAN_HEAD) is for use by filters so they dont copy all data */
-	char *inend;
+	gchar *realbuf;		/* the real buffer, SCAN_HEAD*2 + SCAN_BUF bytes */
+	gchar *inbuf;		/* points to a subset of the allocated memory, the underflow */
+	gchar *inptr;		/* (upto SCAN_HEAD) is for use by filters so they dont copy all data */
+	gchar *inend;
 
-	int atleast;
+	gint atleast;
 
 	off_t seek;		/* current offset to start of buffer */
-	int unstep;		/* how many states to 'unstep' (repeat the current state) */
+	gint unstep;		/* how many states to 'unstep' (repeat the current state) */
 
-	unsigned int midline:1;		/* are we mid-line interrupted? */
-	unsigned int scan_from:1;	/* do we care about From lines? */
-	unsigned int scan_pre_from:1;	/* do we return pre-from data? */
-	unsigned int eof:1;		/* reached eof? */
+	guint midline:1;		/* are we mid-line interrupted? */
+	guint scan_from:1;	/* do we care about From lines? */
+	guint scan_pre_from:1;	/* do we return pre-from data? */
+	guint eof:1;		/* reached eof? */
 
 	off_t start_of_from;	/* where from started */
 	off_t start_of_boundary; /* where the last boundary started */
@@ -106,7 +106,7 @@ struct _header_scan_state {
 	off_t header_start;	/* start of last header, or -1 */
 
 	/* filters to apply to all content before output */
-	int filterid;		/* id of next filter */
+	gint filterid;		/* id of next filter */
 	struct _header_scan_filter *filters;
 
     /* per message/part info */
@@ -129,45 +129,45 @@ struct _header_scan_stack {
 	/* I dont use GString's casue you can't efficiently append a buffer to them */
 	GByteArray *pretext;	/* for multipart types, save the pre-boundary data here */
 	GByteArray *posttext;	/* for multipart types, save the post-boundary data here */
-	int prestage;		/* used to determine if it is a pre-boundary or post-boundary data segment */
+	gint prestage;		/* used to determine if it is a pre-boundary or post-boundary data segment */
 
 	GByteArray *from_line;	/* the from line */
 
-	char *boundary;		/* for multipart/ * boundaries, including leading -- and trailing -- for the final part */
-	int boundarylen;	/* actual length of boundary, including leading -- if there is one */
-	int boundarylenfinal;	/* length of boundary, including trailing -- if there is one */
-	int atleast;		/* the biggest boundary from here to the parent */
+	gchar *boundary;		/* for multipart/ * boundaries, including leading -- and trailing -- for the final part */
+	gint boundarylen;	/* actual length of boundary, including leading -- if there is one */
+	gint boundarylenfinal;	/* length of boundary, including trailing -- if there is one */
+	gint atleast;		/* the biggest boundary from here to the parent */
 };
 
 struct _header_scan_filter {
 	struct _header_scan_filter *next;
-	int id;
+	gint id;
 	CamelMimeFilter *filter;
 };
 
-static void folder_scan_step(struct _header_scan_state *s, char **databuffer, size_t *datalength);
+static void folder_scan_step(struct _header_scan_state *s, gchar **databuffer, gsize *datalength);
 static void folder_scan_drop_step(struct _header_scan_state *s);
-static int folder_scan_init_with_fd(struct _header_scan_state *s, int fd);
-static int folder_scan_init_with_stream(struct _header_scan_state *s, CamelStream *stream);
+static gint folder_scan_init_with_fd(struct _header_scan_state *s, gint fd);
+static gint folder_scan_init_with_stream(struct _header_scan_state *s, CamelStream *stream);
 static struct _header_scan_state *folder_scan_init(void);
 static void folder_scan_close(struct _header_scan_state *s);
-static struct _header_scan_stack *folder_scan_content(struct _header_scan_state *s, int *lastone, char **data, size_t *length);
-static struct _header_scan_stack *folder_scan_header(struct _header_scan_state *s, int *lastone);
-static int folder_scan_skip_line(struct _header_scan_state *s, GByteArray *save);
-static off_t folder_seek(struct _header_scan_state *s, off_t offset, int whence);
+static struct _header_scan_stack *folder_scan_content(struct _header_scan_state *s, gint *lastone, gchar **data, gsize *length);
+static struct _header_scan_stack *folder_scan_header(struct _header_scan_state *s, gint *lastone);
+static gint folder_scan_skip_line(struct _header_scan_state *s, GByteArray *save);
+static off_t folder_seek(struct _header_scan_state *s, off_t offset, gint whence);
 static off_t folder_tell(struct _header_scan_state *s);
-static int folder_read(struct _header_scan_state *s);
+static gint folder_read(struct _header_scan_state *s);
 static void folder_push_part(struct _header_scan_state *s, struct _header_scan_stack *h);
 
 #ifdef MEMPOOL
-static void header_append_mempool(struct _header_scan_state *s, struct _header_scan_stack *h, char *header, int offset);
+static void header_append_mempool(struct _header_scan_state *s, struct _header_scan_stack *h, gchar *header, gint offset);
 #endif
 
 static void camel_mime_parser_class_init (CamelMimeParserClass *klass);
 static void camel_mime_parser_init       (CamelMimeParser *obj);
 
 #if d(!)0
-static char *states[] = {
+static gchar *states[] = {
 	"CAMEL_MIME_PARSER_STATE_INITIAL",
 	"CAMEL_MIME_PARSER_STATE_PRE_FROM",	/* pre-from data */
 	"CAMEL_MIME_PARSER_STATE_FROM",		/* got 'From' line */
@@ -219,7 +219,7 @@ CamelType
 camel_mime_parser_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (camel_object_get_type (), "CamelMimeParser",
 					    sizeof (CamelMimeParser),
@@ -229,7 +229,7 @@ camel_mime_parser_get_type (void)
 					    (CamelObjectInitFunc) camel_mime_parser_init,
 					    (CamelObjectFinalizeFunc) camel_mime_parser_finalise);
 	}
-	
+
 	return type;
 }
 
@@ -237,7 +237,7 @@ camel_mime_parser_get_type (void)
  * camel_mime_parser_new:
  *
  * Create a new CamelMimeParser object.
- * 
+ *
  * Return value: A new CamelMimeParser widget.
  **/
 CamelMimeParser *
@@ -250,9 +250,9 @@ camel_mime_parser_new (void)
 
 /**
  * camel_mime_parser_filter_add:
- * @m: 
- * @mf: 
- * 
+ * @m:
+ * @mf:
+ *
  * Add a filter that will be applied to any body content before it is passed
  * to the caller.  Filters may be pipelined to perform multi-pass operations
  * on the content, and are applied in the order they were added.
@@ -260,11 +260,11 @@ camel_mime_parser_new (void)
  * Note that filters are only applied to the body content of messages, and once
  * a filter has been set, all content returned by a filter_step() with a state
  * of CAMEL_MIME_PARSER_STATE_BODY will have passed through the filter.
- * 
+ *
  * Return value: An id that may be passed to filter_remove() to remove
  * the filter, or -1 if the operation failed.
  **/
-int
+gint
 camel_mime_parser_filter_add(CamelMimeParser *m, CamelMimeFilter *mf)
 {
 	struct _header_scan_state *s = _PRIVATE(m);
@@ -288,18 +288,18 @@ camel_mime_parser_filter_add(CamelMimeParser *m, CamelMimeFilter *mf)
 
 /**
  * camel_mime_parser_filter_remove:
- * @m: 
- * @id: 
- * 
+ * @m:
+ * @id:
+ *
  * Remove a processing filter from the pipeline.  There is no
  * restriction on the order the filters can be removed.
  **/
 void
-camel_mime_parser_filter_remove(CamelMimeParser *m, int id)
+camel_mime_parser_filter_remove(CamelMimeParser *m, gint id)
 {
 	struct _header_scan_state *s = _PRIVATE(m);
 	struct _header_scan_filter *f, *old;
-	
+
 	f = (struct _header_scan_filter *)&s->filters;
 	while (f && f->next) {
 		old = f->next;
@@ -316,18 +316,18 @@ camel_mime_parser_filter_remove(CamelMimeParser *m, int id)
 
 /**
  * camel_mime_parser_header:
- * @m: 
+ * @m:
  * @name: Name of header.
  * @offset: Pointer that can receive the offset of the header in
  * the stream from the start of parsing.
- * 
+ *
  * Lookup a header by name.
- * 
+ *
  * Return value: The header value, or NULL if the header is not
  * defined.
  **/
-const char *
-camel_mime_parser_header(CamelMimeParser *m, const char *name, int *offset)
+const gchar *
+camel_mime_parser_header(CamelMimeParser *m, const gchar *name, gint *offset)
 {
 	struct _header_scan_state *s = _PRIVATE(m);
 
@@ -340,12 +340,12 @@ camel_mime_parser_header(CamelMimeParser *m, const char *name, int *offset)
 
 /**
  * camel_mime_parser_headers_raw:
- * @m: 
- * 
+ * @m:
+ *
  * Get the list of the raw headers which are defined for the
  * current state of the parser.  These headers are valid
  * until the next call to parser_step(), or parser_drop_step().
- * 
+ *
  * Return value: The raw headers, or NULL if there are no headers
  * defined for the current part or state.  These are READ ONLY.
  **/
@@ -359,7 +359,7 @@ camel_mime_parser_headers_raw(CamelMimeParser *m)
 	return NULL;
 }
 
-static const char *
+static const gchar *
 byte_array_to_string(GByteArray *array)
 {
 	if (array == NULL)
@@ -368,19 +368,19 @@ byte_array_to_string(GByteArray *array)
 	if (array->len == 0 || array->data[array->len-1] != '\0')
 		g_byte_array_append(array, (guint8 *) "", 1);
 
-	return (const char *) array->data;
+	return (const gchar *) array->data;
 }
 
 /**
  * camel_mime_parser_preface:
- * @m: 
- * 
+ * @m:
+ *
  * Retrieve the preface text for the current multipart.
  * Can only be used when the state is CAMEL_MIME_PARSER_STATE_MULTIPART_END.
- * 
+ *
  * Return value: The preface text, or NULL if there wasn't any.
  **/
-const char *
+const gchar *
 camel_mime_parser_preface(CamelMimeParser *m)
 {
 	struct _header_scan_state *s = _PRIVATE(m);
@@ -393,15 +393,15 @@ camel_mime_parser_preface(CamelMimeParser *m)
 
 /**
  * camel_mime_parser_postface:
- * @m: 
- * 
+ * @m:
+ *
  * Retrieve the postface text for the current multipart.
  * Only returns valid data when the current state if
  * CAMEL_MIME_PARSER_STATE_MULTIPART_END.
- * 
+ *
  * Return value: The postface text, or NULL if there wasn't any.
  **/
-const char *
+const gchar *
 camel_mime_parser_postface(CamelMimeParser *m)
 {
 	struct _header_scan_state *s = _PRIVATE(m);
@@ -414,18 +414,18 @@ camel_mime_parser_postface(CamelMimeParser *m)
 
 /**
  * camel_mime_parser_from_line:
- * @m: 
- * 
+ * @m:
+ *
  * Get the last scanned "From " line, from a recently scanned from.
  * This should only be called in the CAMEL_MIME_PARSER_STATE_FROM state.  The
  * from line will include the closing \n found (if there was one).
  *
  * The return value will remain valid while in the CAMEL_MIME_PARSER_STATE_FROM
  * state, or any deeper state.
- * 
+ *
  * Return value: The From line, or NULL if called out of context.
  **/
-const char *
+const gchar *
 camel_mime_parser_from_line(CamelMimeParser *m)
 {
 	struct _header_scan_state *s = _PRIVATE(m);
@@ -438,9 +438,9 @@ camel_mime_parser_from_line(CamelMimeParser *m)
 
 /**
  * camel_mime_parser_init_with_fd:
- * @m: 
+ * @m:
  * @fd: A valid file descriptor.
- * 
+ *
  * Initialise the scanner with an fd.  The scanner's offsets
  * will be relative to the current file position of the file
  * descriptor.  As a result, seekable descritors should
@@ -448,8 +448,8 @@ camel_mime_parser_from_line(CamelMimeParser *m)
  *
  * Return value: Returns -1 on error.
  **/
-int
-camel_mime_parser_init_with_fd(CamelMimeParser *m, int fd)
+gint
+camel_mime_parser_init_with_fd(CamelMimeParser *m, gint fd)
 {
 	struct _header_scan_state *s = _PRIVATE(m);
 
@@ -458,17 +458,17 @@ camel_mime_parser_init_with_fd(CamelMimeParser *m, int fd)
 
 /**
  * camel_mime_parser_init_with_stream:
- * @m: 
- * @stream: 
- * 
+ * @m:
+ * @stream:
+ *
  * Initialise the scanner with a source stream.  The scanner's
  * offsets will be relative to the current file position of
  * the stream.  As a result, seekable streams should only
  * be seeked using the parser seek function.
- * 
+ *
  * Return value: -1 on error.
  **/
-int
+gint
 camel_mime_parser_init_with_stream(CamelMimeParser *m, CamelStream *stream)
 {
 	struct _header_scan_state *s = _PRIVATE(m);
@@ -480,7 +480,7 @@ camel_mime_parser_init_with_stream(CamelMimeParser *m, CamelStream *stream)
  * camel_mime_parser_scan_from:
  * @parser: MIME parser object
  * @scan_from: #TRUE if the scanner should scan From lines.
- * 
+ *
  * Tell the scanner if it should scan "^From " lines or not.
  *
  * If the scanner is scanning from lines, two additional
@@ -496,7 +496,7 @@ void
 camel_mime_parser_scan_from (CamelMimeParser *parser, gboolean scan_from)
 {
 	struct _header_scan_state *s = _PRIVATE (parser);
-	
+
 	s->scan_from = scan_from;
 }
 
@@ -504,7 +504,7 @@ camel_mime_parser_scan_from (CamelMimeParser *parser, gboolean scan_from)
  * camel_mime_parser_scan_pre_from:
  * @parser: MIME parser object
  * @scan_pre_from: #TRUE if we want to get pre-from data.
- * 
+ *
  * Tell the scanner whether we want to know abou the pre-from
  * data during a scan.  If we do, then we may get an additional
  * state CAMEL_MIME_PARSER_STATE_PRE_FROM which returns the specified data.
@@ -513,16 +513,16 @@ void
 camel_mime_parser_scan_pre_from (CamelMimeParser *parser, gboolean scan_pre_from)
 {
 	struct _header_scan_state *s = _PRIVATE (parser);
-	
+
 	s->scan_pre_from = scan_pre_from;
 }
 
 /**
  * camel_mime_parser_content_type:
  * @parser: MIME parser object
- * 
+ *
  * Get the content type defined in the current part.
- * 
+ *
  * Return value: A content_type structure, or NULL if there
  * is no content-type defined for this part of state of the
  * parser.
@@ -531,20 +531,20 @@ CamelContentType *
 camel_mime_parser_content_type (CamelMimeParser *parser)
 {
 	struct _header_scan_state *s = _PRIVATE (parser);
-	
+
 	/* FIXME: should this search up until it's found the 'right'
 	   content-type?  can it? */
 	if (s->parts)
 		return s->parts->content_type;
-	
+
 	return NULL;
 }
 
 /**
  * camel_mime_parser_unstep:
  * @parser: MIME parser object
- * 
- * Cause the last step operation to repeat itself.  If this is 
+ *
+ * Cause the last step operation to repeat itself.  If this is
  * called repeated times, then the same step will be repeated
  * that many times.
  *
@@ -555,14 +555,14 @@ void
 camel_mime_parser_unstep (CamelMimeParser *parser)
 {
 	struct _header_scan_state *s = _PRIVATE (parser);
-	
+
 	s->unstep++;
 }
 
 /**
  * camel_mime_parser_drop_step:
  * @parser: MIME parser object
- * 
+ *
  * Drop the last step call.  This should only be used
  * in conjunction with seeking of the stream as the
  * stream may be in an undefined state relative to the
@@ -574,20 +574,20 @@ void
 camel_mime_parser_drop_step (CamelMimeParser *parser)
 {
 	struct _header_scan_state *s = _PRIVATE (parser);
-	
+
 	s->unstep = 0;
 	folder_scan_drop_step(s);
 }
 
 /**
  * camel_mime_parser_step:
- * @parser: MIME parser object 
+ * @parser: MIME parser object
  * @databuffer: Pointer to accept a pointer to the data
  * associated with this step (if any).  May be #NULL,
  * in which case datalength is also ingored.
  * @datalength: Pointer to accept a pointer to the data
  * length associated with this step (if any).
- * 
+ *
  * Parse the next part of the MIME message.  If _unstep()
  * has been called, then continue to return the same state
  * for that many calls.
@@ -605,21 +605,21 @@ camel_mime_parser_drop_step (CamelMimeParser *parser)
  * is returned.
  **/
 camel_mime_parser_state_t
-camel_mime_parser_step (CamelMimeParser *parser, char **databuffer, size_t *datalength)
+camel_mime_parser_step (CamelMimeParser *parser, gchar **databuffer, gsize *datalength)
 {
 	struct _header_scan_state *s = _PRIVATE (parser);
 
 	d(printf("OLD STATE:  '%s' :\n", states[s->state]));
 
 	if (s->unstep <= 0) {
-		char *dummy;
-		size_t dummylength;
+		gchar *dummy;
+		gsize dummylength;
 
 		if (databuffer == NULL) {
 			databuffer = &dummy;
 			datalength = &dummylength;
 		}
-			
+
 		folder_scan_step(s, databuffer, datalength);
 	} else
 		s->unstep--;
@@ -632,9 +632,9 @@ camel_mime_parser_step (CamelMimeParser *parser, char **databuffer, size_t *data
 /**
  * camel_mime_parser_read:
  * @parser: MIME parser object
- * @databuffer: 
- * @len: 
- * 
+ * @databuffer:
+ * @len:
+ *
  * Read at most @len bytes from the internal mime parser buffer.
  *
  * Returns the address of the internal buffer in @databuffer,
@@ -649,11 +649,11 @@ camel_mime_parser_step (CamelMimeParser *parser, char **databuffer, size_t *data
  *
  * Return value: The number of bytes available, or -1 on error.
  **/
-int
-camel_mime_parser_read (CamelMimeParser *parser, const char **databuffer, int len)
+gint
+camel_mime_parser_read (CamelMimeParser *parser, const gchar **databuffer, gint len)
 {
 	struct _header_scan_state *s = _PRIVATE (parser);
-	int there;
+	gint there;
 
 	if (len == 0)
 		return 0;
@@ -683,7 +683,7 @@ camel_mime_parser_read (CamelMimeParser *parser, const char **databuffer, int le
 /**
  * camel_mime_parser_tell:
  * @parser: MIME parser object
- * 
+ *
  * Return the current scanning offset.  The meaning of this
  * value will depend on the current state of the parser.
  *
@@ -697,7 +697,7 @@ camel_mime_parser_read (CamelMimeParser *parser, const char **databuffer, int le
  * CAMEL_MIME_PARSER_STATE_*_END, The position of the character starting
  * the next section of the scan (the last position + 1 of
  * the respective current state).
- * 
+ *
  * Return value: See above.
  **/
 off_t
@@ -711,11 +711,11 @@ camel_mime_parser_tell (CamelMimeParser *parser)
 /**
  * camel_mime_parser_tell_start_headers:
  * @parser: MIME parser object
- * 
+ *
  * Find out the position within the file of where the
  * headers started, this is cached by the parser
  * at the time.
- * 
+ *
  * Return value: The header start position, or -1 if
  * no headers were scanned in the current state.
  **/
@@ -730,10 +730,10 @@ camel_mime_parser_tell_start_headers (CamelMimeParser *parser)
 /**
  * camel_mime_parser_tell_start_from:
  * @parser: MIME parser object
- * 
+ *
  * If the parser is scanning From lines, then this returns
  * the position of the start of the From line.
- * 
+ *
  * Return value: The start of the from line, or -1 if there
  * was no From line, or From lines are not being scanned.
  **/
@@ -748,10 +748,10 @@ camel_mime_parser_tell_start_from (CamelMimeParser *parser)
 /**
  * camel_mime_parser_tell_start_boundary:
  * @parser: MIME parser object
- * 
+ *
  * When parsing a multipart, this returns the start of the last
  * boundary.
- * 
+ *
  * Return value: The start of the boundary, or -1 if there
  * was no boundary encountered yet.
  **/
@@ -768,39 +768,39 @@ camel_mime_parser_tell_start_boundary(CamelMimeParser *parser)
  * @parser: MIME parser object
  * @offset: Number of bytes to offset the seek by.
  * @whence: SEEK_SET, SEEK_CUR, SEEK_END
- * 
+ *
  * Reset the source position to a known value.
  *
  * Note that if the source stream/descriptor was not
  * positioned at 0 to begin with, and an absolute seek
  * is specified (whence != SEEK_CUR), then the seek
  * position may not match the desired seek position.
- * 
+ *
  * Return value: The new seek offset, or -1 on
  * an error (for example, trying to seek on a non-seekable
  * stream or file descriptor).
  **/
 off_t
-camel_mime_parser_seek(CamelMimeParser *parser, off_t offset, int whence)
+camel_mime_parser_seek(CamelMimeParser *parser, off_t offset, gint whence)
 {
 	struct _header_scan_state *s = _PRIVATE (parser);
-	
+
 	return folder_seek(s, offset, whence);
 }
 
 /**
  * camel_mime_parser_state:
  * @parser: MIME parser object
- * 
+ *
  * Get the current parser state.
- * 
+ *
  * Return value: The current parser state.
  **/
 camel_mime_parser_state_t
 camel_mime_parser_state (CamelMimeParser *parser)
 {
 	struct _header_scan_state *s = _PRIVATE (parser);
-	
+
 	return s->state;
 }
 
@@ -809,12 +809,12 @@ camel_mime_parser_state (CamelMimeParser *parser)
  * @mp: MIME parser object
  * @newstate: New state
  * @boundary: Boundary marker for state.
- * 
+ *
  * Pre-load a new parser state.  Used to post-parse multipart content
  * without headers.
  **/
 void
-camel_mime_parser_push_state(CamelMimeParser *mp, camel_mime_parser_state_t newstate, const char *boundary)
+camel_mime_parser_push_state(CamelMimeParser *mp, camel_mime_parser_state_t newstate, const gchar *boundary)
 {
 	struct _header_scan_stack *h;
 	struct _header_scan_state *s = _PRIVATE(mp);
@@ -831,12 +831,12 @@ camel_mime_parser_push_state(CamelMimeParser *mp, camel_mime_parser_state_t news
 /**
  * camel_mime_parser_stream:
  * @parser: MIME parser object
- * 
+ *
  * Get the stream, if any, the parser has been initialised
  * with.  May be used to setup sub-streams, but should not
  * be read from directly (without saving and restoring
  * the seek position in between).
- * 
+ *
  * Return value: The stream from _init_with_stream(), or NULL
  * if the parser is reading from a file descriptor or is
  * uninitialised.
@@ -845,38 +845,38 @@ CamelStream *
 camel_mime_parser_stream (CamelMimeParser *parser)
 {
 	struct _header_scan_state *s = _PRIVATE (parser);
-	
+
 	return s->stream;
 }
 
 /**
  * camel_mime_parser_fd:
  * @parser: MIME parser object
- * 
+ *
  * Return the file descriptor, if any, the parser has been
  * initialised with.
  *
  * Should not be read from unless the parser it to terminate,
  * or the seek offset can be reset before the next parse
  * step.
- * 
+ *
  * Return value: The file descriptor or -1 if the parser
  * is reading from a stream or has not been initialised.
  **/
-int
+gint
 camel_mime_parser_fd (CamelMimeParser *parser)
 {
 	struct _header_scan_state *s = _PRIVATE (parser);
-	
+
 	return s->fd;
 }
 
 /* Return errno of the parser, incase any error occured during processing */
-int
+gint
 camel_mime_parser_errno (CamelMimeParser *parser)
 {
 	struct _header_scan_state *s = _PRIVATE (parser);
-	
+
 	return s->ioerrno;
 }
 
@@ -885,11 +885,11 @@ camel_mime_parser_errno (CamelMimeParser *parser)
 /* ********************************************************************** */
 
 /* read the next bit of data, ensure there is enough room 'atleast' bytes */
-static int
+static gint
 folder_read(struct _header_scan_state *s)
 {
-	int len;
-	int inoffset;
+	gint len;
+	gint inoffset;
 
 	if (s->inptr<s->inend-s->atleast || s->eof)
 		return s->inend-s->inptr;
@@ -938,11 +938,11 @@ folder_tell(struct _header_scan_state *s)
 }
 
 /*
-  need some way to prime the parser state, so this actually works for 
+  need some way to prime the parser state, so this actually works for
   other than top-level messages
 */
 static off_t
-folder_seek(struct _header_scan_state *s, off_t offset, int whence)
+folder_seek(struct _header_scan_state *s, off_t offset, gint whence)
 {
 	off_t newoffset;
 
@@ -1016,12 +1016,12 @@ folder_pull_part(struct _header_scan_state *s)
 	}
 }
 
-static int
+static gint
 folder_scan_skip_line(struct _header_scan_state *s, GByteArray *save)
 {
-	int atleast = s->atleast;
-	register char *inptr, *inend, c;
-	int len;
+	gint atleast = s->atleast;
+	register gchar *inptr, *inend, c;
+	gint len;
 
 	s->atleast = 1;
 
@@ -1058,10 +1058,10 @@ folder_scan_skip_line(struct _header_scan_state *s, GByteArray *save)
 
 /* TODO: Is there any way to make this run faster?  It gets called a lot ... */
 static struct _header_scan_stack *
-folder_boundary_check(struct _header_scan_state *s, const char *boundary, int *lastone)
+folder_boundary_check(struct _header_scan_state *s, const gchar *boundary, gint *lastone)
 {
 	struct _header_scan_stack *part;
-	int len = s->inend - boundary; /* make sure we dont access past the buffer */
+	gint len = s->inend - boundary; /* make sure we dont access past the buffer */
 
 	h(printf("checking boundary marker upto %d bytes\n", len));
 	part = s->parts;
@@ -1074,8 +1074,8 @@ folder_boundary_check(struct _header_scan_state *s, const char *boundary, int *l
 			h(printf("matched boundary: %s\n", part->boundary));
 			/* again, make sure we're in range */
 			if (part->boundarylenfinal <= len) {
-				int extra = part->boundarylenfinal - part->boundarylen;
-				
+				gint extra = part->boundarylenfinal - part->boundarylen;
+
 				/* check the extra stuff on an final boundary, normally -- for mime parts */
 				if (extra>0) {
 					*lastone = memcmp(&boundary[part->boundarylen],
@@ -1099,38 +1099,38 @@ folder_boundary_check(struct _header_scan_state *s, const char *boundary, int *l
 
 #ifdef MEMPOOL
 static void
-header_append_mempool(struct _header_scan_state *s, struct _header_scan_stack *h, char *header, int offset)
+header_append_mempool(struct _header_scan_state *s, struct _header_scan_stack *h, gchar *header, gint offset)
 {
 	struct _camel_header_raw *l, *n;
-	char *content;
-	
+	gchar *content;
+
 	content = strchr(header, ':');
 	if (content) {
-		register int len;
+		register gint len;
 		n = e_mempool_alloc(h->pool, sizeof(*n));
 		n->next = NULL;
-		
+
 		len = content-header;
 		n->name = e_mempool_alloc(h->pool, len+1);
 		memcpy(n->name, header, len);
 		n->name[len] = 0;
-		
+
 		content++;
-		
+
 		len = s->outptr - content;
 		n->value = e_mempool_alloc(h->pool, len+1);
 		memcpy(n->value, content, len);
 		n->value[len] = 0;
-		
+
 		n->offset = offset;
-		
+
 		l = (struct _camel_header_raw *)&h->headers;
 		while (l->next) {
 			l = l->next;
 		}
 		l->next = n;
 	}
-	
+
 }
 
 #define header_raw_append_parse(a, b, c) (header_append_mempool(s, h, b, c))
@@ -1144,12 +1144,12 @@ header_append_mempool(struct _header_scan_state *s, struct _header_scan_stack *h
 /* Basically an optimised version of g_byte_array_append() */
 #define header_append(s, start, inptr)								\
 {												\
-	register int headerlen = inptr-start;							\
+	register gint headerlen = inptr-start;							\
 												\
 	if (headerlen > 0) {									\
 		if (headerlen >= (s->outend - s->outptr)) {					\
-			register char *outnew;							\
-			register int olen = ((s->outend - s->outbuf) + headerlen) * 2 + 1;	\
+			register gchar *outnew;							\
+			register gint olen = ((s->outend - s->outbuf) + headerlen) * 2 + 1;	\
 			outnew = g_realloc(s->outbuf, olen);					\
 			s->outptr = s->outptr - s->outbuf + outnew;				\
 			s->outbuf = outnew;							\
@@ -1165,14 +1165,14 @@ header_append_mempool(struct _header_scan_state *s, struct _header_scan_stack *h
 }
 
 static struct _header_scan_stack *
-folder_scan_header(struct _header_scan_state *s, int *lastone)
+folder_scan_header(struct _header_scan_state *s, gint *lastone)
 {
-	int atleast = s->atleast, newatleast;
-	char *start = NULL;
-	int len;
+	gint atleast = s->atleast, newatleast;
+	gchar *start = NULL;
+	gint len;
 	struct _header_scan_stack *h;
-	char *inend;
-	register char *inptr;
+	gchar *inend;
+	register gchar *inptr;
 
 	h(printf("scanning first bit\n"));
 
@@ -1195,25 +1195,24 @@ folder_scan_header(struct _header_scan_state *s, int *lastone)
 		while ((len = folder_read(s))>0 && len >= s->atleast) { /* ensure we have at least enough room here */
 			inptr = s->inptr;
 			inend = s->inend-s->atleast+1;
-			
+
 			while (inptr<inend) {
+				start = inptr;
 				if (!s->midline) {
 					if (folder_boundary_check(s, inptr, lastone)) {
 						if ((s->outptr>s->outbuf))
 							goto header_truncated; /* may not actually be truncated */
-						
+
 						goto header_done;
 					}
 				}
-				
-				start = inptr;
 
 				/* goto next line/sentinal */
 				while ((*inptr++)!='\n')
 					;
-			
+
 				g_assert(inptr<=s->inend+1);
-				
+
 				/* check for sentinal or real end of line */
 				if (inptr > inend) {
 					h(printf("not at end of line yet, going further\n"));
@@ -1231,7 +1230,7 @@ folder_scan_header(struct _header_scan_state *s, int *lastone)
 					if (s->outbuf == s->outptr)
 						goto header_done;
 
-					/* check for continuation/compress headers, we have atleast 1 char here to work with */
+					/* check for continuation/compress headers, we have atleast 1 gchar here to work with */
 					if (inptr[0] ==  ' ' || inptr[0] == '\t') {
 						h(printf("continuation\n"));
 
@@ -1253,9 +1252,9 @@ folder_scan_header(struct _header_scan_state *s, int *lastone)
 					} else {
 						/* otherwise, complete header, add it */
 						s->outptr[0] = 0;
-				
-						h(printf("header '%s' at %d\n", s->outbuf, (int)s->header_start));
-						
+
+						h(printf("header '%s' at %d\n", s->outbuf, (gint)s->header_start));
+
 						header_raw_append_parse(&h->headers, s->outbuf, s->header_start);
 						s->outptr = s->outbuf;
 						s->header_start = -1;
@@ -1277,20 +1276,20 @@ folder_scan_header(struct _header_scan_state *s, int *lastone)
 		}
 		goto header_truncated;
 	}
-	
+
 	s->atleast = atleast;
-	
+
 	return h;
-	
+
 header_truncated:
 	header_append(s, start, inptr);
-	
+
 	s->outptr[0] = 0;
 	if (s->outbuf == s->outptr)
 		goto header_done;
-	
+
 	header_raw_append_parse(&h->headers, s->outbuf, s->header_start);
-	
+
 	s->outptr = s->outbuf;
 header_done:
 	s->inptr = inptr;
@@ -1300,15 +1299,15 @@ header_done:
 }
 
 static struct _header_scan_stack *
-folder_scan_content(struct _header_scan_state *s, int *lastone, char **data, size_t *length)
+folder_scan_content(struct _header_scan_state *s, gint *lastone, gchar **data, gsize *length)
 {
-	int atleast = s->atleast, newatleast;
-	register char *inptr;
-	char *inend;
-	char *start;
-	int len;
+	gint atleast = s->atleast, newatleast;
+	register gchar *inptr;
+	gchar *inend;
+	gchar *start;
+	gint len;
 	struct _header_scan_stack *part;
-	int onboundary = FALSE;
+	gint onboundary = FALSE;
 
 	c(printf("scanning content\n"));
 
@@ -1339,7 +1338,7 @@ folder_scan_content(struct _header_scan_state *s, int *lastone, char **data, siz
 				    && (part = folder_boundary_check(s, inptr, lastone))) {
 					onboundary = TRUE;
 
-					/* since we truncate the boundary data, we need at least 1 char here spare,
+					/* since we truncate the boundary data, we need at least 1 gchar here spare,
 					   to remain in the same state */
 					if ( (inptr-start) > 1)
 						goto content;
@@ -1347,7 +1346,7 @@ folder_scan_content(struct _header_scan_state *s, int *lastone, char **data, siz
 					/* otherwise, jump to the state of the boundary we actually found */
 					goto normal_exit;
 				}
-				
+
 				/* goto the next line */
 				while ((*inptr++)!='\n')
 					;
@@ -1495,8 +1494,8 @@ folder_scan_reset(struct _header_scan_state *s)
 	s->eof = FALSE;
 }
 
-static int
-folder_scan_init_with_fd(struct _header_scan_state *s, int fd)
+static gint
+folder_scan_init_with_fd(struct _header_scan_state *s, gint fd)
 {
 	folder_scan_reset(s);
 	s->fd = fd;
@@ -1504,7 +1503,7 @@ folder_scan_init_with_fd(struct _header_scan_state *s, int fd)
 	return 0;
 }
 
-static int
+static gint
 folder_scan_init_with_stream(struct _header_scan_state *s, CamelStream *stream)
 {
 	folder_scan_reset(s);
@@ -1517,15 +1516,15 @@ folder_scan_init_with_stream(struct _header_scan_state *s, CamelStream *stream)
 #define USE_FROM
 
 static void
-folder_scan_step(struct _header_scan_state *s, char **databuffer, size_t *datalength)
+folder_scan_step(struct _header_scan_state *s, gchar **databuffer, gsize *datalength)
 {
 	struct _header_scan_stack *h, *hb;
-	const char *content;
-	const char *bound;
-	int type, state, seenlast;
+	const gchar *content;
+	const gchar *bound;
+	gint type, state, seenlast;
 	CamelContentType *ct = NULL;
 	struct _header_scan_filter *f;
-	size_t presize;
+	gsize presize;
 
 /*	printf("\nSCAN PASS: state = %d '%s'\n", s->state, states[s->state]);*/
 
@@ -1647,21 +1646,21 @@ tail_recurse:
 		folder_push_part(s, h);
 		s->state = type;
 		return;
-		
+
 	case CAMEL_MIME_PARSER_STATE_HEADER:
 		s->state = CAMEL_MIME_PARSER_STATE_BODY;
-		
+
 	case CAMEL_MIME_PARSER_STATE_BODY:
 		h = s->parts;
 		*datalength = 0;
 		presize = SCAN_HEAD;
 		f = s->filters;
-		
+
 		do {
 			hb = folder_scan_content (s, &state, databuffer, datalength);
 
 			d(printf ("\n\nOriginal content: '"));
-			d(fwrite(*databuffer, sizeof(char), *datalength, stdout));
+			d(fwrite(*databuffer, sizeof(gchar), *datalength, stdout));
 			d(printf("'\n"));
 
 			if (*datalength > 0) {
@@ -1669,14 +1668,14 @@ tail_recurse:
 					camel_mime_filter_filter(f->filter, *databuffer, *datalength, presize,
 								 databuffer, datalength, &presize);
 					d(printf("Filtered content (%s): '", ((CamelObject *)f->filter)->klass->name));
-					d(fwrite(*databuffer, sizeof(char), *datalength, stdout));
+					d(fwrite(*databuffer, sizeof(gchar), *datalength, stdout));
 					d(printf("'\n"));
 					f = f->next;
 				}
 				return;
 			}
 		} while (hb == h && *datalength > 0);
-		
+
 		/* check for any filter completion data */
 		while (f) {
 			camel_mime_filter_complete(f->filter, *databuffer, *datalength, presize,
@@ -1686,10 +1685,10 @@ tail_recurse:
 
 		if (*datalength > 0)
 			return;
-		
+
 		s->state = CAMEL_MIME_PARSER_STATE_BODY_END;
 		break;
-		
+
 	case CAMEL_MIME_PARSER_STATE_MULTIPART:
 		h = s->parts;
 		/* This mess looks for the next boundary on this
@@ -1804,17 +1803,17 @@ folder_scan_drop_step(struct _header_scan_state *s)
 }
 
 #ifdef STANDALONE
-int main(int argc, char **argv)
+gint main(gint argc, gchar **argv)
 {
-	int fd;
+	gint fd;
 	struct _header_scan_state *s;
-	char *data;
-	size_t len;
-	int state;
-	char *name = "/tmp/evmail/Inbox";
+	gchar *data;
+	gsize len;
+	gint state;
+	gchar *name = "/tmp/evmail/Inbox";
 	struct _header_scan_stack *h;
-	int i;
-	int attach = 0;
+	gint i;
+	gint attach = 0;
 
 	if (argc==2)
 		name = argv[1];
@@ -1822,12 +1821,12 @@ int main(int argc, char **argv)
 	printf("opening: %s", name);
 
 	for (i=1;i<argc;i++) {
-		const char *encoding = NULL, *charset = NULL;
-		char *attachname;
+		const gchar *encoding = NULL, *charset = NULL;
+		gchar *attachname;
 
 		name = argv[i];
 		printf("opening: %s", name);
-		
+
 		fd = g_open(name, O_RDONLY|O_BINARY, 0);
 		if (fd==-1) {
 			perror("Cannot open mailbox");
@@ -1840,7 +1839,7 @@ int main(int argc, char **argv)
 		h = g_malloc0(sizeof(*h));
 		h->savestate = CAMEL_MIME_PARSER_STATE_EOF;
 		folder_push_part(s, h);
-#endif	
+#endif
 		while (s->state != CAMEL_MIME_PARSER_STATE_EOF) {
 			folder_scan_step(s, &data, &len);
 			printf("\n -- PARSER STEP RETURN -- %d '%s'\n\n", s->state, states[s->state]);
