@@ -1,15 +1,15 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; fill-column: 160 -*- */
 /* camelMimePart.c : Abstract class for a mime_part */
 
-/* 
+/*
  * Authors: Bertrand Guiheneuf <bertrand@helixcode.com>
  *	    Michael Zucchi <notzed@ximian.com>
  *          Jeffrey Stedfast <fejj@ximian.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -74,29 +74,29 @@ static CamelMediumClass *parent_class=NULL;
 #define CMD_CLASS(so) CAMEL_MEDIUM_CLASS (CAMEL_OBJECT_GET_CLASS(so))
 
 /* from CamelDataWrapper */
-static ssize_t         write_to_stream                 (CamelDataWrapper *dw, CamelStream *stream);
-static int	       construct_from_stream	       (CamelDataWrapper *dw, CamelStream *stream);
+static gssize         write_to_stream                 (CamelDataWrapper *dw, CamelStream *stream);
+static gint	       construct_from_stream	       (CamelDataWrapper *dw, CamelStream *stream);
 
-/* from CamelMedium */ 
-static void            add_header                      (CamelMedium *medium, const char *name, const void *value);
-static void            set_header                      (CamelMedium *medium, const char *name, const void *value);
-static void            remove_header                   (CamelMedium *medium, const char *name);
-static const void     *get_header                      (CamelMedium *medium, const char *name);
+/* from CamelMedium */
+static void            add_header                      (CamelMedium *medium, const gchar *name, gconstpointer value);
+static void            set_header                      (CamelMedium *medium, const gchar *name, gconstpointer value);
+static void            remove_header                   (CamelMedium *medium, const gchar *name);
+static const void     *get_header                      (CamelMedium *medium, const gchar *name);
 static GArray         *get_headers                     (CamelMedium *medium);
 static void            free_headers                    (CamelMedium *medium, GArray *headers);
 
 static void            set_content_object              (CamelMedium *medium, CamelDataWrapper *content);
 
 /* from camel mime parser */
-static int             construct_from_parser           (CamelMimePart *mime_part, CamelMimeParser *mp);
+static gint             construct_from_parser           (CamelMimePart *mime_part, CamelMimeParser *mp);
 
 /* forward references */
-static void set_disposition (CamelMimePart *mime_part, const char *disposition);
+static void set_disposition (CamelMimePart *mime_part, const gchar *disposition);
 
 /* format output of headers */
-static ssize_t write_references(CamelStream *stream, struct _camel_header_raw *h);
-/*static int write_fold(CamelStream *stream, struct _camel_header_raw *h);*/
-static ssize_t write_raw(CamelStream *stream, struct _camel_header_raw *h);
+static gssize write_references(CamelStream *stream, struct _camel_header_raw *h);
+/*static gint write_fold(CamelStream *stream, struct _camel_header_raw *h);*/
+static gssize write_raw(CamelStream *stream, struct _camel_header_raw *h);
 
 
 /* loads in a hash table the set of header names we */
@@ -105,26 +105,69 @@ static ssize_t write_raw(CamelStream *stream, struct _camel_header_raw *h);
 static void
 init_header_name_table(void)
 {
-	header_name_table = g_hash_table_new (camel_strcase_hash, camel_strcase_equal);
-	g_hash_table_insert (header_name_table, "Content-Description", (gpointer)HEADER_DESCRIPTION);
-	g_hash_table_insert (header_name_table, "Content-Disposition", (gpointer)HEADER_DISPOSITION);
-	g_hash_table_insert (header_name_table, "Content-id", (gpointer)HEADER_CONTENT_ID);
-	g_hash_table_insert (header_name_table, "Content-Transfer-Encoding", (gpointer)HEADER_ENCODING);
-	g_hash_table_insert (header_name_table, "Content-MD5", (gpointer)HEADER_CONTENT_MD5);
-	g_hash_table_insert (header_name_table, "Content-Location", (gpointer)HEADER_CONTENT_LOCATION);
-	g_hash_table_insert (header_name_table, "Content-Type", (gpointer)HEADER_CONTENT_TYPE);
+	header_name_table = g_hash_table_new (
+		camel_strcase_hash, camel_strcase_equal);
+	g_hash_table_insert (
+		header_name_table,
+		(gpointer) "Content-Description",
+		(gpointer) HEADER_DESCRIPTION);
+	g_hash_table_insert (
+		header_name_table,
+		(gpointer) "Content-Disposition",
+		(gpointer) HEADER_DISPOSITION);
+	g_hash_table_insert (
+		header_name_table,
+		(gpointer) "Content-id",
+		(gpointer) HEADER_CONTENT_ID);
+	g_hash_table_insert (
+		header_name_table,
+		(gpointer) "Content-Transfer-Encoding",
+		(gpointer) HEADER_ENCODING);
+	g_hash_table_insert (
+		header_name_table,
+		(gpointer) "Content-MD5",
+		(gpointer) HEADER_CONTENT_MD5);
+	g_hash_table_insert (
+		header_name_table,
+		(gpointer) "Content-Location",
+		(gpointer) HEADER_CONTENT_LOCATION);
+	g_hash_table_insert (
+		header_name_table,
+		(gpointer) "Content-Type",
+		(gpointer) HEADER_CONTENT_TYPE);
 
-	header_formatted_table = g_hash_table_new (camel_strcase_hash, camel_strcase_equal);
-	g_hash_table_insert(header_formatted_table, "Content-Type", write_raw);
-	g_hash_table_insert(header_formatted_table, "Content-Disposition", write_raw);
-	g_hash_table_insert(header_formatted_table, "To", write_raw);
-	g_hash_table_insert(header_formatted_table, "From", write_raw);
-	g_hash_table_insert(header_formatted_table, "Reply-To", write_raw);
-	g_hash_table_insert(header_formatted_table, "Cc", write_raw);
-	g_hash_table_insert(header_formatted_table, "Bcc", write_raw);
-	g_hash_table_insert(header_formatted_table, "Message-ID", write_raw);
-	g_hash_table_insert(header_formatted_table, "In-Reply-To", write_raw);
-	g_hash_table_insert(header_formatted_table, "References", write_references);
+	header_formatted_table = g_hash_table_new (
+		camel_strcase_hash, camel_strcase_equal);
+	g_hash_table_insert (
+		header_formatted_table,
+		(gpointer) "Content-Type", write_raw);
+	g_hash_table_insert (
+		header_formatted_table,
+		(gpointer) "Content-Disposition", write_raw);
+	g_hash_table_insert (
+		header_formatted_table,
+		(gpointer) "To", write_raw);
+	g_hash_table_insert (
+		header_formatted_table,
+		(gpointer) "From", write_raw);
+	g_hash_table_insert (
+		header_formatted_table,
+		(gpointer) "Reply-To", write_raw);
+	g_hash_table_insert (
+		header_formatted_table,
+		(gpointer) "Cc", write_raw);
+	g_hash_table_insert (
+		header_formatted_table,
+		(gpointer) "Bcc", write_raw);
+	g_hash_table_insert (
+		header_formatted_table,
+		(gpointer) "Message-ID", write_raw);
+	g_hash_table_insert (
+		header_formatted_table,
+		(gpointer) "In-Reply-To", write_raw);
+	g_hash_table_insert (
+		header_formatted_table,
+		(gpointer) "References", write_references);
 }
 
 static void
@@ -137,8 +180,8 @@ camel_mime_part_class_init (CamelMimePartClass *camel_mime_part_class)
 	init_header_name_table();
 
 	camel_mime_part_class->construct_from_parser = construct_from_parser;
-	
-	/* virtual method overload */	
+
+	/* virtual method overload */
 	camel_medium_class->add_header                = add_header;
 	camel_medium_class->set_header                = set_header;
 	camel_medium_class->get_header                = get_header;
@@ -146,7 +189,7 @@ camel_mime_part_class_init (CamelMimePartClass *camel_mime_part_class)
 	camel_medium_class->get_headers               = get_headers;
 	camel_medium_class->free_headers              = free_headers;
 	camel_medium_class->set_content_object        = set_content_object;
-	
+
 	camel_data_wrapper_class->write_to_stream     = write_to_stream;
 	camel_data_wrapper_class->construct_from_stream= construct_from_stream;
 }
@@ -155,11 +198,11 @@ static void
 camel_mime_part_init (gpointer object, gpointer klass)
 {
 	CamelMimePart *mime_part = CAMEL_MIME_PART (object);
-	
+
 	if (((CamelDataWrapper *) mime_part)->mime_type)
 		camel_content_type_unref (((CamelDataWrapper *) mime_part)->mime_type);
 	((CamelDataWrapper *) mime_part)->mime_type = camel_content_type_new ("text", "plain");
-	
+
 	mime_part->description          = NULL;
 	mime_part->disposition          = NULL;
 	mime_part->content_id           = NULL;
@@ -170,18 +213,18 @@ camel_mime_part_init (gpointer object, gpointer klass)
 }
 
 
-static void           
+static void
 camel_mime_part_finalize (CamelObject *object)
 {
 	CamelMimePart *mime_part = CAMEL_MIME_PART (object);
-	
+
 	g_free (mime_part->description);
 	g_free (mime_part->content_id);
 	g_free (mime_part->content_MD5);
 	g_free (mime_part->content_location);
 	camel_string_list_free (mime_part->content_languages);
 	camel_content_disposition_unref(mime_part->disposition);
-	
+
 	camel_header_raw_clear(&mime_part->headers);
 }
 
@@ -191,7 +234,7 @@ CamelType
 camel_mime_part_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE)	{
 		type = camel_type_register (CAMEL_MEDIUM_TYPE,
 					    "CamelMimePart",
@@ -202,7 +245,7 @@ camel_mime_part_get_type (void)
 					    (CamelObjectInitFunc) camel_mime_part_init,
 					    (CamelObjectFinalizeFunc) camel_mime_part_finalize);
 	}
-	
+
 	return type;
 }
 
@@ -210,12 +253,12 @@ camel_mime_part_get_type (void)
 /* **** */
 
 static gboolean
-process_header(CamelMedium *medium, const char *name, const char *value)
+process_header(CamelMedium *medium, const gchar *name, const gchar *value)
 {
 	CamelMimePart *mime_part = CAMEL_MIME_PART (medium);
 	CamelHeaderType header_type;
-	const char *charset;
-	char *text;
+	const gchar *charset;
+	gchar *text;
 
 	/* Try to parse the header pair. If it corresponds to something   */
 	/* known, the job is done in the parsing routine. If not,         */
@@ -264,19 +307,19 @@ process_header(CamelMedium *medium, const char *name, const char *value)
 }
 
 static void
-set_header (CamelMedium *medium, const char *name, const void *value)
+set_header (CamelMedium *medium, const gchar *name, gconstpointer value)
 {
 	CamelMimePart *part = CAMEL_MIME_PART (medium);
-	
+
 	process_header(medium, name, value);
 	camel_header_raw_replace(&part->headers, name, value, -1);
 }
 
 static void
-add_header (CamelMedium *medium, const char *name, const void *value)
+add_header (CamelMedium *medium, const gchar *name, gconstpointer value)
 {
 	CamelMimePart *part = CAMEL_MIME_PART (medium);
-	
+
 	/* Try to parse the header pair. If it corresponds to something   */
 	/* known, the job is done in the parsing routine. If not,         */
 	/* we simply add the header in a raw fashion                      */
@@ -289,16 +332,16 @@ add_header (CamelMedium *medium, const char *name, const void *value)
 }
 
 static void
-remove_header (CamelMedium *medium, const char *name)
+remove_header (CamelMedium *medium, const gchar *name)
 {
 	CamelMimePart *part = (CamelMimePart *)medium;
-	
+
 	process_header(medium, name, NULL);
 	camel_header_raw_remove(&part->headers, name);
 }
 
-static const void *
-get_header (CamelMedium *medium, const char *name)
+static gconstpointer
+get_header (CamelMedium *medium, const gchar *name)
 {
 	CamelMimePart *part = (CamelMimePart *)medium;
 
@@ -339,9 +382,9 @@ free_headers (CamelMedium *medium, GArray *gheaders)
  * Set a description on the MIME part.
  **/
 void
-camel_mime_part_set_description (CamelMimePart *mime_part, const char *description)
+camel_mime_part_set_description (CamelMimePart *mime_part, const gchar *description)
 {
-	char *text = camel_header_encode_string ((const unsigned char *) description);
+	gchar *text = camel_header_encode_string ((const guchar *) description);
 
 	camel_medium_set_header (CAMEL_MEDIUM (mime_part),
 				 "Content-Description", text);
@@ -357,7 +400,7 @@ camel_mime_part_set_description (CamelMimePart *mime_part, const char *descripti
  *
  * Returns: the description
  **/
-const char *
+const gchar *
 camel_mime_part_get_description (CamelMimePart *mime_part)
 {
 	return mime_part->description;
@@ -366,7 +409,7 @@ camel_mime_part_get_description (CamelMimePart *mime_part)
 /* **** Content-Disposition */
 
 static void
-set_disposition (CamelMimePart *mime_part, const char *disposition)
+set_disposition (CamelMimePart *mime_part, const gchar *disposition)
 {
 	camel_content_disposition_unref(mime_part->disposition);
 	if (disposition)
@@ -384,9 +427,9 @@ set_disposition (CamelMimePart *mime_part, const char *disposition)
  * Set a disposition on the MIME part.
  **/
 void
-camel_mime_part_set_disposition (CamelMimePart *mime_part, const char *disposition)
+camel_mime_part_set_disposition (CamelMimePart *mime_part, const gchar *disposition)
 {
-	char *text;
+	gchar *text;
 
 	/* we poke in a new disposition (so we dont lose 'filename', etc) */
 	if (mime_part->disposition == NULL) {
@@ -413,7 +456,7 @@ camel_mime_part_set_disposition (CamelMimePart *mime_part, const char *dispositi
  *
  * Returns: the dispisition
  **/
-const char *
+const gchar *
 camel_mime_part_get_disposition (CamelMimePart *mime_part)
 {
 	if (mime_part->disposition)
@@ -433,11 +476,11 @@ camel_mime_part_get_disposition (CamelMimePart *mime_part)
  * Set the filename on a MIME part.
  **/
 void
-camel_mime_part_set_filename (CamelMimePart *mime_part, const char *filename)
+camel_mime_part_set_filename (CamelMimePart *mime_part, const gchar *filename)
 {
-	char *str;
+	gchar *str;
 	CamelDataWrapper *dw;
-	
+
 	if (mime_part->disposition == NULL)
 		mime_part->disposition = camel_content_disposition_decode("attachment");
 
@@ -466,15 +509,15 @@ camel_mime_part_set_filename (CamelMimePart *mime_part, const char *filename)
  *
  * Returns: the filename of the MIME part
  **/
-const char *
+const gchar *
 camel_mime_part_get_filename (CamelMimePart *mime_part)
 {
 	if (mime_part->disposition) {
-		const char *name = camel_header_param (mime_part->disposition->params, "filename");
+		const gchar *name = camel_header_param (mime_part->disposition->params, "filename");
 		if (name)
 			return name;
 	}
-	
+
 	return camel_content_type_param (((CamelDataWrapper *) mime_part)->mime_type, "name");
 }
 
@@ -489,15 +532,15 @@ camel_mime_part_get_filename (CamelMimePart *mime_part)
  * Set the content-id field on a MIME part.
  **/
 void
-camel_mime_part_set_content_id (CamelMimePart *mime_part, const char *contentid)
+camel_mime_part_set_content_id (CamelMimePart *mime_part, const gchar *contentid)
 {
-	char *cid, *id;
-	
+	gchar *cid, *id;
+
 	if (contentid)
 		id = g_strstrip (g_strdup (contentid));
 	else
 		id = camel_header_msgid_generate ();
-	
+
 	cid = g_strdup_printf ("<%s>", id);
 	g_free (id);
 	camel_medium_set_header (CAMEL_MEDIUM (mime_part), "Content-ID", cid);
@@ -513,7 +556,7 @@ camel_mime_part_set_content_id (CamelMimePart *mime_part, const char *contentid)
  *
  * Returns: the content-id field of the MIME part
  **/
-const char *
+const gchar *
 camel_mime_part_get_content_id (CamelMimePart *mime_part)
 {
 	return mime_part->content_id;
@@ -529,7 +572,7 @@ camel_mime_part_get_content_id (CamelMimePart *mime_part)
  * Set the content-md5 field of the MIME part.
  **/
 void
-camel_mime_part_set_content_MD5 (CamelMimePart *mime_part, const char *md5)
+camel_mime_part_set_content_MD5 (CamelMimePart *mime_part, const gchar *md5)
 {
 	camel_medium_set_header (CAMEL_MEDIUM (mime_part), "Content-MD5", md5);
 }
@@ -543,7 +586,7 @@ camel_mime_part_set_content_MD5 (CamelMimePart *mime_part, const char *md5)
  *
  * Returns: the content-md5 field of the MIME part
  **/
-const char *
+const gchar *
 camel_mime_part_get_content_MD5 (CamelMimePart *mime_part)
 {
 	return mime_part->content_MD5;
@@ -560,7 +603,7 @@ camel_mime_part_get_content_MD5 (CamelMimePart *mime_part)
  * Set the content-location field of the MIME part.
  **/
 void
-camel_mime_part_set_content_location (CamelMimePart *mime_part, const char *location)
+camel_mime_part_set_content_location (CamelMimePart *mime_part, const gchar *location)
 {
 	/* FIXME: this should perform content-location folding */
 	camel_medium_set_header (CAMEL_MEDIUM (mime_part), "Content-Location", location);
@@ -575,7 +618,7 @@ camel_mime_part_set_content_location (CamelMimePart *mime_part, const char *loca
  *
  * Returns: the content-location field of a MIME part
  **/
-const char *
+const gchar *
 camel_mime_part_get_content_location (CamelMimePart *mime_part)
 {
 	return mime_part->content_location;
@@ -595,7 +638,7 @@ void
 camel_mime_part_set_encoding (CamelMimePart *mime_part,
 			      CamelTransferEncoding encoding)
 {
-	const char *text;
+	const gchar *text;
 
 	text = camel_transfer_encoding_to_string (encoding);
 	camel_medium_set_header (CAMEL_MEDIUM (mime_part),
@@ -632,7 +675,7 @@ camel_mime_part_set_content_languages (CamelMimePart *mime_part, GList *content_
 {
 	if (mime_part->content_languages)
 		camel_string_list_free (mime_part->content_languages);
-	
+
 	mime_part->content_languages = content_languages;
 
 	/* FIXME: translate to a header and set it */
@@ -666,7 +709,7 @@ camel_mime_part_get_content_languages (CamelMimePart *mime_part)
  * Set the content-type on a MIME part.
  **/
 void
-camel_mime_part_set_content_type (CamelMimePart *mime_part, const char *content_type)
+camel_mime_part_set_content_type (CamelMimePart *mime_part, const gchar *content_type)
 {
 	camel_medium_set_header (CAMEL_MEDIUM (mime_part),
 				 "Content-Type", content_type);
@@ -692,13 +735,13 @@ set_content_object (CamelMedium *medium, CamelDataWrapper *content)
 {
 	CamelDataWrapper *mime_part = CAMEL_DATA_WRAPPER (medium);
 	CamelContentType *content_type;
-	
+
 	parent_class->set_content_object (medium, content);
-	
+
 	content_type = camel_data_wrapper_get_mime_type_field (content);
 	if (mime_part->mime_type != content_type) {
-		char *txt;
-		
+		gchar *txt;
+
 		txt = camel_content_type_format (content_type);
 		camel_medium_set_header (CAMEL_MEDIUM (mime_part), "Content-Type", txt);
 		g_free (txt);
@@ -707,12 +750,12 @@ set_content_object (CamelMedium *medium, CamelDataWrapper *content)
 
 /**********************************************************************/
 
-static ssize_t
+static gssize
 write_references(CamelStream *stream, struct _camel_header_raw *h)
 {
-	ssize_t len, out, total;
-	char *v, *ids, *ide;
-	
+	gssize len, out, total;
+	gchar *v, *ids, *ide;
+
 	/* this is only approximate, based on the next >, this way it retains any content
 	   from the original which may not be properly formatted, etc.  It also doesn't handle
 	   the case where an individual messageid is too long, however thats a bad mail to
@@ -751,11 +794,11 @@ write_references(CamelStream *stream, struct _camel_header_raw *h)
 
 #if 0
 /* not needed - yet - handled by default case */
-static ssize_t
+static gssize
 write_fold(CamelStream *stream, struct _camel_header_raw *h)
 {
-	char *val;
-	int count;
+	gchar *val;
+	gint count;
 
 	val = camel_header_fold(h->value, strlen(h->name));
 	count = camel_stream_printf(stream, "%s%s%s\n", h->name, isspace(val[0]) ? ":" : ": ", val);
@@ -765,35 +808,35 @@ write_fold(CamelStream *stream, struct _camel_header_raw *h)
 }
 #endif
 
-static ssize_t
+static gssize
 write_raw(CamelStream *stream, struct _camel_header_raw *h)
 {
-	char *val = h->value;
+	gchar *val = h->value;
 
 	return camel_stream_printf(stream, "%s%s%s\n", h->name, isspace(val[0]) ? ":" : ": ", val);
 }
 
-static ssize_t
+static gssize
 write_to_stream (CamelDataWrapper *dw, CamelStream *stream)
 {
 	CamelMimePart *mp = CAMEL_MIME_PART (dw);
 	CamelMedium *medium = CAMEL_MEDIUM (dw);
 	CamelStream *ostream = stream;
 	CamelDataWrapper *content;
-	ssize_t total = 0;
-	ssize_t count;
-	int errnosav;
-	
+	gssize total = 0;
+	gssize count;
+	gint errnosav;
+
 	d(printf("mime_part::write_to_stream\n"));
-	
+
 	/* FIXME: something needs to be done about this ... */
 	/* TODO: content-languages header? */
-	
+
 	if (mp->headers) {
 		struct _camel_header_raw *h = mp->headers;
-		char *val;
-		ssize_t (*writefn)(CamelStream *stream, struct _camel_header_raw *);
-		
+		gchar *val;
+		gssize (*writefn)(CamelStream *stream, struct _camel_header_raw *);
+
 		/* fold/write the headers.   But dont fold headers that are already formatted
 		   (e.g. ones with parameter-lists, that we know about, and have created) */
 		while (h) {
@@ -814,32 +857,32 @@ write_to_stream (CamelDataWrapper *dw, CamelStream *stream)
 			h = h->next;
 		}
 	}
-	
+
 	count = camel_stream_write(stream, "\n", 1);
 	if (count == -1)
 		return -1;
 	total += count;
-	
+
 	content = camel_medium_get_content_object(medium);
 	if (content) {
 		CamelMimeFilter *filter = NULL;
 		CamelStreamFilter *filter_stream = NULL;
 		CamelMimeFilter *charenc = NULL;
-		const char *content_charset = NULL;
-		const char *part_charset = NULL;
+		const gchar *content_charset = NULL;
+		const gchar *part_charset = NULL;
 		gboolean reencode = FALSE;
-		const char *filename;
-		
+		const gchar *filename;
+
 		if (camel_content_type_is (dw->mime_type, "text", "*")) {
 			content_charset = camel_content_type_param (content->mime_type, "charset");
 			part_charset = camel_content_type_param (dw->mime_type, "charset");
-			
+
 			if (content_charset && part_charset) {
 				content_charset = camel_iconv_charset_name (content_charset);
 				part_charset = camel_iconv_charset_name (part_charset);
 			}
 		}
-		
+
 		if (mp->encoding != content->encoding) {
 			switch (mp->encoding) {
 			case CAMEL_TRANSFER_ENCODING_BASE64:
@@ -862,55 +905,55 @@ write_to_stream (CamelDataWrapper *dw, CamelStream *stream)
 				break;
 			}
 		}
-		
+
 		if (content_charset && part_charset && part_charset != content_charset)
 			charenc = (CamelMimeFilter *) camel_mime_filter_charset_new_convert (content_charset, part_charset);
-		
+
 		if (filter || charenc) {
 			filter_stream = camel_stream_filter_new_with_stream(stream);
-			
+
 			/* if we have a character encoder, add that always */
 			if (charenc) {
 				camel_stream_filter_add(filter_stream, charenc);
 				camel_object_unref (charenc);
 			}
-			
+
 			/* we only re-do crlf on encoded blocks */
 			if (filter && camel_content_type_is (dw->mime_type, "text", "*")) {
 				CamelMimeFilter *crlf = camel_mime_filter_crlf_new(CAMEL_MIME_FILTER_CRLF_ENCODE,
 										   CAMEL_MIME_FILTER_CRLF_MODE_CRLF_ONLY);
-				
+
 				camel_stream_filter_add(filter_stream, crlf);
 				camel_object_unref (crlf);
 			}
-			
+
 			if (filter) {
 				camel_stream_filter_add(filter_stream, filter);
 				camel_object_unref (filter);
 			}
-			
+
 			stream = (CamelStream *)filter_stream;
-			
+
 			reencode = TRUE;
 		}
-		
+
 		if (reencode)
 			count = camel_data_wrapper_decode_to_stream (content, stream);
 		else
 			count = camel_data_wrapper_write_to_stream (content, stream);
-		
+
 		if (filter_stream) {
 			errnosav = errno;
 			camel_stream_flush (stream);
 			camel_object_unref (filter_stream);
 			errno = errnosav;
 		}
-		
+
 		if (count == -1)
 			return -1;
-		
+
 		total += count;
-		
+
 		if (reencode && mp->encoding == CAMEL_TRANSFER_ENCODING_UUENCODE) {
 			count = camel_stream_write (ostream, "end\n", 4);
 			if (count == -1)
@@ -920,23 +963,23 @@ write_to_stream (CamelDataWrapper *dw, CamelStream *stream)
 	} else {
 		g_warning("No content for medium, nothing to write");
 	}
-	
+
 	return total;
 }
 
 /* mime_part */
-static int
+static gint
 construct_from_parser (CamelMimePart *mime_part, CamelMimeParser *mp)
 {
 	CamelDataWrapper *dw = (CamelDataWrapper *) mime_part;
 	struct _camel_header_raw *headers;
-	const char *content;
-	char *buf;
-	size_t len;
-	int err;
-	
+	const gchar *content;
+	gchar *buf;
+	gsize len;
+	gint err;
+
 	d(printf("mime_part::construct_from_parser()\n"));
-	
+
 	switch (camel_mime_parser_step(mp, &buf, &len)) {
 	case CAMEL_MIME_PARSER_STATE_MESSAGE:
 		/* set the default type of a message always */
@@ -984,20 +1027,20 @@ construct_from_parser (CamelMimePart *mime_part, CamelMimeParser *mp)
  * @parser: a #CamelMimeParser object
  *
  * Constructs a MIME part from a parser.
- * 
+ *
  * Returns: %0 on success or %-1 on fail
  **/
-int
+gint
 camel_mime_part_construct_from_parser(CamelMimePart *mime_part, CamelMimeParser *mp)
 {
 	return CMP_CLASS (mime_part)->construct_from_parser (mime_part, mp);
 }
 
-static int
+static gint
 construct_from_stream(CamelDataWrapper *dw, CamelStream *s)
 {
 	CamelMimeParser *mp;
-	int ret;
+	gint ret;
 
 	d(printf("mime_part::construct_from_stream()\n"));
 
@@ -1034,16 +1077,16 @@ camel_mime_part_new (void)
  * @data: data to put into the part
  * @length: length of @data
  * @type: Content-Type of the data
- * 
- * Utility function used to set the content of a mime part object to 
+ *
+ * Utility function used to set the content of a mime part object to
  * be the provided data. If @length is 0, this routine can be used as
  * a way to remove old content (in which case @data and @type are
  * ignored and may be %NULL).
  **/
-void 
+void
 camel_mime_part_set_content (CamelMimePart *mime_part,
-			     const char *data, int length,
-			     const char *type) /* why on earth is the type last? */
+			     const gchar *data, gint length,
+			     const gchar *type) /* why on earth is the type last? */
 {
 	CamelMedium *medium = CAMEL_MEDIUM (mime_part);
 
@@ -1073,22 +1116,22 @@ camel_mime_part_set_content (CamelMimePart *mime_part,
  *
  * Returns: the size of the MIME part's content in bytes.
  **/
-size_t
+gsize
 camel_mime_part_get_content_size (CamelMimePart *mime_part)
 {
 	CamelStreamNull *null;
 	CamelDataWrapper *dw;
-	size_t size;
-	
+	gsize size;
+
 	g_return_val_if_fail (CAMEL_IS_MIME_PART (mime_part), 0);
-	
+
 	dw = camel_medium_get_content_object (CAMEL_MEDIUM (mime_part));
-	
+
 	null = (CamelStreamNull *) camel_stream_null_new ();
 	camel_data_wrapper_decode_to_stream (dw, (CamelStream *) null);
 	size = null->written;
-	
+
 	camel_object_unref (null);
-	
+
 	return size;
 }
