@@ -1,11 +1,11 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-movemail.h: mbox copy function */
 
-/* 
- * Author: 
+/*
+ * Author:
  *  Dan Winship <danw@ximian.com>
  *
- * Copyright 2000 Ximian, Inc. (www.ximian.com)
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -30,7 +30,7 @@
 
 G_BEGIN_DECLS
 
-int camel_movemail (const char *source, const char *dest, CamelException *ex);
+gint camel_movemail (const gchar *source, const gchar *dest, CamelException *ex);
 
 G_END_DECLS
 
