@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@novell.com>
  *
- *  Copyright 2004 Novell, Inc. (www.novell.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -45,7 +45,7 @@
 #include "camel-offline-journal.h"
 #include "camel-private.h"
 
-#define d(x) x
+#define d(x)
 
 static void camel_offline_journal_class_init (CamelOfflineJournalClass *klass);
 static void camel_offline_journal_init (CamelOfflineJournal *journal, CamelOfflineJournalClass *klass);
@@ -59,7 +59,7 @@ CamelType
 camel_offline_journal_get_type (void)
 {
 	static CamelType type = NULL;
-	
+
 	if (!type) {
 		type = camel_type_register (camel_object_get_type (),
 					    "CamelOfflineJournal",
@@ -70,7 +70,7 @@ camel_offline_journal_get_type (void)
 					    (CamelObjectInitFunc) camel_offline_journal_init,
 					    (CamelObjectFinalizeFunc) camel_offline_journal_finalize);
 	}
-	
+
 	return type;
 }
 
@@ -85,18 +85,18 @@ camel_offline_journal_init (CamelOfflineJournal *journal, CamelOfflineJournalCla
 {
 	journal->folder = NULL;
 	journal->filename = NULL;
-	e_dlist_init (&journal->queue);
+	camel_dlist_init (&journal->queue);
 }
 
 static void
 camel_offline_journal_finalize (CamelObject *object)
 {
 	CamelOfflineJournal *journal = (CamelOfflineJournal *) object;
-	EDListNode *entry;
-	
+	CamelDListNode *entry;
+
 	g_free (journal->filename);
-	
-	while ((entry = e_dlist_remhead (&journal->queue)))
+
+	while ((entry = camel_dlist_remhead (&journal->queue)))
 		CAMEL_OFFLINE_JOURNAL_GET_CLASS (journal)->entry_free (journal, entry);
 }
 
@@ -109,18 +109,18 @@ camel_offline_journal_finalize (CamelObject *object)
  * Constructs a journal object.
  **/
 void
-camel_offline_journal_construct (CamelOfflineJournal *journal, CamelFolder *folder, const char *filename)
+camel_offline_journal_construct (CamelOfflineJournal *journal, CamelFolder *folder, const gchar *filename)
 {
-	EDListNode *entry;
+	CamelDListNode *entry;
 	FILE *fp;
-	
+
 	journal->filename = g_strdup (filename);
 	journal->folder = folder;
-	
+
 	if ((fp = g_fopen (filename, "rb"))) {
 		while ((entry = CAMEL_OFFLINE_JOURNAL_GET_CLASS (journal)->entry_load (journal, fp)))
-			e_dlist_addtail (&journal->queue, entry);
-		
+			camel_dlist_addtail (&journal->queue, entry);
+
 		fclose (fp);
 	}
 }
@@ -134,10 +134,10 @@ camel_offline_journal_construct (CamelOfflineJournal *journal, CamelFolder *fold
  * Set the filename where the journal should load/save from.
  **/
 void
-camel_offline_journal_set_filename (CamelOfflineJournal *journal, const char *filename)
+camel_offline_journal_set_filename (CamelOfflineJournal *journal, const gchar *filename)
 {
 	g_return_if_fail (CAMEL_IS_OFFLINE_JOURNAL (journal));
-	
+
 	g_free (journal->filename);
 	journal->filename = g_strdup (filename);
 }
@@ -150,22 +150,22 @@ camel_offline_journal_set_filename (CamelOfflineJournal *journal, const char *fi
  *
  * Save the journal to disk.
  *
- * Returns %0 on success or %-1 on fail
+ * Returns: %0 on success or %-1 on fail
  **/
-int
+gint
 camel_offline_journal_write (CamelOfflineJournal *journal, CamelException *ex)
 {
-	EDListNode *entry;
+	CamelDListNode *entry;
 	FILE *fp;
-	int fd;
-	
+	gint fd;
+
 	if ((fd = g_open (journal->filename, O_CREAT | O_TRUNC | O_WRONLY | O_BINARY, 0666)) == -1) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 				      _("Cannot write offline journal for folder '%s': %s"),
 				      journal->folder->full_name, g_strerror (errno));
 		return -1;
 	}
-	
+
 	fp = fdopen (fd, "w");
 	entry = journal->queue.head;
 	while (entry->next) {
@@ -173,22 +173,22 @@ camel_offline_journal_write (CamelOfflineJournal *journal, CamelException *ex)
 			goto exception;
 		entry = entry->next;
 	}
-	
+
 	if (fsync (fd) == -1)
 		goto exception;
-	
+
 	fclose (fp);
-	
+
 	return 0;
-	
+
  exception:
-	
+
 	camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 			      _("Cannot write offline journal for folder '%s': %s"),
 			      journal->folder->full_name, g_strerror (errno));
-	
+
 	fclose (fp);
-	
+
 	return -1;
 }
 
@@ -200,17 +200,17 @@ camel_offline_journal_write (CamelOfflineJournal *journal, CamelException *ex)
  *
  * Replay all entries in the journal.
  *
- * Returns %0 on success (no entry failed to replay) or %-1 on fail
+ * Returns: %0 on success (no entry failed to replay) or %-1 on fail
  **/
-int
+gint
 camel_offline_journal_replay (CamelOfflineJournal *journal, CamelException *ex)
 {
-	EDListNode *entry, *next;
+	CamelDListNode *entry, *next;
 	CamelException lex;
-	int failed = 0;
-	
+	gint failed = 0;
+
 	camel_exception_init (&lex);
-	
+
 	entry = journal->queue.head;
 	while (entry->next) {
 		next = entry->next;
@@ -220,13 +220,13 @@ camel_offline_journal_replay (CamelOfflineJournal *journal, CamelException *ex)
 			camel_exception_clear (&lex);
 			failed++;
 		} else {
-			e_dlist_remove (entry);
+			camel_dlist_remove (entry);
 		}
 		entry = next;
 	}
-	
+
 	if (failed > 0)
 		return -1;
-	
+
 	return 0;
 }
