@@ -50,7 +50,7 @@ CamelType
 camel_offline_store_get_type (void)
 {
 	static CamelType type = NULL;
-	
+
 	if (!type) {
 		type = camel_type_register (CAMEL_STORE_TYPE,
 					    "CamelOfflineStore",
@@ -61,7 +61,7 @@ camel_offline_store_get_type (void)
 					    (CamelObjectInitFunc) camel_offline_store_init,
 					    (CamelObjectFinalizeFunc) camel_offline_store_finalize);
 	}
-	
+
 	return type;
 }
 
@@ -70,7 +70,7 @@ static void
 camel_offline_store_class_init (CamelOfflineStoreClass *klass)
 {
 	parent_class = (CamelStoreClass *) camel_type_get_global_classfuncs (CAMEL_STORE_TYPE);
-	
+
 	((CamelServiceClass *) klass)->construct = offline_store_construct;
 }
 
@@ -93,11 +93,11 @@ offline_store_construct (CamelService *service, CamelSession *session,
 			  CamelException *ex)
 {
 	CamelOfflineStore *store = CAMEL_OFFLINE_STORE (service);
-	
+
 	CAMEL_SERVICE_CLASS (parent_class)->construct (service, session, provider, url, ex);
 	if (camel_exception_is_set (ex))
 		return;
-	
+
 	store->state = camel_session_is_online (session) ?
 		CAMEL_OFFLINE_STORE_NETWORK_AVAIL : CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL;
 }
@@ -110,10 +110,10 @@ offline_store_construct (CamelService *service, CamelSession *session,
  * Return the network state either #CAMEL_OFFLINE_STORE_NETWORK_AVAIL
  * or #CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL.
  **/
-int 
+gint
 camel_offline_store_get_network_state (CamelOfflineStore *store, CamelException *ex)
 {
-	return store->state;	
+	return store->state;
 }
 
 /**
@@ -126,7 +126,7 @@ camel_offline_store_get_network_state (CamelOfflineStore *store, CamelException
  * or #CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL.
  **/
 void
-camel_offline_store_set_network_state (CamelOfflineStore *store, int state, CamelException *ex)
+camel_offline_store_set_network_state (CamelOfflineStore *store, gint state, CamelException *ex)
 {
 	CamelException lex;
 	CamelService *service = CAMEL_SERVICE (store);
@@ -134,7 +134,7 @@ camel_offline_store_set_network_state (CamelOfflineStore *store, int state, Came
 
 	if (store->state == state)
 		return;
-	
+
 	camel_exception_init (&lex);
 	if (store->state == CAMEL_OFFLINE_STORE_NETWORK_AVAIL) {
 		/* network available -> network unavailable */
@@ -142,26 +142,26 @@ camel_offline_store_set_network_state (CamelOfflineStore *store, int state, Came
 			if (((CamelStore *) store)->folders) {
 				GPtrArray *folders;
 				CamelFolder *folder;
-				int i, sync;
-				
+				gint i, sync;
+
 				sync = camel_url_get_param (((CamelService *) store)->url, "sync_offline") != NULL;
-				
+
 				folders = camel_object_bag_list (((CamelStore *) store)->folders);
 				for (i = 0; i < folders->len; i++) {
 					folder = folders->pdata[i];
-					
+
 					if (CAMEL_CHECK_TYPE (folder, CAMEL_OFFLINE_FOLDER_TYPE)
 					    && (sync || ((CamelOfflineFolder *) folder)->sync_offline)) {
 						camel_offline_folder_downsync ((CamelOfflineFolder *) folder, NULL, &lex);
 						camel_exception_clear (&lex);
 					}
-					
+
 					camel_object_unref (folder);
 				}
-				
+
 				g_ptr_array_free (folders, TRUE);
 			}
-			
+
 			camel_store_sync (CAMEL_STORE (store), FALSE, &lex);
 			camel_exception_clear (&lex);
 		}
@@ -176,7 +176,7 @@ camel_offline_store_set_network_state (CamelOfflineStore *store, int state, Came
 			return;
 		}
 	}
-	
+
 	store->state = state;
 }
 
@@ -188,15 +188,15 @@ camel_offline_store_prepare_for_offline (CamelOfflineStore *store, CamelExceptio
 	gboolean network_state = camel_session_get_network_state (service->session);
 
 	camel_exception_init (&lex);
-	if (network_state) {	
+	if (network_state) {
 		if (store->state == CAMEL_OFFLINE_STORE_NETWORK_AVAIL) {
 			if (((CamelStore *) store)->folders) {
 				GPtrArray *folders;
 				CamelFolder *folder;
-				int i, sync;
-				
+				gint i, sync;
+
 				sync = camel_url_get_param (((CamelService *) store)->url, "sync_offline") != NULL;
-				
+
 				folders = camel_object_bag_list (((CamelStore *) store)->folders);
 				for (i = 0; i < folders->len; i++) {
 					folder = folders->pdata[i];
@@ -210,10 +210,10 @@ camel_offline_store_prepare_for_offline (CamelOfflineStore *store, CamelExceptio
 				}
 				g_ptr_array_free (folders, TRUE);
 			}
-		}	
+		}
 
 		camel_store_sync (CAMEL_STORE (store), FALSE, &lex);
 		camel_exception_clear (&lex);
-	
+
 	}
 }
