@@ -35,8 +35,7 @@
 
 #include <glib.h>
 
-#include <libedataserver/e-msgport.h>  /* for EDList */
-
+#include "camel-list-utils.h"
 #include "camel-operation.h"
 #include "camel-msgport.h"
 
@@ -46,9 +45,9 @@
 
 struct _status_stack {
 	guint32 flags;
-	char *msg;
-	int pc;				/* last pc reported */
-	unsigned int stamp;		/* last stamp reported */
+	gchar *msg;
+	gint pc;				/* last pc reported */
+	guint stamp;		/* last stamp reported */
 };
 
 struct _CamelOperation {
@@ -57,19 +56,19 @@ struct _CamelOperation {
 
 	pthread_t id;		/* id of running thread */
 	guint32 flags;		/* cancelled ? */
-	int blocked;		/* cancellation blocked depth */
-	int refcount;
+	gint blocked;		/* cancellation blocked depth */
+	gint refcount;
 
 	CamelOperationStatusFunc status;
-	void *status_data;
-	unsigned int status_update;
+	gpointer status_data;
+	guint status_update;
 
 	/* stack of status messages (struct _status_stack *) */
 	GSList *status_stack;
 	struct _status_stack *lastreport;
 
 	CamelMsgPort *cancel_port;
-	int cancel_fd;
+	gint cancel_fd;
 #ifdef HAVE_NSS
 	PRFileDesc *cancel_prfd;
 #endif
@@ -86,14 +85,14 @@ static pthread_mutex_t operation_lock = PTHREAD_MUTEX_INITIALIZER;
 #define UNLOCK() pthread_mutex_unlock(&operation_lock)
 
 
-static unsigned int stamp (void);
-static EDList operation_list = E_DLIST_INITIALISER(operation_list);
+static guint stamp (void);
+static CamelDList operation_list = CAMEL_DLIST_INITIALISER(operation_list);
 static pthread_key_t operation_key;
 static pthread_once_t operation_once = PTHREAD_ONCE_INIT;
 
 typedef struct _CamelOperationMsg {
 	CamelMsg msg;
-} CamelOperationMsg ;
+} CamelOperationMsg;
 
 static void
 co_createspecific(void)
@@ -114,17 +113,17 @@ co_getcc(void)
  * @status: Callback for receiving status messages.  This will always
  * be called with an internal lock held.
  * @status_data: User data.
- * 
+ *
  * Create a new camel operation handle.  Camel operation handles can
  * be used in a multithreaded application (or a single operation
  * handle can be used in a non threaded appliation) to cancel running
  * operations and to obtain notification messages of the internal
  * status of messages.
- * 
+ *
  * Return value: A new operation handle.
  **/
 CamelOperation *
-camel_operation_new (CamelOperationStatusFunc status, void *status_data)
+camel_operation_new (CamelOperationStatusFunc status, gpointer status_data)
 {
 	CamelOperation *cc;
 
@@ -139,16 +138,16 @@ camel_operation_new (CamelOperationStatusFunc status, void *status_data)
 	cc->cancel_fd = -1;
 
 	LOCK();
-	e_dlist_addtail(&operation_list, (EDListNode *)cc);
+	camel_dlist_addtail(&operation_list, (CamelDListNode *)cc);
 	UNLOCK();
-	
+
 	return cc;
 }
 
 /**
  * camel_operation_mute:
- * @cc: 
- * 
+ * @cc:
+ *
  * mutes a camel operation permanently.  from this point on you will never
  * receive operation updates, even if more are sent.
  **/
@@ -180,7 +179,7 @@ camel_operation_registered (void)
 /**
  * camel_operation_ref:
  * @cc: operation context
- * 
+ *
  * Add a reference to the CamelOperation @cc.
  **/
 void
@@ -196,7 +195,7 @@ camel_operation_ref (CamelOperation *cc)
 /**
  * camel_operation_unref:
  * @cc: operation context
- * 
+ *
  * Unref and potentially free @cc.
  **/
 void
@@ -209,17 +208,17 @@ camel_operation_unref (CamelOperation *cc)
 	LOCK();
 	if (cc->refcount == 1) {
 		CamelOperationMsg *msg;
-		
-		e_dlist_remove((EDListNode *)cc);
+
+		camel_dlist_remove((CamelDListNode *)cc);
 
 		while ((msg = (CamelOperationMsg *)camel_msgport_try_pop(cc->cancel_port)))
 			g_free(msg);
 
 		camel_msgport_destroy(cc->cancel_port);
-		
+
 		n = cc->status_stack;
 		while (n) {
-			g_warning("Camel operation status stack non empty: %s", (char *)n->data);
+			g_warning("Camel operation status stack non empty: %s", (gchar *)n->data);
 			g_free(n->data);
 			n = n->next;
 		}
@@ -235,7 +234,7 @@ camel_operation_unref (CamelOperation *cc)
 /**
  * camel_operation_cancel_block:
  * @cc: operation context
- * 
+ *
  * Block cancellation for this operation.  If @cc is NULL, then the
  * current thread is blocked.
  **/
@@ -255,7 +254,7 @@ camel_operation_cancel_block (CamelOperation *cc)
 /**
  * camel_operation_cancel_unblock:
  * @cc: operation context
- * 
+ *
  * Unblock cancellation, when the unblock count reaches the block
  * count, then this operation can be cancelled.  If @cc is NULL, then
  * the current thread is unblocked.
@@ -276,7 +275,7 @@ camel_operation_cancel_unblock (CamelOperation *cc)
 /**
  * camel_operation_cancel:
  * @cc: operation context
- * 
+ *
  * Cancel a given operation.  If @cc is NULL then all outstanding
  * operations are cancelled.
  **/
@@ -284,7 +283,7 @@ void
 camel_operation_cancel (CamelOperation *cc)
 {
 	CamelOperationMsg *msg;
-	
+
 	LOCK();
 
 	if (cc == NULL) {
@@ -313,7 +312,7 @@ camel_operation_cancel (CamelOperation *cc)
 /**
  * camel_operation_uncancel:
  * @cc: operation context
- * 
+ *
  * Uncancel a cancelled operation.  If @cc is NULL then the current
  * operation is uncancelled.
  *
@@ -342,7 +341,7 @@ camel_operation_uncancel(CamelOperation *cc)
 /**
  * camel_operation_register:
  * @cc: operation context
- * 
+ *
  * Register a thread or the main thread for cancellation through @cc.
  * If @cc is NULL, then a new cancellation is created for this thread.
  *
@@ -366,7 +365,7 @@ camel_operation_register (CamelOperation *cc)
 /**
  * camel_operation_unregister:
  * @cc: operation context
- * 
+ *
  * Unregister the current thread for all cancellations.
  **/
 void
@@ -379,17 +378,17 @@ camel_operation_unregister (CamelOperation *cc)
 /**
  * camel_operation_cancel_check:
  * @cc: operation context
- * 
+ *
  * Check if cancellation has been applied to @cc.  If @cc is NULL,
  * then the CamelOperation registered for the current thread is used.
- * 
+ *
  * Return value: TRUE if the operation has been cancelled.
  **/
 gboolean
 camel_operation_cancel_check (CamelOperation *cc)
 {
 	CamelOperationMsg *msg;
-	int cancelled;
+	gint cancelled;
 
 	d(printf("checking for cancel in thread %d\n", pthread_self()));
 
@@ -422,14 +421,14 @@ camel_operation_cancel_check (CamelOperation *cc)
 /**
  * camel_operation_cancel_fd:
  * @cc: operation context
- * 
+ *
  * Retrieve a file descriptor that can be waited on (select, or poll)
  * for read, to asynchronously detect cancellation.
- * 
+ *
  * Return value: The fd, or -1 if cancellation is not available
  * (blocked, or has not been registered for this thread).
  **/
-int
+gint
 camel_operation_cancel_fd (CamelOperation *cc)
 {
 	if (cc == NULL)
@@ -452,10 +451,10 @@ camel_operation_cancel_fd (CamelOperation *cc)
 /**
  * camel_operation_cancel_prfd:
  * @cc: operation context
- * 
+ *
  * Retrieve a file descriptor that can be waited on (select, or poll)
  * for read, to asynchronously detect cancellation.
- * 
+ *
  * Return value: The fd, or NULL if cancellation is not available
  * (blocked, or has not been registered for this thread).
  **/
@@ -484,15 +483,15 @@ camel_operation_cancel_prfd (CamelOperation *cc)
  * @cc: operation context
  * @what: action being performed (printf-style format string)
  * @Varargs: varargs
- * 
+ *
  * Report the start of an operation.  All start operations should have
  * similar end operations.
  **/
 void
-camel_operation_start (CamelOperation *cc, char *what, ...)
+camel_operation_start (CamelOperation *cc, const gchar *what, ...)
 {
 	va_list ap;
-	char *msg;
+	gchar *msg;
 	struct _status_stack *s;
 
 	if (cc == NULL)
@@ -530,16 +529,16 @@ camel_operation_start (CamelOperation *cc, char *what, ...)
  * @cc: operation context
  * @what: printf-style format string describing the action being performed
  * @Varargs: varargs
- * 
+ *
  * Start a transient event.  We only update this to the display if it
  * takes very long to process, and if we do, we then go back to the
  * previous state when finished.
  **/
 void
-camel_operation_start_transient (CamelOperation *cc, char *what, ...)
+camel_operation_start_transient (CamelOperation *cc, const gchar *what, ...)
 {
 	va_list ap;
-	char *msg;
+	gchar *msg;
 	struct _status_stack *s;
 
 	if (cc == NULL)
@@ -567,7 +566,7 @@ camel_operation_start_transient (CamelOperation *cc, char *what, ...)
 	/*cc->status(cc, msg, CAMEL_OPERATION_START, cc->status_data);*/
 }
 
-static unsigned int stamp(void)
+static guint stamp(void)
 {
 	GTimeVal tv;
 
@@ -580,7 +579,7 @@ static unsigned int stamp(void)
  * camel_operation_progress:
  * @cc: Operation to report to.
  * @pc: Percent complete, 0 to 100.
- * 
+ *
  * Report progress on the current operation.  If @cc is NULL, then the
  * currently registered operation is used.  @pc reports the current
  * percentage of completion, which should be in the range of 0 to 100.
@@ -589,11 +588,11 @@ static unsigned int stamp(void)
  * camel_operation_progress_count().
  **/
 void
-camel_operation_progress (CamelOperation *cc, int pc)
+camel_operation_progress (CamelOperation *cc, gint pc)
 {
-	unsigned int now;
+	guint now;
 	struct _status_stack *s;
-	char *msg = NULL;
+	gchar *msg = NULL;
 
 	if (cc == NULL)
 		cc = co_getcc();
@@ -645,7 +644,7 @@ camel_operation_progress (CamelOperation *cc, int pc)
  *
  **/
 void
-camel_operation_progress_count (CamelOperation *cc, int sofar)
+camel_operation_progress_count (CamelOperation *cc, gint sofar)
 {
 	camel_operation_progress(cc, sofar);
 }
@@ -653,7 +652,7 @@ camel_operation_progress_count (CamelOperation *cc, int sofar)
 /**
  * camel_operation_end:
  * @cc: operation context
- * 
+ *
  * Report the end of an operation.  If @cc is NULL, then the currently
  * registered operation is notified.
  **/
@@ -661,9 +660,9 @@ void
 camel_operation_end (CamelOperation *cc)
 {
 	struct _status_stack *s, *p;
-	unsigned int now;
-	char *msg = NULL;
-	int pc = 0;
+	guint now;
+	gchar *msg = NULL;
+	gint pc = 0;
 
 	if (cc == NULL)
 		cc = co_getcc();
