@@ -58,14 +58,14 @@ static GStaticRecMutex provider_lock = G_STATIC_REC_MUTEX_INIT;
 static CamelProvider vee_provider = {
 	"vfolder",
 	N_("Virtual folder email provider"),
-	
+
 	N_("For reading mail as a query of another set of folders"),
-	
+
 	"vfolder",
-	
+
 	CAMEL_PROVIDER_IS_STORAGE,
 	CAMEL_URL_NEED_PATH | CAMEL_URL_PATH_IS_ABSOLUTE | CAMEL_URL_FRAGMENT_IS_PATH,
-	
+
 	/* ... */
 };
 
@@ -101,10 +101,10 @@ void
 camel_provider_init (void)
 {
 	GDir *dir;
-	const char *entry;
-	char *p, *name, buf[80];
+	const gchar *entry;
+	gchar *p, *name, buf[80];
 	CamelProviderModule *m;
-	static int loaded = 0;
+	static gint loaded = 0;
 
 	pthread_once(&setup_once, provider_setup);
 
@@ -119,14 +119,14 @@ camel_provider_init (void)
 			  CAMEL_PROVIDERDIR, g_strerror (errno));
 		return;
 	}
-	
+
 	while ((entry = g_dir_read_name (dir))) {
 		FILE *fp;
-		
+
 		p = strrchr (entry, '.');
 		if (!p || strcmp (p, ".urls") != 0)
 			continue;
-		
+
 		name = g_strdup_printf ("%s/%s", CAMEL_PROVIDERDIR, entry);
 		fp = g_fopen (name, "r");
 		if (!fp) {
@@ -135,7 +135,7 @@ camel_provider_init (void)
 			g_free (name);
 			continue;
 		}
-		
+
 		p = strrchr (name, '.');
 		strcpy (p, "." G_MODULE_SUFFIX);
 
@@ -147,9 +147,9 @@ camel_provider_init (void)
 			p = strchr (buf, '\n');
 			if (p)
 				*p = '\0';
-			
+
 			if (*buf) {
-				char *protocol = g_strdup(buf);
+				gchar *protocol = g_strdup(buf);
 
 				m->types = g_slist_prepend(m->types, protocol);
 				g_hash_table_insert(module_table, protocol, m);
@@ -170,9 +170,9 @@ camel_provider_init (void)
  * Loads the provider at @path, and calls its initialization function,
  * passing @session as an argument. The provider should then register
  * itself with @session.
- **/ 
+ **/
 void
-camel_provider_load(const char *path, CamelException *ex)
+camel_provider_load(const gchar *path, CamelException *ex)
 {
 	GModule *module;
 	CamelProvider *(*camel_provider_module_init) (void);
@@ -216,7 +216,7 @@ camel_provider_load(const char *path, CamelException *ex)
 void
 camel_provider_register(CamelProvider *provider)
 {
-	int i;
+	gint i;
 	CamelProviderConfEntry *conf;
 	GList *l;
 
@@ -231,7 +231,7 @@ camel_provider_register(CamelProvider *provider)
 		UNLOCK();
 		return;
 	}
-	
+
 	for (i = 0; i < CAMEL_NUM_PROVIDER_TYPES; i++) {
 		if (provider->object_types[i])
 			provider->service_cache[i] = camel_object_bag_new (provider->url_hash, provider->url_equal,
@@ -260,7 +260,9 @@ camel_provider_register(CamelProvider *provider)
 		l = l->next;
 	}
 
-	g_hash_table_insert(provider_table, provider->protocol, provider);
+	g_hash_table_insert (
+		provider_table,
+		(gpointer) provider->protocol, provider);
 
 	UNLOCK();
 }
@@ -302,7 +304,7 @@ camel_provider_list(gboolean load)
 	/* provider_table can be NULL, so initialize it */
 	if (G_UNLIKELY (provider_table == NULL))
 		camel_provider_init ();
-	
+
 	g_return_val_if_fail (provider_table != NULL, NULL);
 
 	LOCK();
@@ -343,11 +345,11 @@ camel_provider_list(gboolean load)
  * Return value: the provider, or %NULL, in which case @ex will be set.
  **/
 CamelProvider *
-camel_provider_get(const char *url_string, CamelException *ex)
+camel_provider_get(const gchar *url_string, CamelException *ex)
 {
 	CamelProvider *provider = NULL;
-	char *protocol;
-	size_t len;
+	gchar *protocol;
+	gsize len;
 
 	g_return_val_if_fail (url_string != NULL, NULL);
 	g_return_val_if_fail (provider_table != NULL, NULL);
@@ -405,7 +407,7 @@ fail:
  *
  * Returns: 0 on success or -1 on fail.
  **/
-int
+gint
 camel_provider_auto_detect (CamelProvider *provider, CamelURL *url,
 			    GHashTable **auto_detected, CamelException *ex)
 {
