@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2001-2003 Ximian, Inc. (www.ximian.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -67,7 +67,7 @@ enum {
 };
 
 typedef struct {
-	char *name;
+	const gchar *name;
 	guint type;
 } DataType;
 
@@ -124,57 +124,57 @@ static DataType cipher_types[] = {
 };
 
 struct _param {
-	char *name;
-	char *value;
+	gchar *name;
+	gchar *value;
 };
 
 struct _DigestChallenge {
 	GPtrArray *realms;
-	char *nonce;
+	gchar *nonce;
 	guint qop;
 	gboolean stale;
 	gint32 maxbuf;
-	char *charset;
-	char *algorithm;
+	gchar *charset;
+	gchar *algorithm;
 	guint cipher;
 	GList *params;
 };
 
 struct _DigestURI {
-	char *type;
-	char *host;
-	char *name;
+	gchar *type;
+	gchar *host;
+	gchar *name;
 };
 
 struct _DigestResponse {
-	char *username;
-	char *realm;
-	char *nonce;
-	char *cnonce;
-	char nc[9];
+	gchar *username;
+	gchar *realm;
+	gchar *nonce;
+	gchar *cnonce;
+	gchar nc[9];
 	guint qop;
 	struct _DigestURI *uri;
-	char resp[33];
+	gchar resp[33];
 	guint32 maxbuf;
-	char *charset;
+	gchar *charset;
 	guint cipher;
-	char *authzid;
-	char *param;
+	gchar *authzid;
+	gchar *param;
 };
 
 struct _CamelSaslDigestMd5Private {
 	struct _DigestChallenge *challenge;
 	struct _DigestResponse *response;
-	int state;
+	gint state;
 };
 
 static void
 camel_sasl_digest_md5_class_init (CamelSaslDigestMd5Class *camel_sasl_digest_md5_class)
 {
 	CamelSaslClass *camel_sasl_class = CAMEL_SASL_CLASS (camel_sasl_digest_md5_class);
-	
+
 	parent_class = CAMEL_SASL_CLASS (camel_type_get_global_classfuncs (camel_sasl_get_type ()));
-	
+
 	/* virtual method overload */
 	camel_sasl_class->challenge = digest_md5_challenge;
 }
@@ -183,7 +183,7 @@ static void
 camel_sasl_digest_md5_init (gpointer object, gpointer klass)
 {
 	CamelSaslDigestMd5 *sasl_digest = CAMEL_SASL_DIGEST_MD5 (object);
-	
+
 	sasl_digest->priv = g_new0 (struct _CamelSaslDigestMd5Private, 1);
 }
 
@@ -194,19 +194,19 @@ camel_sasl_digest_md5_finalize (CamelObject *object)
 	struct _DigestChallenge *c = sasl->priv->challenge;
 	struct _DigestResponse *r = sasl->priv->response;
 	GList *p;
-	int i;
-	
+	gint i;
+
 	if (c != NULL) {
 		for (i = 0; i < c->realms->len; i++)
 			g_free (c->realms->pdata[i]);
 		g_ptr_array_free (c->realms, TRUE);
-		
+
 		g_free (c->nonce);
 		g_free (c->charset);
 		g_free (c->algorithm);
 		for (p = c->params; p; p = p->next) {
 			struct _param *param = p->data;
-			
+
 			g_free (param->name);
 			g_free (param->value);
 			g_free (param);
@@ -214,7 +214,7 @@ camel_sasl_digest_md5_finalize (CamelObject *object)
 		g_list_free (c->params);
 		g_free (c);
 	}
-	
+
 	if (r != NULL) {
 		g_free (r->username);
 		g_free (r->realm);
@@ -230,7 +230,7 @@ camel_sasl_digest_md5_finalize (CamelObject *object)
 		g_free (r->param);
 		g_free (r);
 	}
-	
+
 	g_free (sasl->priv);
 }
 
@@ -239,7 +239,7 @@ CamelType
 camel_sasl_digest_md5_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (camel_sasl_get_type (),
 					    "CamelSaslDigestMd5",
@@ -250,34 +250,34 @@ camel_sasl_digest_md5_get_type (void)
 					    (CamelObjectInitFunc) camel_sasl_digest_md5_init,
 					    (CamelObjectFinalizeFunc) camel_sasl_digest_md5_finalize);
 	}
-	
+
 	return type;
 }
 
 static void
-decode_lwsp (const char **in)
+decode_lwsp (const gchar **in)
 {
-	const char *inptr = *in;
-	
+	const gchar *inptr = *in;
+
 	while (isspace (*inptr))
 		inptr++;
-	
+
 	*in = inptr;
 }
 
-static char *
-decode_quoted_string (const char **in)
+static gchar *
+decode_quoted_string (const gchar **in)
 {
-	const char *inptr = *in;
-	char *out = NULL, *outptr;
-	int outlen;
-	int c;
-	
+	const gchar *inptr = *in;
+	gchar *out = NULL, *outptr;
+	gint outlen;
+	gint c;
+
 	decode_lwsp (&inptr);
 	if (*inptr == '"') {
-		const char *intmp;
-		int skip = 0;
-		
+		const gchar *intmp;
+		gint skip = 0;
+
 		/* first, calc length */
 		inptr++;
 		intmp = inptr;
@@ -287,10 +287,10 @@ decode_quoted_string (const char **in)
 				skip++;
 			}
 		}
-		
+
 		outlen = intmp - inptr - skip;
 		out = outptr = g_malloc (outlen + 1);
-		
+
 		while ((c = *inptr++) && c != '"') {
 			if (c == '\\' && *inptr) {
 				c = *inptr++;
@@ -299,24 +299,24 @@ decode_quoted_string (const char **in)
 		}
 		*outptr = '\0';
 	}
-	
+
 	*in = inptr;
-	
+
 	return out;
 }
 
-static char *
-decode_token (const char **in)
+static gchar *
+decode_token (const gchar **in)
 {
-	const char *inptr = *in;
-	const char *start;
-	
+	const gchar *inptr = *in;
+	const gchar *start;
+
 	decode_lwsp (&inptr);
 	start = inptr;
-	
+
 	while (*inptr && *inptr != '=' && *inptr != ',')
 		inptr++;
-	
+
 	if (inptr > start) {
 		*in = inptr;
 		return g_strndup (start, inptr - start);
@@ -325,11 +325,11 @@ decode_token (const char **in)
 	}
 }
 
-static char *
-decode_value (const char **in)
+static gchar *
+decode_value (const gchar **in)
 {
-	const char *inptr = *in;
-	
+	const gchar *inptr = *in;
+
 	decode_lwsp (&inptr);
 	if (*inptr == '"') {
 		d(printf ("decoding quoted string token\n"));
@@ -341,12 +341,12 @@ decode_value (const char **in)
 }
 
 static GList *
-parse_param_list (const char *tokens)
+parse_param_list (const gchar *tokens)
 {
 	GList *params = NULL;
 	struct _param *param;
-	const char *ptr;
-	
+	const gchar *ptr;
+
 	for (ptr = tokens; ptr && *ptr; ) {
 		param = g_new0 (struct _param, 1);
 		param->name = decode_token (&ptr);
@@ -354,26 +354,26 @@ parse_param_list (const char *tokens)
 			ptr++;
 			param->value = decode_value (&ptr);
 		}
-		
+
 		params = g_list_prepend (params, param);
-		
+
 		if (*ptr == ',')
 			ptr++;
 	}
-	
+
 	return params;
 }
 
 static guint
-decode_data_type (DataType *dtype, const char *name)
+decode_data_type (DataType *dtype, const gchar *name)
 {
-	int i;
-	
+	gint i;
+
 	for (i = 0; dtype[i].name; i++) {
 		if (!g_ascii_strcasecmp (dtype[i].name, name))
 			break;
 	}
-	
+
 	return dtype[i].type;
 }
 
@@ -381,16 +381,16 @@ decode_data_type (DataType *dtype, const char *name)
 #define decode_qop(name)     decode_data_type (qop_types, name)
 #define decode_cipher(name)  decode_data_type (cipher_types, name)
 
-static const char *
+static const gchar *
 type_to_string (DataType *dtype, guint type)
 {
-	int i;
-	
+	gint i;
+
 	for (i = 0; dtype[i].name; i++) {
 		if (dtype[i].type == type)
 			break;
 	}
-	
+
 	return dtype[i].name;
 }
 
@@ -406,44 +406,44 @@ digest_abort (gboolean *have_type, gboolean *abort)
 }
 
 static struct _DigestChallenge *
-parse_server_challenge (const char *tokens, gboolean *abort)
+parse_server_challenge (const gchar *tokens, gboolean *abort)
 {
 	struct _DigestChallenge *challenge = NULL;
 	GList *params, *p;
-	const char *ptr;
+	const gchar *ptr;
 #ifdef PARANOID
 	gboolean got_algorithm = FALSE;
 	gboolean got_stale = FALSE;
 	gboolean got_maxbuf = FALSE;
 	gboolean got_charset = FALSE;
 #endif /* PARANOID */
-	
+
 	params = parse_param_list (tokens);
 	if (!params) {
 		*abort = TRUE;
 		return NULL;
 	}
-	
+
 	*abort = FALSE;
-	
+
 	challenge = g_new0 (struct _DigestChallenge, 1);
 	challenge->realms = g_ptr_array_new ();
 	challenge->maxbuf = 65536;
-	
+
 	for (p = params; p; p = p->next) {
 		struct _param *param = p->data;
-		int type;
-		
+		gint type;
+
 		type = get_digest_arg (param->name);
 		switch (type) {
 		case DIGEST_REALM:
 			for (ptr = param->value; ptr && *ptr; ) {
-				char *token;
-				
+				gchar *token;
+
 				token = decode_token (&ptr);
 				if (token)
 					g_ptr_array_add (challenge->realms, token);
-				
+
 				if (*ptr == ',')
 					ptr++;
 			}
@@ -459,16 +459,16 @@ parse_server_challenge (const char *tokens, gboolean *abort)
 			break;
 		case DIGEST_QOP:
 			for (ptr = param->value; ptr && *ptr; ) {
-				char *token;
-				
+				gchar *token;
+
 				token = decode_token (&ptr);
 				if (token)
 					challenge->qop |= decode_qop (token);
-				
+
 				if (*ptr == ',')
 					ptr++;
 			}
-			
+
 			if (challenge->qop & QOP_INVALID)
 				challenge->qop = QOP_INVALID;
 			g_free (param->value);
@@ -511,12 +511,12 @@ parse_server_challenge (const char *tokens, gboolean *abort)
 			break;
 		case DIGEST_CIPHER:
 			for (ptr = param->value; ptr && *ptr; ) {
-				char *token;
-				
+				gchar *token;
+
 				token = decode_token (&ptr);
 				if (token)
 					challenge->cipher |= decode_cipher (token);
-				
+
 				if (*ptr == ',')
 					ptr++;
 			}
@@ -531,13 +531,13 @@ parse_server_challenge (const char *tokens, gboolean *abort)
 			break;
 		}
 	}
-	
+
 	g_list_free (params);
-	
+
 	return challenge;
 }
 
-static char *
+static gchar *
 digest_uri_to_string (struct _DigestURI *uri)
 {
 	if (uri->name)
@@ -547,7 +547,7 @@ digest_uri_to_string (struct _DigestURI *uri)
 }
 
 static void
-compute_response (struct _DigestResponse *resp, const char *passwd, gboolean client, guchar out[33])
+compute_response (struct _DigestResponse *resp, const gchar *passwd, gboolean client, guchar out[33])
 {
 	GString *buffer;
 	GChecksum *checksum;
@@ -645,8 +645,8 @@ compute_response (struct _DigestResponse *resp, const char *passwd, gboolean cli
 }
 
 static struct _DigestResponse *
-generate_response (struct _DigestChallenge *challenge, const char *host,
-		   const char *protocol, const char *user, const char *passwd)
+generate_response (struct _DigestChallenge *challenge, const gchar *host,
+		   const gchar *protocol, const gchar *user, const gchar *passwd)
 {
 	struct _DigestResponse *resp;
 	struct _DigestURI *uri;
@@ -665,13 +665,13 @@ generate_response (struct _DigestChallenge *challenge, const char *host,
 		resp->realm = g_strdup (challenge->realms->pdata[0]);
 	else
 		resp->realm = g_strdup ("");
-	
+
 	resp->nonce = g_strdup (challenge->nonce);
-	
+
 	/* generate the cnonce */
-	bgen = g_strdup_printf ("%p:%lu:%lu", (void *) resp,
-				(unsigned long) getpid (),
-				(unsigned long) time (NULL));
+	bgen = g_strdup_printf ("%p:%lu:%lu", (gpointer) resp,
+				(gulong) getpid (),
+				(gulong) time (NULL));
 	checksum = g_checksum_new (G_CHECKSUM_MD5);
 	g_checksum_update (checksum, (guchar *) bgen, -1);
 	g_checksum_get_digest (checksum, digest, &length);
@@ -722,17 +722,17 @@ static GByteArray *
 digest_response (struct _DigestResponse *resp)
 {
 	GByteArray *buffer;
-	const char *str;
-	char *buf;
-	
+	const gchar *str;
+	gchar *buf;
+
 	buffer = g_byte_array_new ();
 	g_byte_array_append (buffer, (guint8 *) "username=\"", 10);
 	if (resp->charset) {
 		/* Encode the username using the requested charset */
-		char *username, *outbuf;
-		const char *charset;
-		size_t len, outlen;
-		const char *inbuf;
+		gchar *username, *outbuf;
+		const gchar *charset;
+		gsize len, outlen;
+		const gchar *inbuf;
 		iconv_t cd;
 
 		charset = camel_iconv_locale_charset ();
@@ -746,7 +746,7 @@ digest_response (struct _DigestResponse *resp)
 
 		outbuf = username = g_malloc0 (outlen + 1);
 		inbuf = resp->username;
-		if (cd == (iconv_t) -1 || camel_iconv (cd, &inbuf, &len, &outbuf, &outlen) == (size_t) -1) {
+		if (cd == (iconv_t) -1 || camel_iconv (cd, &inbuf, &len, &outbuf, &outlen) == (gsize) -1) {
 			/* We can't convert to UTF-8 - pretend we never got a charset param? */
 			g_free (resp->charset);
 			resp->charset = NULL;
@@ -798,7 +798,7 @@ digest_response (struct _DigestResponse *resp)
 
 	if (resp->charset) {
 		g_byte_array_append (buffer, (guint8 *) ",charset=", 9);
-		g_byte_array_append (buffer, (guint8 *) resp->charset, strlen ((char *) resp->charset));
+		g_byte_array_append (buffer, (guint8 *) resp->charset, strlen ((gchar *) resp->charset));
 	}
 
 	if (resp->cipher != CIPHER_INVALID) {
@@ -827,17 +827,17 @@ digest_md5_challenge (CamelSasl *sasl, GByteArray *token, CamelException *ex)
 	struct _param *rspauth;
 	GByteArray *ret = NULL;
 	gboolean abort = FALSE;
-	const char *ptr;
+	const gchar *ptr;
 	guchar out[33];
-	char *tokens;
+	gchar *tokens;
 	struct addrinfo *ai, hints;
-	
+
 	/* Need to wait for the server */
 	if (!token)
 		return NULL;
-	
+
 	g_return_val_if_fail (sasl->service->url->passwd != NULL, NULL);
-	
+
 	switch (priv->state) {
 	case STATE_AUTH:
 		if (token->len > 2048) {
@@ -854,7 +854,7 @@ digest_md5_challenge (CamelSasl *sasl, GByteArray *token, CamelException *ex)
 					      _("Server challenge invalid\n"));
 			return NULL;
 		}
-		
+
 		if (priv->challenge->qop == QOP_INVALID) {
 			camel_exception_setv (ex, CAMEL_EXCEPTION_SERVICE_CANT_AUTHENTICATE,
 					      _("Server challenge contained invalid "
@@ -900,7 +900,7 @@ digest_md5_challenge (CamelSasl *sasl, GByteArray *token, CamelException *ex)
 			rspauth->value = decode_value (&ptr);
 		}
 		g_free (tokens);
-		
+
 		if (!rspauth->value) {
 			g_free (rspauth->name);
 			g_free (rspauth);
@@ -908,7 +908,7 @@ digest_md5_challenge (CamelSasl *sasl, GByteArray *token, CamelException *ex)
 					      _("Server response contained incomplete authorization data"));
 			return NULL;
 		}
-		
+
 		compute_response (priv->response, sasl->service->url->passwd, FALSE, out);
 		if (memcmp (out, rspauth->value, 32) != 0) {
 			g_free (rspauth->name);
@@ -917,22 +917,22 @@ digest_md5_challenge (CamelSasl *sasl, GByteArray *token, CamelException *ex)
 			camel_exception_setv (ex, CAMEL_EXCEPTION_SERVICE_CANT_AUTHENTICATE,
 					      _("Server response does not match"));
 			sasl->authenticated = TRUE;
-			
+
 			return NULL;
 		}
-		
+
 		g_free (rspauth->name);
 		g_free (rspauth->value);
 		g_free (rspauth);
-		
+
 		ret = g_byte_array_new ();
-		
+
 		sasl->authenticated = TRUE;
 	default:
 		break;
 	}
-	
+
 	priv->state++;
-	
+
 	return ret;
 }
