@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2001 Ximian, Inc. (www.ximian.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -65,11 +65,11 @@ static CamelSaslClass *parent_class = NULL;
 static GByteArray *krb4_challenge (CamelSasl *sasl, GByteArray *token, CamelException *ex);
 
 struct _CamelSaslKerberos4Private {
-	int state;
-	
+	gint state;
+
 	guint32 nonce_n;
 	guint32 nonce_h;
-	
+
 	des_cblock session;
 	des_key_schedule schedule;
 };
@@ -78,9 +78,9 @@ static void
 camel_sasl_kerberos4_class_init (CamelSaslKerberos4Class *camel_sasl_kerberos4_class)
 {
 	CamelSaslClass *camel_sasl_class = CAMEL_SASL_CLASS (camel_sasl_kerberos4_class);
-	
+
 	parent_class = CAMEL_SASL_CLASS (camel_type_get_global_classfuncs (camel_sasl_get_type ()));
-	
+
 	/* virtual method overload */
 	camel_sasl_class->challenge = krb4_challenge;
 }
@@ -89,7 +89,7 @@ static void
 camel_sasl_kerberos4_init (gpointer object, gpointer klass)
 {
 	CamelSaslKerberos4 *sasl_krb4 = CAMEL_SASL_KERBEROS4 (object);
-	
+
 	sasl_krb4->priv = g_new0 (struct _CamelSaslKerberos4Private, 1);
 }
 
@@ -109,7 +109,7 @@ CamelType
 camel_sasl_kerberos4_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (camel_sasl_get_type (),
 					    "CamelSaslKerberos4",
@@ -120,7 +120,7 @@ camel_sasl_kerberos4_get_type (void)
 					    (CamelObjectInitFunc) camel_sasl_kerberos4_init,
 					    (CamelObjectFinalizeFunc) camel_sasl_kerberos4_finalize);
 	}
-	
+
 	return type;
 }
 
@@ -129,9 +129,9 @@ krb4_challenge (CamelSasl *sasl, GByteArray *token, CamelException *ex)
 {
 	struct _CamelSaslKerberos4Private *priv = CAMEL_SASL_KERBEROS4 (sasl)->priv;
 	GByteArray *ret = NULL;
-	char *inst, *realm, *username;
+	gchar *inst, *realm, *username;
 	struct hostent *h;
-	int status, len;
+	gint status, len;
 	KTEXT_ST authenticator;
 	CREDENTIALS credentials;
 	guint32 plus1;
@@ -212,7 +212,7 @@ krb4_challenge (CamelSasl *sasl, GByteArray *token, CamelException *ex)
 		ret->data[5] = ret->data[6] = ret->data[7] = 0;
 		strcpy (ret->data + 8, username);
 
-		des_pcbc_encrypt ((void *)ret->data, (void *)ret->data, len,
+		des_pcbc_encrypt ((gpointer)ret->data, (gpointer)ret->data, len,
 				  priv->schedule, &priv->session, 1);
 		memset (&priv->session, 0, sizeof (priv->session));
 
