@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2001 Ximian, Inc. (www.ximian.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -55,7 +55,7 @@ static CamelSaslClass *parent_class = NULL;
 static GByteArray *login_challenge (CamelSasl *sasl, GByteArray *token, CamelException *ex);
 
 struct _CamelSaslLoginPrivate {
-	int state;
+	gint state;
 };
 
 static void
