@@ -48,9 +48,9 @@ static void
 camel_sasl_ntlm_class_init (CamelSaslNTLMClass *camel_sasl_ntlm_class)
 {
 	CamelSaslClass *camel_sasl_class = CAMEL_SASL_CLASS (camel_sasl_ntlm_class);
-	
+
 	parent_class = CAMEL_SASL_CLASS (camel_type_get_global_classfuncs (camel_sasl_get_type ()));
-	
+
 	/* virtual method overload */
 	camel_sasl_class->challenge = ntlm_challenge;
 }
@@ -74,9 +74,8 @@ camel_sasl_ntlm_get_type (void)
 
 #define NTLM_REQUEST "NTLMSSP\x00\x01\x00\x00\x00\x06\x82\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00"
 
-#define NTLM_CHALLENGE_NONCE_OFFSET      24
-#define NTLM_CHALLENGE_DOMAIN_OFFSET     48
-#define NTLM_CHALLENGE_DOMAIN_LEN_OFFSET 44
+#define NTLM_CHALLENGE_DOMAIN_OFFSET		12
+#define NTLM_CHALLENGE_NONCE_OFFSET		24
 
 #define NTLM_RESPONSE_HEADER         "NTLMSSP\x00\x03\x00\x00\x00"
 #define NTLM_RESPONSE_FLAGS          "\x82\x01"
@@ -91,32 +90,74 @@ camel_sasl_ntlm_get_type (void)
 static void ntlm_calc_response   (const guchar key[21],
 				  const guchar plaintext[8],
 				  guchar results[24]);
-static void ntlm_lanmanager_hash (const char *password, char hash[21]);
-static void ntlm_nt_hash         (const char *password, char hash[21]);
-static void ntlm_set_string      (GByteArray *ba, int offset,
-				  const char *data, int len);
+static void ntlm_lanmanager_hash (const gchar *password, gchar hash[21]);
+static void ntlm_nt_hash         (const gchar *password, gchar hash[21]);
+
+typedef struct {
+	guint16 length;
+	guint16 allocated;
+	guint32 offset;
+} SecurityBuffer;
+
+static GString *
+ntlm_get_string (GByteArray *ba, gint offset)
+{
+	SecurityBuffer *secbuf;
+	GString *string;
+	gchar *buf_string;
+	guint16 buf_length;
+	guint32 buf_offset;
+
+	secbuf = (SecurityBuffer *) &ba->data[offset];
+	buf_length = GUINT16_FROM_LE (secbuf->length);
+	buf_offset = GUINT32_FROM_LE (secbuf->offset);
+
+	if (ba->len < buf_offset + buf_length)
+		return NULL;
+
+	string = g_string_sized_new (buf_length);
+	buf_string = (gchar *) &ba->data[buf_offset];
+	g_string_append_len (string, buf_string, buf_length);
+
+	return string;
+}
+
+static void
+ntlm_set_string (GByteArray *ba, gint offset, const gchar *data, gint len)
+{
+	SecurityBuffer *secbuf;
+
+	secbuf = (SecurityBuffer *) &ba->data[offset];
+	secbuf->length = GUINT16_TO_LE (len);
+	secbuf->offset = GUINT32_TO_LE (ba->len);
+	secbuf->allocated = secbuf->length;
+
+	g_byte_array_append (ba, (guint8 *) data, len);
+}
 
 static GByteArray *
 ntlm_challenge (CamelSasl *sasl, GByteArray *token, CamelException *ex)
 {
 	GByteArray *ret;
 	guchar nonce[8], hash[21], lm_resp[24], nt_resp[24];
+	GString *domain;
 
 	ret = g_byte_array_new ();
 
-	if (!token || !token->len) {
-		g_byte_array_append (ret, (guint8 *) NTLM_REQUEST,
-				     sizeof (NTLM_REQUEST) - 1);
-		return ret;
-	}
+	if (!token || token->len < NTLM_CHALLENGE_NONCE_OFFSET + 8)
+		goto fail;
 
 	memcpy (nonce, token->data + NTLM_CHALLENGE_NONCE_OFFSET, 8);
-	ntlm_lanmanager_hash (sasl->service->url->passwd, (char *) hash);
+	ntlm_lanmanager_hash (sasl->service->url->passwd, (gchar *) hash);
 	ntlm_calc_response (hash, nonce, lm_resp);
-	ntlm_nt_hash (sasl->service->url->passwd, (char *) hash);
+	ntlm_nt_hash (sasl->service->url->passwd, (gchar *) hash);
 	ntlm_calc_response (hash, nonce, nt_resp);
 
-	ret = g_byte_array_new ();
+	domain = ntlm_get_string (token, NTLM_CHALLENGE_DOMAIN_OFFSET);
+	if (domain == NULL)
+		goto fail;
+
+	/* Don't jump to 'fail' label after this point. */
 	g_byte_array_set_size (ret, NTLM_RESPONSE_BASE_SIZE);
 	memset (ret->data, 0, NTLM_RESPONSE_BASE_SIZE);
 	memcpy (ret->data, NTLM_RESPONSE_HEADER,
@@ -125,33 +166,44 @@ ntlm_challenge (CamelSasl *sasl, GByteArray *token, CamelException *ex)
 		NTLM_RESPONSE_FLAGS, sizeof (NTLM_RESPONSE_FLAGS) - 1);
 
 	ntlm_set_string (ret, NTLM_RESPONSE_DOMAIN_OFFSET,
-			 (const char *) token->data + NTLM_CHALLENGE_DOMAIN_OFFSET,
-			 atoi ((char *) token->data + NTLM_CHALLENGE_DOMAIN_LEN_OFFSET));
+			 domain->str, domain->len);
 	ntlm_set_string (ret, NTLM_RESPONSE_USER_OFFSET,
 			 sasl->service->url->user,
 			 strlen (sasl->service->url->user));
 	ntlm_set_string (ret, NTLM_RESPONSE_HOST_OFFSET,
 			 "UNKNOWN", sizeof ("UNKNOWN") - 1);
 	ntlm_set_string (ret, NTLM_RESPONSE_LM_RESP_OFFSET,
-			 (const char *) lm_resp, sizeof (lm_resp));
+			 (const gchar *) lm_resp, sizeof (lm_resp));
 	ntlm_set_string (ret, NTLM_RESPONSE_NT_RESP_OFFSET,
-			 (const char *) nt_resp, sizeof (nt_resp));
+			 (const gchar *) nt_resp, sizeof (nt_resp));
 
 	sasl->authenticated = TRUE;
+
+	g_string_free (domain, TRUE);
+
+	goto exit;
+
+fail:
+	/* If the challenge is malformed, restart authentication.
+	 * XXX A malicious server could make this loop indefinitely. */
+	g_byte_array_append (ret, (guint8 *) NTLM_REQUEST,
+			     sizeof (NTLM_REQUEST) - 1);
+
+exit:
 	return ret;
 }
 
 /* MD4 */
-static void md4sum                (const unsigned char *in, 
-				   int                  nbytes, 
-				   unsigned char        digest[16]);
+static void md4sum                (const guchar *in,
+				   gint                  nbytes,
+				   guchar        digest[16]);
 
 /* DES */
 typedef guint32 DES_KS[16][2]; /* Single-key DES key schedule */
 
-static void deskey                (DES_KS, unsigned char *, int);
+static void deskey                (DES_KS, guchar *, gint);
 
-static void des                   (DES_KS, unsigned char *);
+static void des                   (DES_KS, guchar *);
 
 static void setup_schedule        (const guchar *key_56, DES_KS ks);
 
@@ -162,14 +214,14 @@ static void setup_schedule        (const guchar *key_56, DES_KS ks);
 			  "\x00\x00\x00\x00\x00"
 
 static void
-ntlm_lanmanager_hash (const char *password, char hash[21])
+ntlm_lanmanager_hash (const gchar *password, gchar hash[21])
 {
 	guchar lm_password [15];
 	DES_KS ks;
-	int i;
+	gint i;
 
 	for (i = 0; i < 14 && password [i]; i++)
-		lm_password [i] = toupper ((unsigned char) password [i]);
+		lm_password [i] = toupper ((guchar) password [i]);
 
 	for (; i < 15; i++)
 		lm_password [i] = '\0';
@@ -177,16 +229,16 @@ ntlm_lanmanager_hash (const char *password, char hash[21])
 	memcpy (hash, LM_PASSWORD_MAGIC, 21);
 
 	setup_schedule (lm_password, ks);
-	des (ks, (unsigned char *) hash);
+	des (ks, (guchar *) hash);
 
 	setup_schedule (lm_password + 7, ks);
-	des (ks, (unsigned char *) hash + 8);
+	des (ks, (guchar *) hash + 8);
 }
 
 static void
-ntlm_nt_hash (const char *password, char hash[21])
+ntlm_nt_hash (const gchar *password, gchar hash[21])
 {
-	unsigned char *buf, *p;
+	guchar *buf, *p;
 
 	p = buf = g_malloc (strlen (password) * 2);
 
@@ -195,23 +247,12 @@ ntlm_nt_hash (const char *password, char hash[21])
 		*p++ = '\0';
 	}
 
-	md4sum (buf, p - buf, (unsigned char *) hash);
+	md4sum (buf, p - buf, (guchar *) hash);
 	memset (hash + 16, 0, 5);
 
 	g_free (buf);
 }
 
-static void
-ntlm_set_string (GByteArray *ba, int offset, const char *data, int len)
-{
-	ba->data[offset    ] = ba->data[offset + 2] =  len       & 0xFF;
-	ba->data[offset + 1] = ba->data[offset + 3] = (len >> 8) & 0xFF;
-	ba->data[offset + 4] =  ba->len       & 0xFF;
-	ba->data[offset + 5] = (ba->len >> 8) & 0xFF;
-	g_byte_array_append (ba, (guint8 *) data, len);
-}
-
-
 #define KEYBITS(k,s) \
         (((k[(s)/8] << ((s)%8)) & 0xFF) | (k[(s)/8+1] >> (8-(s)%8)))
 
@@ -221,7 +262,7 @@ static void
 setup_schedule (const guchar *key_56, DES_KS ks)
 {
 	guchar key[8];
-	int i, c, bit;
+	gint i, c, bit;
 
 	for (i = 0; i < 8; i++) {
 		key [i] = KEYBITS (key_56, i * 7);
@@ -258,7 +299,7 @@ ntlm_calc_response (const guchar key[21], const guchar plaintext[8],
 }
 
 
-/* 
+/*
  * MD4 encoder. (The one everyone else uses is not GPL-compatible;
  * this is a reimplementation from spec.) This doesn't need to be
  * efficient for our purposes, although it would be nice to fix
@@ -271,11 +312,11 @@ ntlm_calc_response (const guchar key[21], const guchar plaintext[8],
 #define ROT(val, n) ( ((val) << (n)) | ((val) >> (32 - (n))) )
 
 static void
-md4sum (const unsigned char *in, int nbytes, unsigned char digest[16])
+md4sum (const guchar *in, gint nbytes, guchar digest[16])
 {
-	unsigned char *M;
+	guchar *M;
 	guint32 A, B, C, D, AA, BB, CC, DD, X[16];
-	int pbytes, nbits = nbytes * 8, i, j;
+	gint pbytes, nbits = nbytes * 8, i, j;
 
 	pbytes = (120 - (nbytes % 64)) % 64;
 	M = alloca (nbytes + pbytes + 8);
@@ -529,10 +570,10 @@ static guint32 Spbox[8][64] = {
 
 /* Encrypt or decrypt a block of data in ECB mode */
 static void
-des (guint32 ks[16][2], unsigned char block[8])
+des (guint32 ks[16][2], guchar block[8])
 {
 	guint32 left, right, work;
-	
+
 	/* Read input block and place in left/right in big-endian order */
 	left = ((guint32)block[0] << 24)
 	 | ((guint32)block[1] << 16)
@@ -544,11 +585,11 @@ des (guint32 ks[16][2], unsigned char block[8])
 	 | (guint32)block[7];
 
 	/* Hoey's clever initial permutation algorithm, from Outerbridge
-	 * (see Schneier p 478)	
+	 * (see Schneier p 478)
 	 *
 	 * The convention here is the same as Outerbridge: rotate each
 	 * register left by 1 bit, i.e., so that "left" contains permuted
-	 * input bits 2, 3, 4, ... 1 and "right" contains 33, 34, 35, ... 32	
+	 * input bits 2, 3, 4, ... 1 and "right" contains 33, 34, 35, ... 32
 	 * (using origin-1 numbering as in the FIPS). This allows us to avoid
 	 * one of the two rotates that would otherwise be required in each of
 	 * the 16 rounds.
@@ -622,7 +663,7 @@ des (guint32 ks[16][2], unsigned char block[8])
 /* Key schedule-related tables from FIPS-46 */
 
 /* permuted choice table (key) */
-static unsigned char pc1[] = {
+static guchar pc1[] = {
 	57, 49, 41, 33, 25, 17,  9,
 	 1, 58, 50, 42, 34, 26, 18,
 	10,  2, 59, 51, 43, 35, 27,
@@ -635,12 +676,12 @@ static unsigned char pc1[] = {
 };
 
 /* number left rotations of pc1 */
-static unsigned char totrot[] = {
+static guchar totrot[] = {
 	1,2,4,6,8,10,12,14,15,17,19,21,23,25,27,28
 };
 
 /* permuted choice key (table) */
-static unsigned char pc2[] = {
+static guchar pc2[] = {
 	14, 17, 11, 24,  1,  5,
 	 3, 28, 15,  6, 21, 10,
 	23, 19, 12,  4, 26,  8,
@@ -655,7 +696,7 @@ static unsigned char pc2[] = {
 
 
 /* bit 0 is left-most in byte */
-static int bytebit[] = {
+static gint bytebit[] = {
 	0200,0100,040,020,010,04,02,01
 };
 
@@ -664,13 +705,13 @@ static int bytebit[] = {
  * depending on the value of "decrypt"
  */
 static void
-deskey (DES_KS k, unsigned char *key, int decrypt)
+deskey (DES_KS k, guchar *key, gint decrypt)
 {
-	unsigned char pc1m[56];		/* place to modify pc1 into */
-	unsigned char pcr[56];		/* place to rotate pc1 into */
-	register int i,j,l;
-	int m;
-	unsigned char ks[8];
+	guchar pc1m[56];		/* place to modify pc1 into */
+	guchar pcr[56];		/* place to rotate pc1 into */
+	register gint i,j,l;
+	gint m;
+	guchar ks[8];
 
 	for (j=0; j<56; j++) {		/* convert pc1 to bits of key */
 		l=pc1[j]-1;		/* integer bit location	 */
