@@ -59,24 +59,24 @@ static gboolean service_disconnect(CamelService *service, gboolean clean,
 				   CamelException *ex);
 static void cancel_connect (CamelService *service);
 static GList *query_auth_types (CamelService *service, CamelException *ex);
-static char *get_name (CamelService *service, gboolean brief);
-static char *get_path (CamelService *service);
+static gchar *get_name (CamelService *service, gboolean brief);
+static gchar *get_path (CamelService *service);
 
-static int service_setv (CamelObject *object, CamelException *ex, CamelArgV *args);
-static int service_getv (CamelObject *object, CamelException *ex, CamelArgGetV *args);
+static gint service_setv (CamelObject *object, CamelException *ex, CamelArgV *args);
+static gint service_getv (CamelObject *object, CamelException *ex, CamelArgGetV *args);
 
 
 static void
 camel_service_class_init (CamelServiceClass *camel_service_class)
 {
 	CamelObjectClass *object_class = CAMEL_OBJECT_CLASS (camel_service_class);
-	
+
 	parent_class = camel_type_get_global_classfuncs (CAMEL_OBJECT_TYPE);
-	
+
 	/* virtual method overloading */
 	object_class->setv = service_setv;
 	object_class->getv = service_getv;
-	
+
 	/* virtual method definition */
 	camel_service_class->construct = construct;
 	camel_service_class->connect = service_connect;
@@ -88,10 +88,10 @@ camel_service_class_init (CamelServiceClass *camel_service_class)
 }
 
 static void
-camel_service_init (void *o, void *k)
+camel_service_init (gpointer o, gpointer k)
 {
 	CamelService *service = o;
-	
+
 	service->priv = g_malloc0(sizeof(*service->priv));
 	g_static_rec_mutex_init(&service->priv->connect_lock);
 	g_static_mutex_init(&service->priv->connect_op_lock);
@@ -104,7 +104,7 @@ camel_service_finalize (CamelObject *object)
 
 	if (service->status == CAMEL_SERVICE_CONNECTED) {
 		CamelException ex;
-		
+
 		camel_exception_init (&ex);
 		CSERV_CLASS (service)->disconnect (service, TRUE, &ex);
 		if (camel_exception_is_set (&ex)) {
@@ -113,15 +113,15 @@ camel_service_finalize (CamelObject *object)
 		}
 		camel_exception_clear (&ex);
 	}
-	
+
 	if (service->url)
 		camel_url_free (service->url);
 	if (service->session)
 		camel_object_unref (service->session);
-	
+
 	g_static_rec_mutex_free (&service->priv->connect_lock);
 	g_static_mutex_free (&service->priv->connect_op_lock);
-	
+
 	g_free (service->priv);
 }
 
@@ -131,7 +131,7 @@ CamelType
 camel_service_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type =
 			camel_type_register (CAMEL_OBJECT_TYPE,
@@ -143,28 +143,28 @@ camel_service_get_type (void)
 					     (CamelObjectInitFunc) camel_service_init,
 					     camel_service_finalize );
 	}
-	
+
 	return type;
 }
 
 
-static int
+static gint
 service_setv (CamelObject *object, CamelException *ex, CamelArgV *args)
 {
 	CamelService *service = (CamelService *) object;
 	CamelURL *url = service->url;
 	gboolean reconnect = FALSE;
 	guint32 tag;
-	int i;
-	
+	gint i;
+
 	for (i = 0; i < args->argc; i++) {
 		tag = args->argv[i].tag;
-		
+
 		/* make sure this is an arg we're supposed to handle */
 		if ((tag & CAMEL_ARG_TAG) <= CAMEL_SERVICE_ARG_FIRST ||
 		    (tag & CAMEL_ARG_TAG) >= CAMEL_SERVICE_ARG_FIRST + 100)
 			continue;
-		
+
 		if (tag == CAMEL_SERVICE_USERNAME) {
 			/* set the username */
 			if (strcmp (url->user, args->argv[i].ca_str) != 0) {
@@ -199,37 +199,37 @@ service_setv (CamelObject *object, CamelException *ex, CamelArgV *args)
 			/* error? */
 			continue;
 		}
-		
+
 		/* let our parent know that we've handled this arg */
 		camel_argv_ignore (args, i);
 	}
-	
+
 	/* FIXME: what if we are in the process of connecting? */
 	if (reconnect && service->status == CAMEL_SERVICE_CONNECTED) {
 		/* reconnect the service using the new URL */
 		if (camel_service_disconnect (service, TRUE, ex))
 			camel_service_connect (service, ex);
 	}
-	
+
 	return CAMEL_OBJECT_CLASS (parent_class)->setv (object, ex, args);
 }
 
-static int
+static gint
 service_getv (CamelObject *object, CamelException *ex, CamelArgGetV *args)
 {
 	CamelService *service = (CamelService *) object;
 	CamelURL *url = service->url;
 	guint32 tag;
-	int i;
-	
+	gint i;
+
 	for (i = 0; i < args->argc; i++) {
 		tag = args->argv[i].tag;
-		
+
 		/* make sure this is an arg we're supposed to handle */
 		if ((tag & CAMEL_ARG_TAG) <= CAMEL_SERVICE_ARG_FIRST ||
 		    (tag & CAMEL_ARG_TAG) >= CAMEL_SERVICE_ARG_FIRST + 100)
 			continue;
-		
+
 		switch (tag) {
 		case CAMEL_SERVICE_USERNAME:
 			/* get the username */
@@ -256,15 +256,15 @@ service_getv (CamelObject *object, CamelException *ex, CamelArgGetV *args)
 			break;
 		}
 	}
-	
+
 	return CAMEL_OBJECT_CLASS (parent_class)->getv (object, ex, args);
 }
 
 static void
 construct (CamelService *service, CamelSession *session, CamelProvider *provider, CamelURL *url, CamelException *ex)
 {
-	char *err, *url_string;
-	
+	gchar *err, *url_string;
+
 	if (CAMEL_PROVIDER_NEEDS (provider, CAMEL_URL_PART_USER) &&
 	    (url->user == NULL || url->user[0] == '\0')) {
 		err = _("URL '%s' needs a username component");
@@ -278,12 +278,12 @@ construct (CamelService *service, CamelSession *session, CamelProvider *provider
 		err = _("URL '%s' needs a path component");
 		goto fail;
 	}
-	
+
 	service->provider = provider;
 	service->url = camel_url_copy(url);
 	service->session = session;
 	camel_object_ref (session);
-	
+
 	service->status = CAMEL_SERVICE_DISCONNECTED;
 
 	return;
@@ -311,7 +311,7 @@ camel_service_construct (CamelService *service, CamelSession *session,
 {
 	g_return_if_fail (CAMEL_IS_SERVICE (service));
 	g_return_if_fail (CAMEL_IS_SESSION (session));
-	
+
 	CSERV_CLASS (service)->construct (service, session, provider, url, ex);
 }
 
@@ -341,13 +341,14 @@ camel_service_connect (CamelService *service, CamelException *ex)
 {
 	gboolean ret = FALSE;
 	gboolean unreg = FALSE;
-	
+	CamelOperation *connect_op;
+
 	g_return_val_if_fail (CAMEL_IS_SERVICE (service), FALSE);
 	g_return_val_if_fail (service->session != NULL, FALSE);
 	g_return_val_if_fail (service->url != NULL, FALSE);
-	
+
 	CAMEL_SERVICE_REC_LOCK (service, connect_lock);
-	
+
 	if (service->status == CAMEL_SERVICE_CONNECTED) {
 		CAMEL_SERVICE_REC_UNLOCK (service, connect_lock);
 		return TRUE;
@@ -363,6 +364,7 @@ camel_service_connect (CamelService *service, CamelException *ex)
 		camel_operation_register (service->connect_op);
 		unreg = TRUE;
 	}
+	connect_op = service->connect_op;
 	CAMEL_SERVICE_UNLOCK (service, connect_op_lock);
 
 	service->status = CAMEL_SERVICE_CONNECTING;
@@ -370,17 +372,17 @@ camel_service_connect (CamelService *service, CamelException *ex)
 	service->status = ret ? CAMEL_SERVICE_CONNECTED : CAMEL_SERVICE_DISCONNECTED;
 
 	CAMEL_SERVICE_LOCK (service, connect_op_lock);
-	if (service->connect_op) {
-		if (unreg)
-			camel_operation_unregister (service->connect_op);
-		
-		camel_operation_unref (service->connect_op);
+	if (connect_op) {
+		if (unreg && service->connect_op)
+			camel_operation_unregister (connect_op);
+
+		camel_operation_unref (connect_op);
 		service->connect_op = NULL;
 	}
 	CAMEL_SERVICE_UNLOCK (service, connect_op_lock);
 
 	CAMEL_SERVICE_REC_UNLOCK (service, connect_lock);
-	
+
 	return ret;
 }
 
@@ -390,9 +392,9 @@ service_disconnect (CamelService *service, gboolean clean, CamelException *ex)
 	/*service->connect_level--;*/
 
 	/* We let people get away with not having a disconnect
-	 * function -- CamelMboxStore, for example. 
+	 * function -- CamelMboxStore, for example.
 	 */
-	
+
 	return TRUE;
 }
 
@@ -413,10 +415,10 @@ camel_service_disconnect (CamelService *service, gboolean clean,
 			  CamelException *ex)
 {
 	gboolean res = TRUE;
-	int unreg = FALSE;
+	gint unreg = FALSE;
 
 	CAMEL_SERVICE_REC_LOCK (service, connect_lock);
-	
+
 	if (service->status != CAMEL_SERVICE_DISCONNECTED
 	    && service->status != CAMEL_SERVICE_DISCONNECTING) {
 		CAMEL_SERVICE_LOCK (service, connect_op_lock);
@@ -440,9 +442,9 @@ camel_service_disconnect (CamelService *service, gboolean clean,
 		service->connect_op = NULL;
 		CAMEL_SERVICE_UNLOCK (service, connect_op_lock);
 	}
-	
+
 	CAMEL_SERVICE_REC_UNLOCK (service, connect_lock);
-	
+
 		service->status = CAMEL_SERVICE_DISCONNECTED;
 	return res;
 }
@@ -480,20 +482,20 @@ camel_service_cancel_connect (CamelService *service)
  *
  * Returns: the URL representing @service
  **/
-char *
+gchar *
 camel_service_get_url (CamelService *service)
 {
 	return camel_url_to_string (service->url, CAMEL_URL_HIDE_PASSWORD);
 }
 
 
-static char *
+static gchar *
 get_name (CamelService *service, gboolean brief)
 {
 	w(g_warning ("CamelService::get_name not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (service))));
 	return g_strdup ("???");
-}		
+}
 
 
 /**
@@ -508,35 +510,35 @@ get_name (CamelService *service, gboolean brief)
  *
  * Returns: a description of the service which the caller must free
  **/
-char *
+gchar *
 camel_service_get_name (CamelService *service, gboolean brief)
 {
 	g_return_val_if_fail (CAMEL_IS_SERVICE (service), NULL);
 	g_return_val_if_fail (service->url, NULL);
-	
+
 	return CSERV_CLASS (service)->get_name (service, brief);
 }
 
 
-static char *
+static gchar *
 get_path (CamelService *service)
 {
 	CamelProvider *prov = service->provider;
 	CamelURL *url = service->url;
 	GString *gpath;
-	char *path;
-	
+	gchar *path;
+
 	/* A sort of ad-hoc default implementation that works for our
 	 * current set of services.
 	 */
-	
+
 	gpath = g_string_new (service->provider->protocol);
 	if (CAMEL_PROVIDER_ALLOWS (prov, CAMEL_URL_PART_USER)) {
 		if (CAMEL_PROVIDER_ALLOWS (prov, CAMEL_URL_PART_HOST)) {
 			g_string_append_printf (gpath, "/%s@%s",
 						url->user ? url->user : "",
 						url->host ? url->host : "");
-			
+
 			if (url->port)
 				g_string_append_printf (gpath, ":%d", url->port);
 		} else {
@@ -547,19 +549,19 @@ get_path (CamelService *service)
 		g_string_append_printf (gpath, "/%s%s",
 					CAMEL_PROVIDER_NEEDS (prov, CAMEL_URL_PART_HOST) ? "" : "@",
 					url->host ? url->host : "");
-		
+
 		if (url->port)
 			g_string_append_printf (gpath, ":%d", url->port);
 	}
-	
+
 	if (CAMEL_PROVIDER_NEEDS (prov, CAMEL_URL_PART_PATH))
 		g_string_append_printf (gpath, "%s%s", *url->path == '/' ? "" : "/", url->path);
-	
+
 	path = gpath->str;
 	g_string_free (gpath, FALSE);
-	
+
 	return path;
-}		
+}
 
 /**
  * camel_service_get_path:
@@ -573,12 +575,12 @@ get_path (CamelService *service)
  *
  * Returns: the path, which the caller must free
  **/
-char *
+gchar *
 camel_service_get_path (CamelService *service)
 {
 	g_return_val_if_fail (CAMEL_IS_SERVICE (service), NULL);
 	g_return_val_if_fail (service->url, NULL);
-	
+
 	return CSERV_CLASS (service)->get_path (service);
 }
 
