@@ -6,7 +6,7 @@
  *
  *  Authors: David Woodhouse <dwmw2@infradead.org>,
  *	     Jeffrey Stedfast <fejj@ximian.com>
- *  
+ *
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -42,7 +42,7 @@
 #include "camel-file-utils.h"
 #include "camel-stream-process.h"
 
-extern int camel_verbose_debug;
+extern gint camel_verbose_debug;
 
 static CamelObjectClass *parent_class = NULL;
 
@@ -50,10 +50,10 @@ static CamelObjectClass *parent_class = NULL;
 #define CS_CLASS(so) CAMEL_STREAM_PROCESS_CLASS(CAMEL_OBJECT_GET_CLASS(so))
 
 /* dummy implementations, for a PROCESS stream */
-static ssize_t   stream_read       (CamelStream *stream, char *buffer, size_t n);
-static ssize_t   stream_write      (CamelStream *stream, const char *buffer, size_t n);
-static int       stream_close      (CamelStream *stream);
-static int       stream_flush      (CamelStream *stream);
+static gssize   stream_read       (CamelStream *stream, gchar *buffer, gsize n);
+static gssize   stream_write      (CamelStream *stream, const gchar *buffer, gsize n);
+static gint       stream_close      (CamelStream *stream);
+static gint       stream_flush      (CamelStream *stream);
 
 static void
 camel_stream_process_finalise (CamelObject *object)
@@ -67,9 +67,9 @@ static void
 camel_stream_process_class_init (CamelStreamProcessClass *camel_stream_process_class)
 {
 	CamelStreamClass *camel_stream_class = (CamelStreamClass *) camel_stream_process_class;
-	
+
 	parent_class = camel_type_get_global_classfuncs (CAMEL_OBJECT_TYPE);
-	
+
 	/* virtual method definition */
 	camel_stream_class->read = stream_read;
 	camel_stream_class->write = stream_write;
@@ -81,7 +81,7 @@ static void
 camel_stream_process_init (gpointer object, gpointer klass)
 {
         CamelStreamProcess *stream = CAMEL_STREAM_PROCESS (object);
-	
+
         stream->sockfd = -1;
 	stream->childpid = 0;
 }
@@ -91,7 +91,7 @@ CamelType
 camel_stream_process_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type =  camel_type_register (camel_stream_get_type (),
 					     "CamelStreamProcess",
@@ -102,7 +102,7 @@ camel_stream_process_get_type (void)
 					     (CamelObjectInitFunc) camel_stream_process_init,
 					     (CamelObjectFinalizeFunc) camel_stream_process_finalise);
 	}
-	
+
 	return type;
 }
 
@@ -120,44 +120,44 @@ camel_stream_process_new (void)
 }
 
 
-static ssize_t
-stream_read (CamelStream *stream, char *buffer, size_t n)
+static gssize
+stream_read (CamelStream *stream, gchar *buffer, gsize n)
 {
 	CamelStreamProcess *stream_process = CAMEL_STREAM_PROCESS (stream);
-	
+
 	return camel_read (stream_process->sockfd, buffer, n);
 }
 
-static ssize_t
-stream_write (CamelStream *stream, const char *buffer, size_t n)
+static gssize
+stream_write (CamelStream *stream, const gchar *buffer, gsize n)
 {
 	CamelStreamProcess *stream_process = CAMEL_STREAM_PROCESS (stream);
-	
+
 	return camel_write (stream_process->sockfd, buffer, n);
 }
 
-static int
+static gint
 stream_flush (CamelStream *stream)
 {
 	return 0;
 }
 
-static int
+static gint
 stream_close (CamelStream *object)
 {
 	CamelStreamProcess *stream = CAMEL_STREAM_PROCESS (object);
-	
+
 	if (camel_verbose_debug)
 		fprintf (stderr, "Process stream close. sockfd %d, childpid %d\n",
 			 stream->sockfd, stream->childpid);
-	
+
 	if (stream->sockfd != -1) {
 		close (stream->sockfd);
 		stream->sockfd = -1;
 	}
-	
+
 	if (stream->childpid) {
-		int ret, i;
+		gint ret, i;
 		for (i = 0; i < 4; i++) {
 			ret = waitpid (stream->childpid, NULL, WNOHANG);
 			if (camel_verbose_debug)
@@ -184,81 +184,81 @@ stream_close (CamelStream *object)
 				break;
 			}
 		}
-		
+
 		stream->childpid = 0;
 	}
-	
+
 	return 0;
 }
 
-static void
-do_exec_command (int fd, const char *command, char **env)
+G_GNUC_NORETURN static void
+do_exec_command (gint fd, const gchar *command, gchar **env)
 {
-	int i, maxopen;
-	
+	gint i, maxopen;
+
 	/* Not a lot we can do if there's an error other than bail. */
 	if (dup2 (fd, 0) == -1)
 		exit (1);
 	if (dup2 (fd, 1) == -1)
 		exit (1);
-	
+
 	/* What to do with stderr? Possibly put it through a separate pipe
 	   and bring up a dialog box with its output if anything does get
 	   spewed to it? It'd help the user understand what was going wrong
 	   with their command, but it's hard to do cleanly. For now we just
 	   leave it as it is. Perhaps we should close it and reopen /dev/null? */
-	
+
 	maxopen = sysconf (_SC_OPEN_MAX);
 	for (i = 3; i < maxopen; i++)
 		fcntl (i, F_SETFD, FD_CLOEXEC);
-	
+
 	setsid ();
 #ifdef TIOCNOTTY
-	/* Detach from the controlling tty if we have one. Otherwise, 
-	   SSH might do something stupid like trying to use it instead 
+	/* Detach from the controlling tty if we have one. Otherwise,
+	   SSH might do something stupid like trying to use it instead
 	   of running $SSH_ASKPASS. Doh. */
 	if ((fd = open ("/dev/tty", O_RDONLY)) != -1) {
 		ioctl (fd, TIOCNOTTY, NULL);
 		close (fd);
 	}
 #endif /* TIOCNOTTY */
-	
-	/* Set up child's environment. We _add_ to it, don't use execle, 
+
+	/* Set up child's environment. We _add_ to it, don't use execle,
 	   because otherwise we'd destroy stuff like SSH_AUTH_SOCK etc. */
-	for ( ; env && *env; env++)
+	for (; env && *env; env++)
 		putenv(*env);
-	
+
 	execl ("/bin/sh", "/bin/sh", "-c", command, NULL);
-	
+
 	if (camel_verbose_debug)
 		fprintf (stderr, "exec failed %d\n", errno);
-	
+
 	exit (1);
 }
 
-int
-camel_stream_process_connect (CamelStreamProcess *stream, const char *command, const char **env)
+gint
+camel_stream_process_connect (CamelStreamProcess *stream, const gchar *command, const gchar **env)
 {
-	int sockfds[2];
-	
+	gint sockfds[2];
+
 	if (stream->sockfd != -1 || stream->childpid)
 		stream_close (CAMEL_STREAM (stream));
-	
+
 	if (socketpair (AF_UNIX, SOCK_STREAM, 0, sockfds))
 		return -1;
-	
+
 	stream->childpid = fork ();
 	if (!stream->childpid) {
-		do_exec_command (sockfds[1], command, (char **)env);
+		do_exec_command (sockfds[1], command, (gchar **)env);
 	} else if (stream->childpid == -1) {
 		close (sockfds[0]);
 		close (sockfds[1]);
 		stream->sockfd = -1;
 		return -1;
 	}
-	
+
 	close (sockfds[1]);
 	stream->sockfd = sockfds[0];
-	
+
 	return 0;
 }
