@@ -5,7 +5,7 @@
  * Author:
  *  Bertrand Guiheneuf <bertrand@helixcode.com>
  *
- * Copyright 1999, 2000 Ximian, Inc. (www.ximian.com)
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -37,12 +37,12 @@ static CamelObjectClass *parent_class = NULL;
 #define CS_CLASS(so) CAMEL_STREAM_CLASS(CAMEL_OBJECT_GET_CLASS(so))
 
 /* default implementations, do very little */
-static ssize_t   stream_read       (CamelStream *stream, char *buffer, size_t n) { return 0; }
-static ssize_t   stream_write      (CamelStream *stream, const char *buffer, size_t n) { return n; }
-static int       stream_close      (CamelStream *stream) { return 0; }
-static int       stream_flush      (CamelStream *stream) { return 0; }
+static gssize   stream_read       (CamelStream *stream, gchar *buffer, gsize n) { return 0; }
+static gssize   stream_write      (CamelStream *stream, const gchar *buffer, gsize n) { return n; }
+static gint       stream_close      (CamelStream *stream) { return 0; }
+static gint       stream_flush      (CamelStream *stream) { return 0; }
 static gboolean  stream_eos        (CamelStream *stream) { return stream->eos; }
-static int       stream_reset      (CamelStream *stream) { return 0; }
+static gint       stream_reset      (CamelStream *stream) { return 0; }
 
 static void
 camel_stream_class_init (CamelStreamClass *camel_stream_class)
@@ -86,15 +86,15 @@ camel_stream_get_type (void)
  *
  * Attempts to read up to @len bytes from @stream into @buf.
  *
- * Returns the number of bytes actually read, or %-1 on error and set
+ * Returns: the number of bytes actually read, or %-1 on error and set
  * errno.
  **/
-ssize_t
-camel_stream_read (CamelStream *stream, char *buffer, size_t n)
+gssize
+camel_stream_read (CamelStream *stream, gchar *buffer, gsize n)
 {
 	g_return_val_if_fail (CAMEL_IS_STREAM (stream), -1);
 	g_return_val_if_fail (n == 0 || buffer, -1);
-	
+
 	return (CS_CLASS (stream)->read) (stream, buffer, n);
 }
 
@@ -107,11 +107,11 @@ camel_stream_read (CamelStream *stream, char *buffer, size_t n)
  *
  * Attempts to write up to @n bytes of @buffer into @stream.
  *
- * Returns the number of bytes written to the stream, or %-1 on error
+ * Returns: the number of bytes written to the stream, or %-1 on error
  * along with setting errno.
  **/
-ssize_t
-camel_stream_write (CamelStream *stream, const char *buffer, size_t n)
+gssize
+camel_stream_write (CamelStream *stream, const gchar *buffer, gsize n)
 {
 	g_return_val_if_fail (CAMEL_IS_STREAM (stream), -1);
 	g_return_val_if_fail (n == 0 || buffer, -1);
@@ -127,9 +127,9 @@ camel_stream_write (CamelStream *stream, const char *buffer, size_t n)
  * Flushes any buffered data to the stream's backing store.  Only
  * meaningful for writable streams.
  *
- * Returns %0 on success or %-1 on fail along with setting errno.
+ * Returns: %0 on success or %-1 on fail along with setting errno.
  **/
-int
+gint
 camel_stream_flush (CamelStream *stream)
 {
 	g_return_val_if_fail (CAMEL_IS_STREAM (stream), -1);
@@ -141,16 +141,16 @@ camel_stream_flush (CamelStream *stream)
 /**
  * camel_stream_close:
  * @stream: a #CamelStream object
- * 
+ *
  * Closes the stream.
- * 
- * Returns %0 on success or %-1 on error.
+ *
+ * Returns: %0 on success or %-1 on error.
  **/
-int
+gint
 camel_stream_close (CamelStream *stream)
 {
 	g_return_val_if_fail (CAMEL_IS_STREAM (stream), -1);
-	
+
 	return CS_CLASS (stream)->close (stream);
 }
 
@@ -161,13 +161,13 @@ camel_stream_close (CamelStream *stream)
  *
  * Tests if there are bytes left to read on the @stream object.
  *
- * Returns %TRUE on EOS or %FALSE otherwise.
+ * Returns: %TRUE on EOS or %FALSE otherwise.
  **/
 gboolean
 camel_stream_eos (CamelStream *stream)
 {
 	g_return_val_if_fail (CAMEL_IS_STREAM (stream), TRUE);
-	
+
 	return CS_CLASS (stream)->eos (stream);
 }
 
@@ -180,13 +180,13 @@ camel_stream_eos (CamelStream *stream)
  * from the beginning again. Not all streams in Camel are seekable,
  * but they must all be resettable.
  *
- * Returns %0 on success or %-1 on error along with setting errno.
+ * Returns: %0 on success or %-1 on error along with setting errno.
  **/
-int
+gint
 camel_stream_reset (CamelStream *stream)
 {
 	g_return_val_if_fail (CAMEL_IS_STREAM (stream), -1);
-	
+
 	return CS_CLASS (stream)->reset (stream);
 }
 
@@ -199,10 +199,10 @@ camel_stream_reset (CamelStream *stream)
  *
  * Writes the string to the stream.
  *
- * Returns the number of characters written or %-1 on error.
+ * Returns: the number of characters written or %-1 on error.
  **/
-ssize_t
-camel_stream_write_string (CamelStream *stream, const char *string)
+gssize
+camel_stream_write_string (CamelStream *stream, const gchar *string)
 {
 	return camel_stream_write (stream, string, strlen (string));
 }
@@ -215,24 +215,24 @@ camel_stream_write_string (CamelStream *stream, const char *string)
  *
  * Write formatted output to a stream.
  *
- * Returns the number of characters written or %-1 on error.
+ * Returns: the number of characters written or %-1 on error.
  **/
-ssize_t
-camel_stream_printf (CamelStream *stream, const char *fmt, ... )
+gssize
+camel_stream_printf (CamelStream *stream, const gchar *fmt, ... )
 {
 	va_list args;
-	char *string;
-	ssize_t ret;
-	
+	gchar *string;
+	gssize ret;
+
 	g_return_val_if_fail (CAMEL_IS_STREAM (stream), -1);
-	
+
 	va_start (args, fmt);
 	string = g_strdup_vprintf (fmt, args);
 	va_end (args);
-	
+
 	if (!string)
 		return -1;
-	
+
 	ret = camel_stream_write (stream, string, strlen (string));
 	g_free (string);
 	return ret;
@@ -247,16 +247,16 @@ camel_stream_printf (CamelStream *stream, const char *fmt, ... )
  * Write all of a stream (until eos) into another stream, in a
  * blocking fashion.
  *
- * Returns %-1 on error, or the number of bytes succesfully
+ * Returns: %-1 on error, or the number of bytes succesfully
  * copied across streams.
  **/
-ssize_t
+gssize
 camel_stream_write_to_stream (CamelStream *stream, CamelStream *output_stream)
 {
-	char tmp_buf[4096];
-	ssize_t total = 0;
-	ssize_t nb_read;
-	ssize_t nb_written;
+	gchar tmp_buf[4096];
+	gssize total = 0;
+	gssize nb_read;
+	gssize nb_written;
 
 	g_return_val_if_fail (CAMEL_IS_STREAM (stream), -1);
 	g_return_val_if_fail (CAMEL_IS_STREAM (output_stream), -1);
@@ -269,7 +269,7 @@ camel_stream_write_to_stream (CamelStream *stream, CamelStream *output_stream)
 			nb_written = 0;
 
 			while (nb_written < nb_read) {
-				ssize_t len = camel_stream_write (output_stream, tmp_buf + nb_written,
+				gssize len = camel_stream_write (output_stream, tmp_buf + nb_written,
 								  nb_read - nb_written);
 				if (len < 0)
 					return -1;
