@@ -72,24 +72,24 @@ static CamelTcpStreamClass *parent_class = NULL;
 /* Returns the class for a CamelTcpStreamSSL */
 #define CTSS_CLASS(so) CAMEL_TCP_STREAM_SSL_CLASS (CAMEL_OBJECT_GET_CLASS (so))
 
-static ssize_t stream_read (CamelStream *stream, char *buffer, size_t n);
-static ssize_t stream_write (CamelStream *stream, const char *buffer, size_t n);
-static int stream_flush  (CamelStream *stream);
-static int stream_close  (CamelStream *stream);
+static gssize stream_read (CamelStream *stream, gchar *buffer, gsize n);
+static gssize stream_write (CamelStream *stream, const gchar *buffer, gsize n);
+static gint stream_flush  (CamelStream *stream);
+static gint stream_close  (CamelStream *stream);
 
 static PRFileDesc *enable_ssl (CamelTcpStreamSSL *ssl, PRFileDesc *fd);
 
-static int stream_connect    (CamelTcpStream *stream, struct addrinfo *host);
-static int stream_getsockopt (CamelTcpStream *stream, CamelSockOptData *data);
-static int stream_setsockopt (CamelTcpStream *stream, const CamelSockOptData *data);
+static gint stream_connect    (CamelTcpStream *stream, struct addrinfo *host);
+static gint stream_getsockopt (CamelTcpStream *stream, CamelSockOptData *data);
+static gint stream_setsockopt (CamelTcpStream *stream, const CamelSockOptData *data);
 static struct sockaddr *stream_get_local_address (CamelTcpStream *stream, socklen_t *len);
 static struct sockaddr *stream_get_remote_address (CamelTcpStream *stream, socklen_t *len);
 
 struct _CamelTcpStreamSSLPrivate {
 	PRFileDesc *sockfd;
-	
+
 	struct _CamelSession *session;
-	char *expected_host;
+	gchar *expected_host;
 	gboolean ssl_mode;
 	guint32 flags;
 };
@@ -101,15 +101,15 @@ camel_tcp_stream_ssl_class_init (CamelTcpStreamSSLClass *camel_tcp_stream_ssl_cl
 		CAMEL_TCP_STREAM_CLASS (camel_tcp_stream_ssl_class);
 	CamelStreamClass *camel_stream_class =
 		CAMEL_STREAM_CLASS (camel_tcp_stream_ssl_class);
-	
+
 	parent_class = CAMEL_TCP_STREAM_CLASS (camel_type_get_global_classfuncs (camel_tcp_stream_get_type ()));
-	
+
 	/* virtual method overload */
 	camel_stream_class->read = stream_read;
 	camel_stream_class->write = stream_write;
 	camel_stream_class->flush = stream_flush;
 	camel_stream_class->close = stream_close;
-	
+
 	camel_tcp_stream_class->connect = stream_connect;
 	camel_tcp_stream_class->getsockopt = stream_getsockopt;
 	camel_tcp_stream_class->setsockopt = stream_setsockopt;
@@ -121,7 +121,7 @@ static void
 camel_tcp_stream_ssl_init (gpointer object, gpointer klass)
 {
 	CamelTcpStreamSSL *stream = CAMEL_TCP_STREAM_SSL (object);
-	
+
 	stream->priv = g_new0 (struct _CamelTcpStreamSSLPrivate, 1);
 }
 
@@ -139,7 +139,7 @@ camel_tcp_stream_ssl_finalize (CamelObject *object)
 		camel_object_unref(stream->priv->session);
 
 	g_free (stream->priv->expected_host);
-	
+
 	g_free (stream->priv);
 }
 
@@ -148,7 +148,7 @@ CamelType
 camel_tcp_stream_ssl_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (camel_tcp_stream_get_type (),
 					    "CamelTcpStreamSSL",
@@ -159,7 +159,7 @@ camel_tcp_stream_ssl_get_type (void)
 					    (CamelObjectInitFunc) camel_tcp_stream_ssl_init,
 					    (CamelObjectFinalizeFunc) camel_tcp_stream_ssl_finalize);
 	}
-	
+
 	return type;
 }
 
@@ -180,20 +180,20 @@ camel_tcp_stream_ssl_get_type (void)
  * Returns: a new #CamelTcpStreamSSL stream preset in SSL mode
  **/
 CamelStream *
-camel_tcp_stream_ssl_new (CamelSession *session, const char *expected_host, guint32 flags)
+camel_tcp_stream_ssl_new (CamelSession *session, const gchar *expected_host, guint32 flags)
 {
 	CamelTcpStreamSSL *stream;
 
 	g_assert(CAMEL_IS_SESSION(session));
 
 	stream = CAMEL_TCP_STREAM_SSL (camel_object_new (camel_tcp_stream_ssl_get_type ()));
-	
+
 	stream->priv->session = session;
 	camel_object_ref(session);
 	stream->priv->expected_host = g_strdup (expected_host);
 	stream->priv->ssl_mode = TRUE;
 	stream->priv->flags = flags;
-	
+
 	return CAMEL_STREAM (stream);
 }
 
@@ -214,26 +214,26 @@ camel_tcp_stream_ssl_new (CamelSession *session, const char *expected_host, guin
  * Returns: a new #CamelTcpStreamSSL stream not yet toggled into SSL mode
  **/
 CamelStream *
-camel_tcp_stream_ssl_new_raw (CamelSession *session, const char *expected_host, guint32 flags)
+camel_tcp_stream_ssl_new_raw (CamelSession *session, const gchar *expected_host, guint32 flags)
 {
 	CamelTcpStreamSSL *stream;
 
 	g_assert(CAMEL_IS_SESSION(session));
-	
+
 	stream = CAMEL_TCP_STREAM_SSL (camel_object_new (camel_tcp_stream_ssl_get_type ()));
-	
+
 	stream->priv->session = session;
 	camel_object_ref(session);
 	stream->priv->expected_host = g_strdup (expected_host);
 	stream->priv->ssl_mode = FALSE;
 	stream->priv->flags = flags;
-	
+
 	return CAMEL_STREAM (stream);
 }
 
 
 static void
-set_errno (int code)
+set_errno (gint code)
 {
 	/* FIXME: this should handle more. */
 	switch (code) {
@@ -303,7 +303,7 @@ set_errno (int code)
  *
  * Returns: %0 on success or %-1 on fail
  **/
-int
+gint
 camel_tcp_stream_ssl_enable_ssl (CamelTcpStreamSSL *ssl)
 {
 	PRFileDesc *fd;
@@ -335,18 +335,18 @@ camel_tcp_stream_ssl_enable_ssl (CamelTcpStreamSSL *ssl)
 }
 
 
-static ssize_t
-stream_read (CamelStream *stream, char *buffer, size_t n)
+static gssize
+stream_read (CamelStream *stream, gchar *buffer, gsize n)
 {
 	CamelTcpStreamSSL *tcp_stream_ssl = CAMEL_TCP_STREAM_SSL (stream);
 	PRFileDesc *cancel_fd;
-	ssize_t nread;
-	
+	gssize nread;
+
 	if (camel_operation_cancel_check (NULL)) {
 		errno = EINTR;
 		return -1;
 	}
-	
+
 	cancel_fd = camel_operation_cancel_prfd (NULL);
 	if (cancel_fd == NULL) {
 		do {
@@ -360,8 +360,8 @@ stream_read (CamelStream *stream, char *buffer, size_t n)
 		PRSocketOptionData sockopts;
 		PRPollDesc pollfds[2];
 		gboolean nonblock;
-		int error;
-		
+		gint error;
+
 		/* get O_NONBLOCK options */
 		sockopts.option = PR_SockOpt_Nonblocking;
 		PR_GetSocketOption (tcp_stream_ssl->priv->sockfd, &sockopts);
@@ -374,7 +374,7 @@ stream_read (CamelStream *stream, char *buffer, size_t n)
 		pollfds[0].in_flags = PR_POLL_READ;
 		pollfds[1].fd = cancel_fd;
 		pollfds[1].in_flags = PR_POLL_READ;
-		
+
 		do {
 			PRInt32 res;
 
@@ -405,7 +405,7 @@ stream_read (CamelStream *stream, char *buffer, size_t n)
 		} while (nread == -1 && (PR_GetError () == PR_PENDING_INTERRUPT_ERROR ||
 					 PR_GetError () == PR_IO_PENDING_ERROR ||
 					 PR_GetError () == PR_WOULD_BLOCK_ERROR));
-		
+
 		/* restore O_NONBLOCK options */
 	failed:
 		error = errno;
@@ -414,22 +414,22 @@ stream_read (CamelStream *stream, char *buffer, size_t n)
 		PR_SetSocketOption (tcp_stream_ssl->priv->sockfd, &sockopts);
 		errno = error;
 	}
-	
+
 	return nread;
 }
 
-static ssize_t
-stream_write (CamelStream *stream, const char *buffer, size_t n)
+static gssize
+stream_write (CamelStream *stream, const gchar *buffer, gsize n)
 {
 	CamelTcpStreamSSL *tcp_stream_ssl = CAMEL_TCP_STREAM_SSL (stream);
-	ssize_t w, written = 0;
+	gssize w, written = 0;
 	PRFileDesc *cancel_fd;
-	
+
 	if (camel_operation_cancel_check (NULL)) {
 		errno = EINTR;
 		return -1;
 	}
-	
+
 	cancel_fd = camel_operation_cancel_prfd (NULL);
 	if (cancel_fd == NULL) {
 		do {
@@ -440,7 +440,7 @@ stream_write (CamelStream *stream, const char *buffer, size_t n)
 			} while (w == -1 && (PR_GetError () == PR_PENDING_INTERRUPT_ERROR ||
 					     PR_GetError () == PR_IO_PENDING_ERROR ||
 					     PR_GetError () == PR_WOULD_BLOCK_ERROR));
-			
+
 			if (w > 0)
 				written += w;
 		} while (w != -1 && written < n);
@@ -448,8 +448,8 @@ stream_write (CamelStream *stream, const char *buffer, size_t n)
 		PRSocketOptionData sockopts;
 		PRPollDesc pollfds[2];
 		gboolean nonblock;
-		int error;
-		
+		gint error;
+
 		/* get O_NONBLOCK options */
 		sockopts.option = PR_SockOpt_Nonblocking;
 		PR_GetSocketOption (tcp_stream_ssl->priv->sockfd, &sockopts);
@@ -457,12 +457,12 @@ stream_write (CamelStream *stream, const char *buffer, size_t n)
 		nonblock = sockopts.value.non_blocking;
 		sockopts.value.non_blocking = TRUE;
 		PR_SetSocketOption (tcp_stream_ssl->priv->sockfd, &sockopts);
-		
+
 		pollfds[0].fd = tcp_stream_ssl->priv->sockfd;
 		pollfds[0].in_flags = PR_POLL_WRITE;
 		pollfds[1].fd = cancel_fd;
 		pollfds[1].in_flags = PR_POLL_READ;
-		
+
 		do {
 			PRInt32 res;
 
@@ -489,7 +489,7 @@ stream_write (CamelStream *stream, const char *buffer, size_t n)
 					if (w == -1)
 						set_errno (PR_GetError ());
 				} while (w == -1 && PR_GetError () == PR_PENDING_INTERRUPT_ERROR);
-				
+
 				if (w == -1) {
 					if (PR_GetError () == PR_IO_PENDING_ERROR ||
 					    PR_GetError () == PR_WOULD_BLOCK_ERROR)
@@ -498,7 +498,7 @@ stream_write (CamelStream *stream, const char *buffer, size_t n)
 					written += w;
 			}
 		} while (w != -1 && written < n);
-		
+
 		/* restore O_NONBLOCK options */
 		error = errno;
 		sockopts.option = PR_SockOpt_Nonblocking;
@@ -506,21 +506,21 @@ stream_write (CamelStream *stream, const char *buffer, size_t n)
 		PR_SetSocketOption (tcp_stream_ssl->priv->sockfd, &sockopts);
 		errno = error;
 	}
-	
+
 	if (w == -1)
 		return -1;
-	
+
 	return written;
 }
 
-static int
+static gint
 stream_flush (CamelStream *stream)
 {
 	/*return PR_Sync (((CamelTcpStreamSSL *)stream)->priv->sockfd);*/
 	return 0;
 }
 
-static int
+static gint
 stream_close (CamelStream *stream)
 {
 	if (((CamelTcpStreamSSL *)stream)->priv->sockfd == NULL) {
@@ -531,29 +531,29 @@ stream_close (CamelStream *stream)
 	PR_Shutdown (((CamelTcpStreamSSL *)stream)->priv->sockfd, PR_SHUTDOWN_BOTH);
 	if (PR_Close (((CamelTcpStreamSSL *)stream)->priv->sockfd) == PR_FAILURE)
 		return -1;
-	
+
 	((CamelTcpStreamSSL *)stream)->priv->sockfd = NULL;
-	
+
 	return 0;
 }
 
 #if 0
 /* Since this is default implementation, let NSS handle it. */
 static SECStatus
-ssl_get_client_auth (void *data, PRFileDesc *sockfd,
+ssl_get_client_auth (gpointer data, PRFileDesc *sockfd,
 		     struct CERTDistNamesStr *caNames,
 		     struct CERTCertificateStr **pRetCert,
-		     struct SECKEYPrivateKeyStr **pRetKey) 
+		     struct SECKEYPrivateKeyStr **pRetKey)
 {
 	SECStatus status = SECFailure;
 	SECKEYPrivateKey *privkey;
 	CERTCertificate *cert;
-	void *proto_win;
-	
+	gpointer proto_win;
+
 	proto_win = SSL_RevealPinArg (sockfd);
-	
-	if ((char *) data) {
-		cert = PK11_FindCertFromNickname ((char *) data, proto_win);
+
+	if ((gchar *) data) {
+		cert = PK11_FindCertFromNickname ((gchar *) data, proto_win);
 		if (cert) {
 			privKey = PK11_FindKeyByAnyCert (cert, proto_win);
 			if (privkey) {
@@ -565,45 +565,45 @@ ssl_get_client_auth (void *data, PRFileDesc *sockfd,
 	} else {
 		/* no nickname given, automatically find the right cert */
 		CERTCertNicknames *names;
-		int i;
-		
-		names = CERT_GetCertNicknames (CERT_GetDefaultCertDB (), 
+		gint i;
+
+		names = CERT_GetCertNicknames (CERT_GetDefaultCertDB (),
 					       SEC_CERT_NICKNAMES_USER,
 					       proto_win);
-		
+
 		if (names != NULL) {
 			for (i = 0; i < names->numnicknames; i++) {
-				cert = PK11_FindCertFromNickname (names->nicknames[i], 
+				cert = PK11_FindCertFromNickname (names->nicknames[i],
 								  proto_win);
 				if (!cert)
 					continue;
-				
+
 				/* Only check unexpired certs */
 				if (CERT_CheckCertValidTimes (cert, PR_Now (), PR_FALSE) != secCertTimeValid) {
 					CERT_DestroyCertificate (cert);
 					continue;
 				}
-				
+
 				status = NSS_CmpCertChainWCANames (cert, caNames);
 				if (status == SECSuccess) {
 					privkey = PK11_FindKeyByAnyCert (cert, proto_win);
 					if (privkey)
 						break;
-					
+
 					status = SECFailure;
 					break;
 				}
-				
+
 				CERT_FreeNicknames (names);
 			}
 		}
 	}
-	
+
 	if (status == SECSuccess) {
 		*pRetCert = cert;
 		*pRetKey  = privkey;
 	}
-	
+
 	return status;
 }
 #endif
@@ -611,40 +611,40 @@ ssl_get_client_auth (void *data, PRFileDesc *sockfd,
 #if 0
 /* Since this is the default NSS implementation, no need for us to use this. */
 static SECStatus
-ssl_auth_cert (void *data, PRFileDesc *sockfd, PRBool checksig, PRBool is_server)
+ssl_auth_cert (gpointer data, PRFileDesc *sockfd, PRBool checksig, PRBool is_server)
 {
 	CERTCertificate *cert;
 	SECStatus status;
-	void *pinarg;
-	char *host;
-	
+	gpointer pinarg;
+	gchar *host;
+
 	cert = SSL_PeerCertificate (sockfd);
 	pinarg = SSL_RevealPinArg (sockfd);
 	status = CERT_VerifyCertNow ((CERTCertDBHandle *)data, cert,
 				     checksig, certUsageSSLClient, pinarg);
-	
+
 	if (status != SECSuccess)
 		return SECFailure;
-	
+
 	/* Certificate is OK.  Since this is the client side of an SSL
 	 * connection, we need to verify that the name field in the cert
 	 * matches the desired hostname.  This is our defense against
 	 * man-in-the-middle attacks.
 	 */
-	
+
 	/* SSL_RevealURL returns a hostname, not a URL. */
 	host = SSL_RevealURL (sockfd);
-	
+
 	if (host && *host) {
 		status = CERT_VerifyCertName (cert, host);
 	} else {
 		PR_SetError (SSL_ERROR_BAD_CERT_DOMAIN, 0);
 		status = SECFailure;
 	}
-	
+
 	if (host)
 		PR_Free (host);
-	
+
 	return secStatus;
 }
 #endif
@@ -653,15 +653,15 @@ CamelCert *camel_certdb_nss_cert_get(CamelCertDB *certdb, CERTCertificate *cert)
 CamelCert *camel_certdb_nss_cert_add(CamelCertDB *certdb, CERTCertificate *cert);
 void camel_certdb_nss_cert_set(CamelCertDB *certdb, CamelCert *ccert, CERTCertificate *cert);
 
-static char *
+static gchar *
 cert_fingerprint(CERTCertificate *cert)
 {
 	GChecksum *checksum;
 	guint8 *digest;
 	gsize length;
-	unsigned char fingerprint[50], *f;
-	int i;
-	const char tohex[16] = "0123456789abcdef";
+	guchar fingerprint[50], *f;
+	gint i;
+	const gchar tohex[16] = "0123456789abcdef";
 
 	length = g_checksum_type_get_length (G_CHECKSUM_MD5);
 	digest = g_alloca (length);
@@ -672,7 +672,7 @@ cert_fingerprint(CERTCertificate *cert)
 	g_checksum_free (checksum);
 
 	for (i=0,f = fingerprint; i < length; i++) {
-		unsigned int c = digest[i];
+		guint c = digest[i];
 
 		*f++ = tohex[(c >> 4) & 0xf];
 		*f++ = tohex[c & 0xf];
@@ -688,14 +688,14 @@ cert_fingerprint(CERTCertificate *cert)
 
 	fingerprint[47] = 0;
 
-	return g_strdup((char*) fingerprint);
+	return g_strdup((gchar *) fingerprint);
 }
 
 /* lookup a cert uses fingerprint to index an on-disk file */
 CamelCert *
 camel_certdb_nss_cert_get(CamelCertDB *certdb, CERTCertificate *cert)
 {
-	char *fingerprint;
+	gchar *fingerprint;
 	CamelCert *ccert;
 
 	fingerprint = cert_fingerprint (cert);
@@ -754,7 +754,7 @@ CamelCert *
 camel_certdb_nss_cert_add(CamelCertDB *certdb, CERTCertificate *cert)
 {
 	CamelCert *ccert;
-	char *fingerprint;
+	gchar *fingerprint;
 
 	fingerprint = cert_fingerprint(cert);
 
@@ -778,18 +778,18 @@ camel_certdb_nss_cert_add(CamelCertDB *certdb, CERTCertificate *cert)
 void
 camel_certdb_nss_cert_set(CamelCertDB *certdb, CamelCert *ccert, CERTCertificate *cert)
 {
-	char *dir, *path, *fingerprint;
+	gchar *dir, *path, *fingerprint;
 	CamelStream *stream;
 	struct stat st;
-	
+
 	fingerprint = ccert->fingerprint;
-	
+
 	if (ccert->rawcert == NULL)
 		ccert->rawcert = g_byte_array_new ();
-	
+
 	g_byte_array_set_size (ccert->rawcert, cert->derCert.len);
 	memcpy (ccert->rawcert->data, cert->derCert.data, cert->derCert.len);
-	
+
 #ifndef G_OS_WIN32
 	dir = g_strdup_printf ("%s/.camel_certs", getenv ("HOME"));
 #else
@@ -800,13 +800,13 @@ camel_certdb_nss_cert_set(CamelCertDB *certdb, CamelCert *ccert, CERTCertificate
 		g_free (dir);
 		return;
 	}
-	
+
 	path = g_strdup_printf ("%s/%s", dir, fingerprint);
 	g_free (dir);
-	
+
 	stream = camel_stream_fs_new_with_name (path, O_WRONLY | O_CREAT | O_TRUNC, 0600);
 	if (stream != NULL) {
-		if (camel_stream_write (stream, (const char *) ccert->rawcert->data, ccert->rawcert->len) == -1) {
+		if (camel_stream_write (stream, (const gchar *) ccert->rawcert->data, ccert->rawcert->len) == -1) {
 			g_warning ("Could not save cert: %s: %s", path, g_strerror (errno));
 			g_unlink (path);
 		}
@@ -815,18 +815,18 @@ camel_certdb_nss_cert_set(CamelCertDB *certdb, CamelCert *ccert, CERTCertificate
 	} else {
 		g_warning ("Could not save cert: %s: %s", path, g_strerror (errno));
 	}
-	
+
 	g_free (path);
 }
 
 
 #if 0
 /* used by the mozilla-like code below */
-static char *
+static gchar *
 get_nickname(CERTCertificate *cert)
 {
-	char *server, *nick = NULL;
-	int i;
+	gchar *server, *nick = NULL;
+	gint i;
 	PRBool status = PR_TRUE;
 
 	server = CERT_GetCommonName(&cert->subject);
@@ -848,12 +848,12 @@ get_nickname(CERTCertificate *cert)
 #endif
 
 static SECStatus
-ssl_bad_cert (void *data, PRFileDesc *sockfd)
+ssl_bad_cert (gpointer data, PRFileDesc *sockfd)
 {
 	gboolean accept;
 	CamelCertDB *certdb = NULL;
 	CamelCert *ccert = NULL;
-	char *prompt, *cert_str, *fingerprint;
+	gchar *prompt, *cert_str, *fingerprint;
 	CamelTcpStreamSSL *ssl;
 	CERTCertificate *cert;
 	SECStatus status = SECFailure;
@@ -862,7 +862,7 @@ ssl_bad_cert (void *data, PRFileDesc *sockfd)
 	g_return_val_if_fail (CAMEL_IS_TCP_STREAM_SSL (data), SECFailure);
 
 	ssl = data;
-	
+
 	cert = SSL_PeerCertificate (sockfd);
 	if (cert == NULL)
 		return SECFailure;
@@ -890,7 +890,7 @@ ssl_bad_cert (void *data, PRFileDesc *sockfd)
 		prompt = g_strdup_printf (_("SSL Certificate check for %s:\n\n%s\n\nDo you wish to accept?"),
 					  ssl->priv->expected_host, cert_str);
 		g_free (cert_str);
-	
+
 		/* query the user to find out if we want to accept this certificate */
 		accept = camel_session_alert_user (ssl->priv->session, CAMEL_SESSION_ALERT_WARNING, prompt, TRUE);
 		g_free(prompt);
@@ -909,18 +909,18 @@ ssl_bad_cert (void *data, PRFileDesc *sockfd)
 	return accept ? SECSuccess : SECFailure;
 
 #if 0
-	int i, error;
+	gint i, error;
 	CERTCertTrust trust;
 	SECItem *certs[1];
-	int go = 1;
-	char *host, *nick;
+	gint go = 1;
+	gchar *host, *nick;
 
 	error = PR_GetError();
 
 	/* This code is basically what mozilla does - however it doesn't seem to work here
 	   very reliably :-/ */
 	while (go && status != SECSuccess) {
-		char *prompt = NULL;
+		gchar *prompt = NULL;
 
 		printf("looping, error '%d'\n", error);
 
@@ -948,7 +948,7 @@ ssl_bad_cert (void *data, PRFileDesc *sockfd)
 					cert->trust = (CERTCertTrust*)PORT_ArenaZAlloc(cert->arena, sizeof(CERTCertTrust));
 					CERT_DecodeTrustString(cert->trust, "P");
 				}
-		
+
 				certs[0] = &cert->derCert;
 				/*CERT_ImportCerts (cert->dbhandle, certUsageSSLServer, 1, certs, NULL, TRUE, FALSE, nick);*/
 				CERT_ImportCerts(cert->dbhandle, certUsageUserCertImport, 1, certs, NULL, TRUE, FALSE, nick);
@@ -956,7 +956,7 @@ ssl_bad_cert (void *data, PRFileDesc *sockfd)
 
 				printf(" cert type %08x\n", cert->nsCertType);
 
-				memset((void*)&trust, 0, sizeof(trust));
+				memset((gpointer)&trust, 0, sizeof(trust));
 				if (CERT_GetCertTrust(cert, &trust) != SECSuccess) {
 					CERT_DecodeTrustString(&trust, "P");
 				}
@@ -997,7 +997,7 @@ ssl_bad_cert (void *data, PRFileDesc *sockfd)
 			}
 
 			break;
-			
+
 		case SEC_ERROR_EXPIRED_CERTIFICATE:
 			printf("expired\n");
 
@@ -1047,11 +1047,11 @@ static PRFileDesc *
 enable_ssl (CamelTcpStreamSSL *ssl, PRFileDesc *fd)
 {
 	PRFileDesc *ssl_fd;
-	
+
 	ssl_fd = SSL_ImportFD (NULL, fd ? fd : ssl->priv->sockfd);
 	if (!ssl_fd)
 		return NULL;
-	
+
 	SSL_OptionSet (ssl_fd, SSL_SECURITY, PR_TRUE);
 
 	if (ssl->priv->flags & CAMEL_TCP_STREAM_SSL_ENABLE_SSL2) {
@@ -1071,20 +1071,20 @@ enable_ssl (CamelTcpStreamSSL *ssl, PRFileDesc *fd)
 		SSL_OptionSet (ssl_fd, SSL_ENABLE_TLS, PR_TRUE);
 	else
 		SSL_OptionSet (ssl_fd, SSL_ENABLE_TLS, PR_FALSE);
-	
+
 	SSL_SetURL (ssl_fd, ssl->priv->expected_host);
-	
-	/*SSL_GetClientAuthDataHook (sslSocket, ssl_get_client_auth, (void *) certNickname);*/
-	/*SSL_AuthCertificateHook (ssl_fd, ssl_auth_cert, (void *) CERT_GetDefaultCertDB ());*/
+
+	/*SSL_GetClientAuthDataHook (sslSocket, ssl_get_client_auth, (gpointer) certNickname);*/
+	/*SSL_AuthCertificateHook (ssl_fd, ssl_auth_cert, (gpointer) CERT_GetDefaultCertDB ());*/
 	SSL_BadCertHook (ssl_fd, ssl_bad_cert, ssl);
-	
+
 	ssl->priv->ssl_mode = TRUE;
-	
+
 	return ssl_fd;
 }
 
-static int
-sockaddr_to_praddr(struct sockaddr *s, int len, PRNetAddr *addr)
+static gint
+sockaddr_to_praddr(struct sockaddr *s, gint len, PRNetAddr *addr)
 {
 	/* We assume the ip addresses are the same size - they have to be anyway.
 	   We could probably just use memcpy *shrug* */
@@ -1123,7 +1123,7 @@ sockaddr_to_praddr(struct sockaddr *s, int len, PRNetAddr *addr)
 	return -1;
 }
 
-static int
+static gint
 socket_connect(CamelTcpStream *stream, struct addrinfo *host)
 {
 	CamelTcpStreamSSL *ssl = CAMEL_TCP_STREAM_SSL (stream);
@@ -1146,7 +1146,7 @@ socket_connect(CamelTcpStream *stream, struct addrinfo *host)
 
 		ssl_fd = enable_ssl (ssl, fd);
 		if (ssl_fd == NULL) {
-			int errnosave;
+			gint errnosave;
 
 			set_errno (PR_GetError ());
 			errnosave = errno;
@@ -1163,8 +1163,8 @@ socket_connect(CamelTcpStream *stream, struct addrinfo *host)
 	cancel_fd = camel_operation_cancel_prfd(NULL);
 
 	if (PR_Connect (fd, &netaddr, cancel_fd?0:CONNECT_TIMEOUT) == PR_FAILURE) {
-		int errnosave;
-		
+		gint errnosave;
+
 		set_errno (PR_GetError ());
 		if (PR_GetError () == PR_IN_PROGRESS_ERROR ||
 		    (cancel_fd && (PR_GetError () == PR_CONNECT_TIMEOUT_ERROR ||
@@ -1176,7 +1176,7 @@ socket_connect(CamelTcpStream *stream, struct addrinfo *host)
 			poll[0].in_flags = PR_POLL_WRITE | PR_POLL_EXCEPT;
 			poll[1].fd = cancel_fd;
 			poll[1].in_flags = PR_POLL_READ;
-			
+
 			do {
 				poll[0].out_flags = 0;
 				poll[1].out_flags = 0;
@@ -1185,7 +1185,7 @@ socket_connect(CamelTcpStream *stream, struct addrinfo *host)
 					set_errno (PR_GetError ());
 					goto exception;
 				}
-				
+
 				if (poll[1].out_flags == PR_POLL_READ) {
 					errno = EINTR;
 					goto exception;
@@ -1206,19 +1206,19 @@ socket_connect(CamelTcpStream *stream, struct addrinfo *host)
 			PR_Close (fd);
 			ssl->priv->sockfd = NULL;
 			errno = errnosave;
-			
+
 			return -1;
 		}
-		
+
 		errno = 0;
 	}
-	
+
 	ssl->priv->sockfd = fd;
 
 	return 0;
 }
 
-static int
+static gint
 stream_connect(CamelTcpStream *stream, struct addrinfo *host)
 {
 	while (host) {
@@ -1230,33 +1230,33 @@ stream_connect(CamelTcpStream *stream, struct addrinfo *host)
 	return -1;
 }
 
-static int
+static gint
 stream_getsockopt (CamelTcpStream *stream, CamelSockOptData *data)
 {
 	PRSocketOptionData sodata;
-	
-	memset ((void *) &sodata, 0, sizeof (sodata));
-	memcpy ((void *) &sodata, (void *) data, sizeof (CamelSockOptData));
-	
+
+	memset ((gpointer) &sodata, 0, sizeof (sodata));
+	memcpy ((gpointer) &sodata, (gpointer) data, sizeof (CamelSockOptData));
+
 	if (PR_GetSocketOption (((CamelTcpStreamSSL *)stream)->priv->sockfd, &sodata) == PR_FAILURE)
 		return -1;
-	
-	memcpy ((void *) data, (void *) &sodata, sizeof (CamelSockOptData));
-	
+
+	memcpy ((gpointer) data, (gpointer) &sodata, sizeof (CamelSockOptData));
+
 	return 0;
 }
 
-static int
+static gint
 stream_setsockopt (CamelTcpStream *stream, const CamelSockOptData *data)
 {
 	PRSocketOptionData sodata;
-	
-	memset ((void *) &sodata, 0, sizeof (sodata));
-	memcpy ((void *) &sodata, (void *) data, sizeof (CamelSockOptData));
-	
+
+	memset ((gpointer) &sodata, 0, sizeof (sodata));
+	memcpy ((gpointer) &sodata, (gpointer) data, sizeof (CamelSockOptData));
+
 	if (PR_SetSocketOption (((CamelTcpStreamSSL *)stream)->priv->sockfd, &sodata) == PR_FAILURE)
 		return -1;
-	
+
 	return 0;
 }
 
@@ -1286,7 +1286,7 @@ sockaddr_from_praddr(PRNetAddr *addr, socklen_t *len)
 		sin->sin6_scope_id = addr->ipv6.scope_id;
 		*len = sizeof(*sin);
 
-		return (struct sockaddr *)sin;		
+		return (struct sockaddr *)sin;
 	}
 #endif
 
@@ -1298,7 +1298,7 @@ stream_get_local_address(CamelTcpStream *stream, socklen_t *len)
 {
 	PRFileDesc *sockfd = CAMEL_TCP_STREAM_SSL (stream)->priv->sockfd;
 	PRNetAddr addr;
-	
+
 	if (PR_GetSockName(sockfd, &addr) != PR_SUCCESS)
 		return NULL;
 
@@ -1310,7 +1310,7 @@ stream_get_remote_address (CamelTcpStream *stream, socklen_t *len)
 {
 	PRFileDesc *sockfd = CAMEL_TCP_STREAM_SSL (stream)->priv->sockfd;
 	PRNetAddr addr;
-	
+
 	if (PR_GetPeerName(sockfd, &addr) != PR_SUCCESS)
 		return NULL;
 
