@@ -35,9 +35,9 @@ static CamelStreamClass *parent_class = NULL;
 /* Returns the class for a CamelTcpStream */
 #define CTS_CLASS(so) CAMEL_TCP_STREAM_CLASS (CAMEL_OBJECT_GET_CLASS(so))
 
-static int tcp_connect    (CamelTcpStream *stream, struct addrinfo *host);
-static int tcp_getsockopt (CamelTcpStream *stream, CamelSockOptData *data);
-static int tcp_setsockopt (CamelTcpStream *stream, const CamelSockOptData *data);
+static gint tcp_connect    (CamelTcpStream *stream, struct addrinfo *host);
+static gint tcp_getsockopt (CamelTcpStream *stream, CamelSockOptData *data);
+static gint tcp_setsockopt (CamelTcpStream *stream, const CamelSockOptData *data);
 static struct sockaddr *tcp_get_local_address (CamelTcpStream *stream, socklen_t *len);
 static struct sockaddr *tcp_get_remote_address (CamelTcpStream *stream, socklen_t *len);
 
@@ -45,9 +45,9 @@ static void
 camel_tcp_stream_class_init (CamelTcpStreamClass *camel_tcp_stream_class)
 {
 	/*CamelStreamClass *camel_stream_class = CAMEL_STREAM_CLASS (camel_tcp_stream_class);*/
-	
+
 	parent_class = CAMEL_STREAM_CLASS (camel_type_get_global_classfuncs (CAMEL_STREAM_TYPE));
-	
+
 	/* tcp stream methods */
 	camel_tcp_stream_class->connect            = tcp_connect;
 	camel_tcp_stream_class->getsockopt         = tcp_getsockopt;
@@ -57,7 +57,7 @@ camel_tcp_stream_class_init (CamelTcpStreamClass *camel_tcp_stream_class)
 }
 
 static void
-camel_tcp_stream_init (void *o)
+camel_tcp_stream_init (gpointer o)
 {
 	;
 }
@@ -66,7 +66,7 @@ CamelType
 camel_tcp_stream_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (CAMEL_STREAM_TYPE,
 					    "CamelTcpStream",
@@ -82,7 +82,7 @@ camel_tcp_stream_get_type (void)
 }
 
 
-static int
+static gint
 tcp_connect (CamelTcpStream *stream, struct addrinfo *host)
 {
 	w(g_warning ("CamelTcpStream::connect called on default implementation"));
@@ -97,17 +97,17 @@ tcp_connect (CamelTcpStream *stream, struct addrinfo *host)
  *
  * Create a socket and connect based upon the data provided.
  *
- * Returns %0 on success or %-1 on fail
+ * Returns: %0 on success or %-1 on fail
  **/
-int
+gint
 camel_tcp_stream_connect (CamelTcpStream *stream, struct addrinfo *host)
 {
 	g_return_val_if_fail (CAMEL_IS_TCP_STREAM (stream), -1);
-	
+
 	return CTS_CLASS (stream)->connect (stream, host);
 }
 
-static int
+static gint
 tcp_getsockopt (CamelTcpStream *stream, CamelSockOptData *data)
 {
 	w(g_warning ("CamelTcpStream::getsockopt called on default implementation"));
@@ -121,17 +121,17 @@ tcp_getsockopt (CamelTcpStream *stream, CamelSockOptData *data)
  *
  * Get the socket options set on the stream and populate @data.
  *
- * Returns %0 on success or %-1 on fail
+ * Returns: %0 on success or %-1 on fail
  **/
-int
+gint
 camel_tcp_stream_getsockopt (CamelTcpStream *stream, CamelSockOptData *data)
 {
 	g_return_val_if_fail (CAMEL_IS_TCP_STREAM (stream), -1);
-	
+
 	return CTS_CLASS (stream)->getsockopt (stream, data);
 }
 
-static int
+static gint
 tcp_setsockopt (CamelTcpStream *stream, const CamelSockOptData *data)
 {
 	w(g_warning ("CamelTcpStream::setsockopt called on default implementation"));
@@ -145,13 +145,13 @@ tcp_setsockopt (CamelTcpStream *stream, const CamelSockOptData *data)
  *
  * Set the socket options contained in @data on the stream.
  *
- * Returns %0 on success or %-1 on fail
+ * Returns: %0 on success or %-1 on fail
  **/
-int
+gint
 camel_tcp_stream_setsockopt (CamelTcpStream *stream, const CamelSockOptData *data)
 {
 	g_return_val_if_fail (CAMEL_IS_TCP_STREAM (stream), -1);
-	
+
 	return CTS_CLASS (stream)->setsockopt (stream, data);
 }
 
@@ -169,7 +169,7 @@ tcp_get_local_address (CamelTcpStream *stream, socklen_t *len)
  *
  * Get the local address of @stream.
  *
- * Returns the stream's local address (which must be freed with
+ * Returns: the stream's local address (which must be freed with
  * #g_free) if the stream is connected, or %NULL if not
  **/
 struct sockaddr *
@@ -177,7 +177,7 @@ camel_tcp_stream_get_local_address (CamelTcpStream *stream, socklen_t *len)
 {
 	g_return_val_if_fail (CAMEL_IS_TCP_STREAM (stream), NULL);
 	g_return_val_if_fail(len != NULL, NULL);
-	
+
 	return CTS_CLASS (stream)->get_local_address (stream, len);
 }
 
@@ -195,7 +195,7 @@ tcp_get_remote_address (CamelTcpStream *stream, socklen_t *len)
  *
  * Get the remote address of @stream.
  *
- * Returns the stream's remote address (which must be freed with
+ * Returns: the stream's remote address (which must be freed with
  * #g_free) if the stream is connected, or %NULL if not.
  **/
 struct sockaddr *
