@@ -54,16 +54,16 @@ typedef enum {
 	CAMEL_SOCKOPT_KEEPALIVE,       /* keep connections alive */
 	CAMEL_SOCKOPT_RECVBUFFERSIZE,  /* receive buffer size */
 	CAMEL_SOCKOPT_SENDBUFFERSIZE,  /* send buffer size */
-	
+
 	CAMEL_SOCKOPT_IPTIMETOLIVE,    /* time to live */
 	CAMEL_SOCKOPT_IPTYPEOFSERVICE, /* type of service and precedence */
-	
+
 	CAMEL_SOCKOPT_ADDMEMBER,       /* add an IP group membership */
 	CAMEL_SOCKOPT_DROPMEMBER,      /* drop an IP group membership */
 	CAMEL_SOCKOPT_MCASTINTERFACE,  /* multicast interface address */
 	CAMEL_SOCKOPT_MCASTTIMETOLIVE, /* multicast timetolive */
 	CAMEL_SOCKOPT_MCASTLOOPBACK,   /* multicast loopback */
-	
+
 	CAMEL_SOCKOPT_NODELAY,         /* don't delay send to coalesce packets */
 	CAMEL_SOCKOPT_MAXSEGMENT,      /* maximum segment size */
 	CAMEL_SOCKOPT_BROADCAST,       /* enable broadcast */
@@ -84,26 +84,26 @@ typedef struct _CamelSockOptData {
 		gboolean    mcast_loopback;      /* IP multicast loopback */
 		gboolean    no_delay;            /* Don't delay send to coalesce packets */
 		gboolean    broadcast;           /* Enable broadcast */
-		size_t      max_segment;         /* Maximum segment size */
-		size_t      recv_buffer_size;    /* Receive buffer size */
-		size_t      send_buffer_size;    /* Send buffer size */
+		gsize      max_segment;         /* Maximum segment size */
+		gsize      recv_buffer_size;    /* Receive buffer size */
+		gsize      send_buffer_size;    /* Send buffer size */
 		CamelLinger linger;              /* Time to linger on close if data present */
 	} value;
 } CamelSockOptData;
 
 struct _CamelTcpStream {
 	CamelStream parent_object;
-	
+
 };
 
 typedef struct {
 	CamelStreamClass parent_class;
 
 	/* Virtual methods */
-	int (*connect)    (CamelTcpStream *stream, struct addrinfo *host);
-	int (*getsockopt) (CamelTcpStream *stream, CamelSockOptData *data);
-	int (*setsockopt) (CamelTcpStream *stream, const CamelSockOptData *data);
-	
+	gint (*connect)    (CamelTcpStream *stream, struct addrinfo *host);
+	gint (*getsockopt) (CamelTcpStream *stream, CamelSockOptData *data);
+	gint (*setsockopt) (CamelTcpStream *stream, const CamelSockOptData *data);
+
 	struct sockaddr * (*get_local_address)  (CamelTcpStream *stream, socklen_t *len);
 	struct sockaddr * (*get_remote_address) (CamelTcpStream *stream, socklen_t *len);
 } CamelTcpStreamClass;
@@ -112,9 +112,9 @@ typedef struct {
 CamelType camel_tcp_stream_get_type (void);
 
 /* public methods */
-int         camel_tcp_stream_connect    (CamelTcpStream *stream, struct addrinfo *host);
-int         camel_tcp_stream_getsockopt (CamelTcpStream *stream, CamelSockOptData *data);
-int         camel_tcp_stream_setsockopt (CamelTcpStream *stream, const CamelSockOptData *data);
+gint         camel_tcp_stream_connect    (CamelTcpStream *stream, struct addrinfo *host);
+gint         camel_tcp_stream_getsockopt (CamelTcpStream *stream, CamelSockOptData *data);
+gint         camel_tcp_stream_setsockopt (CamelTcpStream *stream, const CamelSockOptData *data);
 
 struct sockaddr *camel_tcp_stream_get_local_address  (CamelTcpStream *stream, socklen_t *len);
 struct sockaddr *camel_tcp_stream_get_remote_address (CamelTcpStream *stream, socklen_t *len);
