@@ -7,7 +7,7 @@
  *   parthasarathi susarla <sparthasarathi@novell.com>
  *
  *
- * Copyright (C) 2004, Novell, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -59,9 +59,9 @@ struct _CamelGroupwiseFolder {
 	CamelOfflineJournal *journal;
 	CamelDataCache *cache;
 
-	unsigned int need_rescan:1;
-	unsigned int need_refresh:1;
-	unsigned int read_only:1;
+	guint need_rescan:1;
+	guint need_refresh:1;
+	guint read_only:1;
 
 
 };
@@ -78,9 +78,8 @@ struct _CamelGroupwiseFolderClass {
 CamelType camel_groupwise_folder_get_type (void);
 
 /* implemented */
-CamelFolder * camel_gw_folder_new(CamelStore *store, const char *folder_dir, const char *folder_name, CamelException *ex) ;
-void gw_update_summary ( CamelFolder *folder, GList *item_list,CamelException *ex) ;
-void groupwise_refresh_folder(CamelFolder *folder, CamelException *ex);
+CamelFolder * camel_gw_folder_new(CamelStore *store, const gchar *folder_dir, const gchar *folder_name, CamelException *ex);
+void gw_update_summary ( CamelFolder *folder, GList *item_list,CamelException *ex);
 
 G_END_DECLS
 
