@@ -32,15 +32,15 @@
 
 G_BEGIN_DECLS
 
-typedef struct _CamelGroupwiseSummary CamelGroupwiseSummary ;
-typedef struct _CamelGroupwiseSummaryClass CamelGroupwiseSummaryClass ;
-typedef struct _CamelGroupwiseMessageInfo CamelGroupwiseMessageInfo ;
-typedef struct _CamelGroupwiseMessageContentInfo CamelGroupwiseMessageContentInfo ;
+typedef struct _CamelGroupwiseSummary CamelGroupwiseSummary;
+typedef struct _CamelGroupwiseSummaryClass CamelGroupwiseSummaryClass;
+typedef struct _CamelGroupwiseMessageInfo CamelGroupwiseMessageInfo;
+typedef struct _CamelGroupwiseMessageContentInfo CamelGroupwiseMessageContentInfo;
 
 /* extra summary flags*/
 enum {
 	CAMEL_GW_MESSAGE_JUNK = 1<<17,
-	CAMEL_GW_MESSAGE_NOJUNK = 1<<18,
+	CAMEL_GW_MESSAGE_NOJUNK = 1<<18
 };
 
 struct _CamelGroupwiseMessageInfo {
@@ -51,31 +51,31 @@ struct _CamelGroupwiseMessageInfo {
 
 
 struct _CamelGroupwiseMessageContentInfo {
-	CamelMessageContentInfo info ;
-} ; 
+	CamelMessageContentInfo info;
+} ;
 
 
 struct _CamelGroupwiseSummary {
-	CamelFolderSummary parent ;
+	CamelFolderSummary parent;
 
-	char *time_string;
-	guint32 version ;
-	guint32 validity ;
+	gchar *time_string;
+	gint32 version;
+	gint32 validity;
 } ;
 
 
 struct _CamelGroupwiseSummaryClass {
-	CamelFolderSummaryClass parent_class ;
+	CamelFolderSummaryClass parent_class;
 } ;
 
 
-CamelType camel_groupwise_summary_get_type (void) ;
+CamelType camel_groupwise_summary_get_type (void);
 
-CamelFolderSummary *camel_groupwise_summary_new (struct _CamelFolder *folder, const char *filename) ;
+CamelFolderSummary *camel_groupwise_summary_new (struct _CamelFolder *folder, const gchar *filename);
 
-void camel_gw_summary_add_offline (CamelFolderSummary *summary, const char *uid, CamelMimeMessage *messgae, const CamelMessageInfo *info) ;
+void camel_gw_summary_add_offline (CamelFolderSummary *summary, const gchar *uid, CamelMimeMessage *messgae, const CamelMessageInfo *info);
 
-void camel_gw_summary_add_offline_uncached (CamelFolderSummary *summary, const char *uid, const CamelMessageInfo *info) ;
+void camel_gw_summary_add_offline_uncached (CamelFolderSummary *summary, const gchar *uid, const CamelMessageInfo *info);
 void groupwise_summary_clear (CamelFolderSummary *summary, gboolean uncache);
 
 G_END_DECLS
