@@ -1,14 +1,14 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-groupwise-transport.c : class for an groupwise transport */
 
-/* 
+/*
  * Authors: Sivaiah Nallagatla <snallagatla@novell.com>
  *	    Parthasarathi Susarla <sparthasarathi@novell.com>
  *
- * Copyright (C) 2004 Novell, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -36,7 +36,7 @@
 #include "camel-mime-message.h"
 #include "camel-mime-utils.h"
 #include "camel-multipart.h"
-#include "camel-session.h" 
+#include "camel-session.h"
 #include "camel-stream-mem.h"
 #include "camel-stream.h"
 
@@ -44,6 +44,8 @@
 #include "camel-groupwise-transport.h"
 #include "camel-groupwise-utils.h"
 
+#define REPLY_VIEW "default message attachments threading"
+
 static gboolean groupwise_send_to (CamelTransport *transport,
 				  CamelMimeMessage *message,
 				  CamelAddress *from,
@@ -51,7 +53,7 @@ static gboolean groupwise_send_to (CamelTransport *transport,
 				  CamelException *ex);
 
 static gboolean groupwise_transport_connect (CamelService *service, CamelException *ex);
-static char *groupwise_transport_get_name (CamelService *service, gboolean brief);
+static gchar *groupwise_transport_get_name (CamelService *service, gboolean brief);
 static void groupwise_transport_construct (CamelService *service, CamelSession *session,
 					   CamelProvider *provider, CamelURL *url, CamelException *ex);
 
@@ -68,13 +70,13 @@ camel_groupwise_transport_class_init (CamelGroupwiseTransportClass *camel_groupw
 
 	CamelServiceClass *camel_service_class =
 		CAMEL_SERVICE_CLASS (camel_groupwise_transport_class);
-	
+
 	parent_class = CAMEL_TRANSPORT_CLASS (camel_type_get_global_classfuncs (camel_transport_get_type ()));
-	
+
 	camel_service_class->connect = groupwise_transport_connect;
 	camel_service_class->get_name = groupwise_transport_get_name;
 	camel_service_class->construct = groupwise_transport_construct;
-	
+
 	/* virtual method overload */
 	camel_transport_class->send_to = groupwise_send_to;
 }
@@ -115,7 +117,7 @@ camel_groupwise_transport_get_type (void)
 	return camel_groupwise_transport_type;
 }
 
-static char *groupwise_transport_get_name (CamelService *service, gboolean brief)
+static gchar *groupwise_transport_get_name (CamelService *service, gboolean brief)
 {
 	if (brief)
 		return g_strdup_printf (_("GroupWise server %s"), service->url->host);
@@ -135,9 +137,9 @@ groupwise_transport_connect (CamelService *service, CamelException *ex)
 
 
 static gboolean
-groupwise_send_to (CamelTransport *transport, 
+groupwise_send_to (CamelTransport *transport,
 		   CamelMimeMessage *message,
-		   CamelAddress *from, 
+		   CamelAddress *from,
 		   CamelAddress *recipients,
 		   CamelException *ex)
 {
@@ -149,8 +151,8 @@ groupwise_send_to (CamelTransport *transport,
 	EGwConnection *cnc = NULL;
 	EGwConnectionStatus status = 0;
 	GSList *sent_item_list = NULL;
-	char *url = NULL;
-	const char *reply_request = NULL;
+	gchar *url = NULL;
+	const gchar *reply_request = NULL;
 	EGwItemLinkInfo *info = NULL;
 
 	if (!transport) {
@@ -160,7 +162,7 @@ groupwise_send_to (CamelTransport *transport,
 
 	service = CAMEL_SERVICE(transport);
 	url = camel_url_to_string (service->url,
-			           (CAMEL_URL_HIDE_PASSWORD |
+				   (CAMEL_URL_HIDE_PASSWORD |
 				    CAMEL_URL_HIDE_PARAMS   |
 				    CAMEL_URL_HIDE_AUTH) );
 
@@ -184,18 +186,18 @@ groupwise_send_to (CamelTransport *transport,
 		camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_CANT_AUTHENTICATE, _("Authentication failed"));
 		return FALSE;
 	}
-	
-	item = camel_groupwise_util_item_from_message (cnc, message, from);
-	
-	reply_request = (char *)camel_medium_get_header (CAMEL_MEDIUM (message), "In-Reply-To");
-	if (reply_request) {
-		char *id;
-		int len = strlen (reply_request);
 
-		id = (char *)g_malloc0 (len-1);
+	item = camel_groupwise_util_item_from_message (cnc, message, from);
+
+	reply_request = (gchar *)camel_medium_get_header (CAMEL_MEDIUM (message), "X-GW-ORIG-ITEM-ID");
+	if (reply_request) {
+		gchar *id;
+		gint len = strlen (reply_request);
+
+		id = (gchar *)g_malloc0 (len-1);
 		id = memcpy(id, reply_request+2, len-3);
-		status = e_gw_connection_reply_item (cnc, id, NULL, &temp_item);
-		if (status != E_GW_CONNECTION_STATUS_OK) 
+		status = e_gw_connection_reply_item (cnc, id, REPLY_VIEW, &temp_item);
+		if (status != E_GW_CONNECTION_STATUS_OK)
 			g_warning ("Could not send a replyRequest...continuing without!!\n");
 		else {
 			info = e_gw_item_get_link_info (temp_item);
@@ -204,8 +206,8 @@ groupwise_send_to (CamelTransport *transport,
 
 		g_free (id);
 	}
-	
-	
+
+
 	/*Send item*/
 	status = e_gw_connection_send_item (cnc, item, &sent_item_list);
 	if (status != E_GW_CONNECTION_STATUS_OK) {
