@@ -34,9 +34,9 @@
 #include "camel-session.h"
 #include "camel-url.h"
 
-static void add_hash (guint *hash, char *s);
+static void add_hash (guint *hash, gchar *s);
 static guint imap_url_hash (gconstpointer key);
-static gint check_equal (char *s1, char *s2);
+static gint check_equal (gchar *s1, gchar *s2);
 static gint imap_url_equal (gconstpointer a, gconstpointer b);
 
 CamelProviderConfEntry imap_conf_entries[] = {
@@ -44,6 +44,8 @@ CamelProviderConfEntry imap_conf_entries[] = {
 	  N_("Checking for New Mail") },
 	{ CAMEL_PROVIDER_CONF_CHECKBOX, "check_all", NULL,
 	  N_("C_heck for new messages in all folders"), "1" },
+	{ CAMEL_PROVIDER_CONF_CHECKBOX, "check_lsub", NULL,
+	  N_("Ch_eck for new messages in subscribed folders"), "0" },
 	{ CAMEL_PROVIDER_CONF_SECTION_END },
 #ifndef G_OS_WIN32
 	{ CAMEL_PROVIDER_CONF_SECTION_START, "cmdsection", NULL,
@@ -96,10 +98,10 @@ static CamelProvider imap_provider = {
 
 CamelServiceAuthType camel_imap_password_authtype = {
 	N_("Password"),
-	
+
 	N_("This option will connect to the IMAP server using a "
 	   "plaintext password."),
-	
+
 	"",
 	TRUE
 };
@@ -118,7 +120,7 @@ camel_provider_module_init(void)
 }
 
 static void
-add_hash (guint *hash, char *s)
+add_hash (guint *hash, gchar *s)
 {
 	if (s)
 		*hash ^= g_str_hash(s);
@@ -131,15 +133,14 @@ imap_url_hash (gconstpointer key)
 	guint hash = 0;
 
 	add_hash (&hash, u->user);
-	add_hash (&hash, u->authmech);
 	add_hash (&hash, u->host);
 	hash ^= u->port;
-	
+
 	return hash;
 }
 
-static int
-check_equal (char *s1, char *s2)
+static gint
+check_equal (gchar *s1, gchar *s2)
 {
 	if (s1 == NULL) {
 		if (s2 == NULL)
@@ -147,21 +148,20 @@ check_equal (char *s1, char *s2)
 		else
 			return FALSE;
 	}
-	
+
 	if (s2 == NULL)
 		return FALSE;
-	
+
 	return strcmp (s1, s2) == 0;
 }
 
-static int
+static gint
 imap_url_equal (gconstpointer a, gconstpointer b)
 {
 	const CamelURL *u1 = a, *u2 = b;
-	
+
 	return check_equal (u1->protocol, u2->protocol)
 		&& check_equal (u1->user, u2->user)
-		&& check_equal (u1->authmech, u2->authmech)
 		&& check_equal (u1->host, u2->host)
 		&& u1->port == u2->port;
 }
