@@ -50,20 +50,20 @@
 #define SUBFOLDER_DIR_NAME     "subfolders"
 #define SUBFOLDER_DIR_NAME_LEN 10
 
-const char *
-imap_next_word (const char *buf)
+const gchar *
+imap_next_word (const gchar *buf)
 {
-	const char *word;
-	
+	const gchar *word;
+
 	/* skip over current word */
 	word = buf;
 	while (*word && *word != ' ')
 		word++;
-	
+
 	/* skip over white space */
 	while (*word && *word == ' ')
 		word++;
-	
+
 	return word;
 }
 
@@ -72,7 +72,7 @@ static void
 imap_namespace_destroy (struct _namespace *namespace)
 {
 	struct _namespace *node, *next;
-	
+
 	node = namespace;
 	while (node) {
 		next = node->next;
@@ -94,71 +94,71 @@ imap_namespaces_destroy (struct _namespaces *namespaces)
 }
 
 static gboolean
-imap_namespace_decode (const char **in, struct _namespace **namespace)
+imap_namespace_decode (const gchar **in, struct _namespace **namespace)
 {
 	struct _namespace *list, *tail, *node;
-	const char *inptr;
-	char *astring;
-	size_t len;
-	
+	const gchar *inptr;
+	gchar *astring;
+	gsize len;
+
 	inptr = *in;
-	
+
 	list = NULL;
 	tail = (struct _namespace *) &list;
-	
+
 	if (g_ascii_strncasecmp (inptr, "NIL", 3) != 0) {
 		if (*inptr++ != '(')
 			goto exception;
-		
+
 		while (*inptr && *inptr != ')') {
 			if (*inptr++ != '(')
 				goto exception;
-			
+
 			node = g_new (struct _namespace, 1);
 			node->next = NULL;
-			
+
 			/* get the namespace prefix */
 			astring = imap_parse_astring (&inptr, &len);
 			if (!astring) {
 				g_free (node);
 				goto exception;
 			}
-			
+
 			/* decode IMAP's modified UTF-7 into UTF-8 */
-			node->prefix = imap_mailbox_decode ((const unsigned char *) astring, len);
+			node->prefix = imap_mailbox_decode ((const guchar *) astring, len);
 			g_free (astring);
 			if (!node->prefix) {
 				g_free (node);
 				goto exception;
 			}
-			
+
 			tail->next = node;
 			tail = node;
-			
+
 			/* get the namespace directory delimiter */
 			inptr = imap_next_word (inptr);
-			
+
 			if (!g_ascii_strncasecmp (inptr, "NIL", 3)) {
 				inptr = imap_next_word (inptr);
 				node->delim = '\0';
 			} else if (*inptr++ == '"') {
 				if (*inptr == '\\')
 					inptr++;
-				
+
 				node->delim = *inptr++;
-				
+
 				if (*inptr++ != '"')
 					goto exception;
 			} else
 				goto exception;
-			
+
 			if (*inptr == ' ') {
 				/* parse extra flags... for now we
                                    don't save them, but in the future
                                    we may want to? */
 				while (*inptr == ' ')
 					inptr++;
-				
+
 				while (*inptr && *inptr != ')') {
 					/* this should be a QSTRING or ATOM */
 					inptr = imap_next_word (inptr);
@@ -166,38 +166,38 @@ imap_namespace_decode (const char **in, struct _namespace **namespace)
 						/* skip over the param list */
 						imap_skip_list (&inptr);
 					}
-					
+
 					while (*inptr == ' ')
 						inptr++;
 				}
 			}
-			
+
 			if (*inptr++ != ')')
 				goto exception;
-			
+
 			/* there shouldn't be spaces according to the
                            ABNF grammar, but we all know how closely
                            people follow specs */
 			while (*inptr == ' ')
 				inptr++;
 		}
-		
+
 		if (*inptr == ')')
 			inptr++;
 	} else {
 		inptr += 3;
 	}
-	
+
 	*in = inptr;
 	*namespace = list;
-	
+
 	return TRUE;
-	
+
  exception:
-	
+
 	/* clean up any namespaces we may have allocated */
 	imap_namespace_destroy (list);
-	
+
 	return FALSE;
 }
 
@@ -206,7 +206,7 @@ static void
 namespace_dump (struct _namespace *namespace)
 {
 	struct _namespace *node;
-	
+
 	if (namespace) {
 		printf ("(");
 		node = namespace;
@@ -216,12 +216,12 @@ namespace_dump (struct _namespace *namespace)
 				printf ("\"%c\")", node->delim);
 			else
 				printf ("NUL)");
-			
+
 			node = node->next;
 			if (node)
 				printf (" ");
 		}
-		
+
 		printf (")");
 	} else {
 		printf ("NIL");
@@ -242,56 +242,56 @@ namespaces_dump (struct _namespaces *namespaces)
 #endif
 
 struct _namespaces *
-imap_parse_namespace_response (const char *response)
+imap_parse_namespace_response (const gchar *response)
 {
 	struct _namespaces *namespaces;
-	const char *inptr;
-	
+	const gchar *inptr;
+
 	d(printf ("parsing: %s\n", response));
-	
+
 	if (*response != '*')
 		return NULL;
-	
+
 	inptr = imap_next_word (response);
 	if (g_ascii_strncasecmp (inptr, "NAMESPACE", 9) != 0)
 		return NULL;
-	
+
 	inptr = imap_next_word (inptr);
-	
+
 	namespaces = g_new (struct _namespaces, 1);
 	namespaces->personal = NULL;
 	namespaces->other = NULL;
 	namespaces->shared = NULL;
-	
+
 	if (!imap_namespace_decode (&inptr, &namespaces->personal))
 		goto exception;
-	
+
 	if (*inptr != ' ')
 		goto exception;
-	
+
 	while (*inptr == ' ')
 		inptr++;
-	
+
 	if (!imap_namespace_decode (&inptr, &namespaces->other))
 		goto exception;
-	
+
 	if (*inptr != ' ')
 		goto exception;
-	
+
 	while (*inptr == ' ')
 		inptr++;
-	
+
 	if (!imap_namespace_decode (&inptr, &namespaces->shared))
 		goto exception;
-	
+
 	d(namespaces_dump (namespaces));
-	
+
 	return namespaces;
-	
+
  exception:
-	
+
 	imap_namespaces_destroy (namespaces);
-	
+
 	return NULL;
 }
 
@@ -309,31 +309,31 @@ imap_parse_namespace_response (const char *response)
  * Return value: whether or not the response was successfully parsed.
  **/
 gboolean
-imap_parse_list_response (CamelImapStore *store, const char *buf, int *flags, char *sep, char **folder)
+imap_parse_list_response (CamelImapStore *store, const gchar *buf, gint *flags, gchar *sep, gchar **folder)
 {
 	gboolean is_lsub = FALSE;
-	const char *word;
-	size_t len;
-	
+	const gchar *word;
+	gsize len;
+
 	if (*buf != '*')
 		return FALSE;
-	
+
 	word = imap_next_word (buf);
 	if (g_ascii_strncasecmp (word, "LIST", 4) && g_ascii_strncasecmp (word, "LSUB", 4))
 		return FALSE;
-	
+
 	/* check if we are looking at an LSUB response */
 	if (word[1] == 'S' || word[1] == 's')
 		is_lsub = TRUE;
-	
+
 	/* get the flags */
 	word = imap_next_word (word);
 	if (*word != '(')
 		return FALSE;
-	
+
 	if (flags)
 		*flags = 0;
-	
+
 	word++;
 	while (*word != ')') {
 		len = strcspn (word, " )");
@@ -351,12 +351,12 @@ imap_parse_list_response (CamelImapStore *store, const char *buf, int *flags, ch
 			else if (!g_ascii_strncasecmp (word, "\\HasNoChildren", len))
 				*flags |= CAMEL_FOLDER_NOCHILDREN;
 		}
-		
+
 		word += len;
 		while (*word == ' ')
 			word++;
 	}
-	
+
 	/* get the directory separator */
 	word = imap_next_word (word);
 	if (!strncmp (word, "NIL", 3)) {
@@ -372,11 +372,11 @@ imap_parse_list_response (CamelImapStore *store, const char *buf, int *flags, ch
 			return FALSE;
 	} else
 		return FALSE;
-	
+
 	if (folder) {
-		char *astring;
-		char *mailbox;
-		
+		gchar *astring;
+		gchar *mailbox;
+
 		/* get the folder name */
 		word = imap_next_word (word);
 		astring = imap_parse_astring (&word, &len);
@@ -385,11 +385,11 @@ imap_parse_list_response (CamelImapStore *store, const char *buf, int *flags, ch
 
 		*folder = astring;
 
-		mailbox = imap_mailbox_decode ((const unsigned char *) astring, strlen (astring));
+		mailbox = imap_mailbox_decode ((const guchar *) astring, strlen (astring));
 		g_free (astring);
 		if (!mailbox)
 			return FALSE;
-		
+
 		/* Kludge around Courier imap's LSUB response for INBOX when it
 		 * isn't subscribed to.
 		 *
@@ -404,11 +404,11 @@ imap_parse_list_response (CamelImapStore *store, const char *buf, int *flags, ch
 		 */
 		if (is_lsub && flags && !g_ascii_strcasecmp (mailbox, "INBOX"))
 			*flags &= ~CAMEL_FOLDER_NOSELECT;
-		
+
 		*folder = mailbox;
 
 	}
-	
+
 	return TRUE;
 }
 
@@ -424,19 +424,19 @@ imap_parse_list_response (CamelImapStore *store, const char *buf, int *flags, ch
  * Results in:
  *   Full, Full/Path, Full/Path/"to / from", Full/Path/"to / from"/Folder
  **/
-char **
-imap_parse_folder_name (CamelImapStore *store, const char *folder_name)
+gchar **
+imap_parse_folder_name (CamelImapStore *store, const gchar *folder_name)
 {
 	GPtrArray *heirarchy;
-	char **paths;
-	const char *p;
-	
+	gchar **paths;
+	const gchar *p;
+
 	p = folder_name;
 	if (*p == store->dir_sep)
 		p++;
-	
+
 	heirarchy = g_ptr_array_new ();
-	
+
 	while (*p) {
 		if (*p == '"') {
 			p++;
@@ -446,19 +446,19 @@ imap_parse_folder_name (CamelImapStore *store, const char *folder_name)
 				p++;
 			continue;
 		}
-		
+
 		if (*p == store->dir_sep)
 			g_ptr_array_add (heirarchy, g_strndup (folder_name, p - folder_name));
-		
+
 		p++;
 	}
-	
+
 	g_ptr_array_add (heirarchy, g_strdup (folder_name));
 	g_ptr_array_add (heirarchy, NULL);
-	
-	paths = (char **) heirarchy->pdata;
+
+	paths = (gchar **) heirarchy->pdata;
 	g_ptr_array_free (heirarchy, FALSE);
-	
+
 	return paths;
 }
 
@@ -471,11 +471,11 @@ imap_parse_folder_name (CamelImapStore *store, const char *folder_name)
  * @param len Length of the flag name.
  * @param server_to_evo if TRUE, then converting server names to evo's names, if FALSE then opposite.
  */
-static const char *
-rename_label_flag (const char *flag, int len, gboolean server_to_evo)
+static const gchar *
+rename_label_flag (const gchar *flag, gint len, gboolean server_to_evo)
 {
-	int i;
-	const char *labels[] = {
+	gint i;
+	const gchar *labels[] = {
 		"$Label1", "$Labelimportant",
 		"$Label2", "$Labelwork",
 		"$Label3", "$Labelpersonal",
@@ -496,7 +496,7 @@ rename_label_flag (const char *flag, int len, gboolean server_to_evo)
 	return "";
 }
 
-char *
+gchar *
 imap_create_flag_list (guint32 flags, CamelMessageInfo *info, guint32 permanent_flags)
 {
 	GString *gstr = g_string_new ("(");
@@ -519,7 +519,7 @@ imap_create_flag_list (guint32 flags, CamelMessageInfo *info, guint32 permanent_
 	/* send user flags to the server only when it supports it, otherwise store it locally only */
 	if (info && (permanent_flags & CAMEL_MESSAGE_USER) != 0) {
 		const CamelFlag *flag;
-		const char *name;
+		const gchar *name;
 
 		/* FIXME: All the custom flags are sent to the server. Not just the changed ones */
 		flag = camel_message_info_user_flags(info);
@@ -548,13 +548,13 @@ imap_create_flag_list (guint32 flags, CamelMessageInfo *info, guint32 permanent_
 }
 
 gboolean
-imap_parse_flag_list (char **flag_list_p, guint32 *flags_out, char **custom_flags_out)
+imap_parse_flag_list (gchar **flag_list_p, guint32 *flags_out, gchar **custom_flags_out)
 {
-	char *flag_list = *flag_list_p;
+	gchar *flag_list = *flag_list_p;
 	guint32 flags = 0;
-	int len;
+	gint len;
 	GString *custom_flags = NULL;
-	char *iter;
+	gchar *iter;
 
 	*flags_out = 0;
 
@@ -655,7 +655,7 @@ quoted_specials ::= <"> / "\"
 resp_specials   ::= "]"
 */
 
-static unsigned char imap_atom_specials[256] = {
+static guchar imap_atom_specials[256] = {
 /*	0  1  2  3  4  5  6  7  8  9  A  B  C  D  E  F */
 /* 00 */0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
 /* 10 */0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
@@ -665,25 +665,25 @@ static unsigned char imap_atom_specials[256] = {
 /* 50 */1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 1,
 /* 60 */1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
 /* 70 */1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 0, 1, 0,
-	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
 };
 
 #define imap_is_atom_char(c) ((imap_atom_specials[(c)&0xff] & 0x01) != 0)
 
 gboolean
-imap_is_atom(const char *in)
+imap_is_atom(const gchar *in)
 {
-	register unsigned char c;
-	register const char *p = in;
+	register guchar c;
+	register const gchar *p = in;
 
-	while ((c = (unsigned char)*p)) {
+	while ((c = (guchar)*p)) {
 		if (!imap_is_atom_char(c))
 			return FALSE;
 		p++;
@@ -696,7 +696,7 @@ imap_is_atom(const char *in)
 /**
  * imap_parse_string_generic:
  * @str_p: a pointer to a string
- * @len: a pointer to a size_t to return the length in
+ * @len: a pointer to a gsize to return the length in
  * @type: type of string (#IMAP_STRING, #IMAP_ASTRING, or #IMAP_NSTRING)
  * to parse.
  *
@@ -714,22 +714,22 @@ imap_is_atom(const char *in)
  * was parsed. (In the former case, *@str_p will be %NULL; in the
  * latter, it will point to the character after the NIL.)
  **/
-char *
-imap_parse_string_generic (const char **str_p, size_t *len, int type)
+gchar *
+imap_parse_string_generic (const gchar **str_p, gsize *len, gint type)
 {
-	const char *str = *str_p;
-	char *out;
-	
+	const gchar *str = *str_p;
+	gchar *out;
+
 	if (!str)
 		return NULL;
 	else if (*str == '"') {
-		char *p;
-		size_t size;
-		
+		gchar *p;
+		gsize size;
+
 		str++;
 		size = strcspn (str, "\"") + 1;
 		p = out = g_malloc (size);
-		
+
 		/* a quoted string cannot be broken into multiple lines */
 		while (*str && *str != '"' && *str != '\n') {
 			if (*str == '\\')
@@ -751,12 +751,12 @@ imap_parse_string_generic (const char **str_p, size_t *len, int type)
 		*len = strlen (out);
 		return out;
 	} else if (*str == '{') {
-		*len = strtoul (str + 1, (char **)&str, 10);
+		*len = strtoul (str + 1, (gchar **)&str, 10);
 		if (*str++ != '}' || *str++ != '\n' || strlen (str) < *len) {
 			*str_p = NULL;
 			return NULL;
 		}
-		
+
 		out = g_strndup (str, *len);
 		*str_p = str + *len;
 		return out;
@@ -764,10 +764,10 @@ imap_parse_string_generic (const char **str_p, size_t *len, int type)
 		*str_p += 3;
 		*len = 0;
 		return NULL;
-	} else if (type == IMAP_ASTRING && imap_is_atom_char ((unsigned char)*str)) {
-		while (imap_is_atom_char ((unsigned char) *str))
+	} else if (type == IMAP_ASTRING && imap_is_atom_char ((guchar)*str)) {
+		while (imap_is_atom_char ((guchar) *str))
 			str++;
-		
+
 		*len = str - *str_p;
 		out = g_strndup (*str_p, *len);
 		*str_p += *len;
@@ -779,7 +779,7 @@ imap_parse_string_generic (const char **str_p, size_t *len, int type)
 }
 
 static inline void
-skip_char (const char **in, char ch)
+skip_char (const gchar **in, gchar ch)
 {
 	if (*in && **in == ch)
 		*in = *in + 1;
@@ -789,10 +789,10 @@ skip_char (const char **in, char ch)
 
 /* Skip atom, string, or number */
 static void
-skip_asn (const char **str_p)
+skip_asn (const gchar **str_p)
 {
-	const char *str = *str_p;
-	
+	const gchar *str = *str_p;
+
 	if (!str)
 		return;
 	else if (*str == '"') {
@@ -808,9 +808,9 @@ skip_asn (const char **str_p)
 		else
 			*str_p = NULL;
 	} else if (*str == '{') {
-		unsigned long len;
-		
-		len = strtoul (str + 1, (char **) &str, 10);
+		gulong len;
+
+		len = strtoul (str + 1, (gchar **) &str, 10);
 		if (*str != '}' || *(str + 1) != '\n' ||
 		    strlen (str + 2) < len) {
 			*str_p = NULL;
@@ -828,7 +828,7 @@ skip_asn (const char **str_p)
 }
 
 void
-imap_skip_list (const char **str_p)
+imap_skip_list (const gchar **str_p)
 {
 	skip_char (str_p, '(');
 	while (*str_p && **str_p != ')') {
@@ -842,98 +842,98 @@ imap_skip_list (const char **str_p)
 	skip_char (str_p, ')');
 }
 
-static int
-parse_params (const char **parms_p, CamelContentType *type)
+static gint
+parse_params (const gchar **parms_p, CamelContentType *type)
 {
-	const char *parms = *parms_p;
-	char *name, *value;
-	size_t len;
-	
+	const gchar *parms = *parms_p;
+	gchar *name, *value;
+	gsize len;
+
 	if (!g_ascii_strncasecmp (parms, "nil", 3)) {
 		*parms_p += 3;
 		return 0;
 	}
-	
+
 	if (*parms++ != '(')
 		return -1;
-	
+
 	while (parms && *parms != ')') {
 		name = imap_parse_nstring (&parms, &len);
 		skip_char (&parms, ' ');
 		value = imap_parse_nstring (&parms, &len);
-		
+
 		if (name && value)
 			camel_content_type_set_param (type, name, value);
 		g_free (name);
 		g_free (value);
-		
+
 		if (parms && *parms == ' ')
 			parms++;
 	}
-	
+
 	if (!parms || *parms++ != ')')
 		return -1;
-	
+
 	*parms_p = parms;
-	
+
 	return 0;
 }
 
 
 static CamelMessageContentInfo *
-imap_body_decode (const char **in, CamelMessageContentInfo *ci, CamelFolder *folder, GPtrArray *cis)
+imap_body_decode (const gchar **in, CamelMessageContentInfo *ci, CamelFolder *folder, GPtrArray *cis)
 {
-	const char *inptr = *in;
+	const gchar *inptr = *in;
 	CamelMessageContentInfo *child = NULL;
-	char *type, *subtype, *id = NULL;
+	gchar *type, *subtype, *id = NULL;
 	CamelContentType *ctype = NULL;
-	char *description = NULL;
-	char *encoding = NULL;
-	size_t len;
-	size_t size;
-	char *p;
-	
+	gchar *description = NULL;
+	gchar *encoding = NULL;
+	gsize len;
+	gsize size;
+	gchar *p;
+
 	if (*inptr++ != '(')
 		return NULL;
-	
+
 	if (ci == NULL) {
 		ci = camel_folder_summary_content_info_new (folder->summary);
 		g_ptr_array_add (cis, ci);
 	}
-	
+
 	if (*inptr == '(') {
 		/* body_type_mpart */
 		CamelMessageContentInfo *tail, *children = NULL;
-		
+
 		tail = (CamelMessageContentInfo *) &children;
-		
+
 		do {
 			if (!(child = imap_body_decode (&inptr, NULL, folder, cis)))
 				return NULL;
-			
+
 			child->parent = ci;
 			tail->next = child;
 			tail = child;
 		} while (*inptr == '(');
-		
+
 		if (*inptr++ != ' ')
 			return NULL;
-		
+
 		if (g_ascii_strncasecmp (inptr, "nil", 3) != 0) {
 			subtype = imap_parse_string (&inptr, &len);
 		} else {
 			subtype = NULL;
 			inptr += 3;
 		}
-		
+
 		ctype = camel_content_type_new ("multipart", subtype ? subtype : "mixed");
 		g_free (subtype);
-		
+
 		if (*inptr++ != ')') {
 			camel_content_type_unref (ctype);
 			return NULL;
 		}
-		
+
 		ci->type = ctype;
 		ci->childs = children;
 	} else {
@@ -945,12 +945,12 @@ imap_body_decode (const char **in, CamelMessageContentInfo *ci, CamelFolder *fol
 		} else {
 			return NULL;
 		}
-		
+
 		if (*inptr++ != ' ') {
 			g_free (type);
 			return NULL;
 		}
-		
+
 		if (g_ascii_strncasecmp (inptr, "nil", 3) != 0) {
 			subtype = imap_parse_string (&inptr, &len);
 			if (inptr == NULL) {
@@ -964,23 +964,23 @@ imap_body_decode (const char **in, CamelMessageContentInfo *ci, CamelFolder *fol
 				subtype = NULL;
 			inptr += 3;
 		}
-		
+
 		camel_strdown (type);
 		camel_strdown (subtype);
 		ctype = camel_content_type_new (type, subtype);
 		g_free (subtype);
 		g_free (type);
-		
+
 		if (*inptr++ != ' ')
 			goto exception;
-		
+
 		/* content-type params */
 		if (parse_params (&inptr, ctype) == -1)
 			goto exception;
-		
+
 		if (*inptr++ != ' ')
 			goto exception;
-		
+
 		/* content-id */
 		if (g_ascii_strncasecmp (inptr, "nil", 3) != 0) {
 			id = imap_parse_string (&inptr, &len);
@@ -988,10 +988,10 @@ imap_body_decode (const char **in, CamelMessageContentInfo *ci, CamelFolder *fol
 				goto exception;
 		} else
 			inptr += 3;
-		
+
 		if (*inptr++ != ' ')
 			goto exception;
-		
+
 		/* description */
 		if (g_ascii_strncasecmp (inptr, "nil", 3) != 0) {
 			description = imap_parse_string (&inptr, &len);
@@ -999,10 +999,10 @@ imap_body_decode (const char **in, CamelMessageContentInfo *ci, CamelFolder *fol
 				goto exception;
 		} else
 			inptr += 3;
-		
+
 		if (*inptr++ != ' ')
 			goto exception;
-		
+
 		/* encoding */
 		if (g_ascii_strncasecmp (inptr, "nil", 3) != 0) {
 			encoding = imap_parse_string (&inptr, &len);
@@ -1010,12 +1010,12 @@ imap_body_decode (const char **in, CamelMessageContentInfo *ci, CamelFolder *fol
 				goto exception;
 		} else
 			inptr += 3;
-		
+
 		if (*inptr++ != ' ')
 			goto exception;
-		
+
 		/* size */
-		size = strtoul ((const char *) inptr, &p, 10);
+		size = strtoul ((const gchar *) inptr, &p, 10);
 
 		/* check if the size wasn't negative */
 		if (p) {
@@ -1029,44 +1029,44 @@ imap_body_decode (const char **in, CamelMessageContentInfo *ci, CamelFolder *fol
 		if (size == 0)
 			goto exception;
 
-		inptr = (const unsigned char *) p;
-		
+		inptr = (const gchar *) p;
+
 		if (camel_content_type_is (ctype, "message", "rfc822")) {
 			/* body_type_msg */
 			if (*inptr++ != ' ')
 				goto exception;
-			
+
 			/* envelope */
 			imap_skip_list (&inptr);
-			
+
 			if (!inptr || *inptr++ != ' ')
 				goto exception;
-			
+
 			/* body */
 			if (!(child = imap_body_decode (&inptr, NULL, folder, cis)))
 				goto exception;
 			child->parent = ci;
-			
+
 			if (!inptr || *inptr++ != ' ')
 				goto exception;
-			
+
 			/* lines */
-			strtoul ((const char *) inptr, &p, 10);
-			inptr = (const unsigned char *) p;
+			strtoul ((const gchar *) inptr, &p, 10);
+			inptr = (const gchar *) p;
 		} else if (camel_content_type_is (ctype, "text", "*")) {
 			if (!inptr || *inptr++ != ' ')
 				goto exception;
-			
+
 			/* lines */
-			strtoul ((const char *) inptr, &p, 10);
-			inptr = (const unsigned char *) p;
+			strtoul ((const gchar *) inptr, &p, 10);
+			inptr = (const gchar *) p;
 		} else {
 			/* body_type_basic */
 		}
-		
+
 		if (!inptr || *inptr++ != ')')
 			goto exception;
-		
+
 		ci->type = ctype;
 		ci->id = id;
 		ci->description = description;
@@ -1074,18 +1074,18 @@ imap_body_decode (const char **in, CamelMessageContentInfo *ci, CamelFolder *fol
 		ci->size = size;
 		ci->childs = child;
 	}
-	
+
 	*in = inptr;
-	
+
 	return ci;
-	
+
  exception:
-	
+
 	camel_content_type_unref (ctype);
 	g_free (id);
 	g_free (description);
 	g_free (encoding);
-	
+
 	return NULL;
 }
 
@@ -1101,38 +1101,38 @@ imap_body_decode (const char **in, CamelMessageContentInfo *ci, CamelFolder *fol
  * set to %NULL and @ci will be unchanged.
  **/
 void
-imap_parse_body (const char **body_p, CamelFolder *folder,
+imap_parse_body (const gchar **body_p, CamelFolder *folder,
 		 CamelMessageContentInfo *ci)
 {
-	const char *inptr = *body_p;
+	const gchar *inptr = *body_p;
 	CamelMessageContentInfo *child;
 	GPtrArray *children;
-	int i;
-	
+	gint i;
+
 	if (!inptr || *inptr != '(') {
 		*body_p = NULL;
 		return;
 	}
-	
+
 	children = g_ptr_array_new ();
-	
+
 	if (!(imap_body_decode (&inptr, ci, folder, children))) {
 		for (i = 0; i < children->len; i++) {
 			child = children->pdata[i];
-			
+
 			/* content_info_free will free all the child
 			 * nodes, but we don't want that. */
 			child->next = NULL;
 			child->parent = NULL;
 			child->childs = NULL;
-			
+
 			camel_folder_summary_content_info_free (folder->summary, child);
 		}
 		*body_p = NULL;
 	} else {
 		*body_p = inptr;
 	}
-	
+
 	g_ptr_array_free (children, TRUE);
 }
 
@@ -1144,22 +1144,22 @@ imap_parse_body (const char **body_p, CamelFolder *folder,
  * Return value: an IMAP "quoted" corresponding to the string, which
  * the caller must free.
  **/
-char *
-imap_quote_string (const char *str)
+gchar *
+imap_quote_string (const gchar *str)
 {
-	const char *p;
-	char *quoted, *q;
-	int len;
-	
+	const gchar *p;
+	gchar *quoted, *q;
+	gint len;
+
 	g_assert (strchr (str, '\r') == NULL);
-	
+
 	len = strlen (str);
 	p = str;
 	while ((p = strpbrk (p, "\"\\"))) {
 		len++;
 		p++;
 	}
-	
+
 	quoted = q = g_malloc (len + 3);
 	*q++ = '"';
 	for (p = str; *p; ) {
@@ -1169,17 +1169,16 @@ imap_quote_string (const char *str)
 	}
 	*q++ = '"';
 	*q = '\0';
-	
+
 	return quoted;
 }
 
 
-static inline unsigned long
-get_summary_uid_numeric (CamelFolderSummary *summary, int index)
+static inline gulong
+get_summary_uid_numeric (CamelFolderSummary *summary, gint index)
 {
-	CamelMessageInfo *info;
-	unsigned long uid;
-	char *suid;
+	gulong uid;
+	gchar *suid;
 
 	suid = camel_folder_summary_uid_from_index (summary, index);
 	uid = strtoul (suid, NULL, 10);
@@ -1188,7 +1187,7 @@ get_summary_uid_numeric (CamelFolderSummary *summary, int index)
 	return uid;
 }
 
-/* the max number of chars that an unsigned 32-bit int can be is 10 chars plus 1 for a possible : */
+/* the max number of chars that an unsigned 32-bit gint can be is 10 chars plus 1 for a possible : */
 #define UID_SET_FULL(setlen, maxlen) (maxlen > 0 ? setlen + 11 >= maxlen : FALSE)
 
 /**
@@ -1208,34 +1207,34 @@ get_summary_uid_numeric (CamelFolderSummary *summary, int index)
  * *not* included in the returned set string.
  *
  * Note: @uids MUST be in sorted order for this code to work properly.
- * 
+ *
  * Return value: the set, which the caller must free with g_free()
  **/
-char *
-imap_uid_array_to_set (CamelFolderSummary *summary, GPtrArray *uids, int uid, ssize_t maxlen, int *lastuid)
+gchar *
+imap_uid_array_to_set (CamelFolderSummary *summary, GPtrArray *uids, gint uid, gssize maxlen, gint *lastuid)
 {
-	unsigned long last_uid, next_summary_uid, this_uid;
+	gulong last_uid, next_summary_uid, this_uid;
 	gboolean range = FALSE;
-	int si, scount;
+	gint si, scount;
 	GString *gset;
-	char *set;
-	
+	gchar *set;
+
 	g_return_val_if_fail (uids->len > uid, NULL);
-	
+
 	gset = g_string_new (uids->pdata[uid]);
 	last_uid = strtoul (uids->pdata[uid], NULL, 10);
 	next_summary_uid = 0;
 	scount = camel_folder_summary_count (summary);
-	
+
 	for (uid++, si = 0; uid < uids->len && !UID_SET_FULL (gset->len, maxlen); uid++) {
 		/* Find the next UID in the summary after the one we
 		 * just wrote out.
 		 */
-		for ( ; last_uid >= next_summary_uid && si < scount; si++)
+		for (; last_uid >= next_summary_uid && si < scount; si++)
 			next_summary_uid = get_summary_uid_numeric (summary, si);
 		if (last_uid >= next_summary_uid)
-			next_summary_uid = (unsigned long) -1;
-		
+			next_summary_uid = (gulong) -1;
+
 		/* Now get the next UID from @uids */
 		this_uid = strtoul (uids->pdata[uid], NULL, 10);
 		if (this_uid == next_summary_uid || this_uid == last_uid + 1)
@@ -1247,18 +1246,18 @@ imap_uid_array_to_set (CamelFolderSummary *summary, GPtrArray *uids, int uid, ss
 			}
 			g_string_append_printf (gset, ",%lu", this_uid);
 		}
-		
+
 		last_uid = this_uid;
 	}
-	
+
 	if (range)
 		g_string_append_printf (gset, ":%lu", last_uid);
-	
+
 	*lastuid = uid;
-	
+
 	set = gset->str;
 	g_string_free (gset, FALSE);
-	
+
 	return set;
 }
 
@@ -1279,24 +1278,24 @@ imap_uid_array_to_set (CamelFolderSummary *summary, GPtrArray *uids, int uid, ss
  * imap_uid_array_free(). (Or %NULL if the uid set can't be parsed.)
  **/
 GPtrArray *
-imap_uid_set_to_array (CamelFolderSummary *summary, const char *uids)
+imap_uid_set_to_array (CamelFolderSummary *summary, const gchar *uids)
 {
 	GPtrArray *arr;
-	char *p, *q;
-	unsigned long uid, suid;
-	int si, scount;
-	
+	gchar *p, *q;
+	gulong uid, suid;
+	gint si, scount;
+
 	arr = g_ptr_array_new ();
 	scount = camel_folder_summary_count (summary);
-	
-	p = (char *)uids;
+
+	p = (gchar *)uids;
 	si = 0;
 	do {
 		uid = strtoul (p, &q, 10);
 		if (p == q)
 			goto lose;
 		g_ptr_array_add (arr, g_strndup (p, q - p));
-		
+
 		if (*q == ':') {
 			/* Find the summary entry for the UID after the one
 			 * we just saw.
@@ -1308,11 +1307,11 @@ imap_uid_set_to_array (CamelFolderSummary *summary, const char *uids)
 			}
 			if (si >= scount)
 				suid = uid + 1;
-			
+
 			uid = strtoul (q + 1, &p, 10);
 			if (p == q + 1)
 				goto lose;
-			
+
 			/* Add each summary UID until we find one
 			 * larger than the end of the range
 			 */
@@ -1326,9 +1325,9 @@ imap_uid_set_to_array (CamelFolderSummary *summary, const char *uids)
 		} else
 			p = q;
 	} while (*p++ == ',');
-	
+
 	return arr;
-	
+
  lose:
 	g_warning ("Invalid uid set %s", uids);
 	imap_uid_array_free (arr);
@@ -1344,18 +1343,18 @@ imap_uid_set_to_array (CamelFolderSummary *summary, const char *uids)
 void
 imap_uid_array_free (GPtrArray *arr)
 {
-	int i;
-	
+	gint i;
+
 	for (i = 0; i < arr->len; i++)
 		g_free (arr->pdata[i]);
 	g_ptr_array_free (arr, TRUE);
 }
 
-char *
-imap_concat (CamelImapStore *imap_store, const char *prefix, const char *suffix)
+gchar *
+imap_concat (CamelImapStore *imap_store, const gchar *prefix, const gchar *suffix)
 {
-	size_t len;
-	
+	gsize len;
+
 	len = strlen (prefix);
 	if (len == 0 || prefix[len - 1] == imap_store->dir_sep)
 		return g_strdup_printf ("%s%s", prefix, suffix);
@@ -1363,36 +1362,36 @@ imap_concat (CamelImapStore *imap_store, const char *prefix, const char *suffix)
 		return g_strdup_printf ("%s%c%s", prefix, imap_store->dir_sep, suffix);
 }
 
-char *
-imap_mailbox_encode (const unsigned char *in, size_t inlen)
+gchar *
+imap_mailbox_encode (const guchar *in, gsize inlen)
 {
-	char *buf;
+	gchar *buf;
 
 	buf = g_alloca (inlen + 1);
 	memcpy (buf, in, inlen);
 	buf[inlen] = 0;
-	
+
 	return camel_utf8_utf7 (buf);
 }
 
-char *
-imap_mailbox_decode (const unsigned char *in, size_t inlen)
+gchar *
+imap_mailbox_decode (const guchar *in, gsize inlen)
 {
-	char *buf;
-	
+	gchar *buf;
+
 	buf = g_alloca (inlen + 1);
 	memcpy (buf, in, inlen);
 	buf[inlen] = 0;
-	
+
 	return camel_utf7_utf8 (buf);
 }
 
-char *
-imap_path_to_physical (const char *prefix, const char *vpath)
+gchar *
+imap_path_to_physical (const gchar *prefix, const gchar *vpath)
 {
 	GString *out = g_string_new(prefix);
-	const char *p = vpath;
-	char c, *res;
+	const gchar *p = vpath;
+	gchar c, *res;
 
 	g_string_append_c(out, '/');
 	p = vpath;
@@ -1412,11 +1411,11 @@ imap_path_to_physical (const char *prefix, const char *vpath)
 }
 
 static gboolean
-find_folders_recursive (const char *physical_path, const char *path,
+find_folders_recursive (const gchar *physical_path, const gchar *path,
 			IMAPPathFindFoldersCallback callback, gpointer data)
 {
 	GDir *dir;
-	char *subfolder_directory_path;
+	gchar *subfolder_directory_path;
 	gboolean ok;
 
 	if (*path) {
@@ -1442,9 +1441,9 @@ find_folders_recursive (const char *physical_path, const char *path,
 	ok = TRUE;
 	while (ok) {
 		struct stat file_stat;
-		const char *dirent;
-		char *file_path;
-		char *new_path;
+		const gchar *dirent;
+		gchar *file_path;
+		gchar *new_path;
 
 		dirent = g_dir_read_name (dir);
 		if (dirent == NULL)
@@ -1485,7 +1484,7 @@ find_folders_recursive (const char *physical_path, const char *path,
  * Return value: %TRUE on success, %FALSE if an error occurs at any point
  **/
 gboolean
-imap_path_find_folders (const char *prefix, IMAPPathFindFoldersCallback callback, gpointer data)
+imap_path_find_folders (const gchar *prefix, IMAPPathFindFoldersCallback callback, gpointer data)
 {
 	return find_folders_recursive (prefix, "", callback, data);
 }
