@@ -33,20 +33,22 @@
 
 G_BEGIN_DECLS
 
-typedef struct {
+typedef struct _CamelImapWrapperClass CamelImapWrapperClass;
+typedef struct _CamelImapWrapperPrivate CamelImapWrapperPrivate;
+
+struct _CamelImapWrapper {
 	CamelDataWrapper parent_object;
 
-	struct _CamelImapWrapperPrivate *priv;
+	CamelImapWrapperPrivate *priv;
 
 	CamelImapFolder *folder;
-	char *uid, *part_spec;
+	gchar *uid, *part_spec;
 	CamelMimePart *part;
-} CamelImapWrapper;
+};
 
-typedef struct {
+struct _CamelImapWrapperClass {
 	CamelDataWrapperClass parent_class;
-
-} CamelImapWrapperClass;
+};
 
 /* Standard Camel function */
 CamelType camel_imap_wrapper_get_type (void);
@@ -55,8 +57,8 @@ CamelType camel_imap_wrapper_get_type (void);
 CamelDataWrapper *camel_imap_wrapper_new (CamelImapFolder *imap_folder,
 					  CamelContentType *type,
 					  CamelTransferEncoding encoding,
-					  const char *uid,
-					  const char *part_spec,
+					  const gchar *uid,
+					  const gchar *part_spec,
 					  CamelMimePart *part);
 
 G_END_DECLS
