@@ -45,25 +45,25 @@
 
 
 CamelFolderInfo *
-camel_imap4_build_folder_info_tree (GPtrArray *array, const char *top)
+camel_imap4_build_folder_info_tree (GPtrArray *array, const gchar *top)
 {
 	CamelFolderInfo *cur, *fi, *root = NULL;
-	const char *p;
-	size_t n = 0;
-	char *pname;
-	int i;
-	
+	const gchar *p;
+	gsize n = 0;
+	gchar *pname;
+	gint i;
+
 	if (array->len == 0)
 		return NULL;
-	
+
 	if (array->len == 1)
 		return array->pdata[0];
-	
+
 	if (top)
 		n = strlen (top);
-	
+
 	cur = root = array->pdata[0];
-	
+
 	for (i = 1; i < array->len; i++) {
 		fi = (CamelFolderInfo *) array->pdata[i];
 		if (top && strncmp (fi->full_name, top, n) != 0) {
@@ -71,7 +71,7 @@ camel_imap4_build_folder_info_tree (GPtrArray *array, const char *top)
 			camel_folder_info_free (fi);
 			continue;
 		}
-		
+
 		if ((p = strrchr (fi->full_name, '/'))) {
 			pname = g_strndup (fi->full_name, p - fi->full_name);
 			if (!strcmp (cur->full_name, pname)) {
@@ -91,7 +91,7 @@ camel_imap4_build_folder_info_tree (GPtrArray *array, const char *top)
 						break;
 					cur = cur->parent;
 				}
-				
+
 				/* cur should now be our sibling */
 				fi->parent = cur->parent;
 				cur->next = fi;
@@ -102,12 +102,12 @@ camel_imap4_build_folder_info_tree (GPtrArray *array, const char *top)
 			/* traverse back to most recent top-level fi */
 			while (cur->parent)
 				cur = cur->parent;
-			
+
 			cur->next = fi;
 			cur = fi;
 		}
 	}
-	
+
 	return root;
 }
 
@@ -140,9 +140,9 @@ guint32
 camel_imap4_merge_flags (guint32 original, guint32 local, guint32 server)
 {
 	flags_diff_t diff;
-	
+
 	camel_imap4_flags_diff (&diff, original, local);
-	
+
 	return camel_imap4_flags_merge (&diff, server);
 }
 
@@ -151,7 +151,7 @@ void
 camel_imap4_namespace_clear (CamelIMAP4Namespace **ns)
 {
 	CamelIMAP4Namespace *node, *next;
-	
+
 	node = *ns;
 	while (node != NULL) {
 		next = node->next;
@@ -159,7 +159,7 @@ camel_imap4_namespace_clear (CamelIMAP4Namespace **ns)
 		g_free (node);
 		node = next;
 	}
-	
+
 	*ns = NULL;
 }
 
@@ -167,10 +167,10 @@ static CamelIMAP4Namespace *
 imap4_namespace_copy (const CamelIMAP4Namespace *ns)
 {
 	CamelIMAP4Namespace *list, *node, *tail;
-	
+
 	list = NULL;
 	tail = (CamelIMAP4Namespace *) &list;
-	
+
 	while (ns != NULL) {
 		tail->next = node = g_malloc (sizeof (CamelIMAP4Namespace));
 		node->path = g_strdup (ns->path);
@@ -178,9 +178,9 @@ imap4_namespace_copy (const CamelIMAP4Namespace *ns)
 		ns = ns->next;
 		tail = node;
 	}
-	
+
 	tail->next = NULL;
-	
+
 	return list;
 }
 
@@ -188,12 +188,12 @@ CamelIMAP4NamespaceList *
 camel_imap4_namespace_list_copy (const CamelIMAP4NamespaceList *nsl)
 {
 	CamelIMAP4NamespaceList *new;
-	
+
 	new = g_malloc (sizeof (CamelIMAP4NamespaceList));
 	new->personal = imap4_namespace_copy (nsl->personal);
 	new->other = imap4_namespace_copy (nsl->other);
 	new->shared = imap4_namespace_copy (nsl->shared);
-	
+
 	return new;
 }
 
@@ -207,28 +207,28 @@ camel_imap4_namespace_list_free (CamelIMAP4NamespaceList *nsl)
 }
 
 
-char
-camel_imap4_get_path_delim (CamelIMAP4StoreSummary *s, const char *full_name)
+gchar
+camel_imap4_get_path_delim (CamelIMAP4StoreSummary *s, const gchar *full_name)
 {
 	CamelIMAP4Namespace *namespace;
-	const char *slash;
-	size_t len;
-	char *top;
-	
+	const gchar *slash;
+	gsize len;
+	gchar *top;
+
 	g_return_val_if_fail (s->namespaces != NULL, '/');
-	
+
 	if ((slash = strchr (full_name, '/')))
 		len = (slash - full_name);
 	else
 		len = strlen (full_name);
-	
+
 	top = g_alloca (len + 1);
 	memcpy (top, full_name, len);
 	top[len] = '\0';
-	
+
 	if (!g_ascii_strcasecmp (top, "INBOX"))
 		strcpy (top, "INBOX");
-	
+
  retry:
 	namespace = s->namespaces->personal;
 	while (namespace != NULL) {
@@ -236,27 +236,27 @@ camel_imap4_get_path_delim (CamelIMAP4StoreSummary *s, const char *full_name)
 			return namespace->sep;
 		namespace = namespace->next;
 	}
-	
+
 	namespace = s->namespaces->other;
 	while (namespace != NULL) {
 		if (!strcmp (namespace->path, top))
 			return namespace->sep;
 		namespace = namespace->next;
 	}
-	
+
 	namespace = s->namespaces->shared;
 	while (namespace != NULL) {
 		if (!strcmp (namespace->path, top))
 			return namespace->sep;
 		namespace = namespace->next;
 	}
-	
+
 	if (top[0] != '\0') {
 		/* look for a default namespace? */
 		top[0] = '\0';
 		goto retry;
 	}
-	
+
 	return '/';
 }
 
@@ -265,21 +265,21 @@ struct _uidset_range {
 	struct _uidset_range *next;
 	guint32 first, last;
 	uint8_t buflen;
-	char buf[24];
+	gchar buf[24];
 };
 
 struct _uidset {
 	CamelFolderSummary *summary;
 	struct _uidset_range *ranges;
 	struct _uidset_range *tail;
-	size_t maxlen, setlen;
+	gsize maxlen, setlen;
 };
 
 static void
 uidset_range_free (struct _uidset_range *range)
 {
 	struct _uidset_range *next;
-	
+
 	while (range != NULL) {
 		next = range->next;
 		g_free (range);
@@ -288,14 +288,14 @@ uidset_range_free (struct _uidset_range *range)
 }
 
 static void
-uidset_init (struct _uidset *uidset, CamelFolderSummary *summary, size_t maxlen)
+uidset_init (struct _uidset *uidset, CamelFolderSummary *summary, gsize maxlen)
 {
 	uidset->ranges = g_new (struct _uidset_range, 1);
 	uidset->ranges->first = (guint32) -1;
 	uidset->ranges->last = (guint32) -1;
 	uidset->ranges->next = NULL;
 	uidset->ranges->buflen = 0;
-	
+
 	uidset->tail = uidset->ranges;
 	uidset->summary = summary;
 	uidset->maxlen = maxlen;
@@ -303,26 +303,26 @@ uidset_init (struct _uidset *uidset, CamelFolderSummary *summary, size_t maxlen)
 }
 
 /* returns: -1 on full-and-not-added, 0 on added-and-not-full or 1 on added-and-full */
-static int
+static gint
 uidset_add (struct _uidset *uidset, CamelMessageInfo *info)
 {
 	GPtrArray *messages = uidset->summary->messages;
 	struct _uidset_range *node, *tail = uidset->tail;
-	const char *iuid = camel_message_info_uid (info);
-	size_t uidlen, len;
-	const char *colon;
+	const gchar *iuid = camel_message_info_uid (info);
+	gsize uidlen, len;
+	const gchar *colon;
 	guint32 index;
-	
+
 	/* Note: depends on integer overflow for initial 'add' */
 	for (index = tail->last + 1; index < messages->len; index++) {
 		if (info == messages->pdata[index])
 			break;
 	}
-	
+
 	g_assert (index < messages->len);
-	
+
 	uidlen = strlen (iuid);
-	
+
 	if (tail->buflen == 0) {
 		/* first add */
 		tail->first = tail->last = index;
@@ -335,21 +335,21 @@ uidset_add (struct _uidset *uidset, CamelMessageInfo *info)
 			/* make sure we've got enough room to add this one... */
 			if ((uidset->setlen + uidlen + 1) > uidset->maxlen)
 				return -1;
-			
+
 			tail->buf[tail->buflen++] = ':';
 			uidset->setlen++;
 		} else {
 			colon = strchr (tail->buf, ':') + 1;
-			
+
 			len = strlen (colon);
 			uidset->setlen -= len;
 			tail->buflen -= len;
 		}
-		
+
 		strcpy (tail->buf + tail->buflen, iuid);
 		uidset->setlen += uidlen;
 		tail->buflen += uidlen;
-		
+
 		tail->last = index;
 	} else if ((uidset->setlen + uidlen + 1) < uidset->maxlen) {
 		/* the beginning of a new range */
@@ -364,24 +364,24 @@ uidset_add (struct _uidset *uidset, CamelMessageInfo *info)
 		/* can't add this one... */
 		return -1;
 	}
-	
+
 	d(fprintf (stderr, "added uid %s to uidset (summary index = %u)\n", iuid, index));
-	
+
 	if (uidset->setlen < uidset->maxlen)
 		return 0;
-	
+
 	return 1;
 }
 
-static char *
+static gchar *
 uidset_to_string (struct _uidset *uidset)
 {
 	struct _uidset_range *range;
 	GString *string;
-	char *str;
-	
+	gchar *str;
+
 	string = g_string_new ("");
-	
+
 	range = uidset->ranges;
 	while (range != NULL) {
 		g_string_append (string, range->buf);
@@ -389,38 +389,38 @@ uidset_to_string (struct _uidset *uidset)
 		if (range)
 			g_string_append_c (string, ',');
 	}
-	
+
 	str = string->str;
 	g_string_free (string, FALSE);
-	
+
 	return str;
 }
 
-int
-camel_imap4_get_uid_set (CamelIMAP4Engine *engine, CamelFolderSummary *summary, GPtrArray *infos, int cur, size_t linelen, char **set)
+gint
+camel_imap4_get_uid_set (CamelIMAP4Engine *engine, CamelFolderSummary *summary, GPtrArray *infos, gint cur, gsize linelen, gchar **set)
 {
 	struct _uidset uidset;
-	size_t maxlen;
-	int rv = 0;
-	int i;
-	
+	gsize maxlen;
+	gint rv = 0;
+	gint i;
+
 	if (engine->maxlentype == CAMEL_IMAP4_ENGINE_MAXLEN_LINE)
 		maxlen = engine->maxlen - linelen;
 	else
 		maxlen = engine->maxlen;
-	
+
 	uidset_init (&uidset, summary, maxlen);
-	
+
 	for (i = cur; i < infos->len && rv != 1; i++) {
 		if ((rv = uidset_add (&uidset, infos->pdata[i])) == -1)
 			break;
 	}
-	
+
 	if (i > cur)
 		*set = uidset_to_string (&uidset);
-	
+
 	uidset_range_free (uidset.ranges);
-	
+
 	return (i - cur);
 }
 
@@ -429,14 +429,14 @@ void
 camel_imap4_utils_set_unexpected_token_error (CamelException *ex, CamelIMAP4Engine *engine, camel_imap4_token_t *token)
 {
 	GString *errmsg;
-	
+
 	if (ex == NULL)
 		return;
-	
+
 	errmsg = g_string_new ("");
 	g_string_append_printf (errmsg, _("Unexpected token in response from IMAP server %s: "),
 				engine->url->host);
-	
+
 	switch (token->token) {
 	case CAMEL_IMAP4_TOKEN_NIL:
 		g_string_append (errmsg, "NIL");
@@ -460,18 +460,18 @@ camel_imap4_utils_set_unexpected_token_error (CamelException *ex, CamelIMAP4Engi
 		g_string_append (errmsg, _("No data"));
 		break;
 	default:
-		g_string_append_c (errmsg, (unsigned char) (token->token & 0xff));
+		g_string_append_c (errmsg, (guchar) (token->token & 0xff));
 		break;
 	}
-	
+
 	camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM, errmsg->str);
-	
+
 	g_string_free (errmsg, TRUE);
 }
 
 
 static struct {
-	const char *name;
+	const gchar *name;
 	guint32 flag;
 } imap4_flags[] = {
 	{ "\\Answered",  CAMEL_MESSAGE_ANSWERED     },
@@ -481,31 +481,31 @@ static struct {
 	{ "\\Seen",      CAMEL_MESSAGE_SEEN         },
 	{ "\\Recent",    CAMEL_IMAP4_MESSAGE_RECENT },
 	{ "\\*",         CAMEL_MESSAGE_USER         },
-	
+
 	/* user flags */
 	{ "Junk",        CAMEL_MESSAGE_JUNK         },
 	{ "NonJunk",     0                          },
 };
 
-int
+gint
 camel_imap4_parse_flags_list (CamelIMAP4Engine *engine, guint32 *flags, CamelException *ex)
 {
 	camel_imap4_token_t token;
 	guint32 new = 0;
-	int i;
-	
+	gint i;
+
 	if (camel_imap4_engine_next_token (engine, &token, ex) == -1)
 		return -1;
-	
+
 	if (token.token != '(') {
 		d(fprintf (stderr, "Expected to find a '(' token starting the flags list\n"));
 		camel_imap4_utils_set_unexpected_token_error (ex, engine, &token);
 		return -1;
 	}
-	
+
 	if (camel_imap4_engine_next_token (engine, &token, ex) == -1)
 		return -1;
-	
+
 	while (token.token == CAMEL_IMAP4_TOKEN_ATOM || token.token == CAMEL_IMAP4_TOKEN_FLAG) {
 		/* parse the flags list */
 		for (i = 0; i < G_N_ELEMENTS (imap4_flags); i++) {
@@ -514,28 +514,28 @@ camel_imap4_parse_flags_list (CamelIMAP4Engine *engine, guint32 *flags, CamelExc
 				break;
 			}
 		}
-		
+
 		if (i == G_N_ELEMENTS (imap4_flags))
 			d(fprintf (stderr, "Encountered unknown flag: %s\n", token.v.atom));
-		
+
 		if (camel_imap4_engine_next_token (engine, &token, ex) == -1)
 			return -1;
 	}
-	
+
 	if (token.token != ')') {
 		d(fprintf (stderr, "Expected to find a ')' token terminating the flags list\n"));
 		camel_imap4_utils_set_unexpected_token_error (ex, engine, &token);
 		return -1;
 	}
-	
+
 	*flags = new;
-	
+
 	return 0;
 }
 
 
 static struct {
-	const char *name;
+	const gchar *name;
 	guint32 flag;
 } list_flags[] = {
 	{ "\\Marked",        CAMEL_IMAP4_FOLDER_MARKED    },
@@ -546,28 +546,28 @@ static struct {
 	{ "\\HasNoChildren", CAMEL_FOLDER_NOCHILDREN      },
 };
 
-int
+gint
 camel_imap4_untagged_list (CamelIMAP4Engine *engine, CamelIMAP4Command *ic, guint32 index, camel_imap4_token_t *token, CamelException *ex)
 {
 	GPtrArray *array = ic->user_data;
 	camel_imap4_list_t *list;
-	unsigned char *buf;
+	guchar *buf;
 	guint32 flags = 0;
 	GString *literal;
-	char delim;
-	size_t n;
-	int i;
-	
+	gchar delim;
+	gsize n;
+	gint i;
+
 	if (camel_imap4_engine_next_token (engine, token, ex) == -1)
 		return -1;
-	
+
 	/* parse the flag list */
 	if (token->token != '(')
 		goto unexpected;
-	
+
 	if (camel_imap4_engine_next_token (engine, token, ex) == -1)
 		return -1;
-	
+
 	while (token->token == CAMEL_IMAP4_TOKEN_FLAG || token->token == CAMEL_IMAP4_TOKEN_ATOM) {
 		for (i = 0; i < G_N_ELEMENTS (list_flags); i++) {
 			if (!g_ascii_strcasecmp (list_flags[i].name, token->v.atom)) {
@@ -575,18 +575,18 @@ camel_imap4_untagged_list (CamelIMAP4Engine *engine, CamelIMAP4Command *ic, guin
 				break;
 			}
 		}
-		
+
 		if (camel_imap4_engine_next_token (engine, token, ex) == -1)
 			return -1;
 	}
-	
+
 	if (token->token != ')')
 		goto unexpected;
-	
+
 	/* parse the path delimiter */
 	if (camel_imap4_engine_next_token (engine, token, ex) == -1)
 		return -1;
-	
+
 	switch (token->token) {
 	case CAMEL_IMAP4_TOKEN_NIL:
 		delim = '\0';
@@ -597,15 +597,15 @@ camel_imap4_untagged_list (CamelIMAP4Engine *engine, CamelIMAP4Command *ic, guin
 	default:
 		goto unexpected;
 	}
-	
+
 	/* parse the folder name */
 	if (camel_imap4_engine_next_token (engine, token, ex) == -1)
 		return -1;
-	
+
 	list = g_new (camel_imap4_list_t, 1);
 	list->flags = flags;
 	list->delim = delim;
-	
+
 	switch (token->token) {
 	case CAMEL_IMAP4_TOKEN_ATOM:
 		list->name = g_strdup (token->v.atom);
@@ -617,7 +617,7 @@ camel_imap4_untagged_list (CamelIMAP4Engine *engine, CamelIMAP4Command *ic, guin
 		literal = g_string_new ("");
 		while ((i = camel_imap4_stream_literal (engine->istream, &buf, &n)) == 1)
 			g_string_append_len (literal, buf, n);
-		
+
 		if (i == -1) {
 			camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 					      _("IMAP server %s unexpectedly disconnected: %s"),
@@ -625,7 +625,7 @@ camel_imap4_untagged_list (CamelIMAP4Engine *engine, CamelIMAP4Command *ic, guin
 			g_string_free (literal, TRUE);
 			return -1;
 		}
-		
+
 		g_string_append_len (literal, buf, n);
 		list->name = literal->str;
 		g_string_free (literal, FALSE);
@@ -634,22 +634,22 @@ camel_imap4_untagged_list (CamelIMAP4Engine *engine, CamelIMAP4Command *ic, guin
 		g_free (list);
 		goto unexpected;
 	}
-	
+
 	g_ptr_array_add (array, list);
-	
+
 	return camel_imap4_engine_eat_line (engine, ex);
-	
+
  unexpected:
-	
+
 	camel_imap4_utils_set_unexpected_token_error (ex, engine, token);
-	
+
 	return -1;
 }
 
 
 static struct {
-	const char *name;
-	int type;
+	const gchar *name;
+	gint type;
 } imap4_status[] = {
 	{ "MESSAGES",    CAMEL_IMAP4_STATUS_MESSAGES    },
 	{ "RECENT",      CAMEL_IMAP4_STATUS_RECENT      },
@@ -663,34 +663,34 @@ void
 camel_imap4_status_free (camel_imap4_status_t *status)
 {
 	camel_imap4_status_attr_t *attr, *next;
-	
+
 	attr = status->attr_list;
 	while (attr != NULL) {
 		next = attr->next;
 		g_free (attr);
 		attr = next;
 	}
-	
+
 	g_free (status->mailbox);
 	g_free (status);
 }
 
 
-int
+gint
 camel_imap4_untagged_status (CamelIMAP4Engine *engine, CamelIMAP4Command *ic, guint32 index, camel_imap4_token_t *token, CamelException *ex)
 {
 	camel_imap4_status_attr_t *attr, *tail, *list = NULL;
 	GPtrArray *array = ic->user_data;
 	camel_imap4_status_t *status;
-	unsigned char *literal;
-	char *mailbox;
-	size_t len;
-	int type;
-	int i;
-	
+	guchar *literal;
+	gchar *mailbox;
+	gsize len;
+	gint type;
+	gint i;
+
 	if (camel_imap4_engine_next_token (engine, token, ex) == -1)
 		return -1;
-	
+
 	switch (token->token) {
 	case CAMEL_IMAP4_TOKEN_ATOM:
 		mailbox = g_strdup (token->v.atom);
@@ -701,36 +701,36 @@ camel_imap4_untagged_status (CamelIMAP4Engine *engine, CamelIMAP4Command *ic, gu
 	case CAMEL_IMAP4_TOKEN_LITERAL:
 		if (camel_imap4_engine_literal (engine, &literal, &len, ex) == -1)
 			return -1;
-		
-		mailbox = (char *) literal;
+
+		mailbox = (gchar *) literal;
 		break;
 	default:
 		fprintf (stderr, "Unexpected token in IMAP4 untagged STATUS response: %s%c\n",
 			 token->token == CAMEL_IMAP4_TOKEN_NIL ? "NIL" : "",
-			 (unsigned char) (token->token & 0xff));
+			 (guchar) (token->token & 0xff));
 		camel_imap4_utils_set_unexpected_token_error (ex, engine, token);
 		return -1;
 	}
-	
+
 	if (camel_imap4_engine_next_token (engine, token, ex) == -1) {
 		g_free (mailbox);
 		return -1;
 	}
-	
+
 	if (token->token != '(') {
 		d(fprintf (stderr, "Expected to find a '(' token after the mailbox token in the STATUS response\n"));
 		camel_imap4_utils_set_unexpected_token_error (ex, engine, token);
 		g_free (mailbox);
 		return -1;
 	}
-	
+
 	if (camel_imap4_engine_next_token (engine, token, ex) == -1) {
 		g_free (mailbox);
 		return -1;
 	}
-	
+
 	tail = (camel_imap4_status_attr_t *) &list;
-	
+
 	while (token->token == CAMEL_IMAP4_TOKEN_ATOM) {
 		/* parse the status messages list */
 		type = CAMEL_IMAP4_STATUS_UNKNOWN;
@@ -740,62 +740,62 @@ camel_imap4_untagged_status (CamelIMAP4Engine *engine, CamelIMAP4Command *ic, gu
 				break;
 			}
 		}
-		
+
 		if (type == CAMEL_IMAP4_STATUS_UNKNOWN)
 			fprintf (stderr, "unrecognized token in STATUS list: %s\n", token->v.atom);
-		
+
 		if (camel_imap4_engine_next_token (engine, token, ex) == -1)
 			goto exception;
-		
+
 		if (token->token != CAMEL_IMAP4_TOKEN_NUMBER)
 			break;
-		
+
 		attr = g_new (camel_imap4_status_attr_t, 1);
 		attr->next = NULL;
 		attr->type = type;
 		attr->value = token->v.number;
-		
+
 		tail->next = attr;
 		tail = attr;
-		
+
 		if (camel_imap4_engine_next_token (engine, token, ex) == -1)
 			goto exception;
 	}
-	
+
 	status = g_new (camel_imap4_status_t, 1);
 	status->mailbox = mailbox;
 	status->attr_list = list;
 	list = NULL;
-	
+
 	g_ptr_array_add (array, status);
-	
+
 	if (token->token != ')') {
 		d(fprintf (stderr, "Expected to find a ')' token terminating the untagged STATUS response\n"));
 		camel_imap4_utils_set_unexpected_token_error (ex, engine, token);
 		return -1;
 	}
-	
+
 	if (camel_imap4_engine_next_token (engine, token, ex) == -1)
 		return -1;
-	
+
 	if (token->token != '\n') {
 		d(fprintf (stderr, "Expected to find a '\\n' token after the STATUS response\n"));
 		camel_imap4_utils_set_unexpected_token_error (ex, engine, token);
 		return -1;
 	}
-	
+
 	return 0;
-	
+
  exception:
-	
+
 	g_free (mailbox);
-	
+
 	attr = list;
 	while (attr != NULL) {
 		list = attr->next;
 		g_free (attr);
 		attr = list;
 	}
-	
+
 	return -1;
 }
