@@ -1,13 +1,13 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-imap-store.c : class for a imap store */
 
-/* 
+/*
  * Authors: Michael Zucchi <notzed@ximian.com>
  *
- * Copyright (C) 2000-2002 Ximian, Inc. (www.ximian.com)
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -68,20 +68,20 @@ static CamelStoreClass *parent_class = NULL;
 static void finalize (CamelObject *object);
 
 static void imap_construct(CamelService *service, CamelSession *session, CamelProvider *provider, CamelURL *url, CamelException *ex);
-/* static char *imap_get_name(CamelService *service, gboolean brief);*/
+/* static gchar *imap_get_name(CamelService *service, gboolean brief);*/
 static gboolean imap_connect (CamelService *service, CamelException *ex);
 static gboolean imap_disconnect (CamelService *service, gboolean clean, CamelException *ex);
 static GList *imap_query_auth_types (CamelService *service, CamelException *ex);
 
 static CamelFolder *imap_get_trash  (CamelStore *store, CamelException *ex);
 
-static CamelFolder *imap_get_folder(CamelStore * store, const char *folder_name, guint32 flags, CamelException * ex);
+static CamelFolder *imap_get_folder(CamelStore * store, const gchar *folder_name, guint32 flags, CamelException * ex);
 static CamelFolder *imap_get_inbox (CamelStore *store, CamelException *ex);
-static void imap_rename_folder(CamelStore *store, const char *old_name, const char *new_name, CamelException *ex);
-static CamelFolderInfo *imap_get_folder_info (CamelStore *store, const char *top, guint32 flags, CamelException *ex);
-static void imap_delete_folder(CamelStore *store, const char *folder_name, CamelException *ex);
-static void imap_rename_folder(CamelStore *store, const char *old, const char *new, CamelException *ex);
-static CamelFolderInfo *imap_create_folder(CamelStore *store, const char *parent_name, const char *folder_name, CamelException *ex);
+static void imap_rename_folder(CamelStore *store, const gchar *old_name, const gchar *new_name, CamelException *ex);
+static CamelFolderInfo *imap_get_folder_info (CamelStore *store, const gchar *top, guint32 flags, CamelException *ex);
+static void imap_delete_folder(CamelStore *store, const gchar *folder_name, CamelException *ex);
+static void imap_rename_folder(CamelStore *store, const gchar *old, const gchar *new, CamelException *ex);
+static CamelFolderInfo *imap_create_folder(CamelStore *store, const gchar *parent_name, const gchar *folder_name, CamelException *ex);
 
 /* yet to see if this should go global or not */
 void camel_imapp_store_folder_selected(CamelIMAPPStore *store, CamelIMAPPFolder *folder, CamelIMAPPSelectResponse *select);
@@ -93,7 +93,7 @@ camel_imapp_store_class_init (CamelIMAPPStoreClass *camel_imapp_store_class)
 	CamelStoreClass *camel_store_class = CAMEL_STORE_CLASS(camel_imapp_store_class);
 
 	parent_class = CAMEL_STORE_CLASS(camel_type_get_global_classfuncs(camel_store_get_type()));
-	
+
 	/* virtual method overload */
 	camel_service_class->construct = imap_construct;
 	/*camel_service_class->get_name = imap_get_name;*/
@@ -154,13 +154,13 @@ finalize (CamelObject *object)
 
 static void imap_construct(CamelService *service, CamelSession *session, CamelProvider *provider, CamelURL *url, CamelException *ex)
 {
-	char *root, *summary;
+	gchar *root, *summary;
 	CamelIMAPPStore *store = (CamelIMAPPStore *)service;
 
 	CAMEL_SERVICE_CLASS (parent_class)->construct (service, session, provider, url, ex);
 	if (camel_exception_is_set(ex))
 		return;
-	
+
 	CAMEL_TRY {
 		store->summary = camel_imapp_store_summary_new();
 		root = camel_session_get_storage_path(service->session, service, ex);
@@ -186,19 +186,19 @@ enum {
 #define STARTTLS_FLAGS (CAMEL_TCP_STREAM_SSL_ENABLE_TLS)
 
 static void
-connect_to_server (CamelService *service, int ssl_mode, int try_starttls)
+connect_to_server (CamelService *service, gint ssl_mode, gint try_starttls)
 /* throws IO exception */
 {
 	CamelIMAPPStore *store = CAMEL_IMAPP_STORE (service);
 	CamelStream * volatile tcp_stream = NULL;
 	CamelIMAPPStream * volatile imap_stream = NULL;
-	int ret;
+	gint ret;
 	CamelException *ex;
 
 	ex = camel_exception_new();
 	CAMEL_TRY {
-		char *serv;
-		const char *port = NULL;
+		gchar *serv;
+		const gchar *port = NULL;
 		struct addrinfo *ai, hints = { 0 };
 
 		/* parent class connect initialization */
@@ -214,7 +214,7 @@ connect_to_server (CamelService *service, int ssl_mode, int try_starttls)
 			port = "143";
 		}
 
-#ifdef HAVE_SSL	
+#ifdef HAVE_SSL
 		if (camel_url_get_param (service->url, "use_ssl")) {
 			if (try_starttls)
 				tcp_stream = camel_tcp_stream_ssl_new_raw (service->session, service->url->host, STARTTLS_FLAGS);
@@ -228,7 +228,7 @@ connect_to_server (CamelService *service, int ssl_mode, int try_starttls)
 		} else {
 			tcp_stream = camel_tcp_stream_raw_new ();
 		}
-#else	
+#else
 		tcp_stream = camel_tcp_stream_raw_new ();
 #endif /* HAVE_SSL */
 
@@ -241,7 +241,7 @@ connect_to_server (CamelService *service, int ssl_mode, int try_starttls)
 
 		if (ex->id)
 			camel_exception_throw_ex(ex);
-	
+
 		ret = camel_tcp_stream_connect(CAMEL_TCP_STREAM(tcp_stream), ai);
 		camel_freeaddrinfo(ai);
 		if (ret == -1) {
@@ -250,7 +250,7 @@ connect_to_server (CamelService *service, int ssl_mode, int try_starttls)
 			else
 				camel_exception_throw(CAMEL_EXCEPTION_SERVICE_UNAVAILABLE,
 						      _("Could not connect to %s (port %s): %s"),
-						      service->url->host, serv, strerror(errno));
+						      service->url->host, serv, g_strerror(errno));
 		}
 
 		imap_stream = (CamelIMAPPStream *)camel_imapp_stream_new(tcp_stream);
@@ -275,8 +275,8 @@ connect_to_server (CamelService *service, int ssl_mode, int try_starttls)
 
 
 static struct {
-	char *value;
-	int mode;
+	gchar *value;
+	gint mode;
 } ssl_options[] = {
 	{ "",              USE_SSL_ALWAYS        },
 	{ "always",        USE_SSL_ALWAYS        },
@@ -289,9 +289,9 @@ static gboolean
 connect_to_server_wrapper (CamelService *service, CamelException *ex)
 {
 #ifdef HAVE_SSL
-	const char *use_ssl;
-	int i, ssl_mode;
-	
+	const gchar *use_ssl;
+	gint i, ssl_mode;
+
 	use_ssl = camel_url_get_param (service->url, "use_ssl");
 	if (use_ssl) {
 		for (i = 0; ssl_options[i].value; i++)
@@ -300,7 +300,7 @@ connect_to_server_wrapper (CamelService *service, CamelException *ex)
 		ssl_mode = ssl_options[i].mode;
 	} else
 		ssl_mode = USE_SSL_NEVER;
-	
+
 	if (ssl_mode == USE_SSL_ALWAYS) {
 		/* First try the ssl port */
 		if (!connect_to_server (service, ssl_mode, FALSE, ex)) {
@@ -312,7 +312,7 @@ connect_to_server_wrapper (CamelService *service, CamelException *ex)
 				return FALSE;
 			}
 		}
-		
+
 		return TRUE;
 	} else if (ssl_mode == USE_SSL_WHEN_POSSIBLE) {
 		/* If the server supports STARTTLS, use it */
@@ -357,8 +357,8 @@ static void
 store_get_pass(CamelIMAPPStore *store)
 {
 	if (((CamelService *)store)->url->passwd == NULL) {
-		char *base_prompt;
-		char *full_prompt;
+		gchar *base_prompt;
+		gchar *full_prompt;
 		CamelException ex;
 
 		camel_exception_init(&ex);
@@ -396,10 +396,10 @@ store_get_sasl(struct _CamelIMAPPDriver *driver, CamelIMAPPStore *store)
 }
 
 static void
-store_get_login(struct _CamelIMAPPDriver *driver, char **login, char **pass, CamelIMAPPStore *store)
+store_get_login(struct _CamelIMAPPDriver *driver, gchar **login, gchar **pass, CamelIMAPPStore *store)
 {
 	store_get_pass(store);
-	
+
 	*login = g_strdup(((CamelService *)store)->url->user);
 	*pass = g_strdup(((CamelService *)store)->url->passwd);
 }
@@ -408,14 +408,14 @@ static gboolean
 imap_connect (CamelService *service, CamelException *ex)
 {
 	CamelIMAPPStore *store = (CamelIMAPPStore *)service;
-	volatile int ret = FALSE;
+	volatile gint ret = FALSE;
 
 	CAMEL_TRY {
-		volatile int retry = TRUE;
+		volatile gint retry = TRUE;
 
 		if (store->cache == NULL) {
-			char *root;
-			
+			gchar *root;
+
 			root = camel_session_get_storage_path(service->session, service, ex);
 			if (root) {
 				store->cache = camel_data_cache_new(root, 0, ex);
@@ -475,7 +475,7 @@ imap_disconnect (CamelService *service, gboolean clean, CamelException *ex)
 	CamelIMAPPStore *store = CAMEL_IMAPP_STORE (service);
 
 	/* FIXME: logout */
-	
+
 	if (!CAMEL_SERVICE_CLASS (parent_class)->disconnect (service, clean, ex))
 		return FALSE;
 
@@ -484,7 +484,7 @@ imap_disconnect (CamelService *service, gboolean clean, CamelException *ex)
 		camel_object_unref(store->driver);
 		store->driver = NULL;
 	}
-	
+
 	return TRUE;
 }
 
@@ -496,7 +496,7 @@ imap_get_trash (CamelStore *store, CamelException *ex)
 }
 
 static CamelFolder *
-imap_get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelException *ex)
+imap_get_folder (CamelStore *store, const gchar *folder_name, guint32 flags, CamelException *ex)
 {
 	CamelIMAPPStore *istore = (CamelIMAPPStore *)store;
 	CamelIMAPPFolder * volatile folder = NULL;
@@ -530,12 +530,12 @@ imap_get_inbox(CamelStore *store, CamelException *ex)
 }
 
 /* 8 bit, string compare */
-static int folders_build_cmp(const void *app, const void *bpp)
+static gint folders_build_cmp(gconstpointer app, gconstpointer bpp)
 {
 	struct _list_info *a = *((struct _list_info **)app);
 	struct _list_info *b = *((struct _list_info **)bpp);
-	unsigned char *ap = (unsigned char *)(a->name);
-	unsigned char *bp = (unsigned char *)(b->name);
+	guchar *ap = (guchar *)(a->name);
+	guchar *bp = (guchar *)(b->name);
 
 	printf("qsort, cmp '%s' <> '%s'\n", ap, bp);
 
@@ -555,7 +555,7 @@ static int folders_build_cmp(const void *app, const void *bpp)
 static CamelFolderInfo *
 folders_build_info(CamelURL *base, struct _list_info *li)
 {
-	char *path, *full_name, *name;
+	gchar *path, *full_name, *name;
 	CamelFolderInfo *fi;
 
 	full_name = imapp_list_get_path(li);
@@ -600,15 +600,15 @@ folders_build_info(CamelURL *base, struct _list_info *li)
 /* note, pname is the raw name, not the folderinfo name */
 /* note also this free's as we go, since we never go 'backwards' */
 static CamelFolderInfo *
-folders_build_rec(CamelURL *base, GPtrArray *folders, int *ip, CamelFolderInfo *pfi, char *pname)
+folders_build_rec(CamelURL *base, GPtrArray *folders, gint *ip, CamelFolderInfo *pfi, gchar *pname)
 {
-	int plen = 0;
+	gint plen = 0;
 	CamelFolderInfo *last = NULL, *first = NULL;
 
 	if (pfi)
 		plen = strlen(pname);
 
-	for(;(*ip)<(int)folders->len;) {
+	for(;(*ip)<(gint)folders->len;) {
 		CamelFolderInfo *fi;
 		struct _list_info *li;
 
@@ -626,7 +626,7 @@ folders_build_rec(CamelURL *base, GPtrArray *folders, int *ip, CamelFolderInfo *
 
 		/* is this not an immediate child of the parent? */
 #if 0
-		char *p;
+		gchar *p;
 		if (pfi != NULL
 		    && li->separator != 0
 		    && (p = strchr(li->name + plen + 1, li->separator)) != NULL) {
@@ -663,9 +663,9 @@ folders_build_rec(CamelURL *base, GPtrArray *folders, int *ip, CamelFolderInfo *
 }
 
 static void
-folder_info_dump(CamelFolderInfo *fi, int depth)
+folder_info_dump(CamelFolderInfo *fi, gint depth)
 {
-	char *s;
+	gchar *s;
 
 	s = alloca(depth+1);
 	memset(s, ' ', depth);
@@ -676,22 +676,22 @@ folder_info_dump(CamelFolderInfo *fi, int depth)
 			folder_info_dump(fi->child, depth+2);
 		fi = fi->next;
 	}
-	
+
 }
 
 static CamelFolderInfo *
-imap_get_folder_info(CamelStore *store, const char *top, guint32 flags, CamelException *ex)
+imap_get_folder_info(CamelStore *store, const gchar *top, guint32 flags, CamelException *ex)
 {
 	CamelIMAPPStore *istore = (CamelIMAPPStore *)store;
 	CamelFolderInfo * fi= NULL;
-	char *name;
+	gchar *name;
 
 	/* FIXME: temporary, since this is not a disco store */
 	if (istore->driver == NULL
 	    && !camel_service_connect((CamelService *)store, ex))
 		return NULL;
 
-	name = (char *)top;
+	name = (gchar *)top;
 	if (name == NULL || name[0] == 0) {
 		/* namespace? */
 		name = "";
@@ -701,7 +701,7 @@ imap_get_folder_info(CamelStore *store, const char *top, guint32 flags, CamelExc
 
 	CAMEL_TRY {
 		CamelURL *base;
-		int i;
+		gint i;
 		GPtrArray *folders;
 
 		/* FIXME: subscriptions? lsub? */
@@ -766,11 +766,11 @@ imap_get_folder_info(CamelStore *store, const char *top, guint32 flags, CamelExc
 	} CAMEL_CATCH (e) {
 		camel_exception_xfer(ex, e);
 	} CAMEL_DONE;
-	
+
 	camel_imapp_engine_command_free(istore->driver->engine, ic);
 
 	printf("got folder list:\n");
-	for (i=0;i<(int)istore->pending_list->len;i++) {
+	for (i=0;i<(gint)istore->pending_list->len;i++) {
 		struct _list_info *linfo = istore->pending_list->pdata[i];
 
 		printf("%s (%c)\n", linfo->name, linfo->separator);
@@ -783,19 +783,19 @@ imap_get_folder_info(CamelStore *store, const char *top, guint32 flags, CamelExc
 }
 
 static void
-imap_delete_folder(CamelStore *store, const char *folder_name, CamelException *ex)
+imap_delete_folder(CamelStore *store, const gchar *folder_name, CamelException *ex)
 {
 	camel_exception_setv(ex, 1, "delete_folder::unimplemented");
 }
 
 static void
-imap_rename_folder(CamelStore *store, const char *old, const char *new, CamelException *ex)
+imap_rename_folder(CamelStore *store, const gchar *old, const gchar *new, CamelException *ex)
 {
 	camel_exception_setv(ex, 1, "rename_folder::unimplemented");
 }
 
 static CamelFolderInfo *
-imap_create_folder(CamelStore *store, const char *parent_name, const char *folder_name, CamelException *ex)
+imap_create_folder(CamelStore *store, const gchar *parent_name, const gchar *folder_name, CamelException *ex)
 {
 	camel_exception_setv(ex, 1, "create_folder::unimplemented");
 	return NULL;
@@ -803,7 +803,7 @@ imap_create_folder(CamelStore *store, const char *parent_name, const char *folde
 
 /* ********************************************************************** */
 #if 0
-static int store_resp_fetch(CamelIMAPPEngine *ie, guint32 id, void *data)
+static gint store_resp_fetch(CamelIMAPPEngine *ie, guint32 id, gpointer data)
 {
 	struct _fetch_info *finfo;
 	CamelIMAPPStore *istore = data;
@@ -861,7 +861,7 @@ static int store_resp_fetch(CamelIMAPPEngine *ie, guint32 id, void *data)
 					camel_folder_summary_add(((CamelFolder *)istore->selected)->summary, info);
 					camel_folder_change_info_add_uid(istore->selected->changes, finfo->uid);
 					if (pending) {
-						e_dlist_remove((EDListNode *)pending);
+						camel_dlist_remove((CamelDListNode *)pending);
 						g_hash_table_remove(istore->pending_fetch_table, finfo->uid);
 						/*e_memchunk_free(istore->pending_fetch_chunks, pending);*/
 					}
@@ -881,7 +881,7 @@ static int store_resp_fetch(CamelIMAPPEngine *ie, guint32 id, void *data)
 					camel_folder_change_info_add_uid(istore->selected->changes, finfo->uid);
 					if (pending) {
 						/* FIXME: use a dlist */
-						e_dlist_remove((EDListNode *)pending);
+						camel_dlist_remove((CamelDListNode *)pending);
 						g_hash_table_remove(istore->pending_fetch_table, camel_message_info_uid(pending->info));
 						camel_message_info_free(pending->info);
 						/*e_memchunk_free(istore->pending_fetch_chunks, pending);*/
@@ -890,8 +890,8 @@ static int store_resp_fetch(CamelIMAPPEngine *ie, guint32 id, void *data)
 					if (pending == NULL) {
 						pending = e_memchunk_alloc(istore->pending_fetch_chunks);
 						pending->info = info;
-						g_hash_table_insert(istore->pending_fetch_table, (char *)camel_message_info_uid(info), pending);
-						e_dlist_addtail(&istore->pending_fetch_list, (EDListNode *)pending);
+						g_hash_table_insert(istore->pending_fetch_table, (gchar *)camel_message_info_uid(info), pending);
+						camel_dlist_addtail(&istore->pending_fetch_list, (CamelDListNode *)pending);
 					}
 				} else {
 					if (pending == NULL)
@@ -924,7 +924,7 @@ camel_imapp_store_folder_selected(CamelIMAPPStore *store, CamelIMAPPFolder *fold
 {
 	CamelIMAPPCommand * volatile ic = NULL;
 	CamelIMAPPStore *istore = (CamelIMAPPStore *)store;
-	int i;
+	gint i;
 	struct _uidset_state ss;
 	GPtrArray *fetch;
 	CamelMessageInfo *info;
@@ -979,7 +979,7 @@ camel_imapp_store_folder_selected(CamelIMAPPStore *store, CamelIMAPPFolder *fold
 			fn = fn->next;
 		}
 
-		printf("The pending list should now be empty: %s\n", e_dlist_empty(&istore->pending_fetch_list)?"TRUE":"FALSE");
+		printf("The pending list should now be empty: %s\n", camel_dlist_empty(&istore->pending_fetch_list)?"TRUE":"FALSE");
 		for (i=0;i<10;i++) {
 			info = camel_folder_summary_index(((CamelFolder *)istore->selected)->summary, i);
 			if (info) {
@@ -1004,14 +1004,14 @@ camel_imapp_store_folder_selected(CamelIMAPPStore *store, CamelIMAPPFolder *fold
 #if 0
 /*char *uids[] = {"1", "2", "4", "5", "6", "7", "9", "11", "12", 0};*/
 /*char *uids[] = {"1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", 0};*/
-char *uids[] = {"1", "3", "5", "7", "9", "11", "12", "13", "14", "15", "20", "21", "24", "25", "26", 0};
+gchar *uids[] = {"1", "3", "5", "7", "9", "11", "12", "13", "14", "15", "20", "21", "24", "25", "26", 0};
 
 void
 uidset_test(CamelIMAPPEngine *ie)
 {
 	struct _uidset_state ss;
 	CamelIMAPPCommand *ic;
-	int i;
+	gint i;
 
 	/*ic = camel_imapp_engine_command_new(ie, 0, "FETCH", NULL, "FETCH ");*/
 	uidset_init(&ss, 0, 0);
