@@ -38,11 +38,11 @@
 
 #define CAMEL_IMAPP_SUMMARY_VERSION (1)
 
-static int summary_header_load(CamelFolderSummary *, FILE *);
-static int summary_header_save(CamelFolderSummary *, FILE *);
+static gint summary_header_load(CamelFolderSummary *, FILE *);
+static gint summary_header_save(CamelFolderSummary *, FILE *);
 
 static CamelMessageInfo *message_info_load(CamelFolderSummary *s, FILE *in);
-static int message_info_save(CamelFolderSummary *s, FILE *out, CamelMessageInfo *info);
+static gint message_info_save(CamelFolderSummary *s, FILE *out, CamelMessageInfo *info);
 
 static void camel_imapp_summary_class_init(CamelIMAPPSummaryClass *klass);
 static void camel_imapp_summary_init      (CamelIMAPPSummary *obj);
@@ -96,7 +96,6 @@ camel_imapp_summary_init(CamelIMAPPSummary *obj)
 
 /**
  * camel_imapp_summary_new:
- * @filename: the file to store the summary in.
  *
  * This will create a new CamelIMAPPSummary object and read in the
  * summary data from disk, if it exists.
@@ -112,7 +111,7 @@ camel_imapp_summary_new(void)
 }
 
 
-static int
+static gint
 summary_header_load(CamelFolderSummary *s, FILE *in)
 {
 	CamelIMAPPSummary *ims = CAMEL_IMAPP_SUMMARY(s);
@@ -135,9 +134,9 @@ summary_header_load(CamelFolderSummary *s, FILE *in)
 	}
 
 	return 0;
-}	
+}
 
-static int
+static gint
 summary_header_save(CamelFolderSummary *s, FILE *out)
 {
 	CamelIMAPPSummary *ims = CAMEL_IMAPP_SUMMARY(s);
@@ -173,7 +172,7 @@ error:
 	return NULL;
 }
 
-static int
+static gint
 message_info_save(CamelFolderSummary *s, FILE *out, CamelMessageInfo *info)
 {
 	CamelIMAPPMessageInfo *iinfo =(CamelIMAPPMessageInfo *)info;
