@@ -51,21 +51,21 @@
 #define EXTRACT_FIRST_DIGIT(val) val=strtoul (part, &part, 10);
 
 static CamelFIRecord * summary_header_to_db (CamelFolderSummary *, CamelException *ex);
-static int summary_header_from_db (CamelFolderSummary *, CamelFIRecord *);
+static gint summary_header_from_db (CamelFolderSummary *, CamelFIRecord *);
 
-static int summary_header_load (CamelFolderSummary *, FILE *);
-static int summary_header_save (CamelFolderSummary *, FILE *);
+static gint summary_header_load (CamelFolderSummary *, FILE *);
+static gint summary_header_save (CamelFolderSummary *, FILE *);
 
 static CamelMessageInfo * message_info_new_from_header (CamelFolderSummary *, struct _camel_header_raw *);
 
-static int local_summary_decode_x_evolution(CamelLocalSummary *cls, const char *xev, CamelLocalMessageInfo *mi);
-static char *local_summary_encode_x_evolution(CamelLocalSummary *cls, const CamelLocalMessageInfo *mi);
+static gint local_summary_decode_x_evolution(CamelLocalSummary *cls, const gchar *xev, CamelLocalMessageInfo *mi);
+static gchar *local_summary_encode_x_evolution(CamelLocalSummary *cls, const CamelLocalMessageInfo *mi);
 
-static int local_summary_load(CamelLocalSummary *cls, int forceindex, CamelException *ex);
-static int local_summary_check(CamelLocalSummary *cls, CamelFolderChangeInfo *changeinfo, CamelException *ex);
-static int local_summary_sync(CamelLocalSummary *cls, gboolean expunge, CamelFolderChangeInfo *changeinfo, CamelException *ex);
+static gint local_summary_load(CamelLocalSummary *cls, gint forceindex, CamelException *ex);
+static gint local_summary_check(CamelLocalSummary *cls, CamelFolderChangeInfo *changeinfo, CamelException *ex);
+static gint local_summary_sync(CamelLocalSummary *cls, gboolean expunge, CamelFolderChangeInfo *changeinfo, CamelException *ex);
 static CamelMessageInfo *local_summary_add(CamelLocalSummary *cls, CamelMimeMessage *msg, const CamelMessageInfo *info, CamelFolderChangeInfo *, CamelException *ex);
-static int local_summary_need_index(void);
+static gint local_summary_need_index(void);
 
 static void camel_local_summary_class_init (CamelLocalSummaryClass *klass);
 static void camel_local_summary_init       (CamelLocalSummary *obj);
@@ -76,7 +76,7 @@ CamelType
 camel_local_summary_get_type(void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register(camel_folder_summary_get_type(), "CamelLocalSummary",
 					   sizeof (CamelLocalSummary),
@@ -86,7 +86,7 @@ camel_local_summary_get_type(void)
 					   (CamelObjectInitFunc) camel_local_summary_init,
 					   (CamelObjectFinalizeFunc) camel_local_summary_finalise);
 	}
-	
+
 	return type;
 }
 
@@ -94,15 +94,15 @@ static void
 camel_local_summary_class_init(CamelLocalSummaryClass *klass)
 {
 	CamelFolderSummaryClass *sklass = (CamelFolderSummaryClass *) klass;
-	
+
 	camel_local_summary_parent = CAMEL_FOLDER_SUMMARY_CLASS(camel_type_get_global_classfuncs(camel_folder_summary_get_type()));
 
 	sklass->summary_header_load = summary_header_load;
 	sklass->summary_header_save = summary_header_save;
-	
+
 	sklass->summary_header_from_db = summary_header_from_db;
 	sklass->summary_header_to_db = summary_header_to_db;
-	
+
 	sklass->message_info_new_from_header  = message_info_new_from_header;
 
 	klass->load = local_summary_load;
@@ -139,7 +139,7 @@ camel_local_summary_finalise(CamelObject *obj)
 }
 
 void
-camel_local_summary_construct(CamelLocalSummary *new, const char *filename, const char *local_name, CamelIndex *index)
+camel_local_summary_construct(CamelLocalSummary *new, const gchar *filename, const gchar *local_name, CamelIndex *index)
 {
 	camel_folder_summary_set_build_content(CAMEL_FOLDER_SUMMARY(new), FALSE);
 	camel_folder_summary_set_filename(CAMEL_FOLDER_SUMMARY(new), filename);
@@ -149,16 +149,16 @@ camel_local_summary_construct(CamelLocalSummary *new, const char *filename, cons
 		camel_object_ref((CamelObject *)index);
 }
 
-static int
-local_summary_load(CamelLocalSummary *cls, int forceindex, CamelException *ex)
+static gint
+local_summary_load(CamelLocalSummary *cls, gint forceindex, CamelException *ex)
 {
 	d(g_print ("\nlocal_summary_load called \n"));
 	return camel_folder_summary_load_from_db ((CamelFolderSummary *)cls, ex);
 }
 
 /* load/check the summary */
-int
-camel_local_summary_load(CamelLocalSummary *cls, int forceindex, CamelException *ex)
+gint
+camel_local_summary_load(CamelLocalSummary *cls, gint forceindex, CamelException *ex)
 {
 	d(printf("Loading summary ...\n"));
 
@@ -177,14 +177,14 @@ void camel_local_summary_check_force(CamelLocalSummary *cls)
 	cls->check_force = 1;
 }
 
-char *
+gchar *
 camel_local_summary_encode_x_evolution(CamelLocalSummary *cls, const CamelLocalMessageInfo *info)
 {
 	return ((CamelLocalSummaryClass *)(CAMEL_OBJECT_GET_CLASS(cls)))->encode_x_evolution(cls, info);
 }
 
-int
-camel_local_summary_decode_x_evolution(CamelLocalSummary *cls, const char *xev, CamelLocalMessageInfo *info)
+gint
+camel_local_summary_decode_x_evolution(CamelLocalSummary *cls, const gchar *xev, CamelLocalMessageInfo *info)
 {
 	return ((CamelLocalSummaryClass *)(CAMEL_OBJECT_GET_CLASS(cls)))->decode_x_evolution(cls, xev, info);
 }
@@ -192,12 +192,12 @@ camel_local_summary_decode_x_evolution(CamelLocalSummary *cls, const char *xev,
 /*#define DOSTATS*/
 #ifdef DOSTATS
 struct _stat_info {
-	int mitotal;
-	int micount;
-	int citotal;
-	int cicount;
-	int msgid;
-	int msgcount;
+	gint mitotal;
+	gint micount;
+	gint citotal;
+	gint cicount;
+	gint msgid;
+	gint msgcount;
 };
 
 static void
@@ -269,16 +269,16 @@ do_stat_mi(CamelLocalSummary *cls, struct _stat_info *info, CamelMessageInfo *mi
 
 #endif
 
-int
+gint
 camel_local_summary_check(CamelLocalSummary *cls, CamelFolderChangeInfo *changeinfo, CamelException *ex)
 {
-	int ret;
+	gint ret;
 
 	ret = ((CamelLocalSummaryClass *)(CAMEL_OBJECT_GET_CLASS(cls)))->check(cls, changeinfo, ex);
 
 #ifdef DOSTATS
 	if (ret != -1) {
-		int i;
+		gint i;
 		CamelFolderSummary *s = (CamelFolderSummary *)cls;
 		struct _stat_info stats = { 0 };
 
@@ -289,7 +289,7 @@ camel_local_summary_check(CamelLocalSummary *cls, CamelFolderChangeInfo *changei
 		}
 
 		printf("\nMemory used by summary:\n\n");
-		printf("Total of %d messages\n", camel_folder_summary_count(s)); 
+		printf("Total of %d messages\n", camel_folder_summary_count(s));
 		printf("Total: %d bytes (ave %f)\n", stats.citotal + stats.mitotal,
 		       (double)(stats.citotal+stats.mitotal)/(double)camel_folder_summary_count(s));
 		printf("Message Info: %d (ave %f)\n", stats.mitotal, (double)stats.mitotal/(double)stats.micount);
@@ -300,7 +300,7 @@ camel_local_summary_check(CamelLocalSummary *cls, CamelFolderChangeInfo *changei
 	return ret;
 }
 
-int
+gint
 camel_local_summary_sync(CamelLocalSummary *cls, gboolean expunge, CamelFolderChangeInfo *changeinfo, CamelException *ex)
 {
 	return ((CamelLocalSummaryClass *)(CAMEL_OBJECT_GET_CLASS(cls)))->sync(cls, expunge, changeinfo, ex);
@@ -314,24 +314,24 @@ camel_local_summary_add(CamelLocalSummary *cls, CamelMimeMessage *msg, const Cam
 
 /**
  * camel_local_summary_write_headers:
- * @fd: 
- * @header: 
- * @xevline: 
+ * @fd:
+ * @header:
+ * @xevline:
  * @status:
  * @xstatus:
- * 
+ *
  * Write a bunch of headers to the file @fd.  IF xevline is non NULL, then
  * an X-Evolution header line is created at the end of all of the headers.
  * If @status is non NULL, then a Status header line is also written.
  * The headers written are termianted with a blank line.
- * 
+ *
  * Return value: -1 on error, otherwise the number of bytes written.
  **/
-int
-camel_local_summary_write_headers(int fd, struct _camel_header_raw *header, const char *xevline, const char *status, const char *xstatus)
+gint
+camel_local_summary_write_headers(gint fd, struct _camel_header_raw *header, const gchar *xevline, const gchar *status, const gchar *xstatus)
 {
-	int outlen = 0, len;
-	int newfd;
+	gint outlen = 0, len;
+	gint newfd;
 	FILE *out;
 
 	/* dum de dum, maybe the whole sync function should just use stdio for output */
@@ -400,17 +400,17 @@ camel_local_summary_write_headers(int fd, struct _camel_header_raw *header, cons
 	return outlen;
 }
 
-static int
+static gint
 local_summary_check(CamelLocalSummary *cls, CamelFolderChangeInfo *changeinfo, CamelException *ex)
 {
 	/* FIXME: sync index here ? */
 	return 0;
 }
 
-static int
+static gint
 local_summary_sync(CamelLocalSummary *cls, gboolean expunge, CamelFolderChangeInfo *changeinfo, CamelException *ex)
 {
-	int ret = 0;
+	gint ret = 0;
 
 	ret = camel_folder_summary_save_to_db ((CamelFolderSummary *)cls, ex);
 	if (ret == -1) {
@@ -424,7 +424,7 @@ local_summary_sync(CamelLocalSummary *cls, gboolean expunge, CamelFolderChangeIn
 	return ret;
 }
 
-static int
+static gint
 local_summary_need_index(void) {
 	return 1;
 }
@@ -432,23 +432,23 @@ local_summary_need_index(void) {
 static void
 update_summary (CamelFolderSummary *summary, CamelMessageInfoBase *info, CamelMessageInfoBase *old)
 {
-	int unread=0, deleted=0, junk=0;
+	gint unread=0, deleted=0, junk=0;
 	guint32 flags = info->flags;
 	guint32 oldflags = old->flags;
 
 	if ((flags & CAMEL_MESSAGE_SEEN) != (oldflags & CAMEL_MESSAGE_SEEN))
 		unread = (oldflags & CAMEL_MESSAGE_SEEN) ? 1 : -1;
-	
+
 	if ((flags & CAMEL_MESSAGE_DELETED) != (oldflags & CAMEL_MESSAGE_DELETED))
 		deleted = (oldflags & CAMEL_MESSAGE_DELETED) ? 1 : -1;
 
 	if ((flags & CAMEL_MESSAGE_JUNK) != (oldflags & CAMEL_MESSAGE_JUNK))
 		junk = (oldflags & CAMEL_MESSAGE_JUNK) ? 1 : -1;
-	
+
 	/* Things would already be flagged */
-	
+
 	if (summary) {
-		
+
 		if (unread)
 			summary->unread_count -= unread;
 		if (deleted)
@@ -457,7 +457,7 @@ update_summary (CamelFolderSummary *summary, CamelMessageInfoBase *info, CamelMe
 			summary->junk_count += junk;
 		if (junk && !deleted)
 			summary->junk_not_deleted_count += junk;
-		if (junk ||  deleted) 
+		if (junk ||  deleted)
 			summary->visible_count -= junk ? junk : deleted;
 	}
 
@@ -468,10 +468,10 @@ local_summary_add(CamelLocalSummary *cls, CamelMimeMessage *msg, const CamelMess
 {
 	CamelLocalMessageInfo *mi;
 	CamelFolderSummary *s = (CamelFolderSummary *)cls;
-	char *xev;
+	gchar *xev;
 
 	d(printf("Adding message to summary\n"));
-	
+
 	mi = (CamelLocalMessageInfo *)camel_folder_summary_add_from_message((CamelFolderSummary *)cls, msg);
 	if (mi) {
 		/*d(printf("Added, uid = %s\n", mi->uid));*/
@@ -483,12 +483,12 @@ local_summary_add(CamelLocalSummary *cls, CamelMimeMessage *msg, const CamelMess
 				camel_message_info_set_user_flag((CamelMessageInfo *)mi, flag->name, TRUE);
 				flag = flag->next;
 			}
-			
+
 			while (tag) {
 				camel_message_info_set_user_tag((CamelMessageInfo *)mi, tag->name, tag->value);
 				tag = tag->next;
 			}
-			
+
 			update_summary (s, (CamelMessageInfoBase *) mi, (CamelMessageInfoBase *) info);
 			mi->info.flags |= (camel_message_info_flags(info) & 0xffff);
 			camel_folder_summary_update_flag_cache (s, mi->info.uid, mi->info.flags);
@@ -517,7 +517,7 @@ local_summary_add(CamelLocalSummary *cls, CamelMimeMessage *msg, const CamelMess
 	return (CamelMessageInfo *)mi;
 }
 
-static char *
+static gchar *
 local_summary_encode_x_evolution(CamelLocalSummary *cls, const CamelLocalMessageInfo *mi)
 {
 	GString *out = g_string_new("");
@@ -525,8 +525,8 @@ local_summary_encode_x_evolution(CamelLocalSummary *cls, const CamelLocalMessage
 	GString *val = g_string_new("");
 	CamelFlag *flag = mi->info.user_flags;
 	CamelTag *tag = mi->info.user_tags;
-	char *ret;
-	const char *p, *uidstr;
+	gchar *ret;
+	const gchar *p, *uidstr;
 	guint32 uid;
 
 	/* FIXME: work out what to do with uid's that aren't stored here? */
@@ -542,7 +542,7 @@ local_summary_encode_x_evolution(CamelLocalSummary *cls, const CamelLocalMessage
 
 	if (flag || tag) {
 		val = g_string_new ("");
-		
+
 		if (flag) {
 			while (flag) {
 				g_string_append (val, flag->name);
@@ -570,18 +570,18 @@ local_summary_encode_x_evolution(CamelLocalSummary *cls, const CamelLocalMessage
 	}
 	ret = out->str;
 	g_string_free (out, FALSE);
-	
+
 	return ret;
 }
 
-static int
-local_summary_decode_x_evolution(CamelLocalSummary *cls, const char *xev, CamelLocalMessageInfo *mi)
+static gint
+local_summary_decode_x_evolution(CamelLocalSummary *cls, const gchar *xev, CamelLocalMessageInfo *mi)
 {
 	struct _camel_header_param *params, *scan;
 	guint32 uid, flags;
-	char *header;
-	int i;
-	char uidstr[20];
+	gchar *header;
+	gint i;
+	gchar uidstr[20];
 
 	uidstr[0] = 0;
 
@@ -600,21 +600,21 @@ local_summary_decode_x_evolution(CamelLocalSummary *cls, const char *xev, CamelL
 	if (mi == NULL)
 		return 0;
 
-	/* check for additional data */	
+	/* check for additional data */
 	header = strchr(xev, ';');
 	if (header) {
 		params = camel_header_param_list_decode(header+1);
 		scan = params;
 		while (scan) {
 			if (!g_ascii_strcasecmp(scan->name, "flags")) {
-				char **flagv = g_strsplit(scan->value, ",", 1000);
+				gchar **flagv = g_strsplit(scan->value, ",", 1000);
 
 				for (i=0;flagv[i];i++)
 					camel_message_info_set_user_flag((CamelMessageInfo *)mi, flagv[i], TRUE);
 				g_strfreev(flagv);
 			} else if (!g_ascii_strcasecmp(scan->name, "tags")) {
-				char **tagv = g_strsplit(scan->value, ",", 10000);
-				char *val;
+				gchar **tagv = g_strsplit(scan->value, ",", 10000);
+				gchar *val;
 
 				for (i=0;tagv[i];i++) {
 					val = strchr(tagv[i], '=');
@@ -638,11 +638,11 @@ local_summary_decode_x_evolution(CamelLocalSummary *cls, const char *xev, CamelL
 }
 
 
-static int 
+static gint
 summary_header_from_db (CamelFolderSummary *s, CamelFIRecord *fir)
 {
 	CamelLocalSummary *cls = (CamelLocalSummary *)s;
-	char *part, *tmp;
+	gchar *part, *tmp;
 
 	/* We dont actually add our own headers, but version that we don't anyway */
 
@@ -663,7 +663,7 @@ summary_header_from_db (CamelFolderSummary *s, CamelFIRecord *fir)
 }
 
 
-static int
+static gint
 summary_header_load(CamelFolderSummary *s, FILE *in)
 {
 	CamelLocalSummary *cls = (CamelLocalSummary *)s;
@@ -678,22 +678,22 @@ summary_header_load(CamelFolderSummary *s, FILE *in)
 		return 0;
 
 	/* otherwise load the version number */
-	return camel_file_util_decode_fixed_int32(in, &cls->version);
+	return camel_file_util_decode_fixed_int32(in, (gint32 *) &cls->version);
 }
 
-static struct _CamelFIRecord * 
+static struct _CamelFIRecord *
 summary_header_to_db (CamelFolderSummary *s, CamelException *ex)
 {
 	struct _CamelFIRecord *fir;
-	
+
 	fir = ((CamelFolderSummaryClass *)camel_local_summary_parent)->summary_header_to_db (s, ex);
 	if (fir)
 		fir->bdata = g_strdup_printf ("%d", CAMEL_LOCAL_SUMMARY_VERSION);
-	
+
 	return fir;
 }
- 
-static int
+
+static gint
 summary_header_save(CamelFolderSummary *s, FILE *out)
 {
 	/*CamelLocalSummary *cls = (CamelLocalSummary *)s;*/
@@ -712,8 +712,8 @@ message_info_new_from_header(CamelFolderSummary *s, struct _camel_header_raw *h)
 
 	mi = (CamelLocalMessageInfo *)((CamelFolderSummaryClass *)camel_local_summary_parent)->message_info_new_from_header(s, h);
 	if (mi) {
-		const char *xev;
-		int doindex = FALSE;
+		const gchar *xev;
+		gint doindex = FALSE;
 
 		xev = camel_header_raw_find(&h, "X-Evolution", NULL);
 		if (xev==NULL || camel_local_summary_decode_x_evolution(cls, xev, mi) == -1) {
@@ -725,7 +725,7 @@ message_info_new_from_header(CamelFolderSummary *s, struct _camel_header_raw *h)
 			/* shortcut, no need to look it up in the index library */
 			doindex = TRUE;
 		}
-		
+
 		if (cls->index
 		    && (doindex
 			|| cls->index_force
@@ -737,6 +737,6 @@ message_info_new_from_header(CamelFolderSummary *s, struct _camel_header_raw *h)
 			camel_folder_summary_set_index(s, NULL);
 		}
 	}
-	
+
 	return (CamelMessageInfo *)mi;
 }
