@@ -48,11 +48,11 @@
 
 #define CAMEL_SPOOL_SUMMARY_VERSION (0x400)
 
-static int spool_summary_load(CamelLocalSummary *cls, int forceindex, CamelException *ex);
-static int spool_summary_check(CamelLocalSummary *cls, CamelFolderChangeInfo *changeinfo, CamelException *ex);
+static gint spool_summary_load(CamelLocalSummary *cls, gint forceindex, CamelException *ex);
+static gint spool_summary_check(CamelLocalSummary *cls, CamelFolderChangeInfo *changeinfo, CamelException *ex);
 
-static int spool_summary_sync_full(CamelMboxSummary *cls, gboolean expunge, CamelFolderChangeInfo *changeinfo, CamelException *ex);
-static int spool_summary_need_index(void);
+static gint spool_summary_sync_full(CamelMboxSummary *cls, gboolean expunge, CamelFolderChangeInfo *changeinfo, CamelException *ex);
+static gint spool_summary_need_index(void);
 
 static void camel_spool_summary_class_init (CamelSpoolSummaryClass *klass);
 static void camel_spool_summary_init       (CamelSpoolSummary *obj);
@@ -64,7 +64,7 @@ CamelType
 camel_spool_summary_get_type(void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register(camel_mbox_summary_get_type(), "CamelSpoolSummary",
 					   sizeof (CamelSpoolSummary),
@@ -74,7 +74,7 @@ camel_spool_summary_get_type(void)
 					   (CamelObjectInitFunc) camel_spool_summary_init,
 					   (CamelObjectFinalizeFunc) camel_spool_summary_finalise);
 	}
-	
+
 	return type;
 }
 
@@ -97,7 +97,7 @@ static void
 camel_spool_summary_init(CamelSpoolSummary *obj)
 {
 	struct _CamelFolderSummary *s = (CamelFolderSummary *)obj;
-	
+
 	/* message info size is from mbox parent */
 
 	/* and a unique file version */
@@ -111,7 +111,7 @@ camel_spool_summary_finalise(CamelObject *obj)
 }
 
 CamelSpoolSummary *
-camel_spool_summary_new(struct _CamelFolder *folder, const char *mbox_name)
+camel_spool_summary_new(struct _CamelFolder *folder, const gchar *mbox_name)
 {
 	CamelSpoolSummary *new = (CamelSpoolSummary *)camel_object_new(camel_spool_summary_get_type());
 
@@ -126,22 +126,22 @@ camel_spool_summary_new(struct _CamelFolder *folder, const char *mbox_name)
 	return new;
 }
 
-static int
-spool_summary_load(CamelLocalSummary *cls, int forceindex, CamelException *ex)
+static gint
+spool_summary_load(CamelLocalSummary *cls, gint forceindex, CamelException *ex)
 {
 	g_warning("spool summary - not loading anything\n");
 	return 0;
 }
 
 /* perform a full sync */
-static int
+static gint
 spool_summary_sync_full(CamelMboxSummary *cls, gboolean expunge, CamelFolderChangeInfo *changeinfo, CamelException *ex)
 {
-	int fd = -1, fdout = -1;
-	char tmpname[64] = { '\0' };
-	char *buffer, *p;
+	gint fd = -1, fdout = -1;
+	gchar tmpname[64] = { '\0' };
+	gchar *buffer, *p;
 	off_t spoollen, outlen;
-	int size, sizeout;
+	gint size, sizeout;
 	struct stat st;
 	guint32 flags = (expunge?1:0);
 
@@ -288,15 +288,15 @@ spool_summary_sync_full(CamelMboxSummary *cls, gboolean expunge, CamelFolderChan
 		unlink(tmpname);
 
 	camel_operation_end(NULL);
-		
+
 	return 0;
  error:
 	if (fd != -1)
 		close(fd);
-	
+
 	if (fdout != -1)
 		close(fdout);
-	
+
 	if (tmpname[0] != '\0')
 		unlink(tmpname);
 
@@ -305,10 +305,10 @@ spool_summary_sync_full(CamelMboxSummary *cls, gboolean expunge, CamelFolderChan
 	return -1;
 }
 
-static int
+static gint
 spool_summary_check(CamelLocalSummary *cls, CamelFolderChangeInfo *changeinfo, CamelException *ex)
 {
-	int i, work, count;
+	gint i, work, count;
 	struct stat st;
 	CamelFolderSummary *s = (CamelFolderSummary *)cls;
 
@@ -330,7 +330,7 @@ spool_summary_check(CamelLocalSummary *cls, CamelFolderChangeInfo *changeinfo, C
 		d(printf("Have to add new headers, re-syncing from the start to accomplish this\n"));
 		if (((CamelMboxSummaryClass *)((CamelObject *)cls)->klass)->sync_full((CamelMboxSummary *)cls, FALSE, changeinfo, ex) == -1)
 			return -1;
-		
+
 		if (stat(cls->folder_path, &st) == -1) {
 			camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 					      _("Unknown error: %s"),
@@ -345,7 +345,7 @@ spool_summary_check(CamelLocalSummary *cls, CamelFolderChangeInfo *changeinfo, C
 	return 0;
 }
 
-static int
+static gint
 spool_summary_need_index(void) {
 	return 0;
 }
