@@ -1,12 +1,12 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-nntp-store.h : class for an nntp store */
 
-/* 
+/*
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -50,6 +50,7 @@ struct _CamelException;
 
 typedef struct _CamelNNTPStore CamelNNTPStore;
 typedef struct _CamelNNTPStoreClass CamelNNTPStoreClass;
+typedef struct _CamelNNTPStorePrivate CamelNNTPStorePrivate;
 
 typedef enum _xover_t {
 	XOVER_STRING = 0,
@@ -60,30 +61,30 @@ typedef enum _xover_t {
 struct _xover_header {
 	struct _xover_header *next;
 
-	const char *name;
-	unsigned int skip:8;
+	const gchar *name;
+	guint skip:8;
 	xover_t type:8;
 };
 
 struct _CamelNNTPStore {
-	CamelDiscoStore parent_object;	
-	
-	struct _CamelNNTPStorePrivate *priv;
-	
+	CamelDiscoStore parent_object;
+
+	CamelNNTPStorePrivate *priv;
+
 	guint32 extensions;
-	
-	unsigned int posting_allowed:1;
-	unsigned int do_short_folder_notation:1;
-	unsigned int folder_hierarchy_relative:1;
+
+	guint posting_allowed:1;
+	guint do_short_folder_notation:1;
+	guint folder_hierarchy_relative:1;
 
 	struct _CamelNNTPStoreSummary *summary;
-	
+
 	struct _CamelNNTPStream *stream;
 	struct _CamelStreamMem *mem;
-	
+
 	struct _CamelDataCache *cache;
-	
-	char *current_folder, *storage_path, *base_url;
+
+	gchar *current_folder, *storage_path, *base_url;
 
 	struct _xover_header *xover;
 };
@@ -96,10 +97,10 @@ struct _CamelNNTPStoreClass {
 /* Standard Camel function */
 CamelType camel_nntp_store_get_type (void);
 
-int camel_nntp_raw_commandv (CamelNNTPStore *store, struct _CamelException *ex, char **line, const char *fmt, va_list ap);
-int camel_nntp_raw_command(CamelNNTPStore *store, struct _CamelException *ex, char **line, const char *fmt, ...);
-int camel_nntp_raw_command_auth(CamelNNTPStore *store, struct _CamelException *ex, char **line, const char *fmt, ...);
-int camel_nntp_command (CamelNNTPStore *store, struct _CamelException *ex, struct _CamelNNTPFolder *folder, char **line, const char *fmt, ...);
+gint camel_nntp_raw_commandv (CamelNNTPStore *store, struct _CamelException *ex, gchar **line, const gchar *fmt, va_list ap);
+gint camel_nntp_raw_command(CamelNNTPStore *store, struct _CamelException *ex, gchar **line, const gchar *fmt, ...);
+gint camel_nntp_raw_command_auth(CamelNNTPStore *store, struct _CamelException *ex, gchar **line, const gchar *fmt, ...);
+gint camel_nntp_command (CamelNNTPStore *store, struct _CamelException *ex, struct _CamelNNTPFolder *folder, gchar **line, const gchar *fmt, ...);
 
 G_END_DECLS
 
