@@ -48,17 +48,17 @@ static CamelObjectClass *parent_class = NULL;
 #define CAMEL_NNTP_STREAM_SIZE (4096)
 #define CAMEL_NNTP_STREAM_LINE_SIZE (1024) /* maximum line size */
 
-static int
+static gint
 stream_fill(CamelNNTPStream *is)
 {
-	int left = 0;
+	gint left = 0;
 
 	if (is->source) {
 		left = is->end - is->ptr;
 		memcpy(is->buf, is->ptr, left);
 		is->end = is->buf + left;
 		is->ptr = is->buf;
-		left = camel_stream_read(is->source, (char *) is->end, CAMEL_NNTP_STREAM_SIZE - (is->end - is->buf));
+		left = camel_stream_read(is->source, (gchar *) is->end, CAMEL_NNTP_STREAM_SIZE - (is->end - is->buf));
 		if (left > 0) {
 			is->end += left;
 			is->end[0] = '\n';
@@ -74,13 +74,13 @@ stream_fill(CamelNNTPStream *is)
 	return 0;
 }
 
-static ssize_t
-stream_read(CamelStream *stream, char *buffer, size_t n)
+static gssize
+stream_read(CamelStream *stream, gchar *buffer, gsize n)
 {
 	CamelNNTPStream *is = (CamelNNTPStream *)stream;
-	char *o, *oe;
-	unsigned char *p, *e, c;
-	int state;
+	gchar *o, *oe;
+	guchar *p, *e, c;
+	gint state;
 
 	if (is->mode != CAMEL_NNTP_STREAM_DATA || n == 0)
 		return 0;
@@ -108,7 +108,7 @@ stream_read(CamelStream *stream, char *buffer, size_t n)
 				is->ptr = p+3;
 				is->mode = CAMEL_NNTP_STREAM_EOD;
 				is->state = 0;
-				dd(printf("NNTP_STREAM_READ(%d):\n%.*s\n", (int)(o-buffer), (int)(o-buffer), buffer));
+				dd(printf("NNTP_STREAM_READ(%d):\n%.*s\n", (gint)(o-buffer), (gint)(o-buffer), buffer));
 				return o-buffer;
 			}
 			p++;
@@ -141,27 +141,27 @@ stream_read(CamelStream *stream, char *buffer, size_t n)
 	is->ptr = p;
 	is->state = state;
 
-	dd(printf("NNTP_STREAM_READ(%d):\n%.*s\n", (int)(o-buffer), (int)(o-buffer), buffer));
+	dd(printf("NNTP_STREAM_READ(%d):\n%.*s\n", (gint)(o-buffer), (gint)(o-buffer), buffer));
 
 	return o-buffer;
 }
 
-static ssize_t
-stream_write(CamelStream *stream, const char *buffer, size_t n)
+static gssize
+stream_write(CamelStream *stream, const gchar *buffer, gsize n)
 {
 	CamelNNTPStream *is = (CamelNNTPStream *)stream;
 
 	return camel_stream_write(is->source, buffer, n);
 }
 
-static int
+static gint
 stream_close(CamelStream *stream)
 {
 	/* nop? */
 	return 0;
 }
 
-static int
+static gint
 stream_flush(CamelStream *stream)
 {
 	/* nop? */
@@ -176,7 +176,7 @@ stream_eos(CamelStream *stream)
 	return is->mode != CAMEL_NNTP_STREAM_DATA;
 }
 
-static int
+static gint
 stream_reset(CamelStream *stream)
 {
 	/* nop?  reset literal mode? */
@@ -263,12 +263,12 @@ camel_nntp_stream_new(CamelStream *source)
 }
 
 /* Get one line from the nntp stream */
-int
-camel_nntp_stream_line(CamelNNTPStream *is, unsigned char **data, unsigned int *len)
+gint
+camel_nntp_stream_line(CamelNNTPStream *is, guchar **data, guint *len)
 {
-	register unsigned char c, *p, *o, *oe;
-	int newlen, oldlen;
-	unsigned char *e;
+	register guchar c, *p, *o, *oe;
+	gint newlen, oldlen;
+	guchar *e;
 
 	if (is->mode == CAMEL_NNTP_STREAM_EOD) {
 		*data = is->linebuf;
@@ -348,10 +348,10 @@ camel_nntp_stream_line(CamelNNTPStream *is, unsigned char **data, unsigned int *
 }
 
 /* returns -1 on error, 0 if last lot of data, >0 if more remaining */
-int camel_nntp_stream_gets(CamelNNTPStream *is, unsigned char **start, unsigned int *len)
+gint camel_nntp_stream_gets(CamelNNTPStream *is, guchar **start, guint *len)
 {
-	int max;
-	unsigned char *end;
+	gint max;
+	guchar *end;
 
 	*len = 0;
 
@@ -370,7 +370,7 @@ int camel_nntp_stream_gets(CamelNNTPStream *is, unsigned char **start, unsigned
 	*len = max;
 	is->ptr += max;
 
-	dd(printf("NNTP_STREAM_GETS(%s,%d): '%.*s'\n", end==NULL?"more":"last", *len, (int)*len, *start));
+	dd(printf("NNTP_STREAM_GETS(%s,%d): '%.*s'\n", end==NULL?"more":"last", *len, (gint)*len, *start));
 
 	return end == NULL?1:0;
 }
@@ -381,10 +381,10 @@ void camel_nntp_stream_set_mode(CamelNNTPStream *is, camel_nntp_stream_mode_t mo
 }
 
 /* returns -1 on erorr, 0 if last data, >0 if more data left */
-int camel_nntp_stream_getd(CamelNNTPStream *is, unsigned char **start, unsigned int *len)
+gint camel_nntp_stream_getd(CamelNNTPStream *is, guchar **start, guint *len)
 {
-	unsigned char *p, *e, *s;
-	int state;
+	guchar *p, *e, *s;
+	gint state;
 
 	*len = 0;
 
@@ -422,7 +422,7 @@ int camel_nntp_stream_getd(CamelNNTPStream *is, unsigned char **start, unsigned
 					is->mode = CAMEL_NNTP_STREAM_EOD;
 					is->state = 0;
 
-					dd(printf("NNTP_STREAM_GETD(%s,%d): '%.*s'\n", "last", *len, (int)*len, *start));
+					dd(printf("NNTP_STREAM_GETD(%s,%d): '%.*s'\n", "last", *len, (gint)*len, *start));
 
 					return 0;
 				}
@@ -437,7 +437,7 @@ int camel_nntp_stream_getd(CamelNNTPStream *is, unsigned char **start, unsigned
 					*start = s;
 					is->state = 1;
 
-					dd(printf("NNTP_STREAM_GETD(%s,%d): '%.*s'\n", "more", *len, (int)*len, *start));
+					dd(printf("NNTP_STREAM_GETD(%s,%d): '%.*s'\n", "more", *len, (gint)*len, *start));
 
 					return 1;
 				}
@@ -462,7 +462,7 @@ int camel_nntp_stream_getd(CamelNNTPStream *is, unsigned char **start, unsigned
 	*len = p-s;
 	*start = s;
 
-	dd(printf("NNTP_STREAM_GETD(%s,%d): '%.*s'\n", "more", *len, (int)*len, *start));
+	dd(printf("NNTP_STREAM_GETD(%s,%d): '%.*s'\n", "more", *len, (gint)*len, *start));
 	return 1;
 }
 
