@@ -3,7 +3,7 @@
  * Author:
  *  Michael Zucchi <notzed@ximian.com>
  *
- * Copyright 1999, 2000 Ximian, Inc. (www.ximian.com)
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -40,8 +40,10 @@
    for the server to accept our data when pipelining */
 #define CAMEL_POP3_SEND_LIMIT (1024)
 
+extern CamelServiceAuthType camel_pop3_password_authtype;
+extern CamelServiceAuthType camel_pop3_apop_authtype;
 
-extern int camel_verbose_debug;
+extern gint camel_verbose_debug;
 #define dd(x) (camel_verbose_debug?(x):0)
 
 static void get_capabilities(CamelPOP3Engine *pe);
@@ -60,9 +62,9 @@ camel_pop3_engine_class_init (CamelPOP3EngineClass *camel_pop3_engine_class)
 static void
 camel_pop3_engine_init(CamelPOP3Engine *pe, CamelPOP3EngineClass *peclass)
 {
-	e_dlist_init(&pe->active);
-	e_dlist_init(&pe->queue);
-	e_dlist_init(&pe->done);
+	camel_dlist_init(&pe->active);
+	camel_dlist_init(&pe->queue);
+	camel_dlist_init(&pe->done);
 	pe->state = CAMEL_POP3_ENGINE_DISCONNECT;
 }
 
@@ -73,7 +75,7 @@ camel_pop3_engine_finalise(CamelPOP3Engine *pe)
 
 	if (pe->stream)
 		camel_object_unref(pe->stream);
-	
+
 	g_list_free(pe->auth);
 	if (pe->apop)
 		g_free(pe->apop);
@@ -98,29 +100,27 @@ camel_pop3_engine_get_type (void)
 	return camel_pop3_engine_type;
 }
 
-static int
+static gint
 read_greeting (CamelPOP3Engine *pe)
 {
-	extern CamelServiceAuthType camel_pop3_password_authtype;
-	extern CamelServiceAuthType camel_pop3_apop_authtype;
-	unsigned char *line, *apop, *apopend;
-	unsigned int len;
-	
+	guchar *line, *apop, *apopend;
+	guint len;
+
 	/* first, read the greeting */
 	if (camel_pop3_stream_line (pe->stream, &line, &len) == -1
-	    || strncmp ((char *) line, (char *) "+OK", 3) != 0)
+	    || strncmp ((gchar *) line, "+OK", 3) != 0)
 		return -1;
-	
-	if ((apop = (unsigned char *) strchr ((char *) line + 3, '<'))
-	    && (apopend = (unsigned char *) strchr ((char *) apop, '>'))) {
+
+	if ((apop = (guchar *) strchr ((gchar *) line + 3, '<'))
+	    && (apopend = (guchar *) strchr ((gchar *) apop, '>'))) {
 		apopend[1] = 0;
 		pe->apop = g_strdup ((gchar *) apop);
 		pe->capa = CAMEL_POP3_CAP_APOP;
 		pe->auth = g_list_append (pe->auth, &camel_pop3_apop_authtype);
 	}
-	
+
 	pe->auth = g_list_prepend (pe->auth, &camel_pop3_password_authtype);
-	
+
 	return 0;
 }
 
@@ -144,14 +144,14 @@ camel_pop3_engine_new(CamelStream *source, guint32 flags)
 	pe->stream = (CamelPOP3Stream *)camel_pop3_stream_new(source);
 	pe->state = CAMEL_POP3_ENGINE_AUTH;
 	pe->flags = flags;
-	
+
 	if (read_greeting (pe) == -1) {
 		camel_object_unref (pe);
 		return NULL;
 	}
-	
+
 	get_capabilities (pe);
-	
+
 	return pe;
 }
 
@@ -166,7 +166,7 @@ void
 camel_pop3_engine_reget_capabilities (CamelPOP3Engine *engine)
 {
 	g_return_if_fail (CAMEL_IS_POP3_ENGINE (engine));
-	
+
 	get_capabilities (engine);
 }
 
@@ -174,7 +174,7 @@ camel_pop3_engine_reget_capabilities (CamelPOP3Engine *engine)
 /* TODO: read implementation too?
    etc? */
 static struct {
-	char *cap;
+	const gchar *cap;
 	guint32 flag;
 } capa[] = {
 	{ "APOP" , CAMEL_POP3_CAP_APOP },
@@ -185,12 +185,12 @@ static struct {
 };
 
 static void
-cmd_capa(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
+cmd_capa(CamelPOP3Engine *pe, CamelPOP3Stream *stream, gpointer data)
 {
-	unsigned char *line, *tok, *next;
-	unsigned int len;
-	int ret;
-	int i;
+	guchar *line, *tok, *next;
+	guint len;
+	gint ret;
+	gint i;
 	CamelServiceAuthType *auth;
 
 	dd(printf("cmd_capa\n"));
@@ -198,14 +198,14 @@ cmd_capa(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
 	do {
 		ret = camel_pop3_stream_line(stream, &line, &len);
 		if (ret >= 0) {
-			if (strncmp((char *) line, "SASL ", 5) == 0) {
+			if (strncmp((gchar *) line, "SASL ", 5) == 0) {
 				tok = line+5;
 				dd(printf("scanning tokens '%s'\n", tok));
 				while (tok) {
-					next = (unsigned char *) strchr((char *) tok, ' ');
+					next = (guchar *) strchr((gchar *) tok, ' ');
 					if (next)
 						*next++ = 0;
-					auth = camel_sasl_authtype((const char *)tok);
+					auth = camel_sasl_authtype((const gchar *) tok);
 					if (auth) {
 						dd(printf("got auth type '%s'\n", tok));
 						pe->auth = g_list_prepend(pe->auth, auth);
@@ -216,7 +216,7 @@ cmd_capa(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
 				}
 			} else {
 				for (i=0;i<sizeof(capa)/sizeof(capa[0]);i++) {
-					if (strcmp((char *) capa[i].cap, (char *) line) == 0)
+					if (strcmp((gchar *) capa[i].cap, (gchar *) line) == 0)
 						pe->capa |= capa[i].flag;
 				}
 			}
@@ -228,61 +228,61 @@ static void
 get_capabilities(CamelPOP3Engine *pe)
 {
 	CamelPOP3Command *pc;
-	
+
 	if (!(pe->flags & CAMEL_POP3_ENGINE_DISABLE_EXTENSIONS)) {
 		pc = camel_pop3_engine_command_new(pe, CAMEL_POP3_COMMAND_MULTI, cmd_capa, NULL, "CAPA\r\n");
 		while (camel_pop3_engine_iterate(pe, pc) > 0)
 			;
 		camel_pop3_engine_command_free(pe, pc);
-		
+
 		if (pe->state == CAMEL_POP3_ENGINE_TRANSACTION && !(pe->capa & CAMEL_POP3_CAP_UIDL)) {
 			/* check for UIDL support manually */
 			pc = camel_pop3_engine_command_new (pe, CAMEL_POP3_COMMAND_SIMPLE, NULL, NULL, "UIDL 1\r\n");
 			while (camel_pop3_engine_iterate (pe, pc) > 0)
 				;
-			
+
 			if (pc->state == CAMEL_POP3_COMMAND_OK)
 				pe->capa |= CAMEL_POP3_CAP_UIDL;
-			
+
 			camel_pop3_engine_command_free (pe, pc);
 		}
 	}
 }
 
 /* returns true if the command was sent, false if it was just queued */
-static int
+static gint
 engine_command_queue(CamelPOP3Engine *pe, CamelPOP3Command *pc)
 {
 	if (((pe->capa & CAMEL_POP3_CAP_PIPE) == 0 || (pe->sentlen + strlen(pc->data)) > CAMEL_POP3_SEND_LIMIT)
 	    && pe->current != NULL) {
-		e_dlist_addtail(&pe->queue, (EDListNode *)pc);
+		camel_dlist_addtail(&pe->queue, (CamelDListNode *)pc);
 		return FALSE;
-	} else {
-		/* ??? */
-		if (camel_stream_write((CamelStream *)pe->stream, pc->data, strlen(pc->data)) == -1) {
-			e_dlist_addtail(&pe->queue, (EDListNode *)pc);
-			return FALSE;
-		}
-
-		pe->sentlen += strlen(pc->data);
-
-		pc->state = CAMEL_POP3_COMMAND_DISPATCHED;
-
-		if (pe->current == NULL)
-			pe->current = pc;
-		else
-			e_dlist_addtail(&pe->active, (EDListNode *)pc);
-
-		return TRUE;
 	}
+
+	/* ??? */
+	if (camel_stream_write((CamelStream *)pe->stream, pc->data, strlen(pc->data)) == -1) {
+		camel_dlist_addtail(&pe->queue, (CamelDListNode *)pc);
+		return FALSE;
+	}
+
+	pe->sentlen += strlen(pc->data);
+
+	pc->state = CAMEL_POP3_COMMAND_DISPATCHED;
+
+	if (pe->current == NULL)
+		pe->current = pc;
+	else
+		camel_dlist_addtail(&pe->active, (CamelDListNode *)pc);
+
+	return TRUE;
 }
 
 /* returns -1 on error (sets errno), 0 when no work to do, or >0 if work remaining */
-int
+gint
 camel_pop3_engine_iterate(CamelPOP3Engine *pe, CamelPOP3Command *pcwait)
 {
-	unsigned char *p;
-	unsigned int len;
+	guchar *p;
+	guint len;
 	CamelPOP3Command *pc, *pw, *pn;
 
 	if (pcwait && pcwait->state >= CAMEL_POP3_COMMAND_OK)
@@ -326,15 +326,16 @@ camel_pop3_engine_iterate(CamelPOP3Engine *pe, CamelPOP3Command *pcwait)
 		break;
 	}
 
-	e_dlist_addtail(&pe->done, (EDListNode *)pc);
+	camel_dlist_addtail(&pe->done, (CamelDListNode *)pc);
 	pe->sentlen -= strlen(pc->data);
 
 	/* Set next command */
-	pe->current = (CamelPOP3Command *)e_dlist_remhead(&pe->active);
-	
+	pe->current = (CamelPOP3Command *)camel_dlist_remhead(&pe->active);
+
 	/* check the queue for sending any we can now send also */
 	pw = (CamelPOP3Command *)pe->queue.head;
 	pn = pw->next;
+
 	while (pn) {
 		if (((pe->capa & CAMEL_POP3_CAP_PIPE) == 0 || (pe->sentlen + strlen(pw->data)) > CAMEL_POP3_SEND_LIMIT)
 		    && pe->current != NULL)
@@ -343,7 +344,7 @@ camel_pop3_engine_iterate(CamelPOP3Engine *pe, CamelPOP3Command *pcwait)
 		if (camel_stream_write((CamelStream *)pe->stream, pw->data, strlen(pw->data)) == -1)
 			goto ioerror;
 
-		e_dlist_remove((EDListNode *)pw);
+		camel_dlist_remove((CamelDListNode *)pw);
 
 		pe->sentlen += strlen(pw->data);
 		pw->state = CAMEL_POP3_COMMAND_DISPATCHED;
@@ -351,7 +352,7 @@ camel_pop3_engine_iterate(CamelPOP3Engine *pe, CamelPOP3Command *pcwait)
 		if (pe->current == NULL)
 			pe->current = pw;
 		else
-			e_dlist_addtail(&pe->active, (EDListNode *)pw);
+			camel_dlist_addtail(&pe->active, (CamelDListNode *)pw);
 
 		pw = pn;
 		pn = pn->next;
@@ -365,19 +366,19 @@ camel_pop3_engine_iterate(CamelPOP3Engine *pe, CamelPOP3Command *pcwait)
 	return pe->current==NULL?0:1;
 ioerror:
 	/* we assume all outstanding commands are gunna fail now */
-	while ( (pw = (CamelPOP3Command*)e_dlist_remhead(&pe->active)) ) {
+	while ( (pw = (CamelPOP3Command*)camel_dlist_remhead(&pe->active)) ) {
 		pw->state = CAMEL_POP3_COMMAND_ERR;
-		e_dlist_addtail(&pe->done, (EDListNode *)pw);
+		camel_dlist_addtail(&pe->done, (CamelDListNode *)pw);
 	}
 
-	while ( (pw = (CamelPOP3Command*)e_dlist_remhead(&pe->queue)) ) {
+	while ( (pw = (CamelPOP3Command*)camel_dlist_remhead(&pe->queue)) ) {
 		pw->state = CAMEL_POP3_COMMAND_ERR;
-		e_dlist_addtail(&pe->done, (EDListNode *)pw);
+		camel_dlist_addtail(&pe->done, (CamelDListNode *)pw);
 	}
 
 	if (pe->current) {
 		pe->current->state = CAMEL_POP3_COMMAND_ERR;
-		e_dlist_addtail(&pe->done, (EDListNode *)pe->current);
+		camel_dlist_addtail(&pe->done, (CamelDListNode *)pe->current);
 		pe->current = NULL;
 	}
 
@@ -385,7 +386,7 @@ ioerror:
 }
 
 CamelPOP3Command *
-camel_pop3_engine_command_new(CamelPOP3Engine *pe, guint32 flags, CamelPOP3CommandFunc func, void *data, const char *fmt, ...)
+camel_pop3_engine_command_new(CamelPOP3Engine *pe, guint32 flags, CamelPOP3CommandFunc func, gpointer data, const gchar *fmt, ...)
 {
 	CamelPOP3Command *pc;
 	va_list ap;
@@ -394,7 +395,7 @@ camel_pop3_engine_command_new(CamelPOP3Engine *pe, guint32 flags, CamelPOP3Comma
 	pc->func = func;
 	pc->func_data = data;
 	pc->flags = flags;
-	
+
 	va_start(ap, fmt);
 	pc->data = g_strdup_vprintf(fmt, ap);
 	pc->state = CAMEL_POP3_COMMAND_IDLE;
@@ -409,7 +410,7 @@ void
 camel_pop3_engine_command_free(CamelPOP3Engine *pe, CamelPOP3Command *pc)
 {
 	if (pe->current != pc)
-		e_dlist_remove((EDListNode *)pc);
+		camel_dlist_remove((CamelDListNode *)pc);
 	g_free(pc->data);
 	g_free(pc);
 }
