@@ -39,14 +39,6 @@ typedef struct _ESExpSymbol ESExpSymbol;
 typedef struct _ESExpResult ESExpResult;
 typedef struct _ESExpTerm ESExpTerm;
 
-typedef struct _ESExpResult *(ESExpFunc)(struct _ESExp *sexp, int argc,
-					 struct _ESExpResult **argv,
-					 void *data);
-
-typedef struct _ESExpResult *(ESExpIFunc)(struct _ESExp *sexp, int argc,
-					  struct _ESExpTerm **argv,
-					  void *data);
-
 enum _ESExpResultType {
 	ESEXP_RES_ARRAY_PTR=0,	/* type is a ptrarray, what it points to is implementation dependant */
 	ESEXP_RES_INT,		/* type is a number */
@@ -60,13 +52,21 @@ struct _ESExpResult {
 	enum _ESExpResultType type;
 	union {
 		GPtrArray *ptrarray;
-		int number;
-		char *string;
-		int bool;
+		gint number;
+		gchar *string;
+		gint bool;
 		time_t time;
 	} value;
 };
 
+typedef struct _ESExpResult *(ESExpFunc)(struct _ESExp *sexp, gint argc,
+					 struct _ESExpResult **argv,
+					 gpointer data);
+
+typedef struct _ESExpResult *(ESExpIFunc)(struct _ESExp *sexp, gint argc,
+					  struct _ESExpTerm **argv,
+					  gpointer data);
+
 enum _ESExpTermType {
 	ESEXP_TERM_INT	= 0,	/* integer literal */
 	ESEXP_TERM_BOOL,	/* boolean literal */
@@ -74,13 +74,13 @@ enum _ESExpTermType {
 	ESEXP_TERM_TIME,	/* time_t literal (number of seconds past the epoch) */
 	ESEXP_TERM_FUNC,	/* normal function, arguments are evaluated before calling */
 	ESEXP_TERM_IFUNC,	/* immediate function, raw terms are arguments */
-	ESEXP_TERM_VAR,		/* variable reference */
+	ESEXP_TERM_VAR		/* variable reference */
 };
 
 struct _ESExpSymbol {
-	int type;		/* ESEXP_TERM_FUNC or ESEXP_TERM_VAR */
-	char *name;
-	void *data;
+	gint type;		/* ESEXP_TERM_FUNC or ESEXP_TERM_VAR */
+	gchar *name;
+	gpointer data;
 	union {
 		ESExpFunc *func;
 		ESExpIFunc *ifunc;
@@ -90,14 +90,14 @@ struct _ESExpSymbol {
 struct _ESExpTerm {
 	enum _ESExpTermType type;
 	union {
-		char *string;
-		int number;
-		int bool;
+		gchar *string;
+		gint number;
+		gint bool;
 		time_t time;
 		struct {
 			struct _ESExpSymbol *sym;
 			struct _ESExpTerm **terms;
-			int termcount;
+			gint termcount;
 		} func;
 		struct _ESExpSymbol *var;
 	} value;
@@ -109,15 +109,16 @@ struct _ESExp {
 #ifdef E_SEXP_IS_G_OBJECT
 	GObject parent_object;
 #else
-	int refcount;
+	gint refcount;
 #endif
 	GScanner *scanner;	/* for parsing text version */
 	ESExpTerm *tree;	/* root of expression tree */
-	
+
 	/* private stuff */
 	jmp_buf failenv;
-	char *error;
-	
+	gchar *error;
+	GSList *operators;
+
 	/* TODO: may also need a pool allocator for term strings, so we dont lose them
 	   in error conditions? */
 	struct _EMemChunk *term_chunks;
@@ -128,14 +129,14 @@ struct _ESExpClass {
 #ifdef E_SEXP_IS_G_OBJECT
 	GObjectClass parent_class;
 #else
-	int dummy;
+	gint dummy;
 #endif
 };
 
 #ifdef E_SEXP_IS_G_OBJECT
 GType           e_sexp_get_type		(void);
 #endif
-ESExp 	       *e_sexp_new		(void);
+ESExp	       *e_sexp_new		(void);
 #ifdef E_SEXP_IS_G_OBJECT
 #define         e_sexp_ref(f)           g_object_ref (f)
 #define         e_sexp_unref(f)         g_object_unref (f)
@@ -143,35 +144,37 @@ ESExp 	       *e_sexp_new		(void);
 void		e_sexp_ref		(ESExp *f);
 void		e_sexp_unref		(ESExp *f);
 #endif
-void		e_sexp_add_function  	(ESExp *f, int scope, char *name, ESExpFunc *func, void *data);
-void		e_sexp_add_ifunction  	(ESExp *f, int scope, char *name, ESExpIFunc *func, void *data);
-void		e_sexp_add_variable  	(ESExp *f, int scope, char *name, ESExpTerm *value);
-void		e_sexp_remove_symbol	(ESExp *f, int scope, char *name);
-int		e_sexp_set_scope	(ESExp *f, int scope);
+void		e_sexp_add_function	(ESExp *f, gint scope, const gchar *name, ESExpFunc *func, gpointer data);
+void		e_sexp_add_ifunction	(ESExp *f, gint scope, const gchar *name, ESExpIFunc *func, gpointer data);
+void		e_sexp_add_variable	(ESExp *f, gint scope, gchar *name, ESExpTerm *value);
+void		e_sexp_remove_symbol	(ESExp *f, gint scope, const gchar *name);
+gint		e_sexp_set_scope	(ESExp *f, gint scope);
 
-void		e_sexp_input_text	(ESExp *f, const char *text, int len);
-void		e_sexp_input_file	(ESExp *f, int fd);
+void		e_sexp_input_text	(ESExp *f, const gchar *text, gint len);
+void		e_sexp_input_file	(ESExp *f, gint fd);
 
 
-int		e_sexp_parse		(ESExp *f);
+gint		e_sexp_parse		(ESExp *f);
 ESExpResult    *e_sexp_eval		(ESExp *f);
 
 ESExpResult    *e_sexp_term_eval	(struct _ESExp *f, struct _ESExpTerm *t);
-ESExpResult    *e_sexp_result_new	(struct _ESExp *f, int type);
+ESExpResult    *e_sexp_result_new	(struct _ESExp *f, gint type);
 void		e_sexp_result_free	(struct _ESExp *f, struct _ESExpResult *t);
 
 /* used in normal functions if they have to abort, to free their arguments */
-void		e_sexp_resultv_free	(struct _ESExp *f, int argc, struct _ESExpResult **argv);
+void		e_sexp_resultv_free	(struct _ESExp *f, gint argc, struct _ESExpResult **argv);
 
 /* utility functions for creating s-exp strings. */
 void		e_sexp_encode_bool	(GString *s, gboolean state);
-void		e_sexp_encode_string	(GString *s, const char *string);
+void		e_sexp_encode_string	(GString *s, const gchar *string);
 
 /* only to be called from inside a callback to signal a fatal execution error */
-void		e_sexp_fatal_error	(struct _ESExp *f, char *why, ...);
+void		e_sexp_fatal_error	(struct _ESExp *f, const gchar *why, ...) G_GNUC_NORETURN;
 
 /* return the error string */
-const char     *e_sexp_error		(struct _ESExp *f);
+const gchar     *e_sexp_error		(struct _ESExp *f);
+
+ESExpTerm * e_sexp_parse_value(ESExp *f);
 
 G_END_DECLS
 
