@@ -63,36 +63,36 @@ GType    e_source_list_get_type (void);
 
 ESourceList *e_source_list_new            (void);
 ESourceList *e_source_list_new_for_gconf  (GConfClient *client,
-					   const char  *path);
-ESourceList *e_source_list_new_for_gconf_default  (const char  *path);
+					   const gchar  *path);
+ESourceList *e_source_list_new_for_gconf_default  (const gchar  *path);
 
 GSList       *e_source_list_peek_groups         (ESourceList *list);
 ESourceGroup *e_source_list_peek_group_by_uid   (ESourceList *list,
-						 const char  *uid);
+						 const gchar  *uid);
 #ifndef EDS_DISABLE_DEPRECATED
 ESourceGroup *e_source_list_peek_group_by_name  (ESourceList *list,
-						 const char *name);
+						 const gchar *name);
 #endif
-ESourceGroup *e_source_list_peek_group_by_base_uri (ESourceList *list, const char *base_uri);
-ESourceGroup *e_source_list_peek_group_by_properties (ESourceList *list, const char *property_name, ...);
+ESourceGroup *e_source_list_peek_group_by_base_uri (ESourceList *list, const gchar *base_uri);
+ESourceGroup *e_source_list_peek_group_by_properties (ESourceList *list, const gchar *property_name, ...);
 
 ESource      *e_source_list_peek_source_by_uid  (ESourceList *list,
-						 const char  *uid);
+						 const gchar  *uid);
 ESource      *e_source_list_peek_source_any     (ESourceList *list);
 
 gboolean  e_source_list_add_group             (ESourceList  *list,
 					       ESourceGroup *group,
-					       int           position);
+					       gint           position);
 gboolean  e_source_list_remove_group          (ESourceList  *list,
 					       ESourceGroup *group);
 gboolean  e_source_list_remove_group_by_uid   (ESourceList  *list,
-					       const char   *uid);
+					       const gchar   *uid);
 
-ESourceGroup *e_source_list_ensure_group (ESourceList *list, const char *name, const char *base_uri, gboolean ret_it);
-gboolean e_source_list_remove_group_by_base_uri (ESourceList *list, const char *base_uri);
+ESourceGroup *e_source_list_ensure_group (ESourceList *list, const gchar *name, const gchar *base_uri, gboolean ret_it);
+gboolean e_source_list_remove_group_by_base_uri (ESourceList *list, const gchar *base_uri);
 
 gboolean  e_source_list_remove_source_by_uid  (ESourceList  *list,
-					       const char   *uidj);
+					       const gchar   *uidj);
 
 gboolean  e_source_list_sync  (ESourceList  *list,
 			       GError      **error);
