@@ -36,10 +36,10 @@
 struct _ESourcePrivate {
 	ESourceGroup *group;
 
-	char *uid;
-	char *name;
-	char *relative_uri;
-	char *absolute_uri;
+	gchar *uid;
+	gchar *name;
+	gchar *relative_uri;
+	gchar *absolute_uri;
 
 	gboolean readonly;
 
@@ -55,7 +55,7 @@ enum {
 	CHANGED,
 	LAST_SIGNAL
 };
-static unsigned int signals[LAST_SIGNAL] = { 0 };
+static guint signals[LAST_SIGNAL] = { 0 };
 
 
 /* Callbacks.  */
@@ -72,7 +72,7 @@ group_weak_notify (ESource *source,
 
 /* GObject methods.  */
 
-G_DEFINE_TYPE (ESource, e_source, G_TYPE_OBJECT);
+G_DEFINE_TYPE (ESource, e_source, G_TYPE_OBJECT)
 
 static void
 impl_finalize (GObject *object)
@@ -163,8 +163,8 @@ set_color_spec (ESource *source,
 /* Public methods.  */
 
 ESource *
-e_source_new  (const char *name,
-	       const char *relative_uri)
+e_source_new  (const gchar *name,
+	       const gchar *relative_uri)
 {
 	ESource *source;
 
@@ -180,8 +180,8 @@ e_source_new  (const char *name,
 }
 
 ESource *
-e_source_new_with_absolute_uri (const char *name,
-				const char *absolute_uri)
+e_source_new_with_absolute_uri (const gchar *name,
+				const gchar *absolute_uri)
 {
 	ESource *source;
 
@@ -208,7 +208,7 @@ e_source_new_from_xml_node (xmlNodePtr node)
 
 	source = g_object_new (e_source_get_type (), NULL);
 
-	source->priv->uid = g_strdup ((char*)uid);
+	source->priv->uid = g_strdup ((gchar *)uid);
 	xmlFree (uid);
 
 	if (e_source_update_from_xml_node (source, node, NULL))
@@ -228,14 +228,14 @@ import_properties (ESource *source,
 	for (prop_node = prop_root->children; prop_node; prop_node = prop_node->next) {
 		xmlChar *name, *value;
 
-		if (!prop_node->name || strcmp ((char*)prop_node->name, "property"))
+		if (!prop_node->name || strcmp ((gchar *)prop_node->name, "property"))
 			continue;
 
 		name = xmlGetProp (prop_node, (xmlChar*)"name");
 		value = xmlGetProp (prop_node, (xmlChar*)"value");
 
 		if (name && value)
-			g_hash_table_insert (priv->properties, g_strdup ((char*)name), g_strdup ((char*)value));
+			g_hash_table_insert (priv->properties, g_strdup ((gchar *)name), g_strdup ((gchar *)value));
 
 		if (name)
 			xmlFree (name);
@@ -308,28 +308,43 @@ e_source_update_from_xml_node (ESource *source,
 		goto done;
 
 	if (source->priv->name == NULL
-	    || strcmp ((char*)name, source->priv->name) != 0
+	    || strcmp ((gchar *)name, source->priv->name) != 0
 	    || source->priv->relative_uri == NULL
-	    || relative_uri != NULL
-	    || strcmp ((char*)relative_uri, source->priv->relative_uri) != 0) {
+	    || relative_uri == NULL
+	    || strcmp ((gchar *)relative_uri, source->priv->relative_uri) != 0) {
 		g_free (source->priv->name);
-		source->priv->name = g_strdup ((char*)name);
+		source->priv->name = g_strdup ((gchar *)name);
+
+		if (source->priv->group) {
+			/* reset the absolute uri to NULL to be regenerated when asked for */
+			g_free (source->priv->absolute_uri);
+			source->priv->absolute_uri = NULL;
+		} else if (source->priv->absolute_uri &&
+			   source->priv->relative_uri &&
+			   g_str_has_suffix (source->priv->absolute_uri, source->priv->relative_uri)) {
+			gchar *tmp = source->priv->absolute_uri;
+
+			tmp [strlen (tmp) - strlen (source->priv->relative_uri)] = 0;
+			source->priv->absolute_uri = g_strconcat (tmp, (gchar *)relative_uri, NULL);
+
+			g_free (tmp);
+		}
 
 		g_free (source->priv->relative_uri);
-		source->priv->relative_uri = g_strdup ((char*)relative_uri);
+		source->priv->relative_uri = g_strdup ((gchar *)relative_uri);
 
 		changed = TRUE;
 	}
 
 	if (absolute_uri != NULL) {
 		g_free (source->priv->absolute_uri);
-		source->priv->absolute_uri = g_strdup ((char*)absolute_uri);
+		source->priv->absolute_uri = g_strdup ((gchar *)absolute_uri);
 		changed = TRUE;
 	}
 
 	if (color == NULL) {
 		/* It is okay for color_spec to be NULL. */
-		changed |= set_color_spec (source, (char*)color_spec);
+		changed |= set_color_spec (source, (gchar *)color_spec);
 	} else {
 		gchar buffer[8];
 		g_snprintf (buffer, sizeof (buffer), "#%s", color);
@@ -347,7 +362,7 @@ e_source_update_from_xml_node (ESource *source,
 		if (!node->name)
 			continue;
 
-		if (!strcmp ((char*)node->name, "properties")) {
+		if (!strcmp ((gchar *)node->name, "properties")) {
 			GHashTable *temp = source->priv->properties;
 			source->priv->properties = g_hash_table_new_full (g_str_hash, g_str_equal,
 									  g_free, g_free);
@@ -392,21 +407,21 @@ e_source_update_from_xml_node (ESource *source,
  * Return value: Name of the source in the specified @node.  The caller must
  * free the string.
  **/
-char *
+gchar *
 e_source_uid_from_xml_node (xmlNodePtr node)
 {
 	xmlChar *uid = xmlGetProp (node, (xmlChar*)"uid");
-	char *retval;
+	gchar *retval;
 
 	if (uid == NULL)
 		return NULL;
 
-	retval = g_strdup ((char*)uid);
+	retval = g_strdup ((gchar *)uid);
 	xmlFree (uid);
 	return retval;
 }
 
-char *
+gchar *
 e_source_build_absolute_uri (ESource *source)
 {
 	const gchar *base_uri_str;
@@ -461,7 +476,7 @@ e_source_set_group (ESource *source,
 
 void
 e_source_set_name (ESource *source,
-		   const char *name)
+		   const gchar *name)
 {
 	g_return_if_fail (E_IS_SOURCE (source));
 	g_return_if_fail (name != NULL);
@@ -481,9 +496,9 @@ e_source_set_name (ESource *source,
 
 void
 e_source_set_relative_uri (ESource *source,
-			   const char *relative_uri)
+			   const gchar *relative_uri)
 {
-	char *absolute_uri;
+	gchar *absolute_uri;
 
 	g_return_if_fail (E_IS_SOURCE (source));
 
@@ -508,7 +523,7 @@ e_source_set_relative_uri (ESource *source,
 
 void
 e_source_set_absolute_uri (ESource *source,
-			   const char *absolute_uri)
+			   const gchar *absolute_uri)
 {
 	g_return_if_fail (E_IS_SOURCE (source));
 
@@ -572,7 +587,7 @@ e_source_unset_color (ESource *source)
  **/
 void
 e_source_set_color_spec (ESource *source,
-		         const gchar *color_spec)
+			 const gchar *color_spec)
 {
 	g_return_if_fail (E_IS_SOURCE (source));
 
@@ -588,7 +603,7 @@ e_source_peek_group (ESource *source)
 	return source->priv->group;
 }
 
-const char *
+const gchar *
 e_source_peek_uid (ESource *source)
 {
 	g_return_val_if_fail (E_IS_SOURCE (source), NULL);
@@ -596,7 +611,7 @@ e_source_peek_uid (ESource *source)
 	return source->priv->uid;
 }
 
-const char *
+const gchar *
 e_source_peek_name (ESource *source)
 {
 	g_return_val_if_fail (E_IS_SOURCE (source), NULL);
@@ -604,7 +619,7 @@ e_source_peek_name (ESource *source)
 	return source->priv->name;
 }
 
-const char *
+const gchar *
 e_source_peek_relative_uri (ESource *source)
 {
 	g_return_val_if_fail (E_IS_SOURCE (source), NULL);
@@ -612,7 +627,7 @@ e_source_peek_relative_uri (ESource *source)
 	return source->priv->relative_uri;
 }
 
-const char *
+const gchar *
 e_source_peek_absolute_uri (ESource *source)
 {
 	g_return_val_if_fail (E_IS_SOURCE (source), NULL);
@@ -631,7 +646,7 @@ e_source_peek_absolute_uri (ESource *source)
  *
  * Since: 1.10
  **/
-const char *
+const gchar *
 e_source_peek_color_spec (ESource *source)
 {
 	g_return_val_if_fail (E_IS_SOURCE (source), NULL);
@@ -684,7 +699,7 @@ e_source_get_color (ESource *source,
 }
 #endif
 
-char *
+gchar *
 e_source_get_uri (ESource *source)
 {
 	g_return_val_if_fail (E_IS_SOURCE (source), NULL);
@@ -720,7 +735,7 @@ dump_common_to_xml_node (ESource *source,
 {
 	ESourcePrivate *priv;
 	xmlNodePtr node;
-	const char *abs_uri = NULL, *relative_uri = NULL;
+	const gchar *abs_uri = NULL, *relative_uri = NULL;
 
 	priv = source->priv;
 
@@ -762,14 +777,14 @@ e_source_dump_to_xml_node (ESource *source,
 }
 
 
-char *
+gchar *
 e_source_to_standalone_xml (ESource *source)
 {
 	xmlDocPtr doc;
 	xmlNodePtr node;
 	xmlChar *xml_buffer;
-	char *returned_buffer;
-	int xml_buffer_size;
+	gchar *returned_buffer;
+	gint xml_buffer_size;
 	gchar *uri;
 
 	g_return_val_if_fail (E_IS_SOURCE (source), NULL);
@@ -801,53 +816,53 @@ e_source_to_standalone_xml (ESource *source)
  *
  * Compares if @a is equivalent to @b.
  *
- * Return value: %TRUE if @a is equivalent to @b, 
+ * Return value: %TRUE if @a is equivalent to @b,
  * %FALSE otherwise.
  **/
-gboolean 
+gboolean
 e_source_equal (ESource *a, ESource *b)
 {
-	g_return_val_if_fail (E_IS_SOURCE (a), FALSE); 
-	g_return_val_if_fail (E_IS_SOURCE (b), FALSE); 
+	g_return_val_if_fail (E_IS_SOURCE (a), FALSE);
+	g_return_val_if_fail (E_IS_SOURCE (b), FALSE);
 
 	#define ONLY_ONE_NULL(aa, bb) (((aa) == NULL && (bb) != NULL) || ((aa) != NULL && (bb) == NULL))
 
 	/* Compare source stuff */
-	if (a->priv->uid 
-	 && b->priv->uid 
+	if (a->priv->uid
+	 && b->priv->uid
 	 && g_ascii_strcasecmp (a->priv->uid, b->priv->uid))
-		return FALSE; 
+		return FALSE;
 
-	if (a->priv->name 
-	 && b->priv->name 
+	if (a->priv->name
+	 && b->priv->name
 	 && g_ascii_strcasecmp (a->priv->name, b->priv->name))
-		return FALSE; 
+		return FALSE;
 
-	if (a->priv->relative_uri 
-	 && b->priv->relative_uri 
+	if (a->priv->relative_uri
+	 && b->priv->relative_uri
 	 && g_ascii_strcasecmp (a->priv->relative_uri, b->priv->relative_uri))
-		return FALSE; 
+		return FALSE;
 
-	if (a->priv->absolute_uri 
-	 && b->priv->absolute_uri 
+	if (a->priv->absolute_uri
+	 && b->priv->absolute_uri
 	 && g_ascii_strcasecmp (a->priv->absolute_uri, b->priv->absolute_uri))
-		return FALSE; 
+		return FALSE;
 
-	if ((a->priv->color_spec 
-	 && b->priv->color_spec 
+	if ((a->priv->color_spec
+	 && b->priv->color_spec
 	 && g_ascii_strcasecmp (a->priv->color_spec, b->priv->color_spec)) ||
 	 (ONLY_ONE_NULL (a->priv->color_spec, b->priv->color_spec)))
-		return FALSE; 
+		return FALSE;
 
 	if (a->priv->readonly != b->priv->readonly)
-		return FALSE; 
+		return FALSE;
 
 	if (!compare_str_hashes (a->priv->properties, b->priv->properties))
-		return FALSE; 
+		return FALSE;
 
 	#undef ONLY_ONE_NULL
 
-	return TRUE; 
+	return TRUE;
 }
 
 /**
@@ -857,28 +872,28 @@ e_source_equal (ESource *a, ESource *b)
  *
  * Compares if @a is equivalent to @b.
  *
- * Return value: %TRUE if @a is equivalent to @b, 
+ * Return value: %TRUE if @a is equivalent to @b,
  * %FALSE otherwise.
  **/
-gboolean 
+gboolean
 e_source_xmlstr_equal (const gchar *a, const gchar *b)
 {
-	ESource *srca, *srcb; 
-	gboolean retval; 
+	ESource *srca, *srcb;
+	gboolean retval;
 
-	srca = e_source_new_from_standalone_xml (a); 
-	srcb = e_source_new_from_standalone_xml (b); 
+	srca = e_source_new_from_standalone_xml (a);
+	srcb = e_source_new_from_standalone_xml (b);
 
-	retval = e_source_equal (srca, srcb); 
+	retval = e_source_equal (srca, srcb);
 
-	g_object_unref (srca); 
-	g_object_unref (srcb); 
+	g_object_unref (srca);
+	g_object_unref (srcb);
 
-	return retval; 
+	return retval;
 }
 
 ESource *
-e_source_new_from_standalone_xml (const char *xml)
+e_source_new_from_standalone_xml (const gchar *xml)
 {
 	xmlDocPtr doc;
 	xmlNodePtr root;
@@ -889,7 +904,7 @@ e_source_new_from_standalone_xml (const char *xml)
 		return NULL;
 
 	root = doc->children;
-	if (strcmp ((char*)root->name, "source") != 0)
+	if (strcmp ((gchar *)root->name, "source") != 0)
 		return NULL;
 
 	source = e_source_new_from_xml_node (root);
@@ -911,15 +926,15 @@ e_source_get_property (ESource *source,
 	return g_hash_table_lookup (priv->properties, property);
 }
 
-char *
-e_source_get_duped_property (ESource *source, const char *property)
+gchar *
+e_source_get_duped_property (ESource *source, const gchar *property)
 {
 	ESourcePrivate *priv;
 
 	g_return_val_if_fail (E_IS_SOURCE (source), NULL);
 	priv = source->priv;
 
- 	return g_strdup (g_hash_table_lookup (priv->properties, property));
+	return g_strdup (g_hash_table_lookup (priv->properties, property));
 }
 
 void
