@@ -41,10 +41,10 @@
 #include <windows.h>
 
 static const gchar *
-get_locale_string (int lctype)
+get_locale_string (gint lctype)
 {
-	int nbytes = GetLocaleInfo (GetThreadLocale (), lctype, NULL, 0);
-	char *tem;
+	gint nbytes = GetLocaleInfo (GetThreadLocale (), lctype, NULL, 0);
+	gchar *tem;
 	GQuark quark;
 
 	if (nbytes == 0)
@@ -63,15 +63,15 @@ get_locale_string (int lctype)
 	return g_quark_to_string (quark);
 }
 
-static const char *
-translate_picture (const char *picture)
+static const gchar *
+translate_picture (const gchar *picture)
 {
 	GString *s = g_string_new ("");
 	GQuark quark;
 
 	while (*picture) {
-		const char *q = picture + 1;
-		int count;
+		const gchar *q = picture + 1;
+		gint count;
 
 		while (*picture == *q)
 			q++;
@@ -238,8 +238,8 @@ localtime_r (t, tp)
 #define match_char(ch1, ch2) if (ch1 != ch2) return NULL
 #if defined _LIBC && defined __GNUC__ && __GNUC__ >= 2
 # define match_string(cs1, s2) \
-  ({ size_t len = strlen (cs1);						      \
-     int result = __strncasecmp_l ((cs1), (s2), len, locale) == 0;	      \
+  ({ gsize len = strlen (cs1);						      \
+     gint result = __strncasecmp_l ((cs1), (s2), len, locale) == 0;	      \
      if (result) (s2) += len;						      \
      result; })
 #else
@@ -251,7 +251,7 @@ localtime_r (t, tp)
    lead to problems with the wide character version.  */
 #define get_number(from, to, n) \
   do {									      \
-    int __n = n;							      \
+    gint __n = n;							      \
     val = 0;								      \
     while (*rp == ' ')							      \
       ++rp;								      \
@@ -317,21 +317,21 @@ extern const struct locale_data _nl_C_LC_TIME attribute_hidden;
 
 # define strncasecmp(s1, s2, n) __strncasecmp (s1, s2, n)
 #else
-static char const weekday_name[][10] =
+static gchar const weekday_name[][10] =
   {
     "Sunday", "Monday", "Tuesday", "Wednesday",
     "Thursday", "Friday", "Saturday"
   };
-static char const ab_weekday_name[][4] =
+static gchar const ab_weekday_name[][4] =
   {
     "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"
   };
-static char const month_name[][10] =
+static gchar const month_name[][10] =
   {
     "January", "February", "March", "April", "May", "June",
     "July", "August", "September", "October", "November", "December"
   };
-static char const ab_month_name[][4] =
+static gchar const ab_month_name[][4] =
   {
     "Jan", "Feb", "Mar", "Apr", "May", "Jun",
     "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"
@@ -343,7 +343,7 @@ static char const ab_month_name[][4] =
 # define HERE_T_FMT_AMPM "%I:%M:%S %p"
 # define HERE_T_FMT "%H:%M:%S"
 
-static const unsigned short int __mon_yday[2][13] =
+static const unsigned short __mon_yday[2][13] =
   {
     /* Normal years.  */
     { 0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334, 365 },
@@ -396,8 +396,8 @@ day_of_the_week (struct tm *tm)
   /* We know that January 1st 1970 was a Thursday (= 4).  Compute the
      the difference between this data in the one on TM and so determine
      the weekday.  */
-  int corr_year = 1900 + tm->tm_year - (tm->tm_mon < 2);
-  int wday = (-473
+  gint corr_year = 1900 + tm->tm_year - (tm->tm_mon < 2);
+  gint wday = (-473
 	      + (365 * (tm->tm_year - 70))
 	      + (corr_year / 4)
 	      - ((corr_year / 4) / 25) + ((corr_year / 4) % 25 < 0)
@@ -417,36 +417,36 @@ day_of_the_year (struct tm *tm)
 
 
 #ifdef _LIBC
-char *
+gchar *
 internal_function
 #else
-static char *
+static gchar *
 #endif
 __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
-     const char *rp;
-     const char *fmt;
+     const gchar *rp;
+     const gchar *fmt;
      struct tm *tm;
      enum ptime_locale_status *decided;
-     int era_cnt;
+     gint era_cnt;
      LOCALE_PARAM_DECL
 {
 #ifdef _LIBC
   struct locale_data *const current = locale->__locales[LC_TIME];
 #endif
 
-  const char *rp_backup;
-  int cnt;
-  size_t val;
-  int have_I, is_pm;
-  int century, want_century;
-  int want_era;
-  int have_wday, want_xday;
-  int have_yday;
-  int have_mon, have_mday;
-  int have_uweek, have_wweek;
-  int week_no;
+  const gchar *rp_backup;
+  gint cnt;
+  gsize val;
+  gint have_I, is_pm;
+  gint century, want_century;
+  gint want_era;
+  gint have_wday, want_xday;
+  gint have_yday;
+  gint have_mon, have_mday;
+  gint have_uweek, have_wweek;
+  gint week_no;
 #ifdef _NL_CURRENT
-  size_t num_eras;
+  gsize num_eras;
 #endif
   struct era_entry *era;
 
@@ -640,12 +640,12 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
 #elif defined (G_OS_WIN32)
 	  if (*decided != raw)
 	    {
-	      char *d_t_fmt =
+	      gchar *d_t_fmt =
 		      g_strconcat (get_locale_string (LOCALE_SSHORTDATE),
 				   " ",
 				   get_locale_string (LOCALE_STIMEFORMAT),
 				   NULL);
-	      const char *posix_d_t_fmt = translate_picture (d_t_fmt);
+	      const gchar *posix_d_t_fmt = translate_picture (d_t_fmt);
 
 	      g_free (d_t_fmt);
 
@@ -717,7 +717,7 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
 #elif defined (G_OS_WIN32)
 	  if (*decided != raw)
 	    {
-		const char *posix_d_fmt = translate_picture (get_locale_string (LOCALE_SSHORTDATE));
+		const gchar *posix_d_fmt = translate_picture (get_locale_string (LOCALE_SSHORTDATE));
 		if (!recursive (posix_d_fmt))
 		{
 		  if (*decided == loc)
@@ -824,9 +824,9 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
 	  if (!match_string (HERE_AM_STR, rp))
 	    {
 	      if (match_string (HERE_PM_STR, rp))
-	        is_pm = 1;
+		is_pm = 1;
 	      else
-	        return NULL;
+		return NULL;
             }
 	  break;
 	case 'r':
@@ -853,11 +853,11 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
 #elif defined (G_OS_WIN32)
 	  if (*decided != raw)
 	    {
-	      char *t_p_fmt =
+	      gchar *t_p_fmt =
 		      g_strconcat (get_locale_string (LOCALE_STIMEFORMAT),
 				   " tt",
 				   NULL);
-	      const char *posix_t_p_fmt = translate_picture (t_p_fmt);
+	      const gchar *posix_t_p_fmt = translate_picture (t_p_fmt);
 
 	      g_free (t_p_fmt);
 
@@ -935,7 +935,7 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
 #elif defined (G_OS_WIN32)
 	  if (*decided != raw)
 	    {
-	      const char *posix_t_fmt = translate_picture (get_locale_string (LOCALE_STIMEFORMAT));
+	      const gchar *posix_t_fmt = translate_picture (get_locale_string (LOCALE_STIMEFORMAT));
 	      if (!recursive (posix_t_fmt))
 		{
 		  if (*decided == loc)
@@ -1027,7 +1027,7 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
 	      /* Match locale's alternate date and time format.  */
 	      if (*decided != raw)
 		{
-		  const char *fmt = _NL_CURRENT (LC_TIME, ERA_D_T_FMT);
+		  const gchar *fmt = _NL_CURRENT (LC_TIME, ERA_D_T_FMT);
 
 		  if (*fmt == '\0')
 		    fmt = _NL_CURRENT (LC_TIME, D_T_FMT);
@@ -1071,7 +1071,7 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
 
 		  num_eras = _NL_CURRENT_WORD (LC_TIME,
 					       _NL_TIME_ERA_NUM_ENTRIES);
-		  for (era_cnt = 0; era_cnt < (int) num_eras;
+		  for (era_cnt = 0; era_cnt < (gint) num_eras;
 		       ++era_cnt, rp = rp_backup)
 		    {
 		      era = _nl_select_era_entry (era_cnt
@@ -1082,7 +1082,7 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
 			  break;
 			}
 		    }
-		  if (era_cnt != (int) num_eras)
+		  if (era_cnt != (gint) num_eras)
 		    break;
 
 		  era_cnt = -1;
@@ -1094,7 +1094,7 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
 	      /* The C locale has no era information, so use the
 		 normal representation.  */
 	      goto match_century;
- 	    case 'y':
+	    case 'y':
 	      if (*decided != raw)
 		{
 		  get_number(0, 9999, 4);
@@ -1108,10 +1108,10 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
 		      assert (*decided == loc);
 
 		      era = _nl_select_era_entry (era_cnt HELPER_LOCALE_ARG);
-		      int match = FALSE;
+		      gint match = FALSE;
 		      if (era != NULL)
 			{
-			  int delta = ((tm->tm_year - era->offset)
+			  gint delta = ((tm->tm_year - era->offset)
 				       * era->absolute_direction);
 			  match = (delta >= 0
 				   && delta < (((int64_t) era->stop_date[0]
@@ -1126,13 +1126,13 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
 
 		  num_eras = _NL_CURRENT_WORD (LC_TIME,
 					       _NL_TIME_ERA_NUM_ENTRIES);
-		  for (era_cnt = 0; era_cnt < (int) num_eras; ++era_cnt)
+		  for (era_cnt = 0; era_cnt < (gint) num_eras; ++era_cnt)
 		    {
 		      era = _nl_select_era_entry (era_cnt
 						  HELPER_LOCALE_ARG);
 		      if (era != NULL)
 			{
-			  int delta = ((tm->tm_year - era->offset)
+			  gint delta = ((tm->tm_year - era->offset)
 				       * era->absolute_direction);
 			  if (delta >= 0
 			      && delta < (((int64_t) era->stop_date[0]
@@ -1144,7 +1144,7 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
 			    }
 			}
 		    }
-		  if (era_cnt != (int) num_eras)
+		  if (era_cnt != (gint) num_eras)
 		    break;
 
 		  era_cnt = -1;
@@ -1160,14 +1160,14 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
 		{
 		  num_eras = _NL_CURRENT_WORD (LC_TIME,
 					       _NL_TIME_ERA_NUM_ENTRIES);
-		  for (era_cnt = 0; era_cnt < (int) num_eras;
+		  for (era_cnt = 0; era_cnt < (gint) num_eras;
 		       ++era_cnt, rp = rp_backup)
 		    {
 		      era = _nl_select_era_entry (era_cnt HELPER_LOCALE_ARG);
 		      if (era != NULL && recursive (era->era_format))
 			break;
 		    }
-		  if (era_cnt == (int) num_eras)
+		  if (era_cnt == (gint) num_eras)
 		    {
 		      era_cnt = -1;
 		      if (*decided == loc)
@@ -1192,7 +1192,7 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
 	    case 'x':
 	      if (*decided != raw)
 		{
-		  const char *fmt = _NL_CURRENT (LC_TIME, ERA_D_FMT);
+		  const gchar *fmt = _NL_CURRENT (LC_TIME, ERA_D_FMT);
 
 		  if (*fmt == '\0')
 		    fmt = _NL_CURRENT (LC_TIME, D_FMT);
@@ -1218,7 +1218,7 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
 	    case 'X':
 	      if (*decided != raw)
 		{
-		  const char *fmt = _NL_CURRENT (LC_TIME, ERA_T_FMT);
+		  const gchar *fmt = _NL_CURRENT (LC_TIME, ERA_T_FMT);
 
 		  if (*fmt == '\0')
 		    fmt = _NL_CURRENT (LC_TIME, T_FMT);
@@ -1374,7 +1374,7 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
       if ( !(have_mon && have_mday) && have_yday)
 	{
 	  /* We don't have tm_mon and/or tm_mday, compute them.  */
-	  int t_mon = 0;
+	  gint t_mon = 0;
 	  while (__mon_yday[__isleap(1900 + tm->tm_year)][t_mon] <= tm->tm_yday)
 	      t_mon++;
 	  if (!have_mon)
@@ -1392,10 +1392,10 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
 
   if ((have_uweek || have_wweek) && have_wday)
     {
-      int save_wday = tm->tm_wday;
-      int save_mday = tm->tm_mday;
-      int save_mon = tm->tm_mon;
-      int w_offset = have_uweek ? 0 : 1;
+      gint save_wday = tm->tm_wday;
+      gint save_mday = tm->tm_mday;
+      gint save_mon = tm->tm_mon;
+      gint w_offset = have_uweek ? 0 : 1;
 
       tm->tm_mday = 1;
       tm->tm_mon = 0;
@@ -1412,7 +1412,7 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
 
       if (!have_mday || !have_mon)
 	{
-	  int t_mon = 0;
+	  gint t_mon = 0;
 	  while (__mon_yday[__isleap(1900 + tm->tm_year)][t_mon]
 		 <= tm->tm_yday)
 	    t_mon++;
@@ -1427,13 +1427,13 @@ __strptime_internal (rp, fmt, tm, decided, era_cnt LOCALE_PARAM)
       tm->tm_wday = save_wday;
     }
 
-  return (char *) rp;
+  return (gchar *) rp;
 }
 
-static char *
+static gchar *
 strptime (buf, format, tm LOCALE_PARAM)
-     const char *buf;
-     const char *format;
+     const gchar *buf;
+     const gchar *format;
      struct tm *tm;
      LOCALE_PARAM_DECL
 {
@@ -1456,9 +1456,9 @@ weak_alias (__strptime_l, strptime_l)
 
 /* Returns whether a string is NULL, empty, or full of whitespace */
 static gboolean
-string_is_empty (const char *value)
+string_is_empty (const gchar *value)
 {
-	const char *p;
+	const gchar *p;
 	gboolean empty = TRUE;
 
 	if (value) {
@@ -1479,13 +1479,13 @@ string_is_empty (const char *value)
  * string with them.
  */
 static ETimeParseStatus
-parse_with_strptime (const char *value, struct tm *result, const char **formats, int n_formats)
+parse_with_strptime (const gchar *value, struct tm *result, const gchar **formats, gint n_formats)
 {
-	const char *parse_end = NULL, *pos;
+	const gchar *parse_end = NULL, *pos;
 	gchar *locale_str;
 	gchar *format_str;
 	ETimeParseStatus parse_ret;
-	int i, n;
+	gint i, n;
 
 	if (string_is_empty (value)) {
 		memset (result, 0, sizeof (*result));
@@ -1495,13 +1495,13 @@ parse_with_strptime (const char *value, struct tm *result, const char **formats,
 
 	parse_ret =  E_TIME_PARSE_INVALID;
 	locale_str = g_locale_from_utf8 (value, -1, NULL, NULL, NULL);
-	pos = (const char *) locale_str;
+	pos = (const gchar *) locale_str;
 
 	if (!locale_str)
 		return E_TIME_PARSE_INVALID;
 
 	/* Skip whitespace */
-	while (n = (int)((unsigned char)*pos), isspace (n) != 0)
+	while (n = (gint)((guchar)*pos), isspace (n) != 0)
 		pos++;
 
 	/* Try each of the formats in turn */
@@ -1544,10 +1544,10 @@ correct_two_digit_year (struct tm *result, gboolean *two_digit_year)
 	if (result->tm_year < 0 && result->tm_year < -1800) {
 		time_t t = time (NULL);
 		struct tm *today_tm = localtime (&t);
-		
+
 		/* This should convert it into a value from 0 to 99. */
 		result->tm_year += 1900;
-		
+
 		/* Now add on the century. */
 		result->tm_year += today_tm->tm_year
 			- (today_tm->tm_year % 100);
@@ -1563,12 +1563,28 @@ static gboolean
 locale_supports_12_hour_format (void)
 {
 	struct tm tmp_tm = { 0 };
-	char s[16];
+	gchar s[16];
 
 	e_utf8_strftime (s, sizeof (s), "%p", &tmp_tm);
 	return s[0] != '\0';
 }
 
+static gboolean
+has_correct_date (const struct tm *value)
+{
+	const gint days_in_month[12] = {31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};
+	gint days, year;
+
+	g_return_val_if_fail (value != NULL, FALSE);
+	g_return_val_if_fail (value->tm_mon >= 0 && value->tm_mon < 12, FALSE);
+
+	year = value->tm_year  + 1900;
+	days = days_in_month[value->tm_mon];
+	if (value->tm_mon == 1 && ((year <= 1752) ? (!(year % 4)) : ((!(year % 4) && (year % 100)) || !(year % 400))))
+		days++;
+
+	return value->tm_mday >= 1 && value->tm_mday <= days;
+}
 
 /**
  * e_time_parse_date_and_time_ex:
@@ -1589,14 +1605,14 @@ locale_supports_12_hour_format (void)
  *          E_TIME_PARSE_INVALID if the string could not be parsed.
  */
 ETimeParseStatus
-e_time_parse_date_and_time_ex		(const char	*value,
+e_time_parse_date_and_time_ex		(const gchar	*value,
 					 struct tm	*result,
 					 gboolean	*two_digit_year)
 {
 	struct tm *today_tm;
 	time_t t;
-	const char *format[16];
-	int num_formats = 0;
+	const gchar *format[16];
+	gint num_formats = 0;
 	gboolean use_12_hour_formats = locale_supports_12_hour_format ();
 	ETimeParseStatus status;
 
@@ -1692,8 +1708,12 @@ e_time_parse_date_and_time_ex		(const char	*value,
 
 	if (two_digit_year)
 		*two_digit_year = FALSE;
-	
+
 	status = parse_with_strptime (value, result, format, num_formats);
+
+	if (status == E_TIME_PARSE_OK && !has_correct_date (result))
+		status = E_TIME_PARSE_INVALID;
+
 	/* Note that we checked if it was empty already, so it is either OK
 	   or INVALID here. */
 	if (status == E_TIME_PARSE_OK) {
@@ -1715,7 +1735,7 @@ e_time_parse_date_and_time_ex		(const char	*value,
 }
 
 ETimeParseStatus
-e_time_parse_date_and_time		(const char	*value,
+e_time_parse_date_and_time		(const gchar	*value,
 					 struct tm	*result)
 {
 	return e_time_parse_date_and_time_ex (value, result, NULL);
@@ -1735,9 +1755,9 @@ e_time_parse_date_and_time		(const char	*value,
  * @value was an empty string, a valid date, or an invalid date.
  **/
 ETimeParseStatus
-e_time_parse_date_ex (const char *value, struct tm *result, gboolean *two_digit_year)
+e_time_parse_date_ex (const gchar *value, struct tm *result, gboolean *two_digit_year)
 {
-	const char *format[4];
+	const gchar *format[4];
 	ETimeParseStatus status;
 
 	g_return_val_if_fail (value != NULL, E_TIME_PARSE_INVALID);
@@ -1759,27 +1779,31 @@ e_time_parse_date_ex (const char *value, struct tm *result, gboolean *two_digit_
 		/* when we need to know about two digit year, then always first try
 		   full year, because for example nl_NL have format %d-%m-%y and it
 		   changes from two year itself, which isn't what we want */
-		const char *tmp = format [1];
+		const gchar *tmp = format [1];
 		format [1] = format [0];
 		format [0] = tmp;
 		*two_digit_year = FALSE;
 	}
 
 	status = parse_with_strptime (value, result, format, sizeof (format)/sizeof (format [0]));
+
+	if (status == E_TIME_PARSE_OK && !has_correct_date (result))
+		status = E_TIME_PARSE_INVALID;
+
 	if (status == E_TIME_PARSE_OK) {
 		correct_two_digit_year (result, two_digit_year);
 	}
 
 	if (two_digit_year)
-		g_free ((char*)format [0]);
+		g_free ((gchar *)format [0]);
 	else
-		g_free ((char*)format [1]);
+		g_free ((gchar *)format [1]);
 
 	return status;
 }
 
 ETimeParseStatus
-e_time_parse_date (const char *value, struct tm *result)
+e_time_parse_date (const gchar *value, struct tm *result)
 {
 	return e_time_parse_date_ex (value, result, NULL);
 }
@@ -1799,10 +1823,10 @@ e_time_parse_date (const char *value, struct tm *result)
  * @value was an empty string, a valid date, or an invalid date.
  **/
 ETimeParseStatus
-e_time_parse_time (const char *value, struct tm *result)
+e_time_parse_time (const gchar *value, struct tm *result)
 {
-	const char *format[7];
-	int num_formats = 0;
+	const gchar *format[7];
+	gint num_formats = 0;
 	gboolean use_12_hour_formats = locale_supports_12_hour_format ();
 
 	if (use_12_hour_formats) {
@@ -1858,10 +1882,10 @@ e_time_format_date_and_time		(struct tm	*date_tm,
 					 gboolean	 use_24_hour_format,
 					 gboolean	 show_midnight,
 					 gboolean	 show_zero_seconds,
-					 char		*buffer,
-					 int		 buffer_size)
+					 gchar		*buffer,
+					 gint		 buffer_size)
 {
-	char *format;
+	gchar *format;
 
 	if (!show_midnight && date_tm->tm_hour == 0
 	    && date_tm->tm_min == 0 && date_tm->tm_sec == 0) {
@@ -1909,10 +1933,10 @@ void
 e_time_format_time			(struct tm	*date_tm,
 					 gboolean	 use_24_hour_format,
 					 gboolean	 show_zero_seconds,
-					 char		*buffer,
-					 int		 buffer_size)
+					 gchar		*buffer,
+					 gint		 buffer_size)
 {
-	char *format;
+	gchar *format;
 
 	if (use_24_hour_format) {
 		if (!show_zero_seconds && date_tm->tm_sec == 0)
@@ -1982,7 +2006,7 @@ e_mktime_utc (struct tm *tm)
  * seconds from UTC time, stored in @offset.
  **/
 void
-e_localtime_with_offset (time_t tt, struct tm *tm, int *offset)
+e_localtime_with_offset (time_t tt, struct tm *tm, gint *offset)
 {
 	localtime_r (&tt, tm);
 
@@ -2000,11 +2024,11 @@ e_localtime_with_offset (time_t tt, struct tm *tm, int *offset)
 #endif
 }
 
-char *
+gchar *
 e_time_get_d_fmt_with_4digit_year (void)
 {
-	char *p;
-	char *res = 
+	gchar *p;
+	gchar *res =
 	#if defined(__linux__)
 		g_strdup (nl_langinfo (D_FMT) );
 	/*#elif defined(G_OS_WIN32)
