@@ -37,8 +37,8 @@ struct _trie_state {
 	struct _trie_state *next;
 	struct _trie_state *fail;
 	struct _trie_match *match;
-	unsigned int final;
-	int id;
+	guint final;
+	gint id;
 };
 
 struct _trie_match {
@@ -63,11 +63,11 @@ struct _ETrie {
 
 
 static inline gunichar
-trie_utf8_getc (const unsigned char **in, size_t inlen)
+trie_utf8_getc (const guchar **in, gsize inlen)
 {
-	register const unsigned char *inptr = *in;
-	const unsigned char *inend = inptr + inlen;
-	register unsigned char c, r;
+	register const guchar *inptr = *in;
+	const guchar *inend = inptr + inlen;
+	register guchar c, r;
 	register gunichar u, m;
 
 	if (inlen == 0)
@@ -163,7 +163,7 @@ g (struct _trie_state *s, gunichar c)
 }
 
 static struct _trie_state *
-trie_insert (ETrie *trie, int depth, struct _trie_state *q, gunichar c)
+trie_insert (ETrie *trie, gint depth, struct _trie_state *q, gunichar c)
 {
 	struct _trie_match *m;
 
@@ -179,7 +179,7 @@ trie_insert (ETrie *trie, int depth, struct _trie_state *q, gunichar c)
 	q->id = -1;
 
 	if (trie->fail_states->len < depth + 1) {
-		unsigned int size = trie->fail_states->len;
+		guint size = trie->fail_states->len;
 
 		size = MAX (size + 64, depth + 1);
 		g_ptr_array_set_size (trie->fail_states, size);
@@ -192,21 +192,21 @@ trie_insert (ETrie *trie, int depth, struct _trie_state *q, gunichar c)
 }
 
 
-#if 1
+#if 0
 static void
-dump_trie (struct _trie_state *s, int depth)
+dump_trie (struct _trie_state *s, gint depth)
 {
-	char *p = g_alloca ((depth * 2) + 1);
+	gchar *p = g_alloca ((depth * 2) + 1);
 	struct _trie_match *m;
 
 	memset (p, ' ', depth * 2);
 	p[depth * 2] = '\0';
 
 	fprintf (stderr, "%s[state] %p: final=%d; pattern-id=%d; fail=%p\n",
-		 p, s, s->final, s->id, s->fail);
+		 p, (gpointer) s, s->final, s->id, (gpointer) s->fail);
 	m = s->match;
 	while (m) {
-		fprintf (stderr, " %s'%c' -> %p\n", p, m->c, m->state);
+		fprintf (stderr, " %s'%c' -> %p\n", p, m->c, (gpointer) m->state);
 		if (m->state)
 			dump_trie (m->state, depth + 1);
 
@@ -239,12 +239,12 @@ dump_trie (struct _trie_state *s, int depth)
  * Add a new pattern to the #ETrie @trie.
  **/
 void
-e_trie_add (ETrie *trie, const char *pattern, int pattern_id)
+e_trie_add (ETrie *trie, const gchar *pattern, gint pattern_id)
 {
-	const unsigned char *inptr = (const unsigned char *) pattern;
+	const guchar *inptr = (const guchar *) pattern;
 	struct _trie_state *q, *q1, *r;
 	struct _trie_match *m, *n;
-	int i, depth = 0;
+	gint i, depth = 0;
 	gunichar c;
 
 	/* Step 1: add the pattern to the trie */
@@ -334,16 +334,16 @@ e_trie_add (ETrie *trie, const char *pattern, int pattern_id)
  *
  * Returns: The matched pattern, or %NULL if no pattern is matched.
  **/
-const char *
-e_trie_search (ETrie *trie, const char *buffer, size_t buflen, int *matched_id)
+const gchar *
+e_trie_search (ETrie *trie, const gchar *buffer, gsize buflen, gint *matched_id)
 {
-	const unsigned char *inptr, *inend, *prev, *pat;
-	register size_t inlen = buflen;
+	const guchar *inptr, *inend, *prev, *pat;
+	register gsize inlen = buflen;
 	struct _trie_state *q;
 	struct _trie_match *m = NULL; /* init to please gcc */
 	gunichar c;
 
-	inptr = (const unsigned char *) buffer;
+	inptr = (const guchar *) buffer;
 	inend = inptr + buflen;
 
 	q = &trie->root;
@@ -371,7 +371,7 @@ e_trie_search (ETrie *trie, const char *buffer, size_t buflen, int *matched_id)
 					if (matched_id)
 						*matched_id = q->id;
 
-					return (const char *) pat;
+					return (const gchar *) pat;
 				}
 			}
 		}
