@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
- * Copyright (C) 2001-2003 Ximian, Inc.
+/*
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef __E_XML_HASH_UTILS_H__
@@ -39,7 +39,7 @@ GHashTable *e_xml_to_hash      (xmlDoc       *doc,
 				EXmlHashType  type);
 xmlDoc     *e_xml_from_hash    (GHashTable   *hash,
 				EXmlHashType  type,
-				const char   *root_node);
+				const gchar   *root_node);
 
 void        e_xml_destroy_hash (GHashTable   *hash);
 
@@ -57,22 +57,22 @@ typedef enum {
 	E_XMLHASH_STATUS_NOT_FOUND
 } EXmlHashStatus;
 
-typedef void (* EXmlHashFunc) (const char *key, const char *value, gpointer user_data);
-typedef gboolean (* EXmlHashRemoveFunc) (const char *key, const char *value, gpointer user_data);
+typedef void (* EXmlHashFunc) (const gchar *key, const gchar *value, gpointer user_data);
+typedef gboolean (* EXmlHashRemoveFunc) (const gchar *key, const gchar *value, gpointer user_data);
 
 typedef struct EXmlHash EXmlHash;
 
-EXmlHash      *e_xmlhash_new         (const char   *filename);
+EXmlHash      *e_xmlhash_new         (const gchar   *filename);
 
 void           e_xmlhash_add         (EXmlHash     *hash,
-				      const char   *key,
-				      const char   *data);
+				      const gchar   *key,
+				      const gchar   *data);
 void           e_xmlhash_remove      (EXmlHash     *hash,
-				      const char   *key);
+				      const gchar   *key);
 
 EXmlHashStatus e_xmlhash_compare     (EXmlHash     *hash,
-				      const char   *key,
-				      const char   *compare_data);
+				      const gchar   *key,
+				      const gchar   *compare_data);
 void           e_xmlhash_foreach_key (EXmlHash     *hash,
 				      EXmlHashFunc  func,
 				      gpointer      user_data);
