@@ -82,7 +82,7 @@ static void     destination_column_formatter  (GtkTreeViewColumn *column, GtkCel
  * Class/object setup *
  * ------------------ */
 
-G_DEFINE_TYPE (ENameSelectorDialog, e_name_selector_dialog, GTK_TYPE_DIALOG);
+G_DEFINE_TYPE (ENameSelectorDialog, e_name_selector_dialog, GTK_TYPE_DIALOG)
 
 #define E_NAME_SELECTOR_DIALOG_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE ((obj), E_TYPE_NAME_SELECTOR_DIALOG, ENameSelectorDialogPrivate))
@@ -137,9 +137,9 @@ e_name_selector_dialog_init (ENameSelectorDialog *name_selector_dialog)
 	GtkWidget         *parent;
 	GtkTreeSelection  *selection;
 	ESourceList       *source_list;
-	char              *gladefile;
+	gchar              *gladefile;
 	GConfClient *gconf_client;
-	char *uid;
+	gchar *uid;
 
 	ENameSelectorDialogPrivate *priv = E_NAME_SELECTOR_DIALOG_GET_PRIVATE (name_selector_dialog);
 	priv->destination_index = 0;
@@ -490,11 +490,11 @@ add_section (ENameSelectorDialog *name_selector_dialog,
 	Section            section;
 	GtkTreeViewColumn *column;
 	GtkCellRenderer   *cell_renderer;
-	GtkWidget  	  *vbox, *hbox, *chbox;
-	GtkWidget 	  *widget, *image, *label;
+	GtkWidget	  *vbox, *hbox, *chbox;
+	GtkWidget	  *widget, *image, *label;
 	SelData		  *data;
 	GtkTreeSelection  *selection;
-	gchar 		  *text;
+	gchar		  *text;
 
 	g_assert (name != NULL);
 	g_assert (pretty_name != NULL);
@@ -1018,7 +1018,7 @@ transfer_button_clicked (ENameSelectorDialog *name_selector_dialog, GtkButton *t
 		if (!gtk_tree_model_get_iter (GTK_TREE_MODEL (name_selector_dialog->contact_sort),
 				      &iter, path)) {
 			gtk_tree_path_free (path);
-			return ;
+			return;
 		}
 
 		gtk_tree_path_free (path);
@@ -1184,7 +1184,7 @@ destination_column_formatter (GtkTreeViewColumn *column, GtkCellRenderer *cell,
 	EDestination      *destination;
 	GString           *buffer;
 
-       	destination = e_destination_store_get_destination (destination_store, iter);
+	destination = e_destination_store_get_destination (destination_store, iter);
 	g_assert (destination);
 
 	buffer = g_string_new (e_destination_get_name (destination));
