@@ -43,7 +43,7 @@ struct _ESourceSelectorPrivate {
 	GtkTreeRowReference *saved_primary_selection;
 	ESourceGroup *primary_source_group;
 
-	int rebuild_model_idle_id;
+	gint rebuild_model_idle_id;
 
 	gboolean toggled_last;
 	gboolean checkboxes_shown;
@@ -71,10 +71,67 @@ enum {
 	DATA_DROPPED,
 	NUM_SIGNALS
 };
-static unsigned int signals[NUM_SIGNALS] = { 0 };
+static guint signals[NUM_SIGNALS] = { 0 };
 
 G_DEFINE_TYPE (ESourceSelector, e_source_selector, GTK_TYPE_TREE_VIEW)
 
+/* safe-toggle-renderer definition - it'll not call 'toggled' signal on 'activate', when mouse is not over the toggle */
+
+typedef struct _ECellRendererSafeToggle {
+	GtkCellRendererToggle parent;
+} ECellRendererSafeToggle;
+
+typedef struct _ECellRendererSafeToggleClass {
+	GtkCellRendererToggleClass parent_class;
+} ECellRendererSafeToggleClass;
+
+GType e_cell_renderer_safe_toggle_get_type (void);
+
+G_DEFINE_TYPE (ECellRendererSafeToggle, e_cell_renderer_safe_toggle, GTK_TYPE_CELL_RENDERER_TOGGLE)
+
+static gboolean
+safe_toggle_activate (GtkCellRenderer      *cell,
+		      GdkEvent             *event,
+		      GtkWidget            *widget,
+		      const gchar          *path,
+		      GdkRectangle         *background_area,
+		      GdkRectangle         *cell_area,
+		      GtkCellRendererState  flags)
+{
+	if (event->type == GDK_BUTTON_PRESS && cell_area) {
+		GdkRegion *reg = gdk_region_rectangle (cell_area);
+
+		if (!gdk_region_point_in (reg, event->button.x, event->button.y)) {
+			gdk_region_destroy (reg);
+			return FALSE;
+		}
+
+		gdk_region_destroy (reg);
+	}
+
+	return GTK_CELL_RENDERER_CLASS (e_cell_renderer_safe_toggle_parent_class)->activate (cell, event, widget, path, background_area, cell_area, flags);
+}
+
+static void
+e_cell_renderer_safe_toggle_class_init (ECellRendererSafeToggleClass *klass)
+{
+	GtkCellRendererClass *rndr_class;
+
+	rndr_class = GTK_CELL_RENDERER_CLASS (klass);
+	rndr_class->activate = safe_toggle_activate;
+}
+
+static void
+e_cell_renderer_safe_toggle_init (ECellRendererSafeToggle *obj)
+{
+}
+
+static GtkCellRenderer *
+e_cell_renderer_safe_toggle_new (void)
+{
+	return g_object_new (e_cell_renderer_safe_toggle_get_type (), NULL);
+}
+
 /* Selection management.  */
 
 static GHashTable *
@@ -163,7 +220,7 @@ find_source_iter (ESourceSelector *selector, ESource *source, GtkTreeIter *paren
 		do {
 			if (gtk_tree_model_iter_children (model, source_iter, parent_iter)) {
 				do {
-					void *data;
+					gpointer data;
 
 					gtk_tree_model_get (model, source_iter, 0, &data, -1);
 					g_assert (E_IS_SOURCE (data));
@@ -188,8 +245,8 @@ static gboolean
 rebuild_existing_cb (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer data)
 {
 	ESourceSelectorRebuildData *rebuild_data = data;
-	void *node;
-	const char *uid;
+	gpointer node;
+	const gchar *uid;
 
 	gtk_tree_model_get (model, iter, 0, &node, -1);
 
@@ -376,7 +433,7 @@ rebuild_model (ESourceSelector *selector)
 	free_rebuild_data (rebuild_data);
 }
 
-static int
+static gint
 on_idle_rebuild_model_callback (ESourceSelector *selector)
 {
 	rebuild_model (selector);
@@ -405,7 +462,7 @@ toggle_cell_data_func (GtkTreeViewColumn *column,
 		       GtkTreeIter *iter,
 		       ESourceSelector *selector)
 {
-	void *data;
+	gpointer data;
 
 	gtk_tree_model_get (model, iter, 0, &data, -1);
 
@@ -431,7 +488,7 @@ text_cell_data_func (GtkTreeViewColumn *column,
 		     GtkTreeIter *iter,
 		     ESourceSelector *selector)
 {
-	void *data;
+	gpointer data;
 
 	gtk_tree_model_get (model, iter, 0, &data, -1);
 
@@ -464,7 +521,7 @@ pixbuf_cell_data_func (GtkTreeViewColumn *column,
 		       GtkTreeIter *iter,
 		       ESourceSelector *selector)
 {
-	void *data;
+	gpointer data;
 
 	gtk_tree_model_get (model, iter, 0, &data, -1);
 
@@ -515,7 +572,7 @@ selection_func (GtkTreeSelection *selection,
 		ESourceSelector *selector)
 {
 	GtkTreeIter iter;
-	void *data;
+	gpointer data;
 
 	if (selector->priv->toggled_last) {
 		selector->priv->toggled_last = FALSE;
@@ -573,14 +630,14 @@ text_cell_edited_cb (ESourceSelector *selector,
 
 static void
 cell_toggled_callback (GtkCellRendererToggle *renderer,
-		       const char *path_string,
+		       const gchar *path_string,
 		       ESourceSelector *selector)
 {
 	GtkTreeModel *model = GTK_TREE_MODEL (selector->priv->tree_store);
 	GtkTreePath *path = gtk_tree_path_new_from_string (path_string);
 	GtkTreeIter iter;
 	ESource *source;
-	void *data;
+	gpointer data;
 
 	if (! gtk_tree_model_get_iter (model, &iter, path)) {
 		gtk_tree_path_free (path);
@@ -972,7 +1029,7 @@ source_selector_popup_menu (GtkWidget *widget)
 
 /* Initialization.  */
 static gboolean
-ess_bool_accumulator(GSignalInvocationHint *ihint, GValue *out, const GValue *in, void *data)
+ess_bool_accumulator(GSignalInvocationHint *ihint, GValue *out, const GValue *in, gpointer data)
 {
 	gboolean val = g_value_get_boolean(in);
 
@@ -1060,8 +1117,8 @@ group_search_function   (GtkTreeModel *model,
 			 GtkTreeIter *iter,
 			 gpointer dummy)
 {
-	void *data;
-	const char *name = NULL;
+	gpointer data;
+	const gchar *name = NULL;
 	gboolean status = TRUE;
 
 	gtk_tree_model_get (model, iter, 0, &data, -1);
@@ -1120,7 +1177,7 @@ e_source_selector_init (ESourceSelector *selector)
 	g_object_set (G_OBJECT (cell_renderer), "mode", GTK_CELL_RENDERER_MODE_ACTIVATABLE, NULL);
 	gtk_tree_view_column_pack_start (column, cell_renderer, FALSE);
 	gtk_tree_view_column_set_cell_data_func (column, cell_renderer, (GtkTreeCellDataFunc) pixbuf_cell_data_func, selector, NULL);
-	cell_renderer = gtk_cell_renderer_toggle_new ();
+	cell_renderer = e_cell_renderer_safe_toggle_new ();
 	gtk_tree_view_column_pack_start (column, cell_renderer, FALSE);
 	gtk_tree_view_column_set_cell_data_func (column, cell_renderer, (GtkTreeCellDataFunc) toggle_cell_data_func, selector, NULL);
 	g_signal_connect (cell_renderer, "toggled", G_CALLBACK (cell_toggled_callback), selector);
@@ -1474,7 +1531,7 @@ e_source_selector_peek_primary_selection (ESourceSelector *selector)
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	gboolean have_iter = FALSE;
-	void *data = NULL;
+	gpointer data = NULL;
 
 	g_return_val_if_fail (E_IS_SOURCE_SELECTOR (selector), NULL);
 
@@ -1568,7 +1625,8 @@ e_source_selector_set_primary_selection (ESourceSelector *selector, ESource *sou
 		gtk_tree_path_free (path);
 	} else {
 		g_warning (G_STRLOC ": Cannot find source %p (%s) in selector %p",
-			   source, e_source_peek_name (source), selector);
+			   (gpointer) source, e_source_peek_name (source),
+			   (gpointer) selector);
 	}
 }
 
