@@ -54,7 +54,7 @@ dump_selection (ESourceSelector *selector)
 
 static void
 selection_changed_callback (ESourceSelector *selector,
-			    void *unused_data)
+			    gpointer unused_data)
 {
 	g_print ("Selection changed!\n");
 	dump_selection (selector);
@@ -67,8 +67,8 @@ check_toggled_callback (GtkToggleButton *button,
 	e_source_selector_show_selection (selector, gtk_toggle_button_get_active (button));
 }
 
-static int
-on_idle_create_widget (const char *gconf_path)
+static gint
+on_idle_create_widget (const gchar *gconf_path)
 {
 	GtkWidget *window;
 	GtkWidget *vbox;
@@ -108,10 +108,10 @@ on_idle_create_widget (const char *gconf_path)
 }
 
 
-int
-main (int argc, char **argv)
+gint
+main (gint argc, gchar **argv)
 {
-	const char *gconf_path;
+	const gchar *gconf_path;
 
 	gtk_init (&argc, &argv);
 	if (argc < 2)
@@ -119,7 +119,7 @@ main (int argc, char **argv)
 	else
 		gconf_path = argv [1];
 
-	g_idle_add ((GSourceFunc) on_idle_create_widget, (void *) gconf_path);
+	g_idle_add ((GSourceFunc) on_idle_create_widget, (gpointer) gconf_path);
 
 	gtk_main ();
 
