@@ -76,7 +76,7 @@
 #define CONNECTOR_PREFIX e_util_get_prefix ()
 #endif
 
-static char *find_olson_timezone (const char *windows_timezone);
+static gchar *find_olson_timezone (const gchar *windows_timezone);
 static void set_account_uri_string (E2kAutoconfig *ac);
 
 /**
@@ -92,8 +92,8 @@ static void set_account_uri_string (E2kAutoconfig *ac);
  * Return value: an autoconfig context
  **/
 E2kAutoconfig *
-e2k_autoconfig_new (const char *owa_uri, const char *username,
-		    const char *password, E2kAutoconfigAuthPref auth_pref)
+e2k_autoconfig_new (const gchar *owa_uri, const gchar *username,
+		    const gchar *password, E2kAutoconfigAuthPref auth_pref)
 {
 	E2kAutoconfig *ac;
 
@@ -106,7 +106,10 @@ e2k_autoconfig_new (const char *owa_uri, const char *username,
 		ac->auth_pref = auth_pref;
 
 	e2k_autoconfig_set_owa_uri (ac, owa_uri);
-	e2k_autoconfig_set_gc_server (ac, NULL, -1);
+	/* use same auth for gal as for the server */
+	e2k_autoconfig_set_gc_server (ac, NULL, -1, ac->auth_pref == E2K_AUTOCONFIG_USE_BASIC ? E2K_AUTOCONFIG_USE_GAL_BASIC :
+						    ac->auth_pref == E2K_AUTOCONFIG_USE_NTLM  ? E2K_AUTOCONFIG_USE_GAL_NTLM  :
+						    E2K_AUTOCONFIG_USE_GAL_DEFAULT);
 	e2k_autoconfig_set_username (ac, username);
 	e2k_autoconfig_set_password (ac, password);
 
@@ -205,11 +208,11 @@ reset_owa_derived (E2kAutoconfig *ac)
  * the old value of #owa_uri.
  **/
 void
-e2k_autoconfig_set_owa_uri (E2kAutoconfig *ac, const char *owa_uri)
+e2k_autoconfig_set_owa_uri (E2kAutoconfig *ac, const gchar *owa_uri)
 {
 	reset_owa_derived (ac);
 	if (ac->gc_server_autodetected)
-		e2k_autoconfig_set_gc_server (ac, NULL, -1);
+		e2k_autoconfig_set_gc_server (ac, NULL, -1, ac->gal_auth);
 	g_free (ac->owa_uri);
 
 	if (owa_uri) {
@@ -226,6 +229,7 @@ e2k_autoconfig_set_owa_uri (E2kAutoconfig *ac, const char *owa_uri)
  * @ac: an autoconfig context
  * @gc_server: the new GC server, or %NULL
  * @gal_limit: GAL search size limit, or -1 for no limit
+ * @gal_auth: Preferred authentication method for gal
  *
  * Sets @ac's #gc_server field to @gc_server (or the default if
  * @gc_server is %NULL) and the #gal_limit field to @gal_limit, and
@@ -233,10 +237,10 @@ e2k_autoconfig_set_owa_uri (E2kAutoconfig *ac, const char *owa_uri)
  * of #gc_server.
  **/
 void
-e2k_autoconfig_set_gc_server (E2kAutoconfig *ac, const char *gc_server,
-			      int gal_limit)
+e2k_autoconfig_set_gc_server (E2kAutoconfig *ac, const gchar *gc_server,
+			      gint gal_limit, E2kAutoconfigGalAuthPref gal_auth)
 {
-	const char *default_gal_limit;
+	const gchar *default_gal_limit;
 
 	reset_gc_derived (ac);
 	g_free (ac->gc_server);
@@ -253,6 +257,7 @@ e2k_autoconfig_set_gc_server (E2kAutoconfig *ac, const char *gc_server,
 			gal_limit = atoi (default_gal_limit);
 	}
 	ac->gal_limit = gal_limit;
+	ac->gal_auth = gal_auth;
 }
 
 /**
@@ -265,9 +270,9 @@ e2k_autoconfig_set_gc_server (E2kAutoconfig *ac, const char *gc_server,
  * set based on the old value of #username.
  **/
 void
-e2k_autoconfig_set_username (E2kAutoconfig *ac, const char *username)
+e2k_autoconfig_set_username (E2kAutoconfig *ac, const gchar *username)
 {
-	int dlen;
+	gint dlen;
 
 	reset_owa_derived (ac);
 	g_free (ac->username);
@@ -294,7 +299,7 @@ e2k_autoconfig_set_username (E2kAutoconfig *ac, const char *username)
  * Sets or clears @ac's #password field.
  **/
 void
-e2k_autoconfig_set_password (E2kAutoconfig *ac, const char *password)
+e2k_autoconfig_set_password (E2kAutoconfig *ac, const gchar *password)
 {
 	g_free (ac->password);
 	ac->password = g_strdup (password);
@@ -305,7 +310,7 @@ get_ctx_auth_handler (SoupMessage *msg, gpointer user_data)
 {
 	E2kAutoconfig *ac = user_data;
 	GSList *headers;
-	const char *challenge_hdr;
+	const gchar *challenge_hdr;
 
 	ac->saw_ntlm = ac->saw_basic = FALSE;
 	headers = e2k_http_get_headers (msg->response_headers,
@@ -389,7 +394,7 @@ e2k_autoconfig_get_context (E2kAutoconfig *ac, E2kOperation *op,
 	E2kContext *ctx;
 	SoupMessage *msg;
 	E2kHTTPStatus status;
-	const char *ms_webstorage;
+	const gchar *ms_webstorage;
 	xmlDoc *doc;
 	xmlNode *node;
 	xmlChar *equiv, *content, *href;
@@ -458,8 +463,8 @@ e2k_autoconfig_get_context (E2kAutoconfig *ac, E2kOperation *op,
 	 * new server.
 	 */
 	if (E2K_HTTP_STATUS_IS_REDIRECTION (status)) {
-		const char *location;
-		char *new_uri;
+		const gchar *location;
+		gchar *new_uri;
 
 		location = soup_message_headers_get (msg->response_headers,
 						     "Location");
@@ -492,7 +497,7 @@ e2k_autoconfig_get_context (E2kAutoconfig *ac, E2kOperation *op,
 	if (status == E2K_HTTP_FORBIDDEN &&
 	    !strncmp (ac->owa_uri, "http:", 5) && msg->response_body->length > 0) {
 		if (strstr (msg->response_body->data, "SSL")) {
-			char *new_uri =
+			gchar *new_uri =
 				g_strconcat ("https:", ac->owa_uri + 5, NULL);
 			e2k_autoconfig_set_owa_uri (ac, new_uri);
 			g_free (new_uri);
@@ -512,7 +517,7 @@ e2k_autoconfig_get_context (E2kAutoconfig *ac, E2kOperation *op,
 		else
 			ac->version = E2K_EXCHANGE_FUTURE;
 	} else {
-		const char *server = soup_message_headers_get (msg->response_headers, "Server");
+		const gchar *server = soup_message_headers_get (msg->response_headers, "Server");
 
 		/* If the server explicitly claims to be something
 		 * other than IIS, then return the "not windows"
@@ -569,11 +574,11 @@ e2k_autoconfig_get_context (E2kAutoconfig *ac, E2kOperation *op,
 	for (node = doc->children; node; node = e2k_xml_find (node, "meta")) {
 		gboolean ex55 = FALSE;
 
-		equiv = xmlGetProp (node, "http-equiv");
-		content = xmlGetProp (node, "content");
+		equiv = xmlGetProp (node, (xmlChar *) "http-equiv");
+		content = xmlGetProp (node, (xmlChar *) "content");
 		if (equiv && content &&
-		    !g_ascii_strcasecmp (equiv, "REFRESH") &&
-		    strstr (content, "/logon.asp"))
+		    !g_ascii_strcasecmp ((gchar *) equiv, "REFRESH") &&
+		    xmlStrstr (content, (xmlChar *) "/logon.asp"))
 			ex55 = TRUE;
 		if (equiv)
 			xmlFree (equiv);
@@ -591,9 +596,9 @@ e2k_autoconfig_get_context (E2kAutoconfig *ac, E2kOperation *op,
 	if (node) {
 		/* We won */
 		*result = E2K_AUTOCONFIG_OK;
-		href = xmlGetProp (node, "href");
+		href = xmlGetProp (node, (xmlChar *) "href");
 		g_free (ac->home_uri);
-		ac->home_uri = g_strdup (href);
+		ac->home_uri = g_strdup ((gchar *) href);
 		xmlFree (href);
 	} else
 		*result = E2K_AUTOCONFIG_FAILED;
@@ -609,11 +614,11 @@ e2k_autoconfig_get_context (E2kAutoconfig *ac, E2kOperation *op,
 	return ctx;
 }
 
-static const char *home_properties[] = {
+static const gchar *home_properties[] = {
 	PR_STORE_ENTRYID,
 	E2K_PR_EXCHANGE_TIMEZONE
 };
-static const int n_home_properties = sizeof (home_properties) / sizeof (home_properties[0]);
+static const gint n_home_properties = sizeof (home_properties) / sizeof (home_properties[0]);
 
 /*
  * e2k_autoconfig_check_exchange:
@@ -647,13 +652,13 @@ e2k_autoconfig_check_exchange (E2kAutoconfig *ac, E2kOperation *op)
 	xmlNode *node;
 	E2kHTTPStatus status;
 	E2kAutoconfigResult result;
-	char *new_uri, *pf_uri;
+	gchar *new_uri, *pf_uri;
 	E2kContext *ctx;
 	gboolean redirected = FALSE;
 	E2kResultIter *iter;
 	E2kResult *results;
 	GByteArray *entryid;
-	const char *exchange_dn, *timezone, *hrefs[] = { "" };
+	const gchar *exchange_dn, *timezone, *hrefs[] = { "" };
 	xmlChar *prop;
 	SoupBuffer *response;
 	E2kUri *euri;
@@ -723,13 +728,13 @@ e2k_autoconfig_check_exchange (E2kAutoconfig *ac, E2kOperation *op)
 
 	if (doc) {
 		for (node = e2k_xml_find (doc->children, "img"); node; node = e2k_xml_find (node, "img")) {
-			prop = xmlGetProp (node, "src");
-			if (prop && strstr (prop, "public") && node->parent) {
+			prop = xmlGetProp (node, (xmlChar *) "src");
+			if (prop && xmlStrstr (prop, (xmlChar *) "public") && node->parent) {
 				node = node->parent;
 				xmlFree (prop);
-				prop = xmlGetProp (node, "href");
+				prop = xmlGetProp (node, (xmlChar *) "href");
 				if (prop) {
-					euri = e2k_uri_new (prop);
+					euri = e2k_uri_new ((gchar *) prop);
 					ac->pf_server = g_strdup (euri->host);
 					e2k_uri_free (euri);
 					xmlFree (prop);
@@ -793,8 +798,8 @@ static void
 find_global_catalog (E2kAutoconfig *ac)
 {
 #ifndef G_OS_WIN32
-	int count, len;
-	unsigned char answer[1024], namebuf[1024], *end, *p;
+	gint count, len;
+	guchar answer[1024], namebuf[1024], *end, *p;
 	guint16 type, qclass, rdlength, priority, weight, port;
 	guint32 ttl;
 	HEADER *header;
@@ -816,13 +821,13 @@ find_global_catalog (E2kAutoconfig *ac)
 	/* Skip query */
 	count = ntohs (header->qdcount);
 	while (count-- && p < end) {
-		p += dn_expand (answer, end, p, namebuf, sizeof (namebuf));
+		p += dn_expand (answer, end, p, (gchar *) namebuf, sizeof (namebuf));
 		p += 4;
 	}
 
 	/* Read answers */
 	while (count-- && p < end) {
-		p += dn_expand (answer, end, p, namebuf, sizeof (namebuf));
+		p += dn_expand (answer, end, p, (gchar *) namebuf, sizeof (namebuf));
 		GETSHORT (type, p);
 		GETSHORT (qclass, p);
 		GETLONG (ttl, p);
@@ -836,10 +841,10 @@ find_global_catalog (E2kAutoconfig *ac)
 		GETSHORT (priority, p);
 		GETSHORT (weight, p);
 		GETSHORT (port, p);
-		p += dn_expand (answer, end, p, namebuf, sizeof (namebuf));
+		p += dn_expand (answer, end, p, (gchar *) namebuf, sizeof (namebuf));
 
 		/* FIXME: obey priority and weight */
-		ac->gc_server = g_strdup (namebuf);
+		ac->gc_server = g_strdup ((gchar *) namebuf);
 		ac->gc_server_autodetected = TRUE;
 		return;
 	}
@@ -899,7 +904,7 @@ e2k_autoconfig_get_global_catalog (E2kAutoconfig *ac, E2kOperation *op)
 
 	return e2k_global_catalog_new (ac->gc_server, ac->gal_limit,
 				       ac->username, ac->nt_domain,
-				       ac->password);
+				       ac->password, ac->gal_auth);
 }
 
 /*
@@ -972,7 +977,7 @@ static void
 set_account_uri_string (E2kAutoconfig *ac)
 {
 	E2kUri *owa_uri, *home_uri;
-	char *path, *mailbox;
+	gchar *path, *mailbox;
 	GString *uri;
 
 	owa_uri = e2k_uri_new (ac->owa_uri);
@@ -1000,6 +1005,18 @@ set_account_uri_string (E2kAutoconfig *ac)
 	e2k_uri_append_encoded (uri, ac->gc_server, FALSE, ";?");
 	if (ac->gal_limit != -1)
 		g_string_append_printf (uri, ";ad_limit=%d", ac->gal_limit);
+	if (ac->gal_auth != E2K_AUTOCONFIG_USE_GAL_DEFAULT) {
+		const gchar *value = NULL;
+
+		switch (ac->gal_auth) {
+		case E2K_AUTOCONFIG_USE_GAL_BASIC: value = "basic"; break;
+		case E2K_AUTOCONFIG_USE_GAL_NTLM:  value = "ntlm";  break;
+		case E2K_AUTOCONFIG_USE_GAL_DEFAULT: /* should not get here */ break;
+		}
+
+		if (value)
+			g_string_append_printf (uri, ";ad_auth=%s", value);
+	}
 
 	path = g_strdup (home_uri->path + 1);
 	mailbox = strrchr (path, '/');
@@ -1035,7 +1052,7 @@ set_account_uri_string (E2kAutoconfig *ac)
  * timezone names. (Actually, we just strip the last two words.)
  */
 static struct {
-	const char *windows_name, *lang, *country, *olson_name;
+	const gchar *windows_name, *lang, *country, *olson_name;
 } zonemap[] = {
 	/* (GMT-12:00) Eniwetok, Kwajalein */
 	{ "Dateline", NULL, NULL, "Pacific/Kwajalein" },
@@ -1304,14 +1321,14 @@ static struct {
 	/* (GMT+13:00) Nuku'alofa */
 	{ "Tonga", NULL, NULL, "Pacific/Tongatapu" }
 };
-static const int n_zone_mappings = sizeof (zonemap) / sizeof (zonemap[0]);
+static const gint n_zone_mappings = sizeof (zonemap) / sizeof (zonemap[0]);
 
-static char *
-find_olson_timezone (const char *windows_timezone)
+static gchar *
+find_olson_timezone (const gchar *windows_timezone)
 {
-	int i, tzlen;
-	const char *locale, *p;
-	char lang[3] = { 0 }, country[3] = { 0 };
+	gint i, tzlen;
+	const gchar *locale, *p;
+	gchar lang[3] = { 0 }, country[3] = { 0 };
 
 	/* Strip " Standard Time" / " Daylight Time" from name */
 	p = windows_timezone + strlen (windows_timezone) - 1;
@@ -1348,7 +1365,7 @@ find_olson_timezone (const char *windows_timezone)
 			strncpy (country, locale, 2);
 	}
 #ifdef G_OS_WIN32
-	g_free ((char *) locale);
+	g_free ((gchar *) locale);
 #endif
 
 	/* Look for an entry where either the country or the
@@ -1378,9 +1395,9 @@ static void
 read_config (void)
 {
 	struct stat st;
-	char *p, *name, *value;
-	char *config_data;
-	int fd = -1;
+	gchar *p, *name, *value;
+	gchar *config_data;
+	gint fd = -1;
 
 	config_options = g_hash_table_new (e2k_ascii_strcase_hash,
 					    e2k_ascii_strcase_equal);
@@ -1420,7 +1437,7 @@ read_config (void)
 	p = config_data;
 
 	while (1) {
-		for (name = p; isspace ((unsigned char)*name); name++)
+		for (name = p; isspace ((guchar)*name); name++)
 			;
 
 		p = strchr (name, ':');
@@ -1452,8 +1469,8 @@ read_config (void)
  *
  * Return value: the string value of the option, or %NULL if it is unset.
  **/
-const char *
-e2k_autoconfig_lookup_option (const char *option)
+const gchar *
+e2k_autoconfig_lookup_option (const gchar *option)
 {
 	if (!config_options)
 		read_config ();
@@ -1461,21 +1478,21 @@ e2k_autoconfig_lookup_option (const char *option)
 }
 
 static gboolean
-validate (const char *owa_url, char *user, char *password, ExchangeParams *exchange_params, E2kAutoconfigResult *result)
+validate (const gchar *owa_url, gchar *user, gchar *password, ExchangeParams *exchange_params, E2kAutoconfigResult *result)
 {
 	E2kAutoconfig *ac;
 	E2kOperation op;        /* FIXME */
 	E2kUri *euri;
 	gboolean valid = FALSE;
-	const char *old, *new;
-	char *path, *mailbox;
+	const gchar *old, *new;
+	gchar *path, *mailbox;
 
 	ac = e2k_autoconfig_new (owa_url, user, password,
 				 E2K_AUTOCONFIG_USE_EITHER);
 
 	e2k_operation_init (&op);
-	// e2k_autoconfig_set_gc_server (ac, ad_server, gal_limit) FIXME
-	// e2k_autoconfig_set_gc_server (ac, NULL, -1);
+	/* e2k_autoconfig_set_gc_server (ac, ad_server, gal_limit) FIXME */
+	/* e2k_autoconfig_set_gc_server (ac, NULL, -1); */
 	*result = e2k_autoconfig_check_exchange (ac, &op);
 
 	if (*result == E2K_AUTOCONFIG_OK) {
@@ -1499,6 +1516,8 @@ validate (const char *owa_url, char *user, char *password, ExchangeParams *excha
 	}
 
 	if (*result == E2K_AUTOCONFIG_OK) {
+		gint len;
+
 		*result = e2k_autoconfig_check_global_catalog (ac, &op);
 		e2k_operation_free (&op);
 
@@ -1506,15 +1525,34 @@ validate (const char *owa_url, char *user, char *password, ExchangeParams *excha
 		euri = e2k_uri_new (ac->home_uri);
 		path = g_strdup (euri->path + 1);
 		e2k_uri_free (euri);
-		mailbox = strrchr (path, '/');
-		if (mailbox && !mailbox[1]) {
-			*mailbox = '\0';
-			mailbox = strrchr (path, '/');
-		}
-		if (mailbox)
-			*mailbox++ = '\0';
 
-		exchange_params->mailbox  = g_strdup (mailbox);
+		/* no slash at the end of path */
+		len = strlen (path);
+		while (len && path [len - 1] == '/') {
+			path [len - 1] = '\0';
+			len--;
+		}
+
+		/* change a mailbox only if not set by the caller */
+		if (!exchange_params->mailbox || !*exchange_params->mailbox) {
+			mailbox = strrchr (path, '/');
+			if (mailbox && !mailbox[1]) {
+				*mailbox = '\0';
+				mailbox = strrchr (path, '/');
+			}
+			if (mailbox)
+				*mailbox++ = '\0';
+
+			g_free (exchange_params->mailbox);
+			exchange_params->mailbox  = g_strdup (mailbox);
+		} else {
+			/* always strip the mailbox part from the path */
+			gchar *slash = strrchr (path, '/');
+
+			if (slash)
+				*slash = '\0';
+		}
+
 		exchange_params->owa_path = g_strdup_printf ("%s%s", "/", path);
 		g_free (path);
 		exchange_params->host = g_strdup (ac->pf_server);
@@ -1538,18 +1576,18 @@ validate (const char *owa_url, char *user, char *password, ExchangeParams *excha
 
 			/* SURF : e_notice (NULL, GTK_MESSAGE_ERROR,
 				  _("Could not connect to the Exchange "
-			    	    "server.\nMake sure the URL is correct "
-			    	    "(try \"%s\" instead of \"%s\"?) "
-			    	    "and try again."), new, old);
+				    "server.\nMake sure the URL is correct "
+				    "(try \"%s\" instead of \"%s\"?) "
+				    "and try again."), new, old);
 			*/
 			valid = FALSE;
 			break;
 
 		case E2K_AUTOCONFIG_CANT_RESOLVE:
 		/* SURF :	e_notice (NULL, GTK_MESSAGE_ERROR,
-			  	_("Could not locate Exchange server.\n"
-			    	  "Make sure the server name is spelled correctly "
-			    	  "and try again."));
+				_("Could not locate Exchange server.\n"
+				  "Make sure the server name is spelled correctly "
+				  "and try again."));
 		*/
 			valid = FALSE;
 			break;
@@ -1558,22 +1596,22 @@ validate (const char *owa_url, char *user, char *password, ExchangeParams *excha
 		case E2K_AUTOCONFIG_AUTH_ERROR_TRY_NTLM:
 		case E2K_AUTOCONFIG_AUTH_ERROR_TRY_BASIC:
 		/* SURF :	e_notice (NULL, GTK_MESSAGE_ERROR,
-			  	_("Could not authenticate to the Exchange "
-			    	  "server.\nMake sure the username and "
-			    	  "password are correct and try again."));
+				_("Could not authenticate to the Exchange "
+				  "server.\nMake sure the username and "
+				  "password are correct and try again."));
 		*/
 			valid = FALSE;
 			break;
 
 		case E2K_AUTOCONFIG_AUTH_ERROR_TRY_DOMAIN:
-		/* SURF : 		e_notice (NULL, GTK_MESSAGE_ERROR,
-			  	_("Could not authenticate to the Exchange "
-			    	  "server.\nMake sure the username and "
-			    	  "password are correct and try again.\n\n"
-			    	  "You may need to specify the Windows "
-			    	  "domain name as part of your username "
-			    	  "(eg, \"MY-DOMAIN\\%s\")."),
-			  	  ac->username);
+		/* SURF :		e_notice (NULL, GTK_MESSAGE_ERROR,
+				_("Could not authenticate to the Exchange "
+				  "server.\nMake sure the username and "
+				  "password are correct and try again.\n\n"
+				  "You may need to specify the Windows "
+				  "domain name as part of your username "
+				  "(eg, \"MY-DOMAIN\\%s\")."),
+				  ac->username);
 		*/
 			valid = FALSE;
 			break;
@@ -1581,8 +1619,8 @@ validate (const char *owa_url, char *user, char *password, ExchangeParams *excha
 		case E2K_AUTOCONFIG_NO_OWA:
 		case E2K_AUTOCONFIG_NOT_EXCHANGE:
 		/* SURF :	e_notice (NULL, GTK_MESSAGE_ERROR,
-			  	_("Could not find OWA data at the indicated URL.\n"
-			    	  "Make sure the URL is correct and try again."));
+				_("Could not find OWA data at the indicated URL.\n"
+				  "Make sure the URL is correct and try again."));
 		*/
 			valid = FALSE;
 			break;
@@ -1591,13 +1629,13 @@ validate (const char *owa_url, char *user, char *password, ExchangeParams *excha
 		/* SURF :	e_notice (
 				NULL, GTK_MESSAGE_ERROR,
 				_("Ximian Connector requires access to certain "
-			  	"functionality on the Exchange Server that appears "
-			  	"to be disabled or blocked.  (This is usually "
-			  	"unintentional.)  Your Exchange Administrator will "
-			  	"need to enable this functionality in order for "
-			  	"you to be able to use Ximian Connector.\n\n"
-			  	"For information to provide to your Exchange "
-			  	"administrator, please follow the link below:\n"
+				"functionality on the Exchange Server that appears "
+				"to be disabled or blocked.  (This is usually "
+				"unintentional.)  Your Exchange Administrator will "
+				"need to enable this functionality in order for "
+				"you to be able to use Ximian Connector.\n\n"
+				"For information to provide to your Exchange "
+				"administrator, please follow the link below:\n"
 				"http://support.novell.com/cgi-bin/search/searchtid.cgi?/ximian/ximian328.html "));
 		*/
 			valid = FALSE;
@@ -1607,17 +1645,17 @@ validate (const char *owa_url, char *user, char *password, ExchangeParams *excha
 		/* SURF :	e_notice (
 				NULL, GTK_MESSAGE_ERROR,
 				_("The Exchange server URL you provided is for an "
-			  	"Exchange 5.5 Server. Ximian Connector supports "
-			  	"Microsoft Exchange 2000 and 2003 only."));
+				"Exchange 5.5 Server. Ximian Connector supports "
+				"Microsoft Exchange 2000 and 2003 only."));
 		*/
 			valid = FALSE;
 			break;
 
 		default:
 		/* SURF :	e_notice (NULL, GTK_MESSAGE_ERROR,
-			  	_("Could not configure Exchange account because "
-			    	  "an unknown error occurred. Check the URL, "
-			    	  "username, and password, and try again."));
+				_("Could not configure Exchange account because "
+				  "an unknown error occurred. Check the URL, "
+				  "username, and password, and try again."));
 		*/
 			valid = FALSE; /* FIXME return valid */
 			break;
@@ -1629,15 +1667,15 @@ validate (const char *owa_url, char *user, char *password, ExchangeParams *excha
 }
 
 gboolean
-e2k_validate_user (const char *owa_url, char *pkey, char **user,
+e2k_validate_user (const gchar *owa_url, gchar *pkey, gchar **user,
 		   ExchangeParams *exchange_params, gboolean *remember_password,
 		   E2kAutoconfigResult *result, GtkWindow *parent)
 {
 	gboolean valid = FALSE, remember=FALSE;
-	char *key, *password, *prompt;
-	char *username;
+	gchar *key, *password, *prompt;
+	gchar *username;
 	gchar **usernames;
-	int try = 0;
+	gint try = 0;
 	EUri *uri;
 
 	uri = e_uri_new (owa_url);
