@@ -36,15 +36,16 @@ struct E2kProperties {
 };
 
 typedef struct {
-	char *name;
-	const char *namespace;
-	const char *short_name;
+	gchar *name;
+	const gchar *namespace;
+	const gchar *short_name;
 
 	E2kPropType type;
 	guint32 proptag;
 } E2kPropInfo;
 
 static GHashTable *known_properties;
+static GStaticMutex known_properties_lock = G_STATIC_MUTEX_INIT;
 
 /**
  * e2k_properties_new:
@@ -68,18 +69,21 @@ e2k_properties_new (void)
 static void
 copy_prop (gpointer key, gpointer value, gpointer data)
 {
-	const char *name = key;
+	const gchar *name = key;
 	GHashTable *props_copy = data;
 	gpointer value_copy;
 	E2kPropInfo *pi;
 
+	g_static_mutex_lock (&known_properties_lock);
 	pi = g_hash_table_lookup (known_properties, name);
+	g_static_mutex_unlock (&known_properties_lock);
+
 	switch (pi->type) {
 	case E2K_PROP_TYPE_BINARY_ARRAY:
 	{
 		GPtrArray *orig = value, *copy;
 		GByteArray *new, *old;
-		int i;
+		gint i;
 
 		copy = g_ptr_array_new ();
 		for (i = 0; i < orig->len; i++) {
@@ -95,7 +99,7 @@ copy_prop (gpointer key, gpointer value, gpointer data)
 	case E2K_PROP_TYPE_STRING_ARRAY:
 	{
 		GPtrArray *orig = value, *copy;
-		int i;
+		gint i;
 
 		copy = g_ptr_array_new ();
 		for (i = 0; i < orig->len; i++)
@@ -158,7 +162,7 @@ free_prop (E2kPropInfo *pi, gpointer value)
 	case E2K_PROP_TYPE_BINARY_ARRAY:
 	{
 		GPtrArray *array = value;
-		int i;
+		gint i;
 
 		for (i = 0; i < array->len; i++)
 			g_byte_array_free (array->pdata[i], TRUE);
@@ -170,7 +174,7 @@ free_prop (E2kPropInfo *pi, gpointer value)
 	case E2K_PROP_TYPE_INT_ARRAY:
 	{
 		GPtrArray *array = value;
-		int i;
+		gint i;
 
 		for (i = 0; i < array->len; i++)
 			g_free (array->pdata[i]);
@@ -198,7 +202,9 @@ properties_free_cb (gpointer key, gpointer value, gpointer data)
 {
 	E2kPropInfo *pi;
 
+	g_static_mutex_lock (&known_properties_lock);
 	pi = g_hash_table_lookup (known_properties, key);
+	g_static_mutex_unlock (&known_properties_lock);
 	if (pi)
 		free_prop (pi, value);
 }
@@ -232,7 +238,7 @@ e2k_properties_free (E2kProperties *props)
  * @props.
  **/
 gpointer
-e2k_properties_get_prop (E2kProperties *props, const char *propname)
+e2k_properties_get_prop (E2kProperties *props, const gchar *propname)
 {
 	g_return_val_if_fail (props != NULL, NULL);
 
@@ -257,13 +263,14 @@ e2k_properties_empty (E2kProperties *props)
 }
 
 
-extern char e2k_des_key[8];
+extern gchar e2k_des_key[8];
 
 static E2kPropInfo *
-get_propinfo (const char *propname, E2kPropType type)
+get_propinfo (const gchar *propname, E2kPropType type)
 {
 	E2kPropInfo *pi;
 
+	g_static_mutex_lock (&known_properties_lock);
 	if (!known_properties)
 		known_properties = g_hash_table_new (g_str_hash, g_str_equal);
 
@@ -271,6 +278,7 @@ get_propinfo (const char *propname, E2kPropType type)
 	if (pi) {
 		if (pi->type == E2K_PROP_TYPE_UNKNOWN)
 			pi->type = type;
+		g_static_mutex_unlock (&known_properties_lock);
 		return pi;
 	}
 
@@ -287,6 +295,8 @@ get_propinfo (const char *propname, E2kPropType type)
 
 	g_hash_table_insert (known_properties, pi->name, pi);
 
+	g_static_mutex_unlock (&known_properties_lock);
+
 	return pi;
 }
 
@@ -390,7 +400,7 @@ get_propinfo (const char *propname, E2kPropType type)
 #define E2K_PROPERTIES_SETTER(fname, valuetype, pitype, data)		\
 void									\
 e2k_properties_set_ ## fname (E2kProperties *props,			\
-			      const char    *propname,			\
+			      const gchar    *propname,			\
 			      valuetype      value)			\
 {									\
 	E2kPropInfo *pi;						\
@@ -401,7 +411,7 @@ e2k_properties_set_ ## fname (E2kProperties *props,			\
 	g_hash_table_remove (props->removed, pi->name);			\
 }
 
-E2K_PROPERTIES_SETTER (string, char *, STRING, value)
+E2K_PROPERTIES_SETTER (string, gchar *, STRING, value)
 E2K_PROPERTIES_SETTER (string_array, GPtrArray *, STRING_ARRAY, value)
 E2K_PROPERTIES_SETTER (binary, GByteArray *, BINARY, value)
 E2K_PROPERTIES_SETTER (binary_array, GPtrArray *, BINARY_ARRAY, value)
@@ -411,7 +421,7 @@ E2K_PROPERTIES_SETTER (int, int, INT, g_strdup_printf ("%d", value))
 E2K_PROPERTIES_SETTER (int_array, GPtrArray *, INT_ARRAY, value)
 E2K_PROPERTIES_SETTER (float, float, FLOAT, g_strdup_printf ("%f", value))
 E2K_PROPERTIES_SETTER (bool, gboolean, BOOL, g_strdup_printf ("%d", value != FALSE))
-E2K_PROPERTIES_SETTER (date, char *, DATE, value)
+E2K_PROPERTIES_SETTER (date, gchar *, DATE, value)
 
 
 
@@ -440,7 +450,7 @@ E2K_PROPERTIES_SETTER (date, char *, DATE, value)
 #define E2K_PROPERTIES_SETTER_AS(fname, valuetype)			\
 void									\
 e2k_properties_set_type_as_ ## fname (E2kProperties *props,		\
-				      const char    *propname,		\
+				      const gchar    *propname,		\
 				      E2kPropType    type,		\
 				      valuetype      value)		\
 {									\
@@ -452,7 +462,7 @@ e2k_properties_set_type_as_ ## fname (E2kProperties *props,		\
 	g_hash_table_remove (props->removed, pi->name);			\
 }
 
-E2K_PROPERTIES_SETTER_AS (string, char *)
+E2K_PROPERTIES_SETTER_AS (string, gchar *)
 E2K_PROPERTIES_SETTER_AS (string_array, GPtrArray *)
 
 /**
@@ -466,7 +476,7 @@ E2K_PROPERTIES_SETTER_AS (string_array, GPtrArray *)
  * this frees the old value.
  **/
 void
-e2k_properties_remove (E2kProperties *props, const char *propname)
+e2k_properties_remove (E2kProperties *props, const gchar *propname)
 {
 	E2kPropInfo *pi;
 
@@ -487,7 +497,9 @@ foreach_callback (gpointer key, gpointer value, gpointer data)
 	struct foreach_data *fd = data;
 	E2kPropInfo *pi;
 
+	g_static_mutex_lock (&known_properties_lock);
 	pi = g_hash_table_lookup (known_properties, key);
+	g_static_mutex_unlock (&known_properties_lock);
 	if (pi)
 		fd->callback (pi->name, pi->type, value, fd->user_data);
 }
@@ -554,16 +566,18 @@ foreach_namespace_callback (gpointer key, gpointer value, gpointer data)
 {
 	struct foreach_namespace_data *fnd = data;
 	E2kPropInfo *pi;
-	const char *name;
+	const gchar *name;
 
+	g_static_mutex_lock (&known_properties_lock);
 	pi = g_hash_table_lookup (known_properties, key);
+	g_static_mutex_unlock (&known_properties_lock);
 	if (!pi)
 		return;
 
 	name = e2k_prop_namespace_name (pi->name);
 	if (!g_hash_table_lookup (fnd->seen_namespaces, name)) {
 		g_hash_table_insert (fnd->seen_namespaces,
-				     (char *)name, (char *)name);
+				     (gchar *)name, (gchar *)name);
 		fnd->callback (name, e2k_prop_namespace_abbrev (pi->name),
 			       fnd->user_data);
 	}
@@ -626,13 +640,13 @@ e2k_properties_foreach_namespace (E2kProperties *props,
 
 
 static GHashTable *namespaces;
-static int next_namespace = 'a';
+static gint next_namespace = 'a';
+static GStaticMutex namespaces_lock = G_STATIC_MUTEX_INIT;
 
-
-static const char *
-get_div (const char *propname)
+static const gchar *
+get_div (const gchar *propname)
 {
-	const char *div;
+	const gchar *div;
 
 	div = strrchr (propname, '/');
 	if (div)
@@ -643,8 +657,8 @@ get_div (const char *propname)
 static gint
 prop_equal (gconstpointer v1, gconstpointer v2)
 {
-	const char *s1 = (const char *)v1, *s2 = (const char *)v2;
-	const char *d1 = get_div (s1), *d2 = get_div (s2);
+	const gchar *s1 = (const gchar *)v1, *s2 = (const gchar *)v2;
+	const gchar *d1 = get_div (s1), *d2 = get_div (s2);
 
 	return (d1 - s1 == d2 - s2) && !g_ascii_strncasecmp (s1, s2, d1 - s1);
 }
@@ -652,8 +666,8 @@ prop_equal (gconstpointer v1, gconstpointer v2)
 static guint
 prop_hash (gconstpointer v)
 {
-	const char *d = get_div (v);
-	const char *p = v;
+	const gchar *d = get_div (v);
+	const gchar *p = v;
 	guint h = g_ascii_tolower (*p);
 
 	for (p += 1; p < d; p++)
@@ -665,7 +679,7 @@ static void
 setup_namespaces (void)
 {
 	namespaces = g_hash_table_new (prop_hash, prop_equal);
-	g_hash_table_insert (namespaces, "DAV", GINT_TO_POINTER ('D'));
+	g_hash_table_insert (namespaces, (gpointer) "DAV", GINT_TO_POINTER ('D'));
 }
 
 /**
@@ -676,22 +690,26 @@ setup_namespaces (void)
  *
  * Return value: the URI of @prop's namespace
  **/
-const char *
-e2k_prop_namespace_name (const char *prop)
+const gchar *
+e2k_prop_namespace_name (const gchar *prop)
 {
-	const char *div = get_div (prop);
+	const gchar *div = get_div (prop);
 	gpointer key, value;
-	char *name;
+	gchar *name;
 
+	g_static_mutex_lock (&namespaces_lock);
 	if (!namespaces)
 		setup_namespaces ();
 
-	if (g_hash_table_lookup_extended (namespaces, prop, &key, &value))
+	if (g_hash_table_lookup_extended (namespaces, prop, &key, &value)) {
+		g_static_mutex_unlock (&namespaces_lock);
 		return key;
+	}
 
 	name = g_strndup (prop, div - prop + 1);
 	g_hash_table_insert (namespaces, name, GINT_TO_POINTER (next_namespace));
 	next_namespace++;
+	g_static_mutex_unlock (&namespaces_lock);
 	return name;
 }
 
@@ -704,22 +722,28 @@ e2k_prop_namespace_name (const char *prop)
  *
  * Return value: the abbreviation used for prop's namespace
  **/
-char
-e2k_prop_namespace_abbrev (const char *prop)
+gchar
+e2k_prop_namespace_abbrev (const gchar *prop)
 {
-	const char *div = get_div (prop);
+	const gchar *div = get_div (prop);
 	gpointer key, value;
-	char *name;
+	gchar *name, res;
 
+	g_static_mutex_lock (&namespaces_lock);
 	if (!namespaces)
 		setup_namespaces ();
 
-	if (g_hash_table_lookup_extended (namespaces, prop, &key, &value))
+	if (g_hash_table_lookup_extended (namespaces, prop, &key, &value)) {
+		g_static_mutex_unlock (&namespaces_lock);
 		return GPOINTER_TO_INT (value);
+	}
 
 	name = g_strndup (prop, div - prop + 1);
 	g_hash_table_insert (namespaces, name, GINT_TO_POINTER (next_namespace));
-	return next_namespace++;
+	res = next_namespace++;
+	g_static_mutex_unlock (&namespaces_lock);
+
+	return res;
 }
 
 /**
@@ -730,8 +754,8 @@ e2k_prop_namespace_abbrev (const char *prop)
  *
  * Return value: the non-namespaced name of @prop
  **/
-const char *
-e2k_prop_property_name (const char *prop)
+const gchar *
+e2k_prop_property_name (const gchar *prop)
 {
 	return get_div (prop) + 1;
 }
@@ -742,11 +766,11 @@ e2k_prop_property_name (const char *prop)
  *
  * Computes the MAPI proptag value of @prop, which must be the name
  * of a MAPI property.
- * 
+ *
  * Return value: the MAPI proptag value
  **/
 guint32
-e2k_prop_proptag (const char *prop)
+e2k_prop_proptag (const gchar *prop)
 {
 	E2kPropInfo *pi;
 
@@ -763,11 +787,11 @@ e2k_prop_proptag (const char *prop)
  *
  * Return value: the WebDAV property name associated with @proptag
  **/
-const char *
+const gchar *
 e2k_proptag_prop (guint32 proptag)
 {
 	E2kPropInfo *pi;
-	char *tmpname;
+	gchar *tmpname;
 
 	tmpname = g_strdup_printf (E2K_NS_MAPI_PROPTAG "x%08x",
 				   (unsigned)proptag);
