@@ -31,17 +31,17 @@
 #include "e2k-utils.h"
 #include "mapi.h"
 
-static const char *contains_types[] = { NULL, "contains", NULL, NULL, NULL, "not contains", NULL, NULL };
-static const char *subject_types[] = { "is", "contains", "starts with", NULL, "is not", "not contains", "not starts with", NULL };
+static const gchar *contains_types[] = { NULL, "contains", NULL, NULL, NULL, "not contains", NULL, NULL };
+static const gchar *subject_types[] = { "is", "contains", "starts with", NULL, "is not", "not contains", "not starts with", NULL };
 #define E2K_FL_NEGATE 4
 #define E2K_FL_MAX 8
 
 #if 0
 static gboolean
-fuzzy_level_from_name (const char *name, const char *map[],
-		       int *fuzzy_level, gboolean *negated)
+fuzzy_level_from_name (const gchar *name, const gchar *map[],
+		       gint *fuzzy_level, gboolean *negated)
 {
-	int i;
+	gint i;
 
 	for (i = 0; i < E2K_FL_MAX; i++) {
 		if (map[i] && !strcmp (name, map[i])) {
@@ -55,8 +55,8 @@ fuzzy_level_from_name (const char *name, const char *map[],
 }
 #endif
 
-static inline const char *
-fuzzy_level_to_name (int fuzzy_level, gboolean negated, const char *map[])
+static inline const gchar *
+fuzzy_level_to_name (gint fuzzy_level, gboolean negated, const gchar *map[])
 {
 	fuzzy_level = E2K_FL_MATCH_TYPE (fuzzy_level);
 	if (negated)
@@ -65,16 +65,16 @@ fuzzy_level_to_name (int fuzzy_level, gboolean negated, const char *map[])
 	return map[fuzzy_level];
 }
 
-static const char *is_types[] = { NULL, NULL, NULL, NULL, "is", "is not" };
-static const char *date_types[] = { "before", "before", "after", "after", NULL, NULL };
-static const char *size_types[] = { "less than", "less than", "greater than", "greater than", NULL, NULL };
+static const gchar *is_types[] = { NULL, NULL, NULL, NULL, "is", "is not" };
+static const gchar *date_types[] = { "before", "before", "after", "after", NULL, NULL };
+static const gchar *gsizeypes[] = { "less than", "less than", "greater than", "greater than", NULL, NULL };
 
 #if 0
 static gboolean
-relop_from_name (const char *name, const char *map[],
+relop_from_name (const gchar *name, const gchar *map[],
 		 E2kRestrictionRelop *relop)
 {
-	int i;
+	gint i;
 
 	for (i = 0; i < E2K_RELOP_RE; i++) {
 		if (map[i] && !strcmp (name, map[i])) {
@@ -87,10 +87,10 @@ relop_from_name (const char *name, const char *map[],
 }
 #endif
 
-static inline const char *
-relop_to_name (E2kRestrictionRelop relop, gboolean negated, const char *map[])
+static inline const gchar *
+relop_to_name (E2kRestrictionRelop relop, gboolean negated, const gchar *map[])
 {
-	static const int negate_map[] = {
+	static const gint negate_map[] = {
 		E2K_RELOP_GE, E2K_RELOP_GT, E2K_RELOP_LE, E2K_RELOP_LT,
 		E2K_RELOP_NE, E2K_RELOP_EQ
 	};
@@ -179,70 +179,84 @@ restriction_is_delegation (E2kRestriction *rn)
 }
 
 static xmlNode *
-new_value (xmlNode *part, const char *name, const char *type, const char *value)
+new_value (xmlNode *part,
+           const xmlChar *name,
+           const xmlChar *type,
+           const xmlChar *value)
 {
 	xmlNode *node;
 
-	node = xmlNewChild (part, NULL, "value", NULL);
-	xmlSetProp (node, "name", name);
-	xmlSetProp (node, "type", type);
+	node = xmlNewChild (part, NULL, (xmlChar *) "value", NULL);
+	xmlSetProp (node, (xmlChar *) "name", name);
+	xmlSetProp (node, (xmlChar *) "type", type);
 	if (value)
-		xmlSetProp (node, "value", value);
+		xmlSetProp (node, (xmlChar *) "value", value);
 
 	return node;
 }
 
 static xmlNode *
-new_value_int (xmlNode *part, const char *name, const char *type,
-	       const char *value_name, long value)
+new_value_int (xmlNode *part,
+               const xmlChar *name,
+               const xmlChar *type,
+               const xmlChar *value_name,
+               glong value)
 {
 	xmlNode *node;
-	char *str;
+	gchar *str;
 
-	node = xmlNewChild (part, NULL, "value", NULL);
-	xmlSetProp (node, "name", name);
-	xmlSetProp (node, "type", type);
+	node = xmlNewChild (part, NULL, (xmlChar *) "value", NULL);
+	xmlSetProp (node, (xmlChar *) "name", name);
+	xmlSetProp (node, (xmlChar *) "type", type);
 
 	str = g_strdup_printf ("%ld", value);
-	xmlSetProp (node, value_name, str);
+	xmlSetProp (node, (xmlChar *) value_name, (xmlChar *) str);
 	g_free (str);
 
 	return node;
 }
 
 static xmlNode *
-new_part (const char *part_name)
+new_part (const xmlChar *part_name)
 {
 	xmlNode *part;
 
-	part = xmlNewNode (NULL, "part");
-	xmlSetProp (part, "name", part_name);
+	part = xmlNewNode (NULL, (xmlChar *) "part");
+	xmlSetProp (part, (xmlChar *) "name", part_name);
 	return part;
 }
 
 static xmlNode *
-match (const char *part_name, const char *value_name, const char *value_value,
-       const char *string_name, const char *string_value)
+match (const xmlChar *part_name,
+       const xmlChar *value_name,
+       const xmlChar *value_value,
+       const xmlChar *string_name,
+       const xmlChar *string_value)
 {
 	xmlNode *part, *value;
 
 	part = new_part (part_name);
-	value = new_value (part, value_name, "option", value_value);
-	value = new_value (part, string_name, "string", NULL);
-	xmlNewTextChild (value, NULL, "string", string_value);
+	value = new_value (
+		part, value_name, (xmlChar *) "option", value_value);
+	value = new_value (part, string_name, (xmlChar *) "string", NULL);
+	xmlNewTextChild (value, NULL, (xmlChar *) "string", string_value);
 
 	return part;
 }
 
 static xmlNode *
-message_is (const char *name, const char *type_name,
-	    const char *kind, gboolean negated)
+message_is (const xmlChar *name,
+            const xmlChar *type_name,
+            const xmlChar *kind,
+            gboolean negated)
 {
 	xmlNode *part;
 
 	part = new_part (name);
-	new_value (part, type_name, "option", negated ? "is not" : "is");
-	new_value (part, "kind", "option", kind);
+	new_value (
+		part, type_name, (xmlChar *) "option",
+		negated ? (xmlChar *) "is not" : (xmlChar *) "is");
+	new_value (part, (xmlChar *) "kind", (xmlChar *) "option", kind);
 
 	return part;
 }
@@ -253,10 +267,10 @@ address_is (E2kRestriction *comment_rn, gboolean recipients, gboolean negated)
 	xmlNode *part;
 	E2kRestriction *rn;
 	E2kPropValue *pv;
-	const char *relation, *display_name, *p;
-	char *addr, *full_addr;
+	const gchar *relation, *display_name, *p;
+	gchar *addr, *full_addr;
 	GByteArray *ba;
-	int i;
+	gint i;
 
 	rn = comment_rn->res.comment.rn;
 	if (rn->type != E2K_RESTRICTION_PROPERTY ||
@@ -274,11 +288,11 @@ address_is (E2kRestriction *comment_rn, gboolean recipients, gboolean negated)
 
 	/* Extract the address part */
 	ba = pv->value;
-	p = strchr ((char *)ba->data, ':');
+	p = strchr ((gchar *)ba->data, ':');
 	if (p)
 		addr = g_ascii_strdown (p + 1, -1);
 	else
-		addr = g_ascii_strdown ((char *)ba->data, -1);
+		addr = g_ascii_strdown ((gchar *)ba->data, -1);
 
 	/* Find the display name in the comment */
 	display_name = NULL;
@@ -296,11 +310,19 @@ address_is (E2kRestriction *comment_rn, gboolean recipients, gboolean negated)
 		full_addr = g_strdup_printf ("<%s>", addr);
 
 	if (recipients) {
-		part = match ("recipient", "recipient-type", relation,
-			      "recipient", full_addr);
+		part = match (
+			(xmlChar *) "recipient",
+			(xmlChar *) "recipient-type",
+			(xmlChar *) relation,
+			(xmlChar *) "recipient",
+			(xmlChar *) full_addr);
 	} else {
-		part = match ("sender", "sender-type", relation,
-			      "sender", full_addr);
+		part = match (
+			(xmlChar *) "sender",
+			(xmlChar *) "sender-type",
+			(xmlChar *) relation,
+			(xmlChar *) "sender",
+			(xmlChar *) full_addr);
 	}
 
 	g_free (full_addr);
@@ -314,23 +336,25 @@ restriction_to_xml (E2kRestriction *rn, xmlNode *partset,
 {
 	xmlNode *part, *value, *node;
 	E2kPropValue *pv;
-	const char *match_type;
-	int i;
+	const gchar *match_type;
+	gint i;
 
 	switch (rn->type) {
 	case E2K_RESTRICTION_AND:
 	case E2K_RESTRICTION_OR:
 		/* Check for special rules */
 		if (restriction_is_only_to_me (rn)) {
-			part = message_is ("message-to-me",
-					   "message-to-me-type",
-					   "only", negated);
+			part = message_is (
+				(xmlChar *) "message-to-me",
+				(xmlChar *) "message-to-me-type",
+				(xmlChar *) "only", negated);
 			break;
 		} else if (restriction_is_delegation (rn)) {
-			part = message_is ("special-message",
-					   "special-message-type",
-					   "delegated-meeting-request",
-					   negated);
+			part = message_is (
+				(xmlChar *) "special-message",
+				(xmlChar *) "special-message-type",
+				(xmlChar *) "delegated-meeting-request",
+				negated);
 			break;
 		}
 
@@ -371,7 +395,7 @@ restriction_to_xml (E2kRestriction *rn, xmlNode *partset,
 
 	case E2K_RESTRICTION_CONTENT:
 	{
-		int fuzzy_level = E2K_FL_MATCH_TYPE (rn->res.content.fuzzy_level);
+		gint fuzzy_level = E2K_FL_MATCH_TYPE (rn->res.content.fuzzy_level);
 
 		pv = &rn->res.content.pv;
 
@@ -382,8 +406,12 @@ restriction_to_xml (E2kRestriction *rn, xmlNode *partset,
 			if (!match_type)
 				return FALSE;
 
-			part = match ("body", "body-type", match_type,
-				      "word", pv->value);
+			part = match (
+				(xmlChar *) "body",
+				(xmlChar *) "body-type",
+				(xmlChar *) match_type,
+				(xmlChar *) "word",
+				(xmlChar *) pv->value);
 			break;
 
 		case E2K_PROPTAG_PR_SUBJECT:
@@ -392,8 +420,12 @@ restriction_to_xml (E2kRestriction *rn, xmlNode *partset,
 			if (!match_type)
 				return FALSE;
 
-			part = match ("subject", "subject-type", match_type,
-				      "subject", pv->value);
+			part = match (
+				(xmlChar *) "subject",
+				(xmlChar *) "subject-type",
+				(xmlChar *) match_type,
+				(xmlChar *) "subject",
+				(xmlChar *) pv->value);
 			break;
 
 		case E2K_PROPTAG_PR_TRANSPORT_MESSAGE_HEADERS:
@@ -402,21 +434,27 @@ restriction_to_xml (E2kRestriction *rn, xmlNode *partset,
 			if (!match_type)
 				return FALSE;
 
-			part = match ("full-headers", "full-headers-type",
-				      match_type, "word", pv->value);
+			part = match (
+				(xmlChar *) "full-headers",
+				(xmlChar *) "full-headers-type",
+				(xmlChar *) match_type,
+				(xmlChar *) "word",
+				(xmlChar *) pv->value);
 			break;
 
 		case E2K_PROPTAG_PR_MESSAGE_CLASS:
 			if ((fuzzy_level == E2K_FL_FULLSTRING) &&
 			    !strcmp (pv->value, "IPM.Note.Rules.OofTemplate.Microsoft")) {
-				part = message_is ("special-message",
-						   "special-message-type",
-						   "oof", negated);
+				part = message_is (
+					(xmlChar *) "special-message",
+					(xmlChar *) "special-message-type",
+					(xmlChar *) "oof", negated);
 			} else if ((fuzzy_level == E2K_FL_PREFIX) &&
 				   !strcmp (pv->value, "IPM.Schedule.Meeting")) {
-				part = message_is ("special-message",
-						   "special-message-type",
-						   "meeting-request", negated);
+				part = message_is (
+					(xmlChar *) "special-message",
+					(xmlChar *) "special-message-type",
+					(xmlChar *) "meeting-request", negated);
 			} else
 				return FALSE;
 
@@ -431,7 +469,7 @@ restriction_to_xml (E2kRestriction *rn, xmlNode *partset,
 	case E2K_RESTRICTION_PROPERTY:
 	{
 		E2kRestrictionRelop relop;
-		const char *relation;
+		const gchar *relation;
 
 		relop = rn->res.property.relop;
 		if (relop >= E2K_RELOP_RE)
@@ -445,9 +483,10 @@ restriction_to_xml (E2kRestriction *rn, xmlNode *partset,
 			    (relop == E2K_RELOP_NE && pv->value))
 				negated = !negated;
 
-			part = message_is ("message-to-me",
-					   "message-to-me-type",
-					   "to", negated);
+			part = message_is (
+				(xmlChar *) "message-to-me",
+				(xmlChar *) "message-to-me-type",
+				(xmlChar *) "to", negated);
 			break;
 
 		case E2K_PROPTAG_PR_MESSAGE_CC_ME:
@@ -455,49 +494,69 @@ restriction_to_xml (E2kRestriction *rn, xmlNode *partset,
 			    (relop == E2K_RELOP_NE && pv->value))
 				negated = !negated;
 
-			part = message_is ("message-to-me",
-					   "message-to-me-type",
-					   "cc", negated);
+			part = message_is (
+				(xmlChar *) "message-to-me",
+				(xmlChar *) "message-to-me-type",
+				(xmlChar *) "cc", negated);
 			break;
 
 		case E2K_PROPTAG_PR_MESSAGE_DELIVERY_TIME:
 		case E2K_PROPTAG_PR_CLIENT_SUBMIT_TIME:
 		{
-			char *timestamp;
+			gchar *timestamp;
 
 			relation = relop_to_name (relop, negated, date_types);
 			if (!relation)
 				return FALSE;
 
 			if (pv->prop.proptag == E2K_PROPTAG_PR_MESSAGE_DELIVERY_TIME)
-				part = new_part ("received-date");
+				part = new_part ((xmlChar *) "received-date");
 			else
-				part = new_part ("sent-date");
+				part = new_part ((xmlChar *) "sent-date");
 
-			value = new_value (part, "date-spec-type", "option", relation);
-			value = new_value (part, "versus", "datespec", NULL);
+			value = new_value (
+				part,
+				(xmlChar *) "date-spec-type",
+				(xmlChar *) "option",
+				(xmlChar *) relation);
+			value = new_value (
+				part,
+				(xmlChar *) "versus",
+				(xmlChar *) "datespec", NULL);
 
-			node = xmlNewChild (value, NULL, "datespec", NULL);
-			xmlSetProp (node, "type", "1");
+			node = xmlNewChild (
+				value, NULL, (xmlChar *) "datespec", NULL);
+			xmlSetProp (
+				node,
+				(xmlChar *) "type",
+				(xmlChar *) "1");
 
-			timestamp = g_strdup_printf ("%lu", (unsigned long)e2k_parse_timestamp (pv->value));
-			xmlSetProp (node, "value", timestamp);
+			timestamp = g_strdup_printf ("%lu", (gulong)e2k_parse_timestamp (pv->value));
+			xmlSetProp (
+				node,
+				(xmlChar *) "value",
+				(xmlChar *) timestamp);
 			g_free (timestamp);
-
 			break;
 		}
 
 		case E2K_PROPTAG_PR_MESSAGE_SIZE:
-			relation = relop_to_name (relop, negated, size_types);
+			relation = relop_to_name (relop, negated, gsizeypes);
 			if (!relation)
 				return FALSE;
 
-			part = new_part ("size");
-
-			new_value (part, "size-type", "option", relation);
-			new_value_int (part, "versus", "integer", "integer",
-				       GPOINTER_TO_INT (pv->value) / 1024);
-
+			part = new_part ((xmlChar *) "size");
+			new_value (
+				part,
+				(xmlChar *) "size-type",
+				(xmlChar *) "option",
+				(xmlChar *) relation);
+			new_value_int (
+				part,
+				(xmlChar *) "versus",
+				(xmlChar *) "integer",
+				(xmlChar *) "integer",
+				GPOINTER_TO_INT (pv->value) / 1024);
 			break;
 
 		case E2K_PROPTAG_PR_IMPORTANCE:
@@ -505,10 +564,18 @@ restriction_to_xml (E2kRestriction *rn, xmlNode *partset,
 			if (!relation)
 				return FALSE;
 
-			part = new_part ("importance");
-			new_value (part, "importance-type", "option", relation);
-			new_value_int (part, "importance", "option", "value",
-				       GPOINTER_TO_INT (pv->value));
+			part = new_part ((xmlChar *) "importance");
+			new_value (
+				part,
+				(xmlChar *) "importance-type",
+				(xmlChar *) "option",
+				(xmlChar *) relation);
+			new_value_int (
+				part,
+				(xmlChar *) "importance",
+				(xmlChar *) "option",
+				(xmlChar *) "value",
+				GPOINTER_TO_INT (pv->value));
 			break;
 
 		case E2K_PROPTAG_PR_SENSITIVITY:
@@ -516,11 +583,22 @@ restriction_to_xml (E2kRestriction *rn, xmlNode *partset,
 			if (!relation)
 				return FALSE;
 
-			part = new_part ("sensitivity");
-			xmlSetProp (part, "name", "sensitivity");
-			new_value (part, "sensitivity-type", "option", relation);
-			new_value_int (part, "sensitivity", "option", "value",
-				       GPOINTER_TO_INT (pv->value));
+			part = new_part ((xmlChar *) "sensitivity");
+			xmlSetProp (
+				part,
+				(xmlChar *) "name",
+				(xmlChar *) "sensitivity");
+			new_value (
+				part,
+				(xmlChar *) "sensitivity-type",
+				(xmlChar *) "option",
+				(xmlChar *) relation);
+			new_value_int (
+				part,
+				(xmlChar *) "sensitivity",
+				(xmlChar *) "option",
+				(xmlChar *) "value",
+				GPOINTER_TO_INT (pv->value));
 			break;
 
 		default:
@@ -540,13 +618,23 @@ restriction_to_xml (E2kRestriction *rn, xmlNode *partset,
 		    rn->res.bitmask.mask != MAPI_MSGFLAG_HASATTACH)
 			return FALSE;
 
-		part = new_part ("attachments");
+		part = new_part ((xmlChar *) "attachments");
 		if (rn->res.bitmask.bitop == E2K_BMR_NEZ) {
-			new_value (part, "match-type", "option",
-				   negated ? "not exist" : "exist");
+			new_value (
+				part,
+				(xmlChar *) "match-type",
+				(xmlChar *) "option",
+				negated ?
+				(xmlChar *) "not exist" :
+				(xmlChar *) "exist");
 		} else {
-			new_value (part, "match-type", "option",
-				   negated ? "exist" : "not exist");
+			new_value (
+				part,
+				(xmlChar *) "match-type",
+				(xmlChar *) "option",
+				negated ?
+				(xmlChar *) "exist" :
+				(xmlChar *) "not exist");
 		}
 		break;
 
@@ -570,12 +658,12 @@ restriction_to_xml (E2kRestriction *rn, xmlNode *partset,
 }
 
 
-static char *
-stringify_entryid (guint8 *data, int len)
+static gchar *
+stringify_entryid (guint8 *data, gint len)
 {
 	GString *string;
-	char *ret;
-	int i;
+	gchar *ret;
+	gint i;
 
 	string = g_string_new (NULL);
 
@@ -595,46 +683,76 @@ static gboolean
 action_to_xml (E2kAction *act, xmlNode *actionset)
 {
 	xmlNode *part, *value;
-	char *entryid;
+	gchar *entryid;
 
 	switch (act->type) {
 	case E2K_ACTION_MOVE:
 	case E2K_ACTION_COPY:
-		part = new_part (act->type == E2K_ACTION_MOVE ? "move-to-folder" : "copy-to-folder");
-		value = new_value (part, "folder", "folder-source-key", NULL);
+		part = new_part (
+			act->type == E2K_ACTION_MOVE ?
+			(xmlChar *) "move-to-folder" :
+			(xmlChar *) "copy-to-folder");
+		value = new_value (
+			part,
+			(xmlChar *) "folder",
+			(xmlChar *) "folder-source-key", NULL);
 		entryid = stringify_entryid (
 			act->act.xfer.folder_source_key->data + 1,
 			act->act.xfer.folder_source_key->len - 1);
-		xmlNewTextChild (value, NULL, "entryid", entryid);
+		xmlNewTextChild (
+			value, NULL,
+			(xmlChar *) "entryid",
+			(xmlChar *) entryid);
 		g_free (entryid);
 		break;
 
 	case E2K_ACTION_REPLY:
 	case E2K_ACTION_OOF_REPLY:
-		part = new_part (act->type == E2K_ACTION_REPLY ? "reply" : "oof-reply");
-		value = new_value (part, "template", "message-entryid", NULL);
+		part = new_part (
+			act->type == E2K_ACTION_REPLY ?
+			(xmlChar *) "reply" :
+			(xmlChar *) "oof-reply");
+		value = new_value (
+			part,
+			(xmlChar *) "template",
+			(xmlChar *) "message-entryid", NULL);
 		entryid = stringify_entryid (
 			act->act.reply.entryid->data,
 			act->act.reply.entryid->len);
-		xmlNewTextChild (value, NULL, "entryid", entryid);
+		xmlNewTextChild (
+			value, NULL,
+			(xmlChar *) "entryid",
+			(xmlChar *) entryid);
 		g_free (entryid);
 		break;
 
 	case E2K_ACTION_DEFER:
-		part = new_part ("defer");
+		part = new_part ((xmlChar *) "defer");
 		break;
 
 	case E2K_ACTION_BOUNCE:
-		part = new_part ("bounce");
+		part = new_part ((xmlChar *) "bounce");
 		switch (act->act.bounce_code) {
 		case E2K_ACTION_BOUNCE_CODE_TOO_LARGE:
-			new_value (part, "bounce_code", "option", "size");
+			new_value (
+				part,
+				(xmlChar *) "bounce_code",
+				(xmlChar *) "option",
+				(xmlChar *) "size");
 			break;
 		case E2K_ACTION_BOUNCE_CODE_FORM_MISMATCH:
-			new_value (part, "bounce_code", "option", "form-mismatch");
+			new_value (
+				part,
+				(xmlChar *) "bounce_code",
+				(xmlChar *) "option",
+				(xmlChar *) "form-mismatch");
 			break;
 		case E2K_ACTION_BOUNCE_CODE_ACCESS_DENIED:
-			new_value (part, "bounce_code", "option", "permission");
+			new_value (
+				part,
+				(xmlChar *) "bounce_code",
+				(xmlChar *) "option",
+				(xmlChar *) "permission");
 			break;
 		}
 		break;
@@ -642,12 +760,12 @@ action_to_xml (E2kAction *act, xmlNode *actionset)
 	case E2K_ACTION_FORWARD:
 	case E2K_ACTION_DELEGATE:
 	{
-		int i, j;
+		gint i, j;
 		E2kAddrList *list;
 		E2kAddrEntry *entry;
 		E2kPropValue *pv;
-		const char *display_name, *email;
-		char *full_addr;
+		const gchar *display_name, *email;
+		gchar *full_addr;
 
 		list = act->act.addr_list;
 		for (i = 0; i < list->nentries; i++) {
@@ -668,9 +786,18 @@ action_to_xml (E2kAction *act, xmlNode *actionset)
 			else
 				full_addr = g_strdup_printf ("<%s>", email);
 
-			part = new_part (act->type == E2K_ACTION_FORWARD ? "forward" : "delegate");
-			value = new_value (part, "recipient", "recipient", NULL);
-			xmlNewTextChild (value, NULL, "recipient", full_addr);
+			part = new_part (
+				act->type == E2K_ACTION_FORWARD ?
+				(xmlChar *) "forward" :
+				(xmlChar *) "delegate");
+			value = new_value (
+				part,
+				(xmlChar *) "recipient",
+				(xmlChar *) "recipient", NULL);
+			xmlNewTextChild (
+				value, NULL,
+				(xmlChar *) "recipient",
+				(xmlChar *) full_addr);
 			g_free (full_addr);
 
 			xmlAddChild (actionset, part);
@@ -682,17 +809,21 @@ action_to_xml (E2kAction *act, xmlNode *actionset)
 		if (act->act.proptag.prop.proptag != E2K_PROPTAG_PR_IMPORTANCE)
 			return FALSE;
 
-		part = new_part ("set-importance");
-		new_value_int (part, "importance", "option", "value",
-			       GPOINTER_TO_INT (act->act.proptag.value));
+		part = new_part ((xmlChar *) "set-importance");
+		new_value_int (
+			part,
+			(xmlChar *) "importance",
+			(xmlChar *) "option",
+			(xmlChar *) "value",
+			GPOINTER_TO_INT (act->act.proptag.value));
 		break;
 
 	case E2K_ACTION_DELETE:
-		part = new_part ("delete");
+		part = new_part ((xmlChar *) "delete");
 		break;
 
 	case E2K_ACTION_MARK_AS_READ:
-		part = new_part ("mark-read");
+		part = new_part ((xmlChar *) "mark-read");
 		break;
 
 	default:
@@ -708,28 +839,43 @@ rule_to_xml (E2kRule *rule, xmlNode *ruleset)
 {
 	xmlNode *top, *set;
 	E2kRestriction *rn;
-	int i;
+	gint i;
 
-	top = xmlNewChild (ruleset, NULL, "rule", NULL);
+	top = xmlNewChild (ruleset, NULL, (xmlChar *) "rule", NULL);
 
-	xmlSetProp (top, "source",
-		    (rule->state & E2K_RULE_STATE_ONLY_WHEN_OOF) ?
-		    "oof" : "incoming");
-	xmlSetProp (top, "enabled", (rule->state & E2K_RULE_STATE_ENABLED) ? "1" : "0");
+	xmlSetProp (
+		top,
+		(xmlChar *) "source",
+		(rule->state & E2K_RULE_STATE_ONLY_WHEN_OOF) ?
+		(xmlChar *) "oof" : (xmlChar *) "incoming");
+	xmlSetProp (
+		top,
+		(xmlChar *) "enabled",
+		(rule->state & E2K_RULE_STATE_ENABLED) ?
+		(xmlChar *) "1" : (xmlChar *) "0");
 
 	if (rule->name)
-		xmlNewTextChild (top, NULL, "title", rule->name);
+		xmlNewTextChild (
+			top, NULL,
+			(xmlChar *) "title",
+			(xmlChar *) rule->name);
 
-	set = xmlNewChild (top, NULL, "partset", NULL);
+	set = xmlNewChild (top, NULL, (xmlChar *) "partset", NULL);
 	rn = rule->condition;
 	if (rn) {
 		E2kRestrictionType wrap_type;
 
 		if (rn->type == E2K_RESTRICTION_OR) {
-			xmlSetProp (top, "grouping", "any");
+			xmlSetProp (
+				top,
+				(xmlChar *) "grouping",
+				(xmlChar *) "any");
 			wrap_type = E2K_RESTRICTION_OR;
 		} else {
-			xmlSetProp (top, "grouping", "all");
+			xmlSetProp (
+				top,
+				(xmlChar *) "grouping",
+				(xmlChar *) "all");
 			wrap_type = E2K_RESTRICTION_AND;
 		}
 
@@ -740,9 +886,9 @@ rule_to_xml (E2kRule *rule, xmlNode *ruleset)
 			return FALSE;
 		}
 	} else
-		xmlSetProp (top, "grouping", "all");
+		xmlSetProp (top, (xmlChar *) "grouping", (xmlChar *) "all");
 
-	set = xmlNewChild (top, NULL, "actionset", NULL);
+	set = xmlNewChild (top, NULL, (xmlChar *) "actionset", NULL);
 	for (i = 0; i < rule->actions->len; i++) {
 		if (!action_to_xml (rule->actions->pdata[i], set)) {
 			g_warning ("could not express action as xml");
@@ -753,7 +899,7 @@ rule_to_xml (E2kRule *rule, xmlNode *ruleset)
 	}
 
 	if (rule->state & E2K_RULE_STATE_EXIT_LEVEL)
-		xmlAddChild (set, new_part ("stop"));
+		xmlAddChild (set, new_part ((xmlChar *) "stop"));
 
 	return TRUE;
 }
@@ -772,13 +918,13 @@ e2k_rules_to_xml (E2kRules *rules)
 {
 	xmlDoc *doc;
 	xmlNode *top, *ruleset;
-	int i;
+	gint i;
 
 	doc = xmlNewDoc (NULL);
-	top = xmlNewNode (NULL, "filteroptions");
+	top = xmlNewNode (NULL, (xmlChar *) "filteroptions");
 	xmlDocSetRootElement (doc, top);
 
-	ruleset = xmlNewChild (top, NULL, "ruleset", NULL);
+	ruleset = xmlNewChild (top, NULL, (xmlChar *) "ruleset", NULL);
 
 	for (i = 0; i < rules->rules->len; i++)
 		rule_to_xml (rules->rules->pdata[i], ruleset);
