@@ -34,9 +34,9 @@ struct _ExchangeAccount {
 	 * account_filename is "username@hostname" run through
 	 * e_filename_make_safe.
 	 */
-	char *account_name, *account_filename, *storage_dir;
-	char *exchange_server, *home_uri, *public_uri;
-	char *legacy_exchange_dn, *default_timezone;
+	gchar *account_name, *account_filename, *storage_dir;
+	gchar *exchange_server, *home_uri, *public_uri;
+	gchar *legacy_exchange_dn, *default_timezone;
 
 	gboolean filter_inbox, filter_junk, filter_junk_inbox_only;
 	gdouble mbox_size;
@@ -80,43 +80,44 @@ ExchangeAccount       *exchange_account_new                  (EAccountList *acco
 E2kContext            *exchange_account_get_context          (ExchangeAccount  *acct);
 E2kGlobalCatalog      *exchange_account_get_global_catalog   (ExchangeAccount  *acct);
 
-EAccount 	      *exchange_account_fetch 		     (ExchangeAccount *acct);
+EAccount	      *exchange_account_fetch		     (ExchangeAccount *acct);
+gchar                  *exchange_account_get_account_uri_param (ExchangeAccount *acct, const gchar *param);
 
-const char            *exchange_account_get_standard_uri     (ExchangeAccount  *acct,
-							      const char       *item);
+const gchar            *exchange_account_get_standard_uri     (ExchangeAccount  *acct,
+							      const gchar       *item);
 
-char                  *exchange_account_get_standard_uri_for (ExchangeAccount  *acct,
-							      const char       *home_uri,
-							      const char       *std_uri_prop);
-char                  *exchange_account_get_foreign_uri      (ExchangeAccount  *acct,
+gchar                  *exchange_account_get_standard_uri_for (ExchangeAccount  *acct,
+							      const gchar       *home_uri,
+							      const gchar       *std_uri_prop);
+gchar                  *exchange_account_get_foreign_uri      (ExchangeAccount  *acct,
 							      E2kGlobalCatalogEntry *entry,
-							      const char       *std_uri_prop);
-ExchangeHierarchy     *exchange_account_get_hierarchy_by_email (ExchangeAccount *account, const char *email);
+							      const gchar       *std_uri_prop);
+ExchangeHierarchy     *exchange_account_get_hierarchy_by_email (ExchangeAccount *account, const gchar *email);
 
-char 		      *exchange_account_get_authtype 	     (ExchangeAccount *account);
+gchar		      *exchange_account_get_authtype	     (ExchangeAccount *account);
 
 E2kContext            *exchange_account_connect              (ExchangeAccount  *acct,
-							      const char *pword,
+							      const gchar *pword,
 							      ExchangeAccountResult *result);
 
 EFolder               *exchange_account_get_folder           (ExchangeAccount  *acct,
-							      const char       *path_or_uri);
+							      const gchar       *path_or_uri);
 GPtrArray             *exchange_account_get_folders          (ExchangeAccount  *acct);
 
-GPtrArray 	       *exchange_account_get_folder_tree      (ExchangeAccount *account, char* path);
+GPtrArray	       *exchange_account_get_folder_tree      (ExchangeAccount *account, gchar * path);
 
 ExchangeHierarchy     *exchange_account_get_hierarchy_by_type	      (ExchangeAccount *acct,
 							       ExchangeHierarchyType type);
 
 void                   exchange_account_rescan_tree          (ExchangeAccount  *acct);
 
-char 		      *exchange_account_get_password 	     (ExchangeAccount  *acct);
+gchar		      *exchange_account_get_password	     (ExchangeAccount  *acct);
 
-ExchangeAccountResult exchange_account_set_password 	     (ExchangeAccount  *acct,
-							      char             *old_password,
-							      char             *new_password);
+ExchangeAccountResult exchange_account_set_password	     (ExchangeAccount  *acct,
+							      gchar             *old_password,
+							      gchar             *new_password);
 
-void 		       exchange_account_forget_password       (ExchangeAccount  *acct);
+void		       exchange_account_forget_password       (ExchangeAccount  *acct);
 
 void		       exchange_account_set_save_password    (ExchangeAccount *account,
 							      gboolean save_password);
@@ -128,10 +129,10 @@ gboolean	       exchange_account_set_offline          (ExchangeAccount  *account
 gboolean	       exchange_account_set_online           (ExchangeAccount  *account);
 
 void		       exchange_account_is_offline           (ExchangeAccount  *account,
-							      int              *mode);
+							      gint              *mode);
 
 void		       exchange_account_is_offline_sync_set  (ExchangeAccount *account,
-							      int             *mode);
+							      gint             *mode);
 
 
 typedef enum {
@@ -148,26 +149,26 @@ typedef enum {
 } ExchangeAccountFolderResult;
 
 ExchangeAccountFolderResult exchange_account_create_folder (ExchangeAccount *account,
-							    const char      *path,
-							    const char      *type);
+							    const gchar      *path,
+							    const gchar      *type);
 ExchangeAccountFolderResult exchange_account_remove_folder (ExchangeAccount *account,
-							    const char      *path);
+							    const gchar      *path);
 ExchangeAccountFolderResult exchange_account_xfer_folder   (ExchangeAccount *account,
-							    const char      *source_path,
-							    const char      *dest_path,
+							    const gchar      *source_path,
+							    const gchar      *dest_path,
 							    gboolean         remove_source);
 ExchangeAccountFolderResult exchange_account_open_folder   (ExchangeAccount *account,
-							    const char      *path);
+							    const gchar      *path);
 
 ExchangeAccountFolderResult exchange_account_discover_shared_folder  (ExchangeAccount *account,
-								      const char      *user,
-								      const char      *folder_name,
+								      const gchar      *user,
+								      const gchar      *folder_name,
 								      EFolder        **folder);
 void       exchange_account_cancel_discover_shared_folder (ExchangeAccount *account,
-							      const char      *user,
-							      const char      *folder);
+							      const gchar      *user,
+							      const gchar      *folder);
 ExchangeAccountFolderResult exchange_account_remove_shared_folder    (ExchangeAccount *account,
-								      const char      *path);
+								      const gchar      *path);
 
 ExchangeAccountFolderResult exchange_account_add_favorite (ExchangeAccount *account,
 							   EFolder         *folder);
@@ -175,30 +176,30 @@ ExchangeAccountFolderResult exchange_account_remove_favorite (ExchangeAccount *a
 							      EFolder         *folder);
 
 gboolean exchange_account_is_favorite_folder              (ExchangeAccount *account,
-						           EFolder         *folder);
+							   EFolder         *folder);
 
-char * exchange_account_get_username 			  (ExchangeAccount *account);
+gchar * exchange_account_get_username			  (ExchangeAccount *account);
 
-char * exchange_account_get_windows_domain 		  (ExchangeAccount *account);
+gchar * exchange_account_get_windows_domain		  (ExchangeAccount *account);
 
-char * exchange_account_get_email_id 			  (ExchangeAccount *account);
+gchar * exchange_account_get_email_id			  (ExchangeAccount *account);
 
-int exchange_account_get_quota_limit			  (ExchangeAccount *account);
+gint exchange_account_get_quota_limit			  (ExchangeAccount *account);
 
-int exchange_account_check_password_expiry		  (ExchangeAccount *account);
+gint exchange_account_check_password_expiry		  (ExchangeAccount *account);
 
 /* Folder Size methods */
-void 			exchange_account_folder_size_add   (ExchangeAccount *account,
-	 					     	     const char *folder_name,
-						     	     gdouble size);
-void 			exchange_account_folder_size_remove (ExchangeAccount *account,
-						     	     const char *folder_name);
-void 			exchange_account_folder_size_rename (ExchangeAccount *account,
-						     	     const char *old_name,
-						     	     const char *new_name);
-GtkListStore 	       *exchange_account_folder_size_get_model (ExchangeAccount *account);
-void 		  	exchange_account_scan_foreign_hierarchy (ExchangeAccount *account,
-							      const char *user_email);
+void			exchange_account_folder_size_add   (ExchangeAccount *account,
+							     const gchar *folder_name,
+							     gdouble size);
+void			exchange_account_folder_size_remove (ExchangeAccount *account,
+							     const gchar *folder_name);
+void			exchange_account_folder_size_rename (ExchangeAccount *account,
+							     const gchar *old_name,
+							     const gchar *new_name);
+GtkListStore	       *exchange_account_folder_size_get_model (ExchangeAccount *account);
+void			exchange_account_scan_foreign_hierarchy (ExchangeAccount *account,
+							      const gchar *user_email);
 
 
 #ifdef __cplusplus
