@@ -99,7 +99,7 @@ send_and_handle_google_redirection (SoupSession *soup_session, SoupMessage *msg)
 
 	if (SOUP_STATUS_IS_REDIRECTION (msg->status_code)) {
 		SoupURI *new_uri;
-		const char *new_loc;
+		const gchar *new_loc;
 
 		new_loc = soup_message_headers_get (msg->response_headers, "Location");
 		g_return_if_fail (new_loc != NULL);
@@ -312,7 +312,7 @@ gdata_google_service_delete_entry (GDataService *service, GDataEntry *entry, GEr
 	entry_edit_url = gdata_entry_get_edit_link (entry);
 	priv = GDATA_GOOGLE_SERVICE_GET_PRIVATE (GDATA_GOOGLE_SERVICE (service));
 	auth = (GDataGoogleServiceAuth *) priv->auth;
-	soup_session = 	(SoupSession *)priv->soup_session;
+	soup_session =	(SoupSession *)priv->soup_session;
 
 	msg = soup_message_new (SOUP_METHOD_DELETE, entry_edit_url);
 	soup_message_headers_append (msg->request_headers,
@@ -323,7 +323,7 @@ gdata_google_service_delete_entry (GDataService *service, GDataEntry *entry, GEr
 	/* Handle redirects ourself */
 	send_and_handle_google_redirection (soup_session, msg);
 
-    	if (msg->status_code != 200) {
+	if (msg->status_code != 200) {
 		g_set_error (error, SOUP_HTTP_ERROR,
 					 msg->status_code, "%s", msg->reason_phrase);
 	} else {
@@ -347,7 +347,7 @@ gdata_google_service_delete_entry (GDataService *service, GDataEntry *entry, GEr
 static GDataEntry*
 gdata_google_service_update_entry (GDataService *service, GDataEntry *entry, GError **error)
 {
-	const char *entry_edit_url;
+	const gchar *entry_edit_url;
 
 	g_return_val_if_fail (service !=NULL, FALSE);
 	g_return_val_if_fail (GDATA_IS_GOOGLE_SERVICE (service), FALSE);
@@ -407,7 +407,7 @@ gdata_google_service_update_entry_with_link (GDataService *service, GDataEntry *
 	/* Handle redirects ourself */
 	send_and_handle_google_redirection (soup_session, msg);
 
-    	if (msg->status_code != 200) {
+	if (msg->status_code != 200) {
 		g_set_error (error, SOUP_HTTP_ERROR,
 					 msg->status_code, "%s", msg->reason_phrase);
 		g_object_unref (msg);
@@ -685,11 +685,11 @@ gdata_google_service_authenticate (GDataGoogleService *service, GError **error)
 	auth = (GDataGoogleServiceAuth *)priv->auth;
 
 	request_form = g_hash_table_new (g_str_hash, g_str_equal);
-	g_hash_table_insert (request_form, "Email", auth->username);
-	g_hash_table_insert (request_form, "Passwd", auth->password);
-	g_hash_table_insert (request_form, "service", priv->name);
-	g_hash_table_insert (request_form, "source", priv->agent);
-	g_hash_table_insert (request_form, "accountType", "HOSTED_OR_GOOGLE");
+	g_hash_table_insert (request_form, (gpointer) "Email", auth->username);
+	g_hash_table_insert (request_form, (gpointer) "Passwd", auth->password);
+	g_hash_table_insert (request_form, (gpointer) "service", priv->name);
+	g_hash_table_insert (request_form, (gpointer) "source", priv->agent);
+	g_hash_table_insert (request_form, (gpointer) "accountType", (gpointer) "HOSTED_OR_GOOGLE");
 	request_body = soup_form_encode_hash (request_form);
 	g_hash_table_destroy (request_form);
 
@@ -701,7 +701,7 @@ gdata_google_service_authenticate (GDataGoogleService *service, GError **error)
 
 	soup_session_send_message (priv->soup_session, msg);
 
-    	if (msg->status_code != 200) {
+	if (msg->status_code != 200) {
 		g_set_error (error, SOUP_HTTP_ERROR,
 					 msg->status_code, "%s", msg->reason_phrase);
 		g_object_unref(msg);
