@@ -4,7 +4,7 @@
  *  JP Rosevear <jpr@ximian.com>
  *  Rodrigo Moya <rodrigo@ximian.com>
  *
- * Copyright 2003, Novell, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -29,17 +29,17 @@
 #include "e-gw-message.h"
 
 struct _EGwContainerPrivate {
-	char *name;
-	char *id;
-	char *parent;
-	guint32 unread ;
-	guint32 total ;
-	int sequence;
-	char *owner;
+	gchar *name;
+	gchar *id;
+	gchar *parent;
+	guint32 unread;
+	guint32 total;
+	gint sequence;
+	gchar *owner;
 	GList *user_list;
-	char *modified;
-	EGwContainerType type ;
-	gboolean is_root ;
+	gchar *modified;
+	EGwContainerType type;
+	gboolean is_root;
 	gboolean is_writable;
 	gboolean is_frequent_contacts; /*indicates  whether this folder is frequent contacts or not */
 	gboolean is_shared_by_me;
@@ -49,9 +49,9 @@ struct _EGwContainerPrivate {
 
 static GObjectClass *parent_class = NULL;
 
-static void e_gw_container_set_sequence (EGwContainer *container, int sequence);
-static void e_gw_container_set_modified (EGwContainer *container, const char *modified);
-static void e_gw_container_set_owner(EGwContainer *container, const char *owner);
+static void e_gw_container_set_sequence (EGwContainer *container, gint sequence);
+static void e_gw_container_set_modified (EGwContainer *container, const gchar *modified);
+static void e_gw_container_set_owner(EGwContainer *container, const gchar *owner);
 static void e_gw_container_set_is_shared_by_me (EGwContainer *container, gboolean is_shared_by_me);
 static void e_gw_container_set_is_shared_to_me (EGwContainer *container, gboolean is_shared_to_me);
 
@@ -59,11 +59,10 @@ static void
 free_node(EShUsers *user)
 {
 	if(user){
-		g_free(user->email);
-		user->email = NULL;
+		g_free (user->email);
+		g_free (user);
 	}
-	g_free (user);
-	return ;
+	return;
 }
 
 static void
@@ -190,9 +189,9 @@ e_gw_container_new_from_soap_parameter (SoupSoapParameter *param)
 gboolean
 e_gw_container_set_from_soap_parameter (EGwContainer *container, SoupSoapParameter *param)
 {
-	char *value;
-	int int_value;
-	int rights = 0;
+	gchar *value;
+	gint int_value;
+	gint rights = 0;
 	gboolean byme = FALSE;
 	gboolean tome = FALSE;
 	SoupSoapParameter *subparam;
@@ -206,60 +205,61 @@ e_gw_container_set_from_soap_parameter (EGwContainer *container, SoupSoapParamet
 	/* retrieve the name */
 	subparam = soup_soap_parameter_get_first_child_by_name (param, "name");
 	if (!subparam) {
-		g_warning (G_STRLOC ": found container with no name");
-		return FALSE;
+			/* GroupWise 7.X servers does not return the name field.
+			This is not an issue with Bonsai 8.X . So, keep this code for
+			working well with the broken GW 7.X series */
+			e_gw_container_set_name (container, "");
+	} else {
+			value = soup_soap_parameter_get_string_value (subparam);
+			e_gw_container_set_name (container, (const gchar *) value);
+			g_free (value);
 	}
 
-	value = soup_soap_parameter_get_string_value (subparam);
-	e_gw_container_set_name (container, (const char *) value);
-	g_free (value);
-
 	/* retrieve the ID */
 	subparam = soup_soap_parameter_get_first_child_by_name (param, "id");
 	if (!subparam) {
-		g_warning (G_STRLOC ": found container with no ID");
-		return FALSE;
+			e_gw_container_set_id (container, "");
+	} else {
+			value = soup_soap_parameter_get_string_value (subparam);
+			e_gw_container_set_id (container, (const gchar *) value);
+			g_free (value);
 	}
 
-	value = soup_soap_parameter_get_string_value (subparam);
-	e_gw_container_set_id (container, (const char *) value);
-	g_free (value);
-
 	/* retrieve the parent container id */
 	subparam = soup_soap_parameter_get_first_child_by_name (param, "parent");
 	if (!subparam) {
 		e_gw_container_set_parent_id (container, "");
-		container->priv->is_root = TRUE ;
+		container->priv->is_root = TRUE;
 	} else {
 
 		value = soup_soap_parameter_get_string_value (subparam);
-		e_gw_container_set_parent_id (container, (const char *) value);
-		g_free (value) ;
+		e_gw_container_set_parent_id (container, (const gchar *) value);
+		g_free (value);
 	}
 
 	/*retrieve the folder type*/
-	subparam = soup_soap_parameter_get_first_child_by_name (param, "folderType") ;
+	subparam = soup_soap_parameter_get_first_child_by_name (param, "folderType");
 	if (!subparam)
-		container->priv->type = E_GW_CONTAINER_TYPE_FOLDER ;
+		container->priv->type = E_GW_CONTAINER_TYPE_FOLDER;
 	else {
 		value = soup_soap_parameter_get_string_value (subparam);
 		if (!strcmp (value, "Root"))
-			container->priv->type = E_GW_CONTAINER_TYPE_ROOT ;
+			container->priv->type = E_GW_CONTAINER_TYPE_ROOT;
 		else if (!strcmp (value, "Mailbox"))
-			container->priv->type = E_GW_CONTAINER_TYPE_INBOX ;
+			container->priv->type = E_GW_CONTAINER_TYPE_INBOX;
 		else if (!strcmp (value, "SentItems"))
 			container->priv->type = E_GW_CONTAINER_TYPE_SENT;
 		else if (!strcmp (value, "Calendar"))
-			container->priv->type = E_GW_CONTAINER_TYPE_CALENDAR ;
+			container->priv->type = E_GW_CONTAINER_TYPE_CALENDAR;
 		else if (!strcmp (value, "Contacts"))
-			container->priv->type = E_GW_CONTAINER_TYPE_CONTACTS ;
+			container->priv->type = E_GW_CONTAINER_TYPE_CONTACTS;
 		else if (!strcmp (value, "Draft"))
-			container->priv->type = E_GW_CONTAINER_TYPE_DRAFT ;
+			container->priv->type = E_GW_CONTAINER_TYPE_DRAFT;
 		else if (!strcmp (value, "Trash"))
-			container->priv->type = E_GW_CONTAINER_TYPE_TRASH ;
+			container->priv->type = E_GW_CONTAINER_TYPE_TRASH;
 		else if (!strcmp (value, "JunkMail"))
 			container->priv->type = E_GW_CONTAINER_TYPE_JUNK;
-		g_free (value) ;
+		g_free (value);
 	}
 
 	subparam = soup_soap_parameter_get_first_child_by_name (param, "isSystemFolder");
@@ -272,28 +272,28 @@ e_gw_container_set_from_soap_parameter (EGwContainer *container, SoupSoapParamet
 
 
 	/* retrive the unread and total count */
-	subparam = soup_soap_parameter_get_first_child_by_name (param, "hasUnread") ;
+	subparam = soup_soap_parameter_get_first_child_by_name (param, "hasUnread");
 	if (!subparam) {
-		container->priv->unread = 0 ;
+		container->priv->unread = 0;
 	} else {
-		subparam = soup_soap_parameter_get_first_child_by_name (param, "unreadCount") ;
+		subparam = soup_soap_parameter_get_first_child_by_name (param, "unreadCount");
 		if (subparam) {
-			value = soup_soap_parameter_get_string_value (subparam) ;
+			value = soup_soap_parameter_get_string_value (subparam);
 			if (value)
-				container->priv->unread = atoi(value) ;
+				container->priv->unread = atoi(value);
 			else
-				container->priv->unread = 0 ; /*XXX:should it be 0?*/
+				container->priv->unread = 0; /*XXX:should it be 0?*/
 
-			g_free (value) ;
+			g_free (value);
 		}
 	}
 
-	subparam = soup_soap_parameter_get_first_child_by_name (param, "count") ;
+	subparam = soup_soap_parameter_get_first_child_by_name (param, "count");
 	if (subparam) {
-		value = soup_soap_parameter_get_string_value (subparam) ;
+		value = soup_soap_parameter_get_string_value (subparam);
 		if (value)
-			container->priv->total = atoi(value) ;
-		g_free (value) ;
+			container->priv->total = atoi(value);
+		g_free (value);
 	}
 	/* Is shared by me*/
 	subparam = soup_soap_parameter_get_first_child_by_name (param, "isSharedByMe");
@@ -396,7 +396,7 @@ e_gw_container_set_from_soap_parameter (EGwContainer *container, SoupSoapParamet
 
 		if (subparam) {
 			value = soup_soap_parameter_get_string_value (subparam);
-			e_gw_container_set_modified (container, (const char *) value);
+			e_gw_container_set_modified (container, (const gchar *) value);
 			g_free (value);
 		}
 
@@ -420,31 +420,31 @@ e_gw_container_get_user_list (EGwContainer *container, GList **user_list)
 
 }
 
-int
+gint
 e_gw_container_get_sequence (EGwContainer *container)
 {
 	g_return_val_if_fail (E_IS_GW_CONTAINER (container), 0);
 
-	return (int)container->priv->sequence;
+	return (gint)container->priv->sequence;
 }
 
 static  void
-e_gw_container_set_sequence (EGwContainer *container, int sequence)
+e_gw_container_set_sequence (EGwContainer *container, gint sequence)
 {
 	g_return_if_fail (E_IS_GW_CONTAINER (container));
 	container->priv->sequence = sequence;
 }
 
-const char *
+const gchar *
 e_gw_container_get_modified (EGwContainer *container)
 {
 	g_return_val_if_fail (E_IS_GW_CONTAINER (container), NULL);
 
-	return (const char *) container->priv->modified;
+	return (const gchar *) container->priv->modified;
 }
 
 static void
-e_gw_container_set_modified (EGwContainer *container, const char *modified)
+e_gw_container_set_modified (EGwContainer *container, const gchar *modified)
 {
 	EGwContainerPrivate *priv;
 
@@ -459,7 +459,7 @@ e_gw_container_set_modified (EGwContainer *container, const char *modified)
 }
 
 static void
-e_gw_container_set_owner(EGwContainer *container, const char *owner)
+e_gw_container_set_owner(EGwContainer *container, const gchar *owner)
 {
 	EGwContainerPrivate *priv;
 
@@ -472,15 +472,15 @@ e_gw_container_set_owner(EGwContainer *container, const char *owner)
 	container->priv->owner = g_strdup (owner);
 }
 
-const char *
+const gchar *
 e_gw_container_get_owner (EGwContainer *container)
 {
 	g_return_val_if_fail (E_GW_CONTAINER (container), NULL);
 
-	return (const char *) container->priv->owner;
+	return (const gchar *) container->priv->owner;
 }
 
-int
+gint
 e_gw_container_get_rights (EGwContainer *container, gchar *email)
 {
 	GList *user_list = NULL;
@@ -548,16 +548,16 @@ e_gw_container_set_is_system_folder (EGwContainer *container, gboolean is_system
 	container->priv->is_system_folder = is_system_folder;
 }
 
-const char *
+const gchar *
 e_gw_container_get_name (EGwContainer *container)
 {
 	g_return_val_if_fail (E_IS_GW_CONTAINER (container), NULL);
 
-	return (const char *) container->priv->name;
+	return (const gchar *) container->priv->name;
 }
 
 void
-e_gw_container_set_name (EGwContainer *container, const char *new_name)
+e_gw_container_set_name (EGwContainer *container, const gchar *new_name)
 {
 	EGwContainerPrivate *priv;
 
@@ -571,16 +571,16 @@ e_gw_container_set_name (EGwContainer *container, const char *new_name)
 	priv->name = g_strdup (new_name);
 }
 
-const char *
+const gchar *
 e_gw_container_get_id (EGwContainer *container)
 {
 	g_return_val_if_fail (E_IS_GW_CONTAINER (container), NULL);
 
-	return (const char *) container->priv->id;
+	return (const gchar *) container->priv->id;
 }
 
 void
-e_gw_container_set_id (EGwContainer *container, const char *new_id)
+e_gw_container_set_id (EGwContainer *container, const gchar *new_id)
 {
 	EGwContainerPrivate *priv;
 
@@ -594,44 +594,44 @@ e_gw_container_set_id (EGwContainer *container, const char *new_id)
 	priv->id = g_strdup (new_id);
 }
 
-const char *
+const gchar *
 e_gw_container_get_parent_id (EGwContainer *container)
 {
 	g_return_val_if_fail (E_IS_GW_CONTAINER (container), NULL);
 
-	return (const char *) container->priv->parent;
+	return (const gchar *) container->priv->parent;
 }
 
 void
-e_gw_container_set_parent_id (EGwContainer *container, const char *parent_id)
+e_gw_container_set_parent_id (EGwContainer *container, const gchar *parent_id)
 {
-	EGwContainerPrivate *priv ;
+	EGwContainerPrivate *priv;
 
 	g_return_if_fail (E_IS_GW_CONTAINER (container));
 	g_return_if_fail (parent_id != NULL);
 
-	priv = container->priv ;
+	priv = container->priv;
 
 	if (priv->parent)
-		g_free (priv->parent) ;
+		g_free (priv->parent);
 
-	priv->parent = g_strdup (parent_id) ;
+	priv->parent = g_strdup (parent_id);
 }
 
 guint32
 e_gw_container_get_total_count (EGwContainer *container)
 {
-	g_return_val_if_fail (E_IS_GW_CONTAINER (container), -1) ;
+	g_return_val_if_fail (E_IS_GW_CONTAINER (container), -1);
 
-	return container->priv->total ;
+	return container->priv->total;
 }
 
 guint32
 e_gw_container_get_unread_count (EGwContainer *container)
 {
-	g_return_val_if_fail (E_IS_GW_CONTAINER (container), -1) ;
+	g_return_val_if_fail (E_IS_GW_CONTAINER (container), -1);
 
-	return container->priv->unread ;
+	return container->priv->unread;
 
 }
 
@@ -673,16 +673,16 @@ e_gw_container_set_is_frequent_contacts (EGwContainer *container, gboolean is_fr
 gboolean
 e_gw_container_is_root (EGwContainer *container)
 {
-	g_return_val_if_fail (E_IS_GW_CONTAINER (container), FALSE) ;
+	g_return_val_if_fail (E_IS_GW_CONTAINER (container), FALSE);
 
-	return container->priv->is_root ;
+	return container->priv->is_root;
 }
 
 EGwContainerType
 e_gw_container_get_container_type (EGwContainer *container)
 {
-	g_return_val_if_fail (E_IS_GW_CONTAINER (container), FALSE) ;
-	return container->priv->type ;
+	g_return_val_if_fail (E_IS_GW_CONTAINER (container), FALSE);
+	return container->priv->type;
 }
 
 /* flag specifies whether we are adding to acl or deleting one or more entries*/
@@ -691,7 +691,7 @@ e_gw_container_get_container_type (EGwContainer *container)
  * flag = 0 :add to acl
  */
 void
-e_gw_container_form_message (SoupSoapMessage *msg, gchar *id, GList *new_list, const char *sub, const char *mesg, int flag)
+e_gw_container_form_message (SoupSoapMessage *msg, gchar *id, GList *new_list, const gchar *sub, const gchar *mesg, gint flag)
 {
 	gboolean add, edit, del;
 	gchar *email = NULL;
@@ -736,7 +736,7 @@ e_gw_container_form_message (SoupSoapMessage *msg, gchar *id, GList *new_list, c
 		soup_soap_message_end_element (msg);
 		soup_soap_message_end_element (msg);
 
-	} else 	if (flag == 1) {
+	} else	if (flag == 1) {
 		soup_soap_message_start_element (msg, "delete", NULL, NULL);
 		soup_soap_message_start_element (msg, "acl", NULL, NULL);
 
