@@ -88,50 +88,50 @@ struct _EGwItemClass {
 
 /* structures defined to hold contact item fields */
 typedef struct {
-	char *name_prefix;
-	char *first_name;
-	char *middle_name;
-	char *last_name;
-	char *name_suffix;
+	gchar *name_prefix;
+	gchar *first_name;
+	gchar *middle_name;
+	gchar *last_name;
+	gchar *name_suffix;
 } FullName;
 
 typedef struct {
-	char *street_address;
-	char *location;
-	char *city;
-	char *state;
-	char *postal_code;
-	char *country;
+	gchar *street_address;
+	gchar *location;
+	gchar *city;
+	gchar *state;
+	gchar *postal_code;
+	gchar *country;
 } PostalAddress;
 
 typedef struct {
 
-	char *service;
-	char *address;
+	gchar *service;
+	gchar *address;
 }IMAddress;
 
 typedef struct {
-	char *id;
-	char *email;
-	char *name;
+	gchar *id;
+	gchar *email;
+	gchar *name;
 } EGroupMember;
 
 typedef struct {
-	char *email;
-	char *display_name;
+	gchar *email;
+	gchar *display_name;
 } EGwItemOrganizer;
 
 typedef struct {
-	char *id ;
-	char *name ;
-	char *item_reference;
-	char *contentid;
-	char *contentType ;
-	int size ;
-	char *date ;
-	char *data ;
+	gchar *id;
+	gchar *name;
+	gchar *item_reference;
+	gchar *contentid;
+	gchar *contentType;
+	gint size;
+	gchar *date;
+	gchar *data;
 	gboolean hidden;
-} EGwItemAttachment ;
+} EGwItemAttachment;
 
 typedef enum {
 	E_GW_ITEM_NOTIFY_NONE,
@@ -146,88 +146,88 @@ typedef enum {
 } EGwItemTrack;
 
 typedef struct {
-	char *id;
-	char *type;
-	char *thread;
+	gchar *id;
+	gchar *type;
+	gchar *thread;
 } EGwItemLinkInfo;
 
 typedef struct {
-	char *item_id;
-	char *ical_id;
-	char *recur_key;
+	gchar *item_id;
+	gchar *ical_id;
+	gchar *recur_key;
 } EGwItemCalId;
 
 GType       e_gw_item_get_type (void);
 EGwItem    *e_gw_item_new_empty (void);
-EGwItem    *e_gw_item_new_from_soap_parameter (const char *email, const char *container, SoupSoapParameter *param);
+EGwItem    *e_gw_item_new_from_soap_parameter (const gchar *email, const gchar *container, SoupSoapParameter *param);
 
 EGwItemType e_gw_item_get_item_type (EGwItem *item);
 void        e_gw_item_set_item_type (EGwItem *item, EGwItemType new_type);
-const char *e_gw_item_get_container_id (EGwItem *item);
-void        e_gw_item_set_container_id (EGwItem *item, const char *new_id);
-const char *e_gw_item_get_icalid (EGwItem *item);
-void        e_gw_item_set_icalid (EGwItem *item, const char *new_icalid);
-const char *e_gw_item_get_id (EGwItem *item);
-void        e_gw_item_set_id (EGwItem *item, const char *new_id);
-char       *e_gw_item_get_creation_date (EGwItem *item);
-void        e_gw_item_set_creation_date (EGwItem *item, const char *new_date);
-char       *e_gw_item_get_delivered_date (EGwItem *item);
-void        e_gw_item_set_delivered_date (EGwItem *item, const char *new_date);
-const char  *e_gw_item_get_modified_date (EGwItem *item);
-void        e_gw_item_set_modified_date (EGwItem *item, const char *new_date);
-char       *e_gw_item_get_start_date (EGwItem *item);
-void        e_gw_item_set_start_date (EGwItem *item, const char *new_date);
-char       *e_gw_item_get_completed_date (EGwItem *item);
-void        e_gw_item_set_completed_date (EGwItem *item, const char *new_date);
-char       *e_gw_item_get_end_date (EGwItem *item);
-void        e_gw_item_set_end_date (EGwItem *item, const char *new_date);
-char       *e_gw_item_get_due_date (EGwItem *item);
-void        e_gw_item_set_due_date (EGwItem *item, const char *new_date);
-const char *e_gw_item_get_subject (EGwItem *item);
-void        e_gw_item_set_subject (EGwItem *item, const char *new_subject);
-const char *e_gw_item_get_message (EGwItem *item);
-void        e_gw_item_set_message (EGwItem *item, const char *new_message);
-const char *e_gw_item_get_place (EGwItem *item);
-void        e_gw_item_set_place (EGwItem *item, const char *new_place);
-const char *e_gw_item_get_security (EGwItem *item);
-void        e_gw_item_set_security (EGwItem *item, const char *new_class);
+const gchar *e_gw_item_get_container_id (EGwItem *item);
+void        e_gw_item_set_container_id (EGwItem *item, const gchar *new_id);
+const gchar *e_gw_item_get_icalid (EGwItem *item);
+void        e_gw_item_set_icalid (EGwItem *item, const gchar *new_icalid);
+const gchar *e_gw_item_get_id (EGwItem *item);
+void        e_gw_item_set_id (EGwItem *item, const gchar *new_id);
+gchar       *e_gw_item_get_creation_date (EGwItem *item);
+void        e_gw_item_set_creation_date (EGwItem *item, const gchar *new_date);
+gchar       *e_gw_item_get_delivered_date (EGwItem *item);
+void        e_gw_item_set_delivered_date (EGwItem *item, const gchar *new_date);
+const gchar  *e_gw_item_get_modified_date (EGwItem *item);
+void        e_gw_item_set_modified_date (EGwItem *item, const gchar *new_date);
+gchar       *e_gw_item_get_start_date (EGwItem *item);
+void        e_gw_item_set_start_date (EGwItem *item, const gchar *new_date);
+gchar       *e_gw_item_get_completed_date (EGwItem *item);
+void        e_gw_item_set_completed_date (EGwItem *item, const gchar *new_date);
+gchar       *e_gw_item_get_end_date (EGwItem *item);
+void        e_gw_item_set_end_date (EGwItem *item, const gchar *new_date);
+gchar       *e_gw_item_get_due_date (EGwItem *item);
+void        e_gw_item_set_due_date (EGwItem *item, const gchar *new_date);
+const gchar *e_gw_item_get_subject (EGwItem *item);
+void        e_gw_item_set_subject (EGwItem *item, const gchar *new_subject);
+const gchar *e_gw_item_get_message (EGwItem *item);
+void        e_gw_item_set_message (EGwItem *item, const gchar *new_message);
+const gchar *e_gw_item_get_place (EGwItem *item);
+void        e_gw_item_set_place (EGwItem *item, const gchar *new_place);
+const gchar *e_gw_item_get_security (EGwItem *item);
+void        e_gw_item_set_security (EGwItem *item, const gchar *new_class);
 gboolean    e_gw_item_get_completed (EGwItem *item);
 void        e_gw_item_set_completed (EGwItem *item, gboolean new_completed);
 gboolean    e_gw_item_get_is_allday_event (EGwItem *item);
 void	    e_gw_item_set_is_allday_event (EGwItem *item, gboolean is_allday);
-char*       e_gw_item_get_field_value (EGwItem *item, char *field_name);
-void        e_gw_item_set_field_value (EGwItem *item, char *field_name, char* field_value);
+gchar *       e_gw_item_get_field_value (EGwItem *item, const gchar *field_name);
+void        e_gw_item_set_field_value (EGwItem *item, const gchar *field_name, gchar * field_value);
 GList*      e_gw_item_get_email_list (EGwItem *item);
 void        e_gw_item_set_email_list (EGwItem *item, GList *email_list);
 FullName*   e_gw_item_get_full_name (EGwItem *item);
 void        e_gw_item_set_full_name (EGwItem *item, FullName* full_name);
 GList*      e_gw_item_get_member_list (EGwItem *item);
 void        e_gw_item_set_member_list (EGwItem *item, GList *list);
-PostalAddress* e_gw_item_get_address (EGwItem *item, char *address_type);
-void        e_gw_item_set_address (EGwItem *item, char *addres_type, PostalAddress *address);
+PostalAddress* e_gw_item_get_address (EGwItem *item, const gchar *address_type);
+void        e_gw_item_set_address (EGwItem *item, const gchar *addres_type, PostalAddress *address);
 GList*      e_gw_item_get_im_list (EGwItem *item);
 void        e_gw_item_set_im_list (EGwItem *item, GList *im_list);
 void        e_gw_item_set_categories (EGwItem *item, GList *category_list);
 GList*      e_gw_item_get_categories (EGwItem *item);
-void 	    e_gw_item_set_to (EGwItem *item, const char *to) ;
-const char* e_gw_item_get_to (EGwItem *item) ;
-const char *e_gw_item_get_msg_content_type (EGwItem *item) ;
+void	    e_gw_item_set_to (EGwItem *item, const gchar *to);
+const gchar * e_gw_item_get_to (EGwItem *item);
+const gchar *e_gw_item_get_msg_content_type (EGwItem *item);
 guint32     e_gw_item_get_item_status (EGwItem *item);
-void	    e_gw_item_set_content_type (EGwItem *item, const char *content_type) ;
+void	    e_gw_item_set_content_type (EGwItem *item, const gchar *content_type);
 void	    e_gw_item_set_link_info (EGwItem *item, EGwItemLinkInfo *info);
 EGwItemLinkInfo *e_gw_item_get_link_info (EGwItem *item);
-char	    *e_gw_item_get_content_type (EGwItem *item) ;
-const char *e_gw_item_get_msg_body_id (EGwItem *item);
-int	    e_gw_item_get_mail_size (EGwItem *item);
-void e_gw_item_set_change (EGwItem *item, EGwItemChangeType change_type, char *field_name, gpointer field_value);
+gchar	    *e_gw_item_get_content_type (EGwItem *item);
+const gchar *e_gw_item_get_msg_body_id (EGwItem *item);
+gint	    e_gw_item_get_mail_size (EGwItem *item);
+void e_gw_item_set_change (EGwItem *item, EGwItemChangeType change_type, const gchar *field_name, gpointer field_value);
 gboolean e_gw_item_append_changes_to_soap_message (EGwItem *item, SoupSoapMessage *msg);
-void e_gw_item_set_category_name (EGwItem *item, char *cateogry_name);
-char* e_gw_item_get_category_name (EGwItem *item);
+void e_gw_item_set_category_name (EGwItem *item, gchar *cateogry_name);
+gchar * e_gw_item_get_category_name (EGwItem *item);
 void e_gw_item_set_sendoptions (EGwItem *item, gboolean set);
 void e_gw_item_set_reply_request (EGwItem *item, gboolean set);
 gboolean e_gw_item_get_reply_request (EGwItem *item);
-void e_gw_item_set_reply_within (EGwItem *item, char *reply_within);
-char *e_gw_item_get_reply_within (EGwItem *item);
+void e_gw_item_set_reply_within (EGwItem *item, gchar *reply_within);
+gchar *e_gw_item_get_reply_within (EGwItem *item);
 void e_gw_item_set_track_info (EGwItem *item, EGwItemTrack track_info);
 EGwItemTrack e_gw_item_get_track_info (EGwItem *item);
 void e_gw_item_set_autodelete (EGwItem *item, gboolean set);
@@ -242,10 +242,10 @@ void e_gw_item_set_notify_opened (EGwItem *item, EGwItemReturnNotify notify);
 EGwItemReturnNotify e_gw_item_get_notify_opened (EGwItem *item);
 void e_gw_item_set_notify_deleted (EGwItem *item, EGwItemReturnNotify notify);
 EGwItemReturnNotify e_gw_item_get_notify_deleted (EGwItem *item);
-void e_gw_item_set_expires (EGwItem *item, char *expires);
-char *e_gw_item_get_expires (EGwItem *item);
-void e_gw_item_set_delay_until (EGwItem *item, char *delay_until);
-char *e_gw_item_get_delay_until (EGwItem *item);
+void e_gw_item_set_expires (EGwItem *item, gchar *expires);
+gchar *e_gw_item_get_expires (EGwItem *item);
+void e_gw_item_set_delay_until (EGwItem *item, gchar *delay_until);
+gchar *e_gw_item_get_delay_until (EGwItem *item);
 void e_gw_item_free_cal_id (EGwItemCalId *calid);
 
 
@@ -253,25 +253,25 @@ void e_gw_item_free_cal_id (EGwItemCalId *calid);
 #define E_GW_ITEM_CLASSIFICATION_PRIVATE      "Private"
 #define E_GW_ITEM_CLASSIFICATION_CONFIDENTIAL "Confidential"
 
-const char *e_gw_item_get_classification (EGwItem *item);
-void        e_gw_item_set_classification (EGwItem *item, const char *new_class);
+const gchar *e_gw_item_get_classification (EGwItem *item);
+void        e_gw_item_set_classification (EGwItem *item, const gchar *new_class);
 
 #define E_GW_ITEM_ACCEPT_LEVEL_BUSY          "Busy"
 #define E_GW_ITEM_ACCEPT_LEVEL_OUT_OF_OFFICE "OutOfOffice"
 #define E_GW_ITEM_ACCEPT_LEVEL_FREE	     "Free"
 
-const char *e_gw_item_get_accept_level (EGwItem *item);
-void        e_gw_item_set_accept_level (EGwItem *item, const char *new_level);
+const gchar *e_gw_item_get_accept_level (EGwItem *item);
+void        e_gw_item_set_accept_level (EGwItem *item, const gchar *new_level);
 
 #define E_GW_ITEM_PRIORITY_HIGH     "High"
 #define E_GW_ITEM_PRIORITY_STANDARD "Standard"
 #define E_GW_ITEM_PRIORITY_LOW      "Low"
 
-const char *e_gw_item_get_priority (EGwItem *item);
-void        e_gw_item_set_priority (EGwItem *item, const char *new_priority);
+const gchar *e_gw_item_get_priority (EGwItem *item);
+void        e_gw_item_set_priority (EGwItem *item, const gchar *new_priority);
 
-const char *e_gw_item_get_task_priority (EGwItem *item);
-void        e_gw_item_set_task_priority (EGwItem *item, const char *new_priority);
+const gchar *e_gw_item_get_task_priority (EGwItem *item);
+void        e_gw_item_set_task_priority (EGwItem *item, const gchar *new_priority);
 
 GSList *e_gw_item_get_recipient_list (EGwItem *item);
 void e_gw_item_set_recipient_list (EGwItem *item, GSList *new_recipient_list);
@@ -279,8 +279,8 @@ void e_gw_item_set_recipient_list (EGwItem *item, GSList *new_recipient_list);
 EGwItemOrganizer *e_gw_item_get_organizer (EGwItem *item);
 void e_gw_item_set_organizer (EGwItem  *item, EGwItemOrganizer *organizer);
 
-GSList * e_gw_item_get_attach_id_list (EGwItem *item) ;
-void e_gw_item_set_attach_id_list (EGwItem *item, GSList *attach_list) ;
+GSList * e_gw_item_get_attach_id_list (EGwItem *item);
+void e_gw_item_set_attach_id_list (EGwItem *item, GSList *attach_list);
 
 
 GSList *e_gw_item_get_recurrence_dates (EGwItem *item);
@@ -292,32 +292,33 @@ void e_gw_item_set_exdate_list (EGwItem  *item, GSList *new_exdate_list);
 void e_gw_item_set_rrule (EGwItem *item, EGwItemRecurrenceRule *rrule);
 EGwItemRecurrenceRule *e_gw_item_get_rrule (EGwItem *item);
 
-int e_gw_item_get_recurrence_key (EGwItem *item);
-void e_gw_item_set_recurrence_key (EGwItem *item, int recurrence_key);
+gint e_gw_item_get_recurrence_key (EGwItem *item);
+void e_gw_item_set_recurrence_key (EGwItem *item, gint recurrence_key);
 
-GSList * e_gw_item_get_attach_id_list (EGwItem *item) ;
-void e_gw_item_set_attach_id_list (EGwItem *item, GSList *attach_list) ;
+void e_gw_item_set_source (EGwItem *item, const gchar *source);
 
-void e_gw_item_set_source (EGwItem *item, char *source) ;
-
-int e_gw_item_get_trigger (EGwItem *item);
-void e_gw_item_set_trigger (EGwItem *item, int trigger);
+gint e_gw_item_get_trigger (EGwItem *item);
+void e_gw_item_set_trigger (EGwItem *item, gint trigger);
 
 gboolean e_gw_item_has_attachment (EGwItem *item);
 
 gboolean e_gw_item_is_from_internet (EGwItem *item);
 
+const gchar *e_gw_item_get_parent_thread_ids (EGwItem *item);
+const gchar * e_gw_item_get_message_id (EGwItem *item);
+
+
 typedef struct {
-	char *email;
-	char *display_name;
+	gchar *email;
+	gchar *display_name;
 	gboolean status_enabled;
-	char *delivered_date;
-	char *opened_date;
-	char *accepted_date;
-	char *deleted_date;
-	char *declined_date;
-	char *completed_date;
-	char *undelivered_date;
+	gchar *delivered_date;
+	gchar *opened_date;
+	gchar *accepted_date;
+	gchar *deleted_date;
+	gchar *declined_date;
+	gchar *completed_date;
+	gchar *undelivered_date;
 	enum {
 		E_GW_ITEM_RECIPIENT_TO,
 		E_GW_ITEM_RECIPIENT_CC,
