@@ -4,7 +4,7 @@
  *  Shreyas Srinivasan <sshreyas@novell.com>
  *  Sankar P <psankar@novell.com>
  *
- * Copyright 2003, Novell, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -25,7 +25,7 @@
 #include <config.h>
 #endif
 
-#include <libsoup/soup-soap-message.h>
+#include "soup-soap-message.h"
 
 /*State of each proxy grant*/
 
@@ -49,9 +49,9 @@
 
 
 struct _proxyHandler {
-    char *uniqueid;
-    char *proxy_name;
-    char *proxy_email;
+    gchar *uniqueid;
+    gchar *proxy_name;
+    gchar *proxy_email;
     guint32 flags;
     guint32 permissions;
 };
@@ -63,5 +63,5 @@ void e_gw_proxy_construct_proxy_list (SoupSoapParameter *param, GList **proxy_in
 void e_gw_proxy_form_proxy_add_msg (SoupSoapMessage *msg, proxyHandler *new_proxy);
 void e_gw_proxy_form_proxy_remove_msg (SoupSoapMessage *msg, proxyHandler *removeProxy);
 void e_gw_proxy_form_modify_proxy_msg (SoupSoapMessage *msg, proxyHandler *new_proxy);
-void e_gw_proxy_parse_proxy_login_response (SoupSoapParameter *param, int *permissions);
+void e_gw_proxy_parse_proxy_login_response (SoupSoapParameter *param, gint *permissions);
 
